@@ -2,23 +2,15 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Arr_circle_segment_traits_2.h $
+// $Id: Arr_circle_segment_traits_2.h ccdb5a0 2023-02-15T14:36:44+02:00 Efi Fogel
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_circle_segment_traits_2.h $
-// $Id: Arr_circle_segment_traits_2.h b984dce 2018-05-11T08:32:11+01:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-//
-// Author(s)     : Ron Wein          <wein@post.tau.ac.il>
-//                 Baruch Zukerman   <baruchzu@post.tau.ac.il>
-//                 Waqar Khan <wkhan@mpi-inf.mpg.de>
+// Author(s): Ron Wein          <wein@post.tau.ac.il>
+//            Baruch Zukerman   <baruchzu@post.tau.ac.il>
+//            Waqar Khan        <wkhan@mpi-inf.mpg.de>
+//            Efi Fogel         <efifogel@gmail.com>
 
 #ifndef CGAL_ARR_CIRCLE_SEGMENT_TRAITS_2_H
 #define CGAL_ARR_CIRCLE_SEGMENT_TRAITS_2_H
@@ -28,16 +20,19 @@
 #include <CGAL/disable_warnings.h>
 
 /*! \file
- * The header file for the Arr_circle_segment_traits_2<Kenrel> class.
+ * The header file for the Arr_circle_segment_traits_2<Kernel> class.
  */
 
-#include <CGAL/atomic.h>
+// Keep the following 2 lines first.
+#include <cmath>
+#include <fstream>
+#include <atomic>
+
 #include <CGAL/tags.h>
 #include <CGAL/Arr_tags.h>
+#include <CGAL/Cartesian.h>
 #include <CGAL/Arr_geometry_traits/Circle_segment_2.h>
 
-#include <fstream>
-
 namespace CGAL {
 
 /*! \class
@@ -88,7 +83,7 @@ public:
 #ifdef CGAL_NO_ATOMIC
     static unsigned int index;
 #else
-    static CGAL::cpp11::atomic<unsigned int> index;
+    static std::atomic<unsigned int> index;
 #endif
     return (++index);
   }
@@ -320,24 +315,24 @@ public:
 
       if ((CGAL::compare (cv1.left().x(),cv1.right().x()) == EQUAL) &&
           (CGAL::compare (cv2.left().x(),cv2.right().x()) == EQUAL))
-	  { //both cv1 and cv2 are vertical
+          { //both cv1 and cv2 are vertical
          CGAL_precondition (!(cv1.left()).equals(p) && !(cv2.left()).equals(p));
-	  }
-	  else if ((CGAL::compare (cv1.left().x(),cv1.right().x()) != EQUAL) &&
+          }
+          else if ((CGAL::compare (cv1.left().x(),cv1.right().x()) != EQUAL) &&
                    (CGAL::compare (cv2.left().x(),cv2.right().x()) == EQUAL))
-	  { //only cv1 is vertical
+          { //only cv1 is vertical
          CGAL_precondition (!(cv1.left()).equals(p));
-	  }
-	  else if ((CGAL::compare (cv1.left().x(),cv1.right().x()) == EQUAL) &&
+          }
+          else if ((CGAL::compare (cv1.left().x(),cv1.right().x()) == EQUAL) &&
                    (CGAL::compare (cv2.left().x(),cv2.right().x()) != EQUAL))
-	  { //only cv2 is vertical
+          { //only cv2 is vertical
          CGAL_precondition (!(cv2.left()).equals(p));
-	  }
-	  else
-	  { //both cv1 and cv2 are non vertical
+          }
+          else
+          { //both cv1 and cv2 are non vertical
         CGAL_precondition (CGAL::compare (cv1.left().x(),p.x()) == SMALLER &&
                            CGAL::compare (cv2.left().x(),p.x()) == SMALLER);
-	  }
+          }
       // Compare the two curves immediately to the left of p:
       return (cv1.compare_to_left (cv2, p));
     }
@@ -386,59 +381,236 @@ public:
   }
   //@}
 
-  /// \name Functor definitions for supporting intersections.
+  /// \name Functor definitions for approximations. Used by the landmarks
+  // point-location strategy and the drawing procedure.
+  //@{
+  typedef double                                        Approximate_number_type;
+  typedef CGAL::Cartesian<Approximate_number_type>      Approximate_kernel;
+  typedef Approximate_kernel::Point_2                   Approximate_point_2;
+
+  class Approximate_2 {
+  protected:
+    using Traits = Arr_circle_segment_traits_2<Kernel, Filter>;
+
+    /*! The traits (in case it has state) */
+    const Traits& m_traits;
+
+    /*! Constructor
+     * \param traits the traits.
+     */
+    Approximate_2(const Traits& traits) : m_traits(traits) {}
+
+    friend class Arr_circle_segment_traits_2<Kernel, Filter>;
+
+  public:
+    /*! Obtain an approximation of a point coordinate.
+     * \param p the exact point.
+     * \param i the coordinate index (either 0 or 1).
+     * \pre i is either 0 or 1.
+     * \return An approximation of p's x-coordinate (if i == 0), or an
+     *         approximation of p's y-coordinate (if i == 1).
+     */
+    Approximate_number_type operator()(const Point_2& p, int i) const {
+      CGAL_precondition((i == 0) || (i == 1));
+      return (i == 0) ? (CGAL::to_double(p.x())) : (CGAL::to_double(p.y()));
+    }
+
+    /*! Obtain an approximation of a point.
+     */
+    Approximate_point_2 operator()(const Point_2& p) const
+    { return Approximate_point_2(operator()(p, 0), operator()(p, 1)); }
+
+    /*! Obtain an approximation of an \f$x\f$-monotone curve.
+     */
+    template <typename OutputIterator>
+    OutputIterator operator()(const X_monotone_curve_2& xcv, double error,
+                              OutputIterator oi, bool l2r = true) const {
+      if (xcv.is_linear()) return approximate_segment(xcv, oi, l2r);
+      return approximate_arc(xcv, error, oi, l2r);;
+    }
+
+  private:
+    /*! Handle segments.
+     */
+    template <typename OutputIterator>
+    OutputIterator approximate_segment(const X_monotone_curve_2& xcv,
+                                       OutputIterator oi,
+                                       bool l2r = true) const {
+      // std::cout << "SEGMENT\n";
+      auto min_vertex = m_traits.construct_min_vertex_2_object();
+      auto max_vertex = m_traits.construct_max_vertex_2_object();
+      const auto& src = (l2r) ? min_vertex(xcv) : max_vertex(xcv);
+      const auto& trg = (l2r) ? max_vertex(xcv) : min_vertex(xcv);
+      auto xs = CGAL::to_double(src.x());
+      auto ys = CGAL::to_double(src.y());
+      auto xt = CGAL::to_double(trg.x());
+      auto yt = CGAL::to_double(trg.y());
+      *oi++ = Approximate_point_2(xs, ys);
+      *oi++ = Approximate_point_2(xt, yt);
+      return oi;
+    }
+
+    template <typename OutputIterator, typename Op, typename Transform>
+    OutputIterator add_points(double x1, double y1, double t1,
+                              double x2, double y2, double t2,
+                              double error, OutputIterator oi,
+                              Op op, Transform transform) const {
+      auto tm = (t1 + t2)*0.5;
+
+      // Compute the canocal point where the error is maximal.
+      double xm, ym;
+      op(tm, xm, ym);
+
+      auto dx = x2 - x1;
+      auto dy = y2 - y1;
+
+      // Compute the error; abort if it is below the threshold
+      auto l = std::sqrt(dx*dx + dy*dy);
+      auto e = std::abs((xm*dy - ym*dx + x2*y1 - x1*y2) / l);
+      if (e < error) return oi;
+
+      double x, y;
+      transform(xm, ym, x, y);
+      add_points(x1, y1, t1, xm, ym, tm, error, oi, op, transform);
+      *oi++ = Approximate_point_2(x, y);
+      add_points(xm, ym, tm, x2, y2, t2, error, oi, op, transform);
+      return oi;
+    }
+
+    /*! Compute the circular point given the parameter t and the transform
+     * data, that is, the center (translation) and the sin and cos of the
+     * rotation angle.
+     */
+    void circular_point(double r, double t, double& x, double& y) const {
+      x = r * std::cos(t);
+      y = r * std::sin(t);
+    }
+
+    /*! Transform a point. In particular, rotate the canonical point
+     * (`xc`,`yc`) by an angle, the sine and cosine of which are `sint` and
+     * `cost`, respectively, and translate by (`cx`,`cy`).
+     */
+    void transform_point(double xc, double yc, double cx, double cy,
+                         double& x, double& y) const {
+      x = xc + cx;
+      y = yc + cy;
+    }
+
+    /*! Handle circular arcs.
+     */
+    template <typename OutputIterator>
+    OutputIterator approximate_arc(const X_monotone_curve_2& xcv,
+                                   double error, OutputIterator oi,
+                                   bool l2r = true) const {
+      auto min_vertex = m_traits.construct_min_vertex_2_object();
+      auto max_vertex = m_traits.construct_max_vertex_2_object();
+      const auto& src = (l2r) ? min_vertex(xcv) : max_vertex(xcv);
+      const auto& trg = (l2r) ? max_vertex(xcv) : min_vertex(xcv);
+      auto xs = CGAL::to_double(src.x());
+      auto ys = CGAL::to_double(src.y());
+      auto xt = CGAL::to_double(trg.x());
+      auto yt = CGAL::to_double(trg.y());
+
+      const typename Kernel::Circle_2& circ = xcv.supporting_circle();
+      auto r_sqr = circ.squared_radius();
+      auto r = std::sqrt(CGAL::to_double(r_sqr));
+
+      // Obtain the center:
+      auto cx = CGAL::to_double(circ.center().x());
+      auto cy = CGAL::to_double(circ.center().y());
+
+      // Inverse transform the source and target
+      auto xs_t = xs - cx;
+      auto ys_t = ys - cy;
+      auto xt_t = xt - cx;
+      auto yt_t = yt - cy;
+
+      // Compute the parameters ts and tt such that
+      // source == (x(ts),y(ts)), and
+      // target == (x(tt),y(tt))
+      auto ts = std::atan2(r*ys_t, r*xs_t);
+      if (ts < 0) ts += 2*CGAL_PI;
+      auto tt = std::atan2(r*yt_t, r*xt_t);
+      if (tt < 0) tt += 2*CGAL_PI;
+      auto orient(xcv.orientation());
+      if (xcv.source() != src) orient = CGAL::opposite(orient);
+      if (orient == COUNTERCLOCKWISE) {
+        if (tt < ts) tt += 2*CGAL_PI;
+      }
+      else {
+        if (ts < tt) ts += 2*CGAL_PI;
+      }
+
+      *oi++ = Approximate_point_2(xs, ys);
+      add_points(xs_t, ys_t, ts, xt_t, yt_t, tt, error, oi,
+                 [&](double tm, double& xm, double& ym) {
+                   circular_point(r, tm, xm, ym);
+                 },
+                 [&](double xc, double& yc, double& x, double& y) {
+                   transform_point(xc, yc, cx, cy, x, y);
+                 });
+      *oi++ = Approximate_point_2(xt, yt);
+      return oi;
+    }
+  };
+
+  /*! Obtain an Approximate_2 functor object. */
+  Approximate_2 approximate_2_object() const { return Approximate_2(*this); }
+  //@}
+
+  /// \name Intersections, subdivisions, and mergings
   //@{
 
-  class Make_x_monotone_2
-  {
+  /*! \class
+   * A functor for subdividing a curve into x-monotone curves.
+   */
+  class Make_x_monotone_2 {
   private:
     typedef Arr_circle_segment_traits_2<Kernel_, Filter> Self;
 
     bool m_use_cache;
 
   public:
+    Make_x_monotone_2(bool use_cache = false) : m_use_cache(use_cache) {}
 
-    Make_x_monotone_2(bool use_cache = false) : m_use_cache(use_cache)
-    {}
-
-    /*!
-     * Cut the given conic curve (ocv.is_in_x_range (p)r conic arc) into x-monotone subcurves
-     * and insert them to the given output iterator.
-     * \param cv The curve.
-     * \param oi The output iterator, whose value-type is Object. The returned
-     *           objects are all wrcv.is_in_x_range (p)appers X_monotone_curve_2 objects.
-     * \return The past-the-end iterator.
+    /*! Subdivide a given circular arc or line segment into x-monotone subcurves
+     * and insert them to a given output iterator.
+     * \param cv the curve.
+     * \param oi the output iterator for the result. Its dereference type is a
+     *           variant that wraps a \c Point_2 or an \c X_monotone_curve_2
+     *           objects.
+     * \return the past-the-end iterator.
      */
-    template<class OutputIterator>
-    OutputIterator operator() (const Curve_2& cv, OutputIterator oi) const
+    template <typename OutputIterator>
+    OutputIterator operator()(const Curve_2& cv, OutputIterator oi) const
     {
+      typedef boost::variant<Point_2, X_monotone_curve_2>
+        Make_x_monotone_result;
+
       // Increment the serial number of the curve cv, which will serve as its
       // unique identifier.
-      unsigned int  index = 0;
-      if(m_use_cache)
-        index = Self::get_index();
+      unsigned int index = 0;
+      if (m_use_cache) index = Self::get_index();
 
-      if (cv.orientation() == COLLINEAR)
-      {
+      if (cv.orientation() == COLLINEAR) {
         // The curve is a line segment.
-        *oi = make_object (X_monotone_curve_2 (cv.supporting_line(),
-                                               cv.source(), cv.target(),
-                                               index));
-        ++oi;
-        return (oi);
+        *oi++ = Make_x_monotone_result(X_monotone_curve_2(cv.supporting_line(),
+                                                          cv.source(),
+                                                          cv.target(),
+                                                          index));
+        return oi;
       }
 
-      // Check the case of a degenrate circle (a point).
+      // Check the case of a degenerate circle (a point).
       const typename Kernel::Circle_2&  circ = cv.supporting_circle();
       CGAL::Sign   sign_rad = CGAL::sign (circ.squared_radius());
       CGAL_precondition (sign_rad != NEGATIVE);
 
-      if (sign_rad == ZERO)
-      {
+      if (sign_rad == ZERO) {
         // Create an isolated point.
-        *oi = make_object (Point_2 (circ.center().x(), circ.center().y()));
-        ++oi;
-        return (oi);
+        *oi++ = Make_x_monotone_result(Point_2(circ.center().x(),
+                                               circ.center().y()));
+        return oi;
       }
 
       // The curve is circular: compute the to vertical tangency points
@@ -446,84 +618,73 @@ public:
       Point_2         vpts[2];
       unsigned int    n_vpts = cv.vertical_tangency_points (vpts);
 
-      if (cv.is_full())
-      {
+      if (cv.is_full()) {
         CGAL_assertion (n_vpts == 2);
 
         // Subdivide the circle into two arcs (an upper and a lower half).
-        *oi = make_object (X_monotone_curve_2 (circ,
-                                               vpts[0], vpts[1],
-                                               cv.orientation(),
-                                               index));
-        ++oi;
+        *oi++ = Make_x_monotone_result(X_monotone_curve_2(circ,
+                                                          vpts[0], vpts[1],
+                                                          cv.orientation(),
+                                                          index));
 
-        *oi = make_object (X_monotone_curve_2 (circ,
-                                               vpts[1], vpts[0],
-                                               cv.orientation(),
-                                               index));
-        ++oi;
+        *oi++ = Make_x_monotone_result(X_monotone_curve_2(circ,
+                                                          vpts[1], vpts[0],
+                                                          cv.orientation(),
+                                                          index));
       }
-      else
-      {
+      else {
         // Act according to the number of vertical tangency points.
-        if (n_vpts == 2)
-        {
+        if (n_vpts == 2) {
           // Subdivide the circular arc into three x-monotone arcs.
-          *oi = make_object (X_monotone_curve_2 (circ,
-                                                 cv.source(), vpts[0],
-                                                 cv.orientation(),
-                                                 index));
-          ++oi;
+          *oi++ = Make_x_monotone_result(X_monotone_curve_2(circ,
+                                                            cv.source(), vpts[0],
+                                                            cv.orientation(),
+                                                            index));
 
-          *oi = make_object (X_monotone_curve_2 (circ,
-                                                 vpts[0], vpts[1],
-                                                 cv.orientation(),
-                                                 index));
-          ++oi;
+          *oi++ = Make_x_monotone_result(X_monotone_curve_2(circ,
+                                                            vpts[0], vpts[1],
+                                                            cv.orientation(),
+                                                            index));
 
-          *oi = make_object (X_monotone_curve_2 (circ,
-                                                 vpts[1], cv.target(),
-                                                 cv.orientation(),
-                                                 index));
-          ++oi;
+          *oi++ = Make_x_monotone_result(X_monotone_curve_2(circ,
+                                                            vpts[1],
+                                                            cv.target(),
+                                                            cv.orientation(),
+                                                            index));
         }
-        else if (n_vpts == 1)
-        {
+        else if (n_vpts == 1) {
           // Subdivide the circular arc into two x-monotone arcs.
-          *oi = make_object (X_monotone_curve_2 (circ,
-                                                 cv.source(), vpts[0],
-                                                 cv.orientation(),
-                                                 index));
-          ++oi;
+          *oi++ = Make_x_monotone_result(X_monotone_curve_2(circ,
+                                                            cv.source(),
+                                                            vpts[0],
+                                                            cv.orientation(),
+                                                            index));
 
-          *oi = make_object (X_monotone_curve_2 (circ,
-                                                 vpts[0], cv.target(),
-                                                 cv.orientation(),
-                                                 index));
-          ++oi;
+          *oi++ = Make_x_monotone_result(X_monotone_curve_2(circ,
+                                                            vpts[0],
+                                                            cv.target(),
+                                                            cv.orientation(),
+                                                            index));
         }
-        else
-        {
-          CGAL_assertion (n_vpts == 0);
+        else {
+          CGAL_assertion(n_vpts == 0);
 
           // The arc is already x-monotone:
-          *oi = make_object (X_monotone_curve_2 (circ,
-                                                 cv.source(), cv.target(),
-                                                 cv.orientation(),
-                                                 index));
-          ++oi;
+          *oi++ = Make_x_monotone_result(X_monotone_curve_2(circ,
+                                                            cv.source(),
+                                                            cv.target(),
+                                                            cv.orientation(),
+                                                            index));
         }
       }
 
-      return (oi);
+      return oi;
     }
   };
 
   /*! Get a Make_x_monotone_2 functor object. */
-  Make_x_monotone_2 make_x_monotone_2_object () const
-  {
-    return Make_x_monotone_2(m_use_cache);
-  }
+  Make_x_monotone_2 make_x_monotone_2_object() const
+  { return Make_x_monotone_2(m_use_cache); }
 
   class Split_2
   {
@@ -555,21 +716,15 @@ public:
     return Split_2();
   }
 
-  class Intersect_2
-  {
+  class Intersect_2 {
   private:
-
-    Intersection_map&  _inter_map;       // The map of intersection points.
+    Intersection_map& _inter_map;       // The map of intersection points.
 
   public:
-
     /*! Constructor. */
-    Intersect_2 (Intersection_map& map) :
-      _inter_map (map)
-    {}
+    Intersect_2(Intersection_map& map) : _inter_map(map) {}
 
-    /*!
-     * Find the intersections of the two given curves and insert them to the
+    /*! Find the intersections of the two given curves and insert them to the
      * given output iterator. As two segments may itersect only once, only a
      * single will be contained in the iterator.
      * \param cv1 The first curve.
@@ -577,20 +732,15 @@ public:
      * \param oi The output iterator.
      * \return The past-the-end iterator.
      */
-    template<class OutputIterator>
-    OutputIterator operator() (const X_monotone_curve_2& cv1,
-                               const X_monotone_curve_2& cv2,
-                               OutputIterator oi) const
-    {
-      return (cv1.intersect (cv2, oi, &_inter_map));
-    }
+    template <typename OutputIterator>
+    OutputIterator operator()(const X_monotone_curve_2& cv1,
+                              const X_monotone_curve_2& cv2,
+                              OutputIterator oi) const
+    { return (cv1.intersect(cv2, oi, &_inter_map)); }
   };
 
   /*! Get an Intersect_2 functor object. */
-  Intersect_2 intersect_2_object () const
-  {
-    return (Intersect_2 (inter_map));
-  }
+  Intersect_2 intersect_2_object() const { return (Intersect_2(inter_map)); }
 
   class Are_mergeable_2
   {
@@ -715,14 +865,11 @@ public:
     friend class Arr_circle_segment_traits_2<Kernel, Filter>;
 
   public:
-    /*!\brief
-     * Returns a trimmed version of an arc
-     *
+    /*! Obtain a trimmed version of an arc
      * \param xcv The arc
      * \param src the new first endpoint
      * \param tgt the new second endpoint
      * \return The trimmed arc
-     *
      * \pre src != tgt
      * \pre both points must be interior and must lie on \c cv
      */
@@ -735,7 +882,7 @@ public:
                              m_traits.compare_y_at_x_2_object());
       CGAL_precondition_code(Equal_2 equal_2 = m_traits.equal_2_object());
       Compare_x_2 compare_x_2 = m_traits.compare_x_2_object();
-      // Check whether source and taget are two distinct points and they lie
+      // Check whether source and target are two distinct points and they lie
       // on the line.
       CGAL_precondition(compare_y_at_x_2(src, xcv) == EQUAL);
       CGAL_precondition(compare_y_at_x_2(tgt, xcv) == EQUAL);
@@ -751,6 +898,9 @@ public:
 
   /*! Obtain a Trim_2 functor object. */
   Trim_2 trim_2_object() const { return Trim_2(*this); }
+
+  // @}
+
 };
 
 } //namespace CGAL
