@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_rat_arc/Rational_function_canonicalized_pair.h $
-// $Id: Rational_function_canonicalized_pair.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Arr_rat_arc/Rational_function_canonicalized_pair.h $
+// $Id: Rational_function_canonicalized_pair.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Oren Salzman <orenzalz@post.tau.ac.il >
 //                 Michael Hemmer <Michael.Hemmer@sophia.inria.fr>
@@ -52,25 +43,25 @@ public:
   typedef typename Base::Solve_1                        Solve_1;
   typedef typename Base::Bound                          Bound;
   typedef typename Base::Coefficient                    Coefficient;
- 
+
 public:
-  Rational_function_canonicalized_pair_rep(const Rational_function& f, 
+  Rational_function_canonicalized_pair_rep(const Rational_function& f,
                                            const Rational_function& g,
                                            Algebraic_kernel_d_1* ak_ptr)
     :_f(f),_g(g),_ak_ptr(ak_ptr)
   {
-    CGAL_precondition(_ak_ptr != NULL);
+    CGAL_precondition(_ak_ptr != nullptr);
     //canonicalized representation
-    if ( !(f.id() < g.id()) ) 
+    if ( !(f.id() < g.id()) )
       std::swap(_f,_g);
     _resultant  = (_f.numer() * _g.denom() - _f.denom() * _g.numer());
 
     //f and g are not the same...
     CGAL_precondition(CGAL::is_zero(_resultant) == false);
-                
-    Solve_1 solve_1(_ak_ptr->solve_1_object());   
+
+    Solve_1 solve_1(_ak_ptr->solve_1_object());
     Root_multiplicity_vector rm_vec;
-    
+
 #if 1
     solve_1(_resultant,std::back_inserter(rm_vec));
 #else
@@ -90,9 +81,9 @@ public:
 
     _roots.reserve(rm_vec.size());
     _multiplicities.reserve(rm_vec.size());
-  
+
     for (typename Root_multiplicity_vector::iterator it = rm_vec.begin();
-         it != rm_vec.end() ; 
+         it != rm_vec.end() ;
          ++it)
     {
       _roots.push_back(it->first);
@@ -109,7 +100,7 @@ public:
     std::merge(tmp.begin(), tmp.end(),
                _roots.begin(), _roots.end(),
                std::back_inserter(_event_roots));
-  
+
     //remove duplicate entries
     typename Algebraic_vector::iterator new_end,old_end;
     new_end = std::unique(_event_roots.begin(), old_end=_event_roots.end());
@@ -137,16 +128,16 @@ public:
       _g.pole_multiplicities().begin();
     typename Algebraic_vector ::const_iterator it_r_root = _roots.begin();
     typename Multiplicity_vector::const_iterator it_r_mult =
-      _multiplicities.begin() ; 
-    while ( (it_f_pole != _f.poles().end()) || 
-        (it_g_pole != _g.poles().end()) || 
+      _multiplicities.begin() ;
+    while ( (it_f_pole != _f.poles().end()) ||
+        (it_g_pole != _g.poles().end()) ||
         (it_r_root != _roots.end()))
     {
       //std::cout << "_f._poles.size() " << _f._poles.size() <<std::endl;
       //std::cout << "_g._poles.size() " << _g._poles.size()<< std::endl;
       //std::cout << "_roots.size()    " << _roots.size() << std::endl;
       //if current event is only a pole of f
-      if ((it_f_pole != _f.poles().end())         && 
+      if ((it_f_pole != _f.poles().end())         &&
           ((it_g_pole == _g.poles().end()) || (*it_f_pole < *it_g_pole)) &&
           ((it_r_root == _roots.end()) || (*it_f_pole < *it_r_root)))
       {
@@ -157,7 +148,7 @@ public:
         ++it_f_mult;
       }
       //if current event is only a pole of g
-      else if ((it_g_pole != _g.poles().end())         && 
+      else if ((it_g_pole != _g.poles().end())         &&
                ((it_f_pole == _f.poles().end()) || (*it_g_pole < *it_f_pole)) &&
                ((it_r_root == _roots.end()) || (*it_g_pole < *it_r_root)))
       {
@@ -168,7 +159,7 @@ public:
         ++it_g_mult;
       }
       //if current event is only a pole of r
-      else if ((it_r_root != _roots.end())         && 
+      else if ((it_r_root != _roots.end())         &&
                ((it_f_pole == _f.poles().end()) || (*it_r_root < *it_f_pole)) &&
                ((it_g_pole == _g.poles().end()) || (*it_r_root < *it_g_pole)))
       {
@@ -179,10 +170,10 @@ public:
         ++it_r_mult;
       }
       //if current event is a pole of f g and r
-      else if ( (it_f_pole != _f.poles().end()) && 
-                (it_g_pole != _g.poles().end()) && 
+      else if ( (it_f_pole != _f.poles().end()) &&
+                (it_g_pole != _g.poles().end()) &&
                 (it_r_root != _roots.end()) &&
-                (*it_r_root == *it_f_pole)    && 
+                (*it_r_root == *it_f_pole)    &&
                 (*it_r_root == *it_g_pole))
       {
         //both functions switch signs
@@ -215,19 +206,19 @@ public:
     CGAL_postcondition_code(std::vector<bool> tmp_is_above =
                             compute_is_above_explicitly();
                             );
-    CGAL_postcondition(_is_above == tmp_is_above);   
+    CGAL_postcondition(_is_above == tmp_is_above);
   }
 
   Comparison_result compare_f_g_at(const Algebraic_real_1& x,
                                    CGAL::Sign epsilon = CGAL::ZERO) const
   {
-    //f and g must be different 
+    //f and g must be different
     CGAL_precondition(!CGAL::is_zero(_resultant));
 
-    //find interval 
+    //find interval
     typename Algebraic_vector::const_iterator iter =
       std::lower_bound(_event_roots.begin(), _event_roots.end(),x);
-  
+
     //case of a value larger than largest root
     if (iter == _event_roots.end())
       return (_is_above.back() ? CGAL:: LARGER : CGAL::SMALLER);
@@ -235,12 +226,12 @@ public:
     typename Algebraic_vector::iterator::difference_type dist =
       iter - _event_roots.begin();
 
-    //if x is not a root, ignore epsilons 
+    //if x is not a root, ignore epsilons
     if (*iter != x){
       return (_is_above[dist] ? CGAL:: LARGER : CGAL::SMALLER);
     }
 
-    //x is a root 
+    //x is a root
     if (epsilon == CGAL::ZERO){
       CGAL_precondition(_f.poles().end() ==
                         std::find(_f.poles().begin(), _f.poles().end(),x));
@@ -248,7 +239,7 @@ public:
                         std::find(_g.poles().begin(), _g.poles().end(),x));
       return (CGAL::EQUAL);
     }
-    
+
     if (epsilon == CGAL::NEGATIVE)
       return (_is_above[dist] ? CGAL:: LARGER : CGAL::SMALLER);
     else // CGAL::POSITIVE
@@ -258,7 +249,7 @@ public:
   {
     CGAL_precondition((boundary == ARR_LEFT_BOUNDARY) ||
         (boundary == ARR_RIGHT_BOUNDARY) );
-  
+
     //f and g are the same...
     if (CGAL::is_zero(_resultant))
       return CGAL::EQUAL;
@@ -279,32 +270,32 @@ public:
 
     //get left index
     typename Algebraic_vector::const_iterator left_index =
-      (left_parameter_space == ARR_LEFT_BOUNDARY) ? 
+      (left_parameter_space == ARR_LEFT_BOUNDARY) ?
       _event_roots.begin():
       std::lower_bound(_event_roots.begin(), _event_roots.end(),left);
     //check if intersect at left index
-    if (*left_index == left) 
+    if (*left_index == left)
       return true;
 
     //get right index
     typename Algebraic_vector::const_iterator right_index =
-      (right_parameter_space == ARR_RIGHT_BOUNDARY) ? 
+      (right_parameter_space == ARR_RIGHT_BOUNDARY) ?
       _event_roots.begin():
       std::lower_bound(_event_roots.begin(), _event_roots.end(),right);
     //check if intersect at right index
-    if (*right_index == right) 
+    if (*right_index == right)
       return true;
-  
+
     //check if indices are the same
     return (left_index == right_index);
   }
 
-  const Rational_function& f() const 
+  const Rational_function& f() const
   {
     return _f;
   }
 
-  const Rational_function& g() const 
+  const Rational_function& g() const
   {
     return _g;
   }
@@ -324,7 +315,7 @@ private:
   {
     bool r = _get_is_above_near_minus_infinity();
     CGAL_postcondition(r == __get_is_above_near_minus_infinity());
-    return r; 
+    return r;
   }
 
   bool _get_is_above_near_minus_infinity()
@@ -346,8 +337,8 @@ private:
           (sign == CGAL::POSITIVE) ? false   :
           (_f.sign_near_minus_infinity() == CGAL::POSITIVE);  // _g == zero;
       }
-            
-    //both have the same degree difference, 
+
+    //both have the same degree difference,
     //check who's leading coeeficient ratio is larger
     Coefficient lead_coeff_ratio =
       CGAL::abs(CGAL::leading_coefficient(_f.numer())) *
@@ -383,11 +374,11 @@ private:
     //
     //  numer_f * denom _g - numer_f * denom _g
     //f-g= -------------------------------------- at b
-    //    denom _f  * denom _g 
+    //    denom _f  * denom _g
 
     //TODO: unnescecary construction of real
     Algebraic_real_1 x(_ak_ptr->construct_algebraic_real_1_object()(b));
-  
+
     CGAL::Sign   numer = _ak_ptr->sign_at_1_object()(_resultant, x);
     CGAL::Sign   denom_f = _ak_ptr->sign_at_1_object()(_f.denom(),x);
     CGAL::Sign   denom_g = _ak_ptr->sign_at_1_object()(_g.denom(),x);
@@ -404,22 +395,22 @@ private:
     if (_event_roots.size()== 0)
     {
       Bound b = 1; //all bound are legal, choose 1 for simplicity
-      tmp_is_above.push_back(is_above_at(b));  
+      tmp_is_above.push_back(is_above_at(b));
       return tmp_is_above;
     }
-  
-    tmp_is_above.reserve(_event_roots.size()+1);  
+
+    tmp_is_above.reserve(_event_roots.size()+1);
     //left boundary
     Bound b  = (_ak_ptr->approximate_relative_1_object()
       (_event_roots.front(),0)).first - 1;  //lower bound of first root
-    tmp_is_above.push_back(is_above_at(b));  
-  
+    tmp_is_above.push_back(is_above_at(b));
+
     //mid intervals
     typename Algebraic_vector::size_type i;
     for (i = 0; i < _event_roots.size()-1; ++i)
     {
       b = _ak_ptr->bound_between_1_object()(_event_roots[i],_event_roots[i+1]);
-      tmp_is_above.push_back(is_above_at(b));      
+      tmp_is_above.push_back(is_above_at(b));
     }
 
     //right boundary
@@ -427,8 +418,8 @@ private:
     tmp_is_above.push_back(is_above_at(b));
     return tmp_is_above;
   }
-   
-private:   
+
+private:
   Rational_function _f,_g;
   Polynomial_1  _resultant;
   Algebraic_vector _roots;
@@ -459,7 +450,7 @@ public:
   typedef typename Rep::Multiplicity_vector           Multiplicity_vector;
   typedef typename Rep::Root_multiplicity_vector      Root_multiplicity_vector;
 
-  Rational_function_canonicalized_pair(const Rational_function& f, 
+  Rational_function_canonicalized_pair(const Rational_function& f,
                                        const Rational_function& g,
                                        Algebraic_kernel_d_1* ak_ptr) :
     Base(f, g, ak_ptr) {}
@@ -486,13 +477,13 @@ public:
     return this->ptr()->is_intersecting_in_range(left_parameter_space, left,
                                                  right_parameter_space, right);
   }
-    
-  const Rational_function& f() const 
+
+  const Rational_function& f() const
   {
     return this->ptr()->f();
   }
-    
-  const Rational_function& g() const 
+
+  const Rational_function& g() const
   {
     return this->ptr()->g();
   }
@@ -509,6 +500,6 @@ public:
 };  //Rational_function_canonicalized_pair
 
 }   //namespace Arr_rational_arc
-}   //namespace CGAL {   
+}   //namespace CGAL {
 
 #endif //CGAL_RATIONAL_FUNCTION_CANONICALIZED_PAIR_H
