@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_rational_function_traits_2.h $
-// $Id: Arr_rational_function_traits_2.h 18acb2e 2018-01-18T15:05:34+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Arr_rational_function_traits_2.h $
+// $Id: Arr_rational_function_traits_2.h 6b64dc8 2020-11-11T09:38:55+02:00 Efi Fogel
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Oren Salzman <orenzalz@post.tau.ac.il >
 //                 Michael Hemmer <Michael.Hemmer@sophia.inria.fr>
@@ -43,20 +34,20 @@ namespace CGAL {
  * A traits class for maintaining an arrangement of bounded arcs (segments) of
  * rational functions of arbitrary degree.
  *
- * The class is templated with two parameters: 
+ * The class is templated with two parameters:
  * Alg_kernel A geometric kernel, where Alg_kernel::FT is the number type
  *            for the coordinates of arrangement vertices, which are algebraic
  *            numbers (defined by Nt_traits::Algebraic).
  * Nt_traits A traits class for performing various operations on the integer,
- *           rational and algebraic types. 
+ *           rational and algebraic types.
  */
- 
+
 template <typename AlgebraicKernel_d_1>
 class Arr_rational_function_traits_2
 {
 public:
   typedef AlgebraicKernel_d_1                           Algebraic_kernel_d_1;
- 
+
   typedef Arr_rational_function_traits_2<Algebraic_kernel_d_1>
                                                         Self;
   typedef Arr_rational_arc::Base_rational_arc_ds_1<Algebraic_kernel_d_1>
@@ -77,18 +68,18 @@ public:
   typedef typename Base_curve_2::Rat_vector                   Rat_vector;
 
   typedef typename Base_rational_arc_ds_1::Integer            Integer;
-  typedef typename Base_rational_arc_ds_1::Rational           Rational; 
-  typedef typename Base_rational_arc_ds_1::Polynomial_1       Polynomial_1; 
-  typedef typename Base_rational_arc_ds_1::Coefficient        Coefficient; 
+  typedef typename Base_rational_arc_ds_1::Rational           Rational;
+  typedef typename Base_rational_arc_ds_1::Polynomial_1       Polynomial_1;
+  typedef typename Base_rational_arc_ds_1::Coefficient        Coefficient;
 
-  typedef typename Base_rational_arc_ds_1::FT_rat_1           FT_rat_1; 
+  typedef typename Base_rational_arc_ds_1::FT_rat_1           FT_rat_1;
   typedef typename Base_rational_arc_ds_1::Polynomial_traits_1
     Polynomial_traits_1;
-  
-  typedef typename Algebraic_kernel_d_1::Bound                Bound; 
+
+  typedef typename Algebraic_kernel_d_1::Bound                Bound;
   typedef Bound
-    Approximate_number_type; 
-  
+    Approximate_number_type;
+
   typedef CGAL::Arr_rational_arc::Rational_function<Algebraic_kernel_d_1>
                                                               Rational_function;
   typedef CGAL::Arr_rational_arc::Cache<Algebraic_kernel_d_1> Cache;
@@ -116,7 +107,7 @@ public:
   bool delete_ak_internal_flag() const
   {
     return delete_ak;
-  } 
+  }
   // Algebraic_kernel_d_1& algebraic_kernel_d_1()             {return _ak;}
 
 public:
@@ -148,7 +139,7 @@ public:
     if (delete_ak)
       _ak_ptr = new Algebraic_kernel_d_1(*other.algebraic_kernel_d_1());
     else
-      _ak_ptr = other.algebraic_kernel_d_1();    
+      _ak_ptr = other.algebraic_kernel_d_1();
 
     //copy cache
     _cache.initialize(other.cache(), _ak_ptr);
@@ -176,9 +167,9 @@ public:
     Construct_x_monotone_curve_2(const Traits* traits) : _traits(traits) {}
 
     friend class Arr_rational_function_traits_2<Algebraic_kernel_d_1>;
-    
+
   public:
-    typedef typename Base_rational_arc_ds_1::Polynomial_1 Polynomial_1; 
+    typedef typename Base_rational_arc_ds_1::Polynomial_1 Polynomial_1;
     typedef typename Base_rational_arc_ds_1::Algebraic_real_1
                                                           Algebraic_real_1;
     typedef Arr_rational_arc::Continuous_rational_arc_d_1<Algebraic_kernel_d_1>
@@ -187,7 +178,7 @@ public:
     typedef Polynomial_1                                  first_argument_type;
     typedef Polynomial_1                                  second_argument_type;
     typedef X_monotone_curve_2                            result_type;
-    
+
     X_monotone_curve_2 operator()( const Polynomial_1& P) const
     {
       return X_monotone_curve_2(P, _traits->cache());
@@ -233,7 +224,7 @@ public:
     }
 
     X_monotone_curve_2 operator()(const Polynomial_1& P,
-                                  const Polynomial_1& Q) const 
+                                  const Polynomial_1& Q) const
     {
       return X_monotone_curve_2(P, Q, _traits->cache());
     }
@@ -242,7 +233,7 @@ public:
     X_monotone_curve_2 operator()(InputIterator begin_numer,
                                   InputIterator end_numer,
                                   InputIterator begin_denom,
-                                  InputIterator end_denom) const 
+                                  InputIterator end_denom) const
     {
       Rat_vector rat_vec_numer(begin_numer,end_numer);
       Rat_vector rat_vec_denom(begin_denom,end_denom);
@@ -314,9 +305,9 @@ public:
     Construct_curve_2(const Traits* traits) : _traits(traits) {}
 
     friend class Arr_rational_function_traits_2<Algebraic_kernel_d_1>;
-    
+
   public:
-    typedef typename Base_rational_arc_ds_1::Polynomial_1 Polynomial_1; 
+    typedef typename Base_rational_arc_ds_1::Polynomial_1 Polynomial_1;
     typedef typename Base_rational_arc_ds_1::Algebraic_real_1
                                                           Algebraic_real_1;
     typedef Arr_rational_arc::Rational_arc_d_1<Algebraic_kernel_d_1>
@@ -325,7 +316,7 @@ public:
     typedef Polynomial_1                                  first_argument_type;
     typedef Polynomial_1                                  second_argument_type;
     typedef Curve_2                                       result_type;
-    
+
     Curve_2 operator()(const Polynomial_1& P) const
     {
       return Curve_2(P, _traits->cache());
@@ -368,14 +359,14 @@ public:
       return Curve_2(rat_vec, x_s, x_t, _traits->cache());
     }
 
-    Curve_2 operator()(const Polynomial_1& P, const Polynomial_1& Q) const 
+    Curve_2 operator()(const Polynomial_1& P, const Polynomial_1& Q) const
     {
       return Curve_2(P, Q, _traits->cache());
     }
 
     template <typename InputIterator>
     Curve_2 operator()(InputIterator begin_numer, InputIterator end_numer,
-                       InputIterator begin_denom, InputIterator end_denom) const 
+                       InputIterator begin_denom, InputIterator end_denom) const
     {
       Rat_vector rat_vec_numer(begin_numer, end_numer);
       Rat_vector rat_vec_denom(begin_denom, end_denom);
@@ -439,26 +430,26 @@ public:
     Construct_point_2(const Traits* traits) : _traits(traits) {}
 
     friend class Arr_rational_function_traits_2<Algebraic_kernel_d_1>;
-    
+
   public:
     Point_2 operator()(const Rational_function& rational_function,
                        const Algebraic_real_1& x_coordinate)
-    { 
+    {
       return Point_2(rational_function, x_coordinate);
     }
 
     Point_2 operator()(const Rational& x, const Rational& y)
-    { 
+    {
       Integer  y_numer,y_denom;
       typename FT_rat_1::Decompose()(y,y_numer,y_denom);
-      
+
       return Point_2(_traits->cache().get_rational_function(Rational(y_numer,
                                                                      y_denom)),
                      _traits->algebraic_kernel_d_1()->
                        construct_algebraic_real_1_object()(x));
     }
     Point_2 operator()(const Algebraic_real_1& x, const Rational& y)
-    {   
+    {
       Integer  y_numer;
       Integer  y_denom;
       typename FT_rat_1::Decompose()(y, y_numer, y_denom);
@@ -482,17 +473,17 @@ public:
 //     Construct_vertical_segment(Cache& cache) : _cache(cache) {}
 
 //     Vertical_segment operator()(const Point_2& p) const
-//     { 
+//     {
 //       return Vertical_segment(p);
 //     }
 
 //     Vertical_segment operator()(const Point_2& p, bool is_directed_up) const
-//     { 
+//     {
 //       return Vertical_segment(p, is_directed_up);
 //     }
 
 //     Vertical_segment operator()(const Point_2& p1,const Point_2& p2) const
-//     {       
+//     {
 //       return Vertical_segment(p1, p2, _cache);
 //     }
 //   }; //Construct_vertical_segment
@@ -507,7 +498,7 @@ public:
   //------------------------
 
   //---------------------------------------------------------------
-  //A functor that compares the x-coordinates of two points 
+  //A functor that compares the x-coordinates of two points
   class Compare_x_2
   {
   public:
@@ -558,7 +549,7 @@ public:
      *         SMALLER if x(p1) < x(p2), or if x(p1) = x(p2) and y(p1) < y(p2);
      *         EQUAL if the two points are equal.
      */
-    Comparison_result operator()(const Point_2& p1, const Point_2& p2) const 
+    Comparison_result operator()(const Point_2& p1, const Point_2& p2) const
     {
       return p1.compare_xy_2(p2, _traits->cache());
     }
@@ -750,7 +741,7 @@ public:
                          cv2.right_parameter_space_in_y() != ARR_INTERIOR ||
                          (p.x() < cv2.right().x())));
 
- 
+
       // Compare the two arcs.
       return cv1.compare_at_intersection (cv2,p,false,_cache);
     }
@@ -777,7 +768,7 @@ public:
     Equal_2(const Traits* traits) : _traits(traits) {}
 
     friend class Arr_rational_function_traits_2<Algebraic_kernel_d_1>;
-    
+
   public:
     /*!
      * Check if the two x-monotone curves are the same (have the same graph).
@@ -817,45 +808,41 @@ public:
     return Equal_2(this);
   }
 
-  /*! A functor that divides a curve into continues (x-monotone) curves. */
-  class Make_x_monotone_2
-  {
+  //! \name Intersections & subdivisions
+  //@{
+
+  /*! \class Make_x_monotone_2
+   * A functor for subdividing a curve into continues x-monotone curves.
+   */
+  class Make_x_monotone_2 {
   public:
-
-    /*!
-     * Cut the given conic curve (or conic arc) into x-monotone subcurves 
-     * and insert them to the given output iterator.
-     * \param cv The curve.
-     * \param oi The output iterator, whose value-type is Object. The returned
-     *           objects is a wrapper for an X_monotone_curve_2 object.
-     * \return The past-the-end iterator.
+    /*! Subdivide a given rational-function curve into x-monotone subcurves
+     * and insert them to a given output iterator.
+     * \param cv the curve.
+     * \param oi the output iterator for the result. Its dereference type is a
+     *           variant that wraps a \c Point_2 or an \c X_monotone_curve_2
+     *           objects.
+     * \return the past-the-end iterator.
      */
-    template<typename OutputIterator>
-    OutputIterator operator()(const Curve_2& cv, OutputIterator oi) const 
+    template <typename OutputIterator>
+    OutputIterator operator()(const Curve_2& cv, OutputIterator oi) const
     {
-      // Make the rational arc continuous.
-      std::list<X_monotone_curve_2>                           arcs;
+      typedef boost::variant<Point_2, X_monotone_curve_2>
+        Make_x_monotone_result;
 
+      // Make the rational arc continuous.
+      std::list<X_monotone_curve_2> arcs;
       cv.make_continuous(std::back_inserter(arcs));
 
       // Create objects.
-      typename std::list<X_monotone_curve_2>::const_iterator  iter;
-
-      for (iter = arcs.begin(); iter != arcs.end(); ++iter)
-      {
-        *oi = make_object (*iter);
-        ++oi;
-      }
-
-      return (oi);
+      for (const auto& arc : arcs) *oi++ = Make_x_monotone_result(arc);
+      return oi;
     }
   };
 
   /*! Obtain a Make_x_monotone_2 functor object. */
   Make_x_monotone_2 make_x_monotone_2_object() const
-  {
-    return Make_x_monotone_2();
-  }
+  { return Make_x_monotone_2(); }
 
   /*! A functor that splits a curve at a point. */
   class Split_2
@@ -951,7 +938,7 @@ public:
 
     /*! The traits (in case it has state) */
     const Traits* m_traits;
-    
+
     /*! Constructor
      * \param traits the traits (in case it has state)
      */
@@ -1026,7 +1013,7 @@ public:
   /*! Obtain a Parameter_space_in_x_2 function object */
   Parameter_space_in_x_2 parameter_space_in_x_2_object() const
   { return Parameter_space_in_x_2(); }
-  
+
   /*! A function object that obtains the parameter space of a geometric
    * entity along the y-axis
    */
@@ -1070,6 +1057,7 @@ public:
   Parameter_space_in_y_2 parameter_space_in_y_2_object() const
   { return Parameter_space_in_y_2(); }
 
+#if 0
   /*! A function object that compares the x-coordinates of arc ends near the
    * boundary of the parameter space
    */
@@ -1085,7 +1073,7 @@ public:
      * \return the comparison result:
      *         SMALLER - x(p) < x(xc, ce);
      *         EQUAL   - x(p) = x(xc, ce);
-     *         LARGER  - x(p) > x(xc, ce).     
+     *         LARGER  - x(p) > x(xc, ce).
      * \pre p lies in the interior of the parameter space.
      * \pre the ce end of the line xcv lies on a boundary.
      */
@@ -1094,9 +1082,9 @@ public:
                                  Arr_curve_end ce) const
     {
       Comparison_result r = xcv.compare_end(ce, p);
-      if (r == EQUAL) 
-        return EQUAL; 
-      return (r == NEGATIVE) ? POSITIVE : NEGATIVE ; 
+      if (r == EQUAL)
+        return EQUAL;
+      return (r == NEGATIVE) ? POSITIVE : NEGATIVE ;
     }
 
     /*! Compare the x-coordinates of 2 arcs ends near the boundary of the
@@ -1128,12 +1116,12 @@ public:
   /*! Obtain a Compare_x_near_boundary_2 function object */
   Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
   { return Compare_x_near_boundary_2(); }
-    
+#endif
 
   /*! A function object that compares the y-coordinates of arc ends near the
    * boundary of the parameter space.
    */
-  class Compare_y_near_boundary_2 
+  class Compare_y_near_boundary_2
   {
   private:
     Cache& _cache;
@@ -1163,19 +1151,19 @@ public:
   Compare_y_near_boundary_2 compare_y_near_boundary_2_object() const
   { return Compare_y_near_boundary_2(_cache); }
 
- 
+
   /*! A function object that compares at limit
    */
   //new functor
-  class Compare_x_at_limit_2
+  class Compare_x_on_boundary_2
   {
    public:
     /*! Compares the x coordinate of p with the curve end
-     * of xcv that is defined by ce at its limit. 
+     * of xcv that is defined by ce at its limit.
      * Returns SMALLER, EQUAL, or LARGER accordingly.
      */
     Comparison_result operator()(const Point_2& p,
-                                 const X_monotone_curve_2&  xcv, 
+                                 const X_monotone_curve_2&  xcv,
                                  Arr_curve_end ce)
     {
       CGAL_precondition(Parameter_space_in_x_2()(xcv,ce) == ARR_INTERIOR);
@@ -1183,14 +1171,14 @@ public:
       return CGAL::compare(p.x(),
                            (ce == ARR_MIN_END) ? xcv.left_x() : xcv.right_x());
     }
-    /*! Compares the curve end of  xcv1 that is defined by ce1 
+    /*! Compares the curve end of  xcv1 that is defined by ce1
      *  with the curve end of xcv2 that is defined by ce2
-     * at their limits in x. 
+     * at their limits in x.
      * Returns SMALLER, EQUAL, or LARGER accordingly.
      */
-    Comparison_result operator()(const X_monotone_curve_2&  xcv1, 
+    Comparison_result operator()(const X_monotone_curve_2&  xcv1,
                                  Arr_curve_end ce1,
-                                 const X_monotone_curve_2&  xcv2, 
+                                 const X_monotone_curve_2&  xcv2,
                                  Arr_curve_end ce2)
     {
       CGAL_precondition(Parameter_space_in_x_2()(xcv1,ce1) == ARR_INTERIOR);
@@ -1202,40 +1190,40 @@ public:
                            (ce2 == ARR_MIN_END) ? xcv2.left_x() : xcv2.right_x());
     }
 
-  }; //Compare_x_at_limit_2
+  }; //Compare_x_on_boundary_2
 
-  /*! Obtain a Compare_x_at_limit_2 function object */
-  Compare_x_at_limit_2 compare_x_at_limit_2_object() const
-  { return Compare_x_at_limit_2(); }
+  /*! Obtain a Compare_x_on_boundary_2 function object */
+  Compare_x_on_boundary_2 compare_x_on_boundary_2_object() const
+  { return Compare_x_on_boundary_2(); }
   //@}
-  
+
   /// \name Functor definitions for the Boolean set-operation traits.
   //@{
- 
+
   //new functor
-  class Compare_x_near_limit_2
+  class Compare_x_near_boundary_2
   {
   private:
     Cache& _cache;
 
   public:
-    Compare_x_near_limit_2(Cache& cache) : _cache(cache) {}
-    /*! Compares the curve end of  xcv1 that is defined by ce1 
+    Compare_x_near_boundary_2(Cache& cache) : _cache(cache) {}
+    /*! Compares the curve end of  xcv1 that is defined by ce1
      *  with the curve end of xcv2 that is defined by ce2
-     * at their limits in x. 
+     * at their limits in x.
      * Returns SMALLER, EQUAL, or LARGER accordingly.
      */
-    Comparison_result operator()( const X_monotone_curve_2& xcv1, 
-                                  const X_monotone_curve_2& xcv2, 
+    Comparison_result operator()( const X_monotone_curve_2& xcv1,
+                                  const X_monotone_curve_2& xcv2,
                                   Arr_curve_end ce) const
     {
       return xcv1.compare_near_end(xcv2,ce,_cache);
     }
-  }; //Compare_x_near_limit_2
+  }; //Compare_x_near_boundary_2
 
-  /*! Obtain a Compare_x_near_limit_2 function object */
-  Compare_x_near_limit_2 compare_x_near_limit_2_object() const
-  { return Compare_x_near_limit_2(_cache); }
+  /*! Obtain a Compare_x_near_boundary_2 function object */
+  Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
+  { return Compare_x_near_boundary_2(_cache); }
 
   class Compare_endpoints_xy_2
   {
@@ -1289,23 +1277,23 @@ public:
   class Approximate_2{
     Approximate_number_type approx_x(const Point_2& p){
       return Approximate_number_type(p.x().lower());
-    } 
+    }
     Approximate_number_type approx_y(const Point_2& p){
       typedef typename Algebraic_kernel_d_1::Polynomial_1 Polynomial_1;
-      typename CGAL::Coercion_traits<Polynomial_1,Bound>::Cast cast;  
+      typename CGAL::Coercion_traits<Polynomial_1,Bound>::Cast cast;
       return
         cast(p.rational_function().numer()).evaluate(p.x().lower())/
         cast(p.rational_function().denom()).evaluate(p.x().lower());
     }
   public:
     Approximate_number_type operator()(const Point_2& p, int i){
-      if(i==0) return approx_x(p); 
+      if(i==0) return approx_x(p);
       if(i==1) return approx_y(p);
       CGAL_assertion(false);
       return Approximate_number_type(0);
     }
   };
-  
+
   Approximate_2 approximate_2_object() const { return Approximate_2(); }
 
   void cleanup_cache() const
