@@ -2,23 +2,14 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_unb_planar_topology_traits_2_impl.h $
-// $Id: Arr_unb_planar_topology_traits_2_impl.h 7936109 2017-11-16T16:31:52+02:00 Efi Fogel
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_unb_planar_topology_traits_2_impl.h $
+// $Id: Arr_unb_planar_topology_traits_2_impl.h 3674c93 2022-11-15T15:21:01+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
-// Author(s)     : Ron Wein  <wein@post.tau.ac.il>
-//                 Efi Fogel <efif@post.tau.ac.il>
+// Author(s): Ron Wein  <wein@post.tau.ac.il>
+//            Efi Fogel <efif@post.tau.ac.il>
 
 #ifndef CGAL_ARR_UNB_PLANAR_TOPOLOGY_TRAITS_2_IMPL_H
 #define CGAL_ARR_UNB_PLANAR_TOPOLOGY_TRAITS_2_IMPL_H
@@ -40,12 +31,12 @@ template <typename GeomTraits, typename Dcel_>
 Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::
 Arr_unb_planar_topology_traits_2():
   Base(),
-  v_bl(NULL),
-  v_tl(NULL),
-  v_br(NULL),
-  v_tr(NULL),
+  v_bl(nullptr),
+  v_tl(nullptr),
+  v_br(nullptr),
+  v_tr(nullptr),
   n_inf_verts(0),
-  fict_face(NULL)
+  fict_face(nullptr)
 {}
 
 //-----------------------------------------------------------------------------
@@ -55,12 +46,12 @@ template <typename GeomTraits, typename Dcel_>
 Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::
 Arr_unb_planar_topology_traits_2 (const Geometry_traits_2 * geom_traits) :
   Base (geom_traits),
-  v_bl (NULL),
-  v_tl (NULL),
-  v_br (NULL),
-  v_tr (NULL),
+  v_bl (nullptr),
+  v_tl (nullptr),
+  v_br (nullptr),
+  v_tr (nullptr),
   n_inf_verts (0),
-  fict_face (NULL)
+  fict_face (nullptr)
 {}
 
 //-----------------------------------------------------------------------------
@@ -89,7 +80,7 @@ void Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::dcel_updated ()
   typename Dcel::Vertex_iterator       vit;
   Halfedge                            *first_he, *next_he;
 
-  v_bl = v_tl = v_br = v_tr = NULL;
+  v_bl = v_tl = v_br = v_tr = nullptr;
   n_inf_verts = 0;
   for (vit = this->m_dcel.vertices_begin();
        vit != this->m_dcel.vertices_end(); ++vit)
@@ -123,23 +114,23 @@ void Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::dcel_updated ()
         CGAL_error();
     }
   }
-  CGAL_assertion(v_bl != NULL && v_tl != NULL && v_br != NULL && v_tr != NULL);
+  CGAL_assertion(v_bl != nullptr && v_tl != nullptr && v_br != nullptr && v_tr != nullptr);
 
   // Go over the DCEL faces and locate the fictitious face.
   typename Dcel::Face_iterator         fit;
 
-  fict_face = NULL;
+  fict_face = nullptr;
   for (fit = this->m_dcel.faces_begin();
        fit != this->m_dcel.faces_end(); ++fit)
   {
     if (fit->is_fictitious())
     {
-      CGAL_assertion (fict_face == NULL);
+      CGAL_assertion (fict_face == nullptr);
 
       fict_face = &(*fit);
     }
   }
-  CGAL_assertion (fict_face != NULL);
+  CGAL_assertion (fict_face != nullptr);
 
   return;
 }
@@ -200,10 +191,10 @@ void Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::init_dcel ()
   Inner_ccb          *ic = this->m_dcel.new_inner_ccb();
   Face               *in_f = this->m_dcel.new_face();
 
-  he1->set_curve (NULL);
-  he2->set_curve (NULL);
-  he3->set_curve (NULL);
-  he4->set_curve (NULL);
+  he1->set_curve (nullptr);
+  he2->set_curve (nullptr);
+  he3->set_curve (nullptr);
+  he4->set_curve (nullptr);
 
   he1->set_next (he2);        he1_t->set_next (he4_t);
   he2->set_next (he3);        he4_t->set_next (he3_t);
@@ -272,7 +263,7 @@ are_equal(const Vertex *v,
     Arr_curve_end                  v_ind;
     const X_monotone_curve_2  *v_cv = _curve (v, v_ind);
 
-    if (v_cv == NULL)
+    if (v_cv == nullptr)
       return (v->parameter_space_in_x() == ps_x &&
               v->parameter_space_in_y() == ps_y);
 
@@ -287,7 +278,7 @@ are_equal(const Vertex *v,
     Arr_curve_end                  v_ind;
     const X_monotone_curve_2  *v_cv = _curve (v, v_ind);
 
-    if (v_cv == NULL)
+    if (v_cv == nullptr)
       return (v->parameter_space_in_x() == ARR_INTERIOR &&
               v->parameter_space_in_y() == ps_y);
 
@@ -305,90 +296,93 @@ are_equal(const Vertex *v,
 // represent the curve end along the face boundary.
 //
 template <typename GeomTraits, typename Dcel_>
-CGAL::Object
+boost::optional
+  <boost::variant
+    <typename Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::Vertex*,
+     typename Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::Halfedge*> >
 Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::
-place_boundary_vertex(Face *f,
+place_boundary_vertex(Face* f,
                       const X_monotone_curve_2& cv, Arr_curve_end ind,
                       Arr_parameter_space ps_x, Arr_parameter_space ps_y)
 {
-  // Get a halfedge on the outer CCB of f and start traversing the CCB.
-  Halfedge           *first = *(f->outer_ccbs_begin());
-  Halfedge           *curr = first;
-  bool                eq_source, eq_target;
+  typedef boost::variant<Vertex*, Halfedge*>    Non_optional_result;
+  typedef boost::optional<Non_optional_result>  Result;
 
-  do
-  {
+  // Get a halfedge on the outer CCB of f and start traversing the CCB.
+  Halfedge* first = *(f->outer_ccbs_begin());
+  Halfedge* curr = first;
+  bool eq_source, eq_target;
+
+  do {
     // Note we consider only fictitious halfedges and check whether they
     // contain the relevant curve end.
     if (curr->has_null_curve() &&
-        _is_on_fictitious_edge (cv, ind, ps_x, ps_y, curr,
-                                eq_source, eq_target))
+        _is_on_fictitious_edge(cv, ind, ps_x, ps_y, curr, eq_source, eq_target))
     {
-      CGAL_assertion (! eq_source && ! eq_target);
-      return (CGAL::make_object (curr));
+      CGAL_assertion(! eq_source && ! eq_target);
+      return Result(curr);
     }
 
-    // Move to the next halfegde along the CCB.
+    // Move to the next halfedge along the CCB.
     curr = curr->next();
 
   } while (curr != first);
 
-  // If we reached here, we did not find a suitable halfegde, which should
+  // If we reached here, we did not find a suitable halfedge, which should
   // never happen.
   CGAL_error();
-  return CGAL::Object();
+  return boost::none;
 }
 
 //-----------------------------------------------------------------------------
 // Locate a DCEL feature that contains the given unbounded curve end.
 //
 template <typename GeomTraits, typename Dcel_>
-CGAL::Object Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::
+boost::variant
+<typename Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::Vertex*,
+ typename Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::Halfedge*,
+ typename Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::Face*>
+Arr_unb_planar_topology_traits_2<GeomTraits, Dcel_>::
 locate_curve_end (const X_monotone_curve_2& cv, Arr_curve_end ind,
                   Arr_parameter_space ps_x, Arr_parameter_space ps_y)
 {
+  typedef boost::variant<Vertex*, Halfedge*, Face*>     Result;
+
   // Start traversing the inner CCB of the fictitious face and try to locate
   // a feature that contains the curve end.
-  Halfedge   *first = *(fict_face->inner_ccbs_begin());
-  Halfedge   *curr = first;
-  bool        eq_source, eq_target;
+  Halfedge* first = *(fict_face->inner_ccbs_begin());
+  Halfedge* curr = first;
+  bool eq_source, eq_target;
 
-  do
-  {
-    if (_is_on_fictitious_edge (cv, ind, ps_x, ps_y, curr,
-                                eq_source, eq_target))
+  do {
+    if (_is_on_fictitious_edge(cv, ind, ps_x, ps_y, curr, eq_source, eq_target))
     {
-      if (eq_source)
-      {
+      if (eq_source) {
         // cv's end coincides with the source vertex of the current
         // fictitious halfedge. This means that cv overlaps the curve that
         // is associated with the only non-fictitious halfedge incident to
         // this vertex. We therefore return a pointer to this halfedge.
-        Halfedge     *he = curr->opposite()->next();
-
-        CGAL_assertion (! he->has_null_curve());
-        return (CGAL::make_object (he));
+        Halfedge* he = curr->opposite()->next();
+        CGAL_assertion(! he->has_null_curve());
+        return Result(he);
       }
-      else if (eq_target)
-      {
+      else if (eq_target) {
         // cv's end coincides with the target vertex of the current
         // fictitious halfedge. This means that cv overlaps the curve that
         // is associated with the only non-fictitious halfedge incident to
         // this vertex. We therefore return a pointer to this halfedge.
-        Halfedge     *he = curr->opposite()->prev();
-
-        CGAL_assertion (! he->has_null_curve());
-        return (CGAL::make_object (he));
+        Halfedge* he = curr->opposite()->prev();
+        CGAL_assertion(! he->has_null_curve());
+        return Result(he);
       }
 
       // The current ficitious edge contains cv's end in its interior.
       // Note we use curr's twin, whose incident face is a valid
       // unbounded face (whereas the incident face of curr is the fictitious
       // face).
-      Face      *uf = curr->opposite()->outer_ccb()->face();
-
+      Face* uf = curr->opposite()->outer_ccb()->face();
       CGAL_assertion (uf->is_unbounded() && ! uf->is_fictitious());
-      return (CGAL::make_object (uf));
+      return Result(uf);
     }
 
     curr = curr->next();
@@ -397,7 +391,8 @@ locate_curve_end (const X_monotone_curve_2& cv, Arr_curve_end ind,
 
   // We should never reach here.
   CGAL_error();
-  return Object();
+  Vertex* v(nullptr);
+  return Result(v);
 }
 
 //-----------------------------------------------------------------------------
@@ -555,23 +550,23 @@ erase_redundant_vertex (Vertex *v)
 
   // Keep pointers to the components that contain two halfedges he3 and he2,
   // pointing at the end vertices of the merged halfedge.
-  Inner_ccb   *ic1 = (he3->is_on_inner_ccb()) ? he3->inner_ccb() : NULL;
-  Outer_ccb   *oc1 = (ic1 == NULL) ? he3->outer_ccb() : NULL;
-  Inner_ccb   *ic2 = (he4->is_on_inner_ccb()) ? he4->inner_ccb() : NULL;
-  Outer_ccb   *oc2 = (ic2 == NULL) ? he4->outer_ccb() : NULL;
+  Inner_ccb   *ic1 = (he3->is_on_inner_ccb()) ? he3->inner_ccb() : nullptr;
+  Outer_ccb   *oc1 = (ic1 == nullptr) ? he3->outer_ccb() : nullptr;
+  Inner_ccb   *ic2 = (he4->is_on_inner_ccb()) ? he4->inner_ccb() : nullptr;
+  Outer_ccb   *oc2 = (ic2 == nullptr) ? he4->outer_ccb() : nullptr;
 
   // As he1 and he2 will evetually represent the merged edge, while he3 and he4
   // will be deleted, check if the deleted halfedges are represantatives of a
   // face boundary or a hole inside these faces. If so, replace he3 by he1 and
   // he4 by he2.
-  if (ic1 != NULL && ic1->halfedge() == he3)
+  if (ic1 != nullptr && ic1->halfedge() == he3)
     ic1->set_halfedge (he1);
-  else if (oc1 != NULL && oc1->halfedge() == he3)
+  else if (oc1 != nullptr && oc1->halfedge() == he3)
     oc1->set_halfedge (he1);
 
-  if (ic2 != NULL && ic2->halfedge() == he4)
+  if (ic2 != nullptr && ic2->halfedge() == he4)
     ic2->set_halfedge (he2);
-  else if (oc2 != NULL && oc2->halfedge() == he4)
+  else if (oc2 != nullptr && oc2->halfedge() == he4)
     oc2->set_halfedge (he2);
 
   // If he3 is the incident halfedge to its target, replace it by he1.
@@ -625,7 +620,7 @@ compare_x (const Point_2& p, const Vertex* v) const
     Arr_curve_end v_ind = ARR_MIN_END;
     const X_monotone_curve_2* v_cv = _curve (v, v_ind);
 
-    CGAL_assertion(v_cv != NULL);
+    CGAL_assertion(v_cv != nullptr);
     return
       (this->m_geom_traits->compare_x_point_curve_end_2_object()(p, *v_cv,
                                                                  v_ind));
@@ -659,7 +654,7 @@ compare_xy (const Point_2& p, const Vertex* v) const
     Arr_curve_end v_ind = ARR_MIN_END;
     const X_monotone_curve_2* v_cv = _curve (v, v_ind);
 
-    CGAL_assertion (v_cv != NULL);
+    CGAL_assertion (v_cv != nullptr);
 
     Comparison_result res =
       this->m_geom_traits->compare_x_point_curve_end_2_object() (p, *v_cv,
@@ -724,7 +719,7 @@ _curve (const Vertex* v, Arr_curve_end& ind) const
     he = he->next()->opposite();
 
     // No incident curve were found:
-    if (he == v->halfedge()) return (NULL);
+    if (he == v->halfedge()) return (nullptr);
   }
 
   // The halfedge he is directed toward v, so if it is directed from left to
@@ -814,7 +809,7 @@ _is_on_fictitious_edge(const X_monotone_curve_2& cv, Arr_curve_end ind,
     }
   }
   else {
-    // If we reched here, we have a "horizontal" fictitious halfedge.
+    // If we reached here, we have a "horizontal" fictitious halfedge.
     Arr_parameter_space he_ps_y = v1->parameter_space_in_y();
 
     CGAL_assertion((he_ps_y == ARR_BOTTOM_BOUNDARY ||
@@ -844,7 +839,7 @@ _is_on_fictitious_edge(const X_monotone_curve_2& cv, Arr_curve_end ind,
       // arrangement, but it hasn't been associated with a valid halfedge
       // yet, as the insertion process is still ongoing.
       // The comparison result in this case is trivial.
-      if (v_cv1 != NULL) {
+      if (v_cv1 != nullptr) {
         res1 =
           this->m_geom_traits->compare_x_curve_ends_2_object()(cv, ind,
                                                                *v_cv1, v_ind);
@@ -878,7 +873,7 @@ _is_on_fictitious_edge(const X_monotone_curve_2& cv, Arr_curve_end ind,
       // arrangement, but it hasn't been associated with a valid halfedge
       // yet, as the insertion process is still ongoing.
       // The comparison result in this case is trivial.
-      if (v_cv2 != NULL) {
+      if (v_cv2 != nullptr) {
         res2 =
           this->m_geom_traits->compare_x_curve_ends_2_object()(cv, ind,
                                                                *v_cv2, v_ind);
