@@ -2,25 +2,22 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arrangement_2_iterators.h $
+// $Id: Arrangement_2_iterators.h 3448035 2021-03-24T08:25:29+01:00 Simon Giraudot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL$
-// $Id$
-// 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
 
 #ifndef CGAL_ARRANGEMENT_2_ITERATORS_H
 #define CGAL_ARRANGEMENT_2_ITERATORS_H
 
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
+
+#include <functional>
+
 /*! \file
  * Definitions of auxiliary iterator adaptors.
  */
@@ -41,9 +38,9 @@ public:
   // Type definitions:
   typedef Iterator_                               Iterator;
   typedef I_Dereference_iterator<Iterator_,
-				 Value_,
-				 Diff_,
-				 Category_>       Self;
+                                 Value_,
+                                 Diff_,
+                                 Category_>       Self;
 
   typedef Category_                               iterator_category;
   typedef Value_                                  value_type;
@@ -73,17 +70,17 @@ public:
   {
     return (iter == it.iter);
   }
-    
+
   bool operator!= (const Self& it) const
   {
     return (!(iter == it.iter));
   }
-    
+
   Iterator current_iterator () const
   {
     return (iter);
   }
-    
+
   pointer ptr () const
   {
     return (static_cast<value_type *> (*iter));
@@ -99,7 +96,7 @@ public:
     return (ptr());
   }
   //@}
-    
+
   /// \name Incremernt operations (forward category).
   //@{
   Self& operator++()
@@ -139,8 +136,8 @@ public:
  * class (given as CIterator_), which is supposed to be a pointer, and handle
  * it as the value-type given by Value_.
  */
-template <class CIterator_, class MIterator_, 
-	  class Value_, class Diff_, class Category_>
+template <class CIterator_, class MIterator_,
+          class Value_, class Diff_, class Category_>
 class I_Dereference_const_iterator
 {
 public:
@@ -149,10 +146,10 @@ public:
   typedef CIterator_                              Const_iterator;
   typedef MIterator_                              Mutable_iterator;
   typedef I_Dereference_const_iterator<CIterator_,
-				       MIterator_,
-				       Value_,
-				       Diff_,
-				       Category_> Self;
+                                       MIterator_,
+                                       Value_,
+                                       Diff_,
+                                       Category_> Self;
 
   typedef Category_                               iterator_category;
   typedef Value_                                  value_type;
@@ -187,17 +184,17 @@ public:
   {
     return (iter == it.iter);
   }
-    
+
   bool operator!= (const Self& it) const
   {
     return (!(iter == it.iter));
   }
-    
+
   Const_iterator current_iterator () const
   {
     return (iter);
   }
-    
+
   pointer ptr () const
   {
     return (static_cast<const value_type *> (*iter));
@@ -213,7 +210,7 @@ public:
     return (ptr());
   }
   //@}
-    
+
   /// \name Incremernt operations (forward category).
   //@{
   Self& operator++()
@@ -259,7 +256,7 @@ class I_Filtered_iterator
 public:
 
   typedef Iterator_                       Iterator;
-  typedef Filter_                         Filter; 
+  typedef Filter_                         Filter;
   typedef I_Filtered_iterator<Iterator_,
                               Filter_,
                               Value_,
@@ -277,7 +274,7 @@ protected:
   Iterator        nt;       // The internal iterator (this member should not
                             // be renamed in order to comply with the
                             // HalfedgeDS circulators that refer to it).
-  Iterator        iend;     // A past-the-end iterator.        
+  Iterator        iend;     // A past-the-end iterator.
   Filter          filt;     // The filter functor.
 
 public:
@@ -291,6 +288,12 @@ public:
     iend (nt)
   {}
 
+  template <typename T>
+  I_Filtered_iterator (T* p) :
+    nt (pointer(p)),
+    iend (nt)
+  {}
+
   I_Filtered_iterator (Iterator it, Iterator end) :
     nt (it),
     iend (end)
@@ -308,6 +311,14 @@ public:
       ++nt;
   }
 
+  template <typename P>
+  I_Filtered_iterator& operator= (const P* p)
+  {
+    nt = pointer(p);
+    iend =nt;
+    return *this;
+  }
+
   /*! Access operations. */
   Iterator current_iterator() const
   {
@@ -334,18 +345,23 @@ public:
   {
     return (nt == it.nt);
   }
-  
-  bool operator!= (const Self& it) const 
+
+  bool operator!= (const Self& it) const
   {
     return !(*this == it);
   }
-  
+
+  bool operator< (const Self& it) const
+  {
+    return &(**this) < (&*it);
+  }
+
   /*! Dereferencing operators. */
   reference operator*() const
   {
     return (*(ptr()));
   }
-  
+
   pointer operator->() const
   {
     return ptr();
@@ -361,7 +377,7 @@ public:
 
     return (*this);
   }
-   
+
   Self operator++ (int)
   {
     Self tmp = *this;
@@ -423,7 +439,7 @@ protected:
   Iterator       nt;       // The internal iterator (this member should not
                            // be renamed in order to comply with the
                            // HalfedgeDS circulators that refer to it).
-  Iterator       iend;     // A past-the-end iterator.        
+  Iterator       iend;     // A past-the-end iterator.
   Filter         filt;     // The filter functor.
 
 public:
@@ -437,6 +453,12 @@ public:
     iend (it)
   {}
 
+  template <typename T>
+  I_Filtered_const_iterator (T* p) :
+    nt (pointer(p)),
+    iend (nt)
+  {}
+
   I_Filtered_const_iterator (Iterator it, Iterator end) :
     nt (it),
     iend (end)
@@ -463,6 +485,14 @@ public:
     //      ++nt;
   }
 
+  template <typename P>
+  I_Filtered_const_iterator& operator= (const P* p)
+  {
+    nt = pointer(p);
+    iend =nt;
+    return *this;
+  }
+
   /*! Access operations. */
   Iterator current_iterator() const
   {
@@ -489,18 +519,23 @@ public:
   {
     return (nt == it.nt);
   }
-  
-  bool operator!= (const Self& it) const 
+
+  bool operator!= (const Self& it) const
   {
     return !(*this == it);
   }
-  
+
+  bool operator< (const Self& it) const
+  {
+    return &(**this) < (&*it);
+  }
+
   /*! Dereferencing operators. */
   reference operator*() const
   {
     return (*(ptr()));
   }
-  
+
   pointer operator->() const
   {
     return ptr();
@@ -516,7 +551,7 @@ public:
 
     return (*this);
   }
-   
+
   Self operator++ (int)
   {
     Self tmp = *this;
@@ -545,4 +580,107 @@ public:
 
 } //namespace CGAL
 
+namespace std {
+
+#if defined(BOOST_MSVC)
+#  pragma warning(push)
+#  pragma warning(disable:4099) // For VC10 it is class hash
+#endif
+
+#ifndef CGAL_CFG_NO_STD_HASH
+
+template <class CIterator_, class Filter_, class MIterator_,
+          class Value_, class Diff_, class Category_>
+struct hash<CGAL::I_Filtered_const_iterator<CIterator_,
+                                            Filter_,
+                                            MIterator_,
+                                            Value_,
+                                            Diff_,
+                                            Category_> > {
+
+  typedef CGAL::I_Filtered_const_iterator<CIterator_,
+                                          Filter_,
+                                          MIterator_,
+                                          Value_,
+                                          Diff_,
+                                          Category_>  I;
+
+    std::size_t operator()(const I& i) const
+    {
+      return reinterpret_cast<std::size_t>(&*i) / sizeof(Value_);
+    }
+  };
+
+  template <class Iterator_, class Filter_,
+          class Value_, class Diff_, class Category_>
+  struct hash<CGAL::I_Filtered_iterator<Iterator_,
+                                        Filter_,
+                                        Value_,
+                                        Diff_,
+                                        Category_> > {
+  typedef CGAL::I_Filtered_iterator<Iterator_,
+                                    Filter_,
+                                    Value_,
+                                    Diff_,
+                                    Category_>  I;
+
+    std::size_t operator()(const I& i) const
+    {
+      return reinterpret_cast<std::size_t>(&*i) / sizeof(typename I::value_type);
+    }
+  };
+
+#endif // CGAL_CFG_NO_STD_HASH
+
+#if defined(BOOST_MSVC)
+#  pragma warning(pop)
+#endif
+
+} // namespace std
+
+namespace  boost {
+  template <typename T> struct hash;
+
+template <class CIterator_, class Filter_, class MIterator_,
+          class Value_, class Diff_, class Category_>
+struct hash<CGAL::I_Filtered_const_iterator<CIterator_,
+                                            Filter_,
+                                            MIterator_,
+                                            Value_,
+                                            Diff_,
+                                            Category_> > {
+
+  typedef CGAL::I_Filtered_const_iterator<CIterator_,
+                                          Filter_,
+                                          MIterator_,
+                                          Value_,
+                                          Diff_,
+                                          Category_>  I;
+
+    std::size_t operator()(const I& i) const
+    {
+      return reinterpret_cast<std::size_t>(&*i) / sizeof(Value_);
+    }
+  };
+
+  template <class Iterator_, class Filter_,
+          class Value_, class Diff_, class Category_>
+  struct hash<CGAL::I_Filtered_iterator<Iterator_,
+                                        Filter_,
+                                        Value_,
+                                        Diff_,
+                                        Category_> > {
+  typedef CGAL::I_Filtered_iterator<Iterator_,
+                                    Filter_,
+                                    Value_,
+                                    Diff_,
+                                    Category_>  I;
+
+    std::size_t operator()(const I& i) const
+    {
+      return reinterpret_cast<std::size_t>(&*i) / sizeof(typename I::value_type);
+    }
+  };
+
+} // namespace boost
 #endif
