@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_agg_op.h $
-// $Id: Gps_agg_op.h 7936109 2017-11-16T16:31:52+02:00 Efi Fogel
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_agg_op.h $
+// $Id: Gps_agg_op.h 62a31ba 2022-11-14T17:44:33+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
 //                 Ophir Setter    <ophir.setter@cs.tau.ac.il>
@@ -117,7 +108,7 @@ public:
   {
     std::list<Meta_X_monotone_curve_2> curves_list;
 
-    unsigned int n_inf_pgn = 0; // number of infinte polygons (arrangement
+    unsigned int n_inf_pgn = 0; // number of infinite polygons (arrangement
                                 // with a contained unbounded face
     unsigned int n_pgn = 0;     // number of polygons (arrangements)
     unsigned int i;
@@ -130,7 +121,7 @@ public:
 
       Edge_iterator  itr = arr->edges_begin();
       for(; itr != arr->edges_end(); ++itr) {
-        // take only relevant edges (which seperate between contained and
+        // take only relevant edges (which separate between contained and
         // non-contained faces.
         Halfedge_iterator he = itr;
         if(he->face()->contained() == he->twin()->face()->contained())
