@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_default_traits.h $
+// $Id: Gps_default_traits.h fcd1289 2020-11-30T10:03:43+02:00 Efi Fogel
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_default_traits.h $
-// $Id: Gps_default_traits.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
 
@@ -34,39 +25,42 @@
 
 namespace CGAL {
 
+//!
 template <class Polygon>
 struct Gps_default_traits
 {};
 
-
+//!
 template <class Kernel, class Container>
 struct Gps_default_traits<CGAL::Polygon_2<Kernel, Container> >
 {
-  typedef Gps_segment_traits_2<Kernel,
-                               Container,
-                               Arr_segment_traits_2<Kernel> >    Traits;
+  typedef Arr_segment_traits_2<Kernel>                          Arr_traits;
+  typedef Gps_segment_traits_2<Kernel, Container, Arr_traits>   Traits;
 };
 
+//!
 template <class Kernel, class Container>
 struct Gps_default_traits<CGAL::Polygon_with_holes_2<Kernel, Container> >
 {
-  typedef Gps_segment_traits_2<Kernel,
-                               Container,
-                               Arr_segment_traits_2<Kernel> >    Traits;
-};
-
-template <class Polygon>
-struct Gps_default_traits<CGAL::General_polygon_with_holes_2<Polygon> >
-{
-  typedef typename Gps_default_traits<Polygon>::Traits Traits;
+  typedef Polygon_2<Kernel, Container>                          Polygon;
+  typedef typename Gps_default_traits<Polygon>::Arr_traits      Arr_traits;
+  typedef typename Gps_default_traits<Polygon>::Traits          Traits;
 };
 
+//!
 template <class Arr_traits>
 struct Gps_default_traits<CGAL::General_polygon_2<Arr_traits> >
 {
   typedef Gps_traits_2<Arr_traits>    Traits;
 };
 
+//!
+template <class Polygon>
+struct Gps_default_traits<CGAL::General_polygon_with_holes_2<Polygon> >
+{
+  typedef typename Gps_default_traits<Polygon>::Traits Traits;
+};
+
 } //namespace CGAL
 
 #endif
