@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Polygon_2_curve_iterator.h $
+// $Id: Polygon_2_curve_iterator.h 0b70318 2020-10-20T09:01:29+02:00 Simon Giraudot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Polygon_2_curve_iterator.h $
-// $Id: Polygon_2_curve_iterator.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
 
@@ -44,16 +35,16 @@ private:
 };
 
 template <class X_monotone_curve_2_, class Polygon_>
-class Polygon_2_curve_iterator 
+class Polygon_2_curve_iterator
 {
 public:
     typedef Polygon_2_curve_iterator< X_monotone_curve_2_, Polygon_ >    Self;
- 
-    
+
+
     typedef X_monotone_curve_2_                           X_monotone_curve_2;
     typedef typename Polygon_::Container                  Container;
     typedef typename Container::iterator                  Container_iterator;
-    typedef typename std::iterator_traits<Container_iterator>::iterator_category 
+    typedef typename std::iterator_traits<Container_iterator>::iterator_category
                                                           iterator_category;
     typedef X_monotone_curve_2                            value_type;
     typedef X_monotone_curve_2*                           pointer;
@@ -61,17 +52,17 @@ public:
 
 
     typedef Polygon_                                      Polygon;
-    typedef typename Polygon::Edge_const_iterator         Edge_const_iterator;
+    typedef typename Polygon::Vertex_pair_iterator        Edge_const_iterator;
     typedef typename Edge_const_iterator::difference_type difference_type;
- 
+
   private:
     const Polygon*      m_pgn;   // needed for dereferencing the last edge
     Edge_const_iterator m_curr_edge;   // points to the current edge iterator
-  
-public:
-    Polygon_2_curve_iterator< X_monotone_curve_2_, Polygon_ >(){}
 
-    Polygon_2_curve_iterator< X_monotone_curve_2_, Polygon_ >
+public:
+    Polygon_2_curve_iterator(){}
+
+    Polygon_2_curve_iterator
       (const Polygon* pgn, Edge_const_iterator ci) : m_pgn(pgn),
                                                      m_curr_edge(ci) {}
 
@@ -79,17 +70,17 @@ public:
     {
       return (m_curr_edge == x.m_curr_edge);
     }
-    
+
     bool operator!=(const Self& x) const
     {
       return !(m_curr_edge == x.m_curr_edge);
     }
 
-    X_monotone_curve_2 operator*() 
+    X_monotone_curve_2 operator*()
     {
-      return X_monotone_curve_2(*m_curr_edge);
+      return X_monotone_curve_2(m_curr_edge->first, m_curr_edge->second);
     }
-    
+
     Polygon_2_curve_ptr<X_monotone_curve_2> operator->()
     {
       return Polygon_2_curve_ptr<X_monotone_curve_2>(operator*());
@@ -108,7 +99,7 @@ public:
       return tmp;
     }
 
-    Self& operator--() 
+    Self& operator--()
     {
       --m_curr_edge;
       return *this;
@@ -121,7 +112,7 @@ public:
     }
 
     // random access iterator requirements
-    Self& operator+=(difference_type n) 
+    Self& operator+=(difference_type n)
     {
       m_curr_edge += n;
       return *this;
@@ -132,12 +123,12 @@ public:
       return Self(m_pgn, m_curr_edge + n);
     }
 
-    Self& operator-=(difference_type n) 
+    Self& operator-=(difference_type n)
     {
       return (*this) -= n;
     }
 
-    Self operator-(difference_type n) 
+    Self operator-(difference_type n)
     {
       return Self(m_pgn, m_curr_edge - n);
     }
@@ -147,7 +138,7 @@ public:
       return (const_cast<Edge_const_iterator&>(m_curr_edge) - a.m_curr_edge);
     }
 
-    X_monotone_curve_2 operator[](int n) 
+    X_monotone_curve_2 operator[](int n)
     {
       return *Self(m_pgn, m_curr_edge+n);
     }
@@ -178,15 +169,15 @@ public:
 template <class X_monotone_curve_2_,  class Polygon_>
 typename Polygon_2_curve_iterator<X_monotone_curve_2_,Polygon_>::difference_type
 distance_type(const Polygon_2_curve_iterator<X_monotone_curve_2_,Polygon_>&)
-{ 
-  return Polygon_2_curve_iterator<X_monotone_curve_2_,Polygon_>::difference_type(); 
+{
+  return Polygon_2_curve_iterator<X_monotone_curve_2_,Polygon_>::difference_type();
 }
 
 template <class X_monotone_curve_2_,  class Polygon_>
 X_monotone_curve_2_*
 value_type(const Polygon_2_curve_iterator<X_monotone_curve_2_,Polygon_>&)
 {
-  return (X_monotone_curve_2_*)(0); 
+  return (X_monotone_curve_2_*)(0);
 }
 
 
