@@ -4,37 +4,26 @@
  * All rights reserved.
  *
  * This file is part of CGAL (www.cgal.org).
- * You can redistribute it and/or modify it under the terms of the GNU
- * Lesser General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
- *
- * Licensees holding a valid commercial license may use this file in
- * accordance with the commercial license agreement provided with the
- * software.
- *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
- *
  *
  * File: ExprRep.h
  * Synopsis: Internal Representation of Expr.
- * 
- * Written by 
+ *
+ * Written by
  *       Koji Ouchi <ouchi@simulation.nyu.edu>
  *       Chee Yap <yap@cs.nyu.edu>
  *       Igor Pechtchanski <pechtcha@cs.nyu.edu>
  *       Vijay Karamcheti <vijayk@cs.nyu.edu>
  *       Chen Li <chenli@cs.nyu.edu>
  *       Zilin Du <zilin@cs.nyu.edu>
- *       Sylvain Pion <pion@cs.nyu.edu> 
+ *       Sylvain Pion <pion@cs.nyu.edu>
  *       Vikram Sharma<sharma@cs.nyu.edu>
  *
- * WWW URL: http://cs.nyu.edu/exact/
+ * WWW URL: https://cs.nyu.edu/exact/
  * Email: exact@cs.nyu.edu
  *
- * $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/CGAL_Core/include/CGAL/CORE/ExprRep.h $
- * $Id: ExprRep.h 3c6640b 2017-12-05T18:20:05+01:00 Laurent Rineau
- * SPDX-License-Identifier: LGPL-3.0+
+ * $URL: https://github.com/CGAL/cgal/blob/v5.6/CGAL_Core/include/CGAL/CORE/ExprRep.h $
+ * $Id: ExprRep.h 0ff7882 2022-12-06T22:21:06+01:00 Mael
+ * SPDX-License-Identifier: LGPL-3.0-or-later
  ***************************************************************************/
 
 #ifndef _CORE_EXPRREP_H_
@@ -51,7 +40,7 @@
 #  pragma warning(disable:4251)
 #endif
 
-namespace CORE { 
+namespace CORE {
 
 #if defined(CGAL_CORE_DEBUG_BOUND) && !defined(CGAL_HEADER_ONLY)
 // These counters are incremented each time each bound is recognized as equal
@@ -88,10 +77,10 @@ inline extLong ceilLg5(const extLong & a) {
 /// \struct NodeInfo
 /// \brief store information of a node
 struct NodeInfo {
-  Real     appValue;		///< current approximate value
-  bool     appComputed;  	///< true if the approx value been computed
-  bool     flagsComputed;  	///< true if rootBound parameters have been computed
-  extLong  knownPrecision; 	///< Precision achieved by current approx value
+  Real     appValue;                ///< current approximate value
+  bool     appComputed;          ///< true if the approx value been computed
+  bool     flagsComputed;          ///< true if rootBound parameters have been computed
+  extLong  knownPrecision;         ///< Precision achieved by current approx value
 
 #ifdef CGAL_CORE_DEBUG
   extLong relPrecision;
@@ -105,8 +94,8 @@ struct NodeInfo {
    *   generalized accordingly.   */
   extLong d_e;
 
-  bool visited;   	///< flag in counting # of sqrts
-  int sign; 		///< sign of the value being represented.
+  bool visited;           ///< flag in counting # of sqrts
+  int sign;                 ///< sign of the value being represented.
 
   extLong  uMSB; ///< upper bound of the position of Most Significant Bit
   extLong  lMSB; ///< lower bound of the position of Most Significant Bit
@@ -145,8 +134,8 @@ struct NodeInfo {
   /** where E = 2^v2*5^v5*U(E)/L(E), U(E) and L(E) are division-free. */
   extLong l25;
 
-  int ratFlag;		///< rational flag
-  BigRat* ratValue;	///< rational value
+  int ratFlag;                ///< rational flag
+  BigRat* ratValue;        ///< rational value
 
   /// default constructor
   CGAL_CORE_EXPORT NodeInfo();
@@ -156,7 +145,7 @@ struct NodeInfo {
 // class Expr;
 
 /// \class ExprRep
-/// \brief The sharable, internal representation of expressions
+/// \brief The shareable, internal representation of expressions
 //  Members: private: int refCount,
 //            public:  NodeInfo* nodeInfo,
 //                     filteredFp ffVal.
@@ -168,7 +157,7 @@ public:
   ExprRep();
   /// virtual destructor for this base class
   virtual ~ExprRep() {
-    if (nodeInfo != NULL) // This check is only for optimization.
+    if (nodeInfo != nullptr) // This check is only for optimization.
       delete nodeInfo;
   }
   //@}
@@ -423,8 +412,8 @@ private:
 public:
   enum {OPERATOR_ONLY, VALUE_ONLY, OPERATOR_VALUE, FULL_DUMP};
 
-  NodeInfo* nodeInfo;	///< node information
-  filteredFp ffVal;	///< filtered value
+  NodeInfo* nodeInfo;        ///< node information
+  filteredFp ffVal;        ///< filtered value
 
   /// \name Approximation Functions
   //@{
@@ -436,7 +425,7 @@ public:
   extLong computeBound();
   /// driver function to approximate
   void approx(const extLong& relPrec, const extLong& absPrec);
-  /// compute an approximate value satifying the specified precisions
+  /// compute an approximate value satisfying the specified precisions
   virtual void computeApproxValue(const extLong&, const extLong&) = 0;
   /// Test whether the current approx. value satisfies [relPrec, absPrec]
   bool withinKnownPrecision(const extLong&, const extLong&);
@@ -576,26 +565,26 @@ public:
     // check whether n-th root exists
     if (I.first == 1 && I.second == 0) {
       core_error("CORE ERROR! root index out of bound",
-		      __FILE__, __LINE__, true);
+                      __FILE__, __LINE__, true);
       abort();
     }
     // test if the root isolated in I is 0:
     if ((I.first == 0)&&(I.second == 0))
       ffVal = 0;
     else
-      ffVal = computeFilteredValue();	// silly to use a filter here!
-    					// since sign is known.
+      ffVal = computeFilteredValue();        // silly to use a filter here!
+                                            // since sign is known.
   }
 
   /// constructor for Polynomial
   ConstPolyRep(const Polynomial<NT>& p, const BFInterval& II)
-	  : ss(p), I(II) {
+          : ss(p), I(II) {
     BFVecInterval v;
     ss.isolateRoots(I.first, I.second, v);
     I = v.front();
     if (v.size() != 1) {
       core_error("CORE ERROR! non-isolating interval",
-		      __FILE__, __LINE__, true);
+                      __FILE__, __LINE__, true);
       abort();
     }
     ffVal = computeFilteredValue(); // Chee: this line seems unnecessary
@@ -604,11 +593,11 @@ public:
   /// destructor
   ~ConstPolyRep() {}
   //@}
-  
+
   void *operator new( size_t size){
     return MemoryPool<ConstPolyRep>::global_allocator().allocate(size);
   }
- 
+
   void operator delete( void *p, size_t ){
     MemoryPool<ConstPolyRep>::global_allocator().free(p);
   }
@@ -616,10 +605,10 @@ public:
 private:
   Sturm<NT> ss; ///< internal Sturm sequences
   BFInterval I; ///< current interval contains the real value
-  		// IMPORTANT: I.first and I.second are exact BigFloats
+                  // IMPORTANT: I.first and I.second are exact BigFloats
   filteredFp computeFilteredValue() {
     // refine initial interval to absolute error of 2^(lMSB(k)-54) where
-    // 	  k is a lower bound on the root (use Cauchy Lower Bound).
+    //           k is a lower bound on the root (use Cauchy Lower Bound).
     //    Hence, the precision we pass to refine should be 54-lMSB(k).
 
     // refine with newton (new method)
@@ -637,7 +626,7 @@ private:
     // It should be "centralized" to set
     // the error bit correctly.
     // E.g., otherwise, radical(4,2) will print wrongly.
-    if ((I.first == 0) && (I.second == 0))	// Checkfor zero value
+    if ((I.first == 0) && (I.second == 0))        // Checkfor zero value
       return filteredFp(0);
     BigFloat x = centerize(I.first, I.second);
     double val = x.doubleValue();
@@ -647,7 +636,7 @@ private:
     long ee = x.exp()*CHUNK_BIT;
     unsigned long err = ee > 0 ? (x.err() << ee) : (x.err() >> (-ee));
     double max = core_abs(val) + err;
-    int ind = longValue((BigInt(x.err()) << 53) / (x.m() + x.err())); 
+    int ind = longValue((BigInt(x.err()) << 53) / (x.m() + x.err()));
     */
     return filteredFp(val, max, ind); // Aug 8, 2004, Comment from Chee:
        // I think we should get rid of filters here!  Given the interval I,
@@ -678,15 +667,15 @@ protected:
       sign() = -1;
     }
     // length() = 1+ ss.seq[0].length().uMSB();
-    measure() = 1+ ss.seq[0].length().uMSB();	// since measure<= length
+    measure() = 1+ ss.seq[0].length().uMSB();        // since measure<= length
 
     // compute u25, l25, v2p, v2m, v5p, v5m
     v2p() = v2m() = v5p() = v5m() = 0;
     u25() = 1+ss.seq[0].CauchyUpperBound().uMSB();
     l25() = ceilLg(ss.seq[0].getLeadCoeff());  // assumed coeff is integer!!
-    		// ceilLg(BigInt) and ceilLg(Expr) are defined. But if
-    		// NT=int, ceilLg(int) is ambiguous!  Added ceilLg(int)
-		// under BigInt.h
+                    // ceilLg(BigInt) and ceilLg(Expr) are defined. But if
+                    // NT=int, ceilLg(int) is ambiguous!  Added ceilLg(int)
+                // under BigInt.h
 
     // compute high, low, lc, tc
     high() = u25();
@@ -994,17 +983,17 @@ void AddSubRep<Operator>::computeExactFlags() {
 
   // BFMSS[2,5] bound.
   v2p() = core_min(first->v2p() + second->v2m(),
-		  first->v2m() + second->v2p());
+                  first->v2m() + second->v2p());
   v2m() = first->v2m() + second->v2m();
   v5p() = core_min(first->v5p() + second->v5m(),
-		  first->v5m() + second->v5p());
+                  first->v5m() + second->v5p());
   v5m() = first->v5m() + second->v5m();
 
   if (v2p().isInfty() || v5p().isInfty())
     u25() = CORE_INFTY;
   else
     u25() = EXTLONG_ONE + core_max(first->v2p() + second->v2m()
-	    - v2p() + ceilLg5(first->v5p() + second->v5m() - v5p())
+            - v2p() + ceilLg5(first->v5p() + second->v5m() - v5p())
             + first->u25() + second->l25(),
                                    first->v2m() + second->v2p() - v2p()
             + ceilLg5(first->v5m() + second->v5p() - v5p())
@@ -1069,7 +1058,7 @@ void AddSubRep<Operator>::computeExactFlags() {
       sign() = ffVal.sign();
       lMSB() = ffVal.lMSB();
       uMSB() = ffVal.uMSB();
-    } else {			// about the same size, might cancel out
+    } else {                        // about the same size, might cancel out
 #ifdef CGAL_CORE_TRACE
       std::cout << "Add/sub Rep:  iteration start" << std::endl;
 #endif
@@ -1088,16 +1077,16 @@ void AddSubRep<Operator>::computeExactFlags() {
         // a relative error requirement "ur", s.t.
         //    |x|*2^(-ur) <= 2^(-lowBound).
         // ==> r >= a + lg(x) >= a + (uMSB + 1);
-        //	    extLong  rf = lowBound + (uf + 1);
-        //	    extLong  rs = lowBound + (us + 1);
-        //	    first->approx(rf, CORE_INFTY);
-        //	    second->approx(rs, CORE_INFTY);
+        //            extLong  rf = lowBound + (uf + 1);
+        //            extLong  rs = lowBound + (us + 1);
+        //            first->approx(rf, CORE_INFTY);
+        //            second->approx(rs, CORE_INFTY);
         // Chen: considering the uMSB is also an approximate bound.
         // we choose to use absolute precision up-front.
         Real newValue = Op(first->getAppValue(CORE_INFTY,
-				lowBound + EXTLONG_ONE),
+                                lowBound + EXTLONG_ONE),
                            second->getAppValue(CORE_INFTY,
-				   lowBound + EXTLONG_ONE));
+                                   lowBound + EXTLONG_ONE));
         if (!newValue.isZeroIn()) { // Op(first, second) != 0
           lMSB() = newValue.lMSB();
           uMSB() = newValue.uMSB();   // chen: to get tighers value.
@@ -1118,14 +1107,14 @@ void AddSubRep<Operator>::computeExactFlags() {
         // Moreover, this is much more efficient.
 
         // ua is the upper bound on the absolute precision in our iteration
-	// Chee, Aug 8, 2004: it is important that ua be strictly
-	//     larger than lowBound AND the defaultInitialProgressivePrec,
-	//     so that we do at least one iteration of the for-loop. So:
-	// i is the variable for iteration.
+        // Chee, Aug 8, 2004: it is important that ua be strictly
+        //     larger than lowBound AND the defaultInitialProgressivePrec,
+        //     so that we do at least one iteration of the for-loop. So:
+        // i is the variable for iteration.
         extLong i = core_min(getInitialProgressivePrec(), lowBound.asLong());
         extLong ua = lowBound.asLong() + EXTLONG_ONE;
         //   NOTE: ua is allowed to be CORE_INFTY
-	
+
 #ifdef CGAL_CORE_DEBUG_BOUND
         std::cout << "DebugBound:" << "ua = " << ua << std::endl;
 #endif
@@ -1133,13 +1122,13 @@ void AddSubRep<Operator>::computeExactFlags() {
         lMSB() = CORE_negInfty;
         sign() = 0;
 
-        get_static_EscapePrecFlag() = 0;	// reset the Escape Flag
+        get_static_EscapePrecFlag() = 0;        // reset the Escape Flag
 
         // Now we try to determine the real lMSB and sign,
         // in case it is not really zero:
 #ifdef CGAL_CORE_TRACE
         std::cout << "Upper bound (ua) for iteration is " << ua << std::endl;
-	std::cout << "Starting iteration at i = " << i << std::endl;
+        std::cout << "Starting iteration at i = " << i << std::endl;
 #endif
 
         bool current_precision_lower_than_bound = true;
@@ -1151,32 +1140,32 @@ void AddSubRep<Operator>::computeExactFlags() {
             i = ua; // do not compute more than needed
           }
           // relative bits = i
-	  //
-	  // PROBLEM WITH NEXT LINE: you must ensure that
-	  // first and second are represented by BigFloats...
-	  //
+          //
+          // PROBLEM WITH NEXT LINE: you must ensure that
+          // first and second are represented by BigFloats...
+          //
           Real newValue = Op(first->getAppValue(CORE_INFTY, i),
                              second->getAppValue(CORE_INFTY, i));
 
 #ifdef CGAL_CORE_TRACE
-	  if (newValue.getRep().ID() == REAL_BIGFLOAT) 
-	  std::cout << "BigFloat! newValue->rep->ID() = "
-		  << newValue.getRep().ID() << std::endl;
-	  else 
-	  std::cout << "ERROR, Not BigFloat! newValue->rep->ID() ="
-		  << newValue.getRep().ID() << std::endl;
-	  std::cout << "newValue = Op(first,second) = "
-		  << newValue << std::endl;
-	  std::cout << "first:appVal, appComputed, knownPrec, sign ="
-		  << first->appValue() << ","
-		  << first->appComputed() << ","
-		  << first->knownPrecision() << ","
-		  << first->sign() << std::endl;
-	  std::cout << "second:appVal, appComputed, knownPrec, sign ="
-		  << second->appValue() << ","
-		  << second->appComputed() << ","
-		  << second->knownPrecision() << ","
-		  << second->sign() << std::endl;
+          if (newValue.getRep().ID() == REAL_BIGFLOAT)
+          std::cout << "BigFloat! newValue->rep->ID() = "
+                  << newValue.getRep().ID() << std::endl;
+          else
+          std::cout << "ERROR, Not BigFloat! newValue->rep->ID() ="
+                  << newValue.getRep().ID() << std::endl;
+          std::cout << "newValue = Op(first,second) = "
+                  << newValue << std::endl;
+          std::cout << "first:appVal, appComputed, knownPrec, sign ="
+                  << first->appValue() << ","
+                  << first->appComputed() << ","
+                  << first->knownPrecision() << ","
+                  << first->sign() << std::endl;
+          std::cout << "second:appVal, appComputed, knownPrec, sign ="
+                  << second->appValue() << ","
+                  << second->appComputed() << ","
+                  << second->knownPrecision() << ","
+                  << second->sign() << std::endl;
 #endif
           if (!newValue.isZeroIn()) {   // Op(first, second) != 0
             lMSB() = newValue.lMSB();
@@ -1186,10 +1175,10 @@ void AddSubRep<Operator>::computeExactFlags() {
             std::cout << "DebugBound(Exit Loop): " << "i=" << i << std::endl;
 #endif
 #ifdef CGAL_CORE_TRACE
-	    std::cout << "Zero is not in, lMSB() = " << lMSB()
-		    << ", uMSB() = " << uMSB()
-		    << ", sign() = " << sign() << std::endl;
-	    std::cout << "newValue = " << newValue << std::endl;
+            std::cout << "Zero is not in, lMSB() = " << lMSB()
+                    << ", uMSB() = " << uMSB()
+                    << ", sign() = " << sign() << std::endl;
+            std::cout << "newValue = " << newValue << std::endl;
 #endif
 
             break; // assert -- this must happen in the loop if nonzero!
@@ -1197,11 +1186,11 @@ void AddSubRep<Operator>::computeExactFlags() {
           //8/9/01, Chee: implement escape precision here:
           if (i> get_static_EscapePrec()) {
             get_static_EscapePrecFlag() = -i.asLong();//negative means EscapePrec is used
-	    core_error("Escape precision triggered at",
-            		 __FILE__, __LINE__, false);
+            core_error("Escape precision triggered at",
+                             __FILE__, __LINE__, false);
             if (get_static_EscapePrecWarning())
               std::cout<< "Escape Precision triggered at "
-		      << get_static_EscapePrec() << " bits" << std::endl;
+                      << get_static_EscapePrec() << " bits" << std::endl;
 #ifdef CGAL_CORE_DEBUG
             std::cout << "EscapePrecFlags=" << get_static_EscapePrecFlag() << std::endl;
             std::cout << "ua =" << ua  << ",lowBound=" << lowBound << std::endl;
@@ -1248,7 +1237,7 @@ void AddSubRep<Operator>::computeApproxValue(const extLong& relPrec,
     std::ostringstream oss;
     oss << "CORE WARNING: a huge lMSB in AddSubRep: " << lMSB();
     core_error(oss.str(),
-	 	__FILE__, __LINE__, false);
+                 __FILE__, __LINE__, false);
   }
 
   extLong rf = first->uMSB()-lMSB()+relPrec+EXTLONG_FOUR;  // 2 better
@@ -1291,7 +1280,7 @@ public:
   /// destructor
   ~MultRep() {}
   //@}
-  
+
   CORE_NEW(MultRep)
   CORE_DELETE(MultRep)
   protected:
@@ -1351,7 +1340,7 @@ inline int ExprRep::getExactSign() {
 }
 
 // Chee, 7/17/02: degreeBound() function is now
-// taken out of "computeExactFlags()
+// taken out of "computeExactFlags()"
 inline int ExprRep::getSign() {
   if (ffVal.isOK())
     return ffVal.sign();
