@@ -1,20 +1,11 @@
 // Copyright (c) 2006-2008 Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Number_types/include/CGAL/CORE_BigFloat.h $
-// $Id: CORE_BigFloat.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Number_types/include/CGAL/CORE_BigFloat.h $
+// $Id: CORE_BigFloat.h 152a084 2021-09-21T13:34:58+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Michael Hemmer   <hemmer@mpi-inf.mpg.de>
@@ -25,54 +16,53 @@
 
 #include <CGAL/basic.h>
 #include <CGAL/number_type_basic.h>
-#include <CGAL/CORE/BigFloat.h>
 #include <CGAL/CORE_coercion_traits.h>
-#include <CGAL/Interval_traits.h> 
-#include <CGAL/Bigfloat_interval_traits.h> 
+#include <CGAL/Interval_traits.h>
+#include <CGAL/Bigfloat_interval_traits.h>
 
 namespace CGAL {
 
-// ######### Interval_traits 
+// ######### Interval_traits
 
-template<> 
-class Interval_traits<CORE::BigFloat> 
+template<>
+class Interval_traits<CORE::BigFloat>
     : public internal::Interval_traits_base<CORE::BigFloat>{
     typedef CORE::BigFloat Interval;
-public: 
-    typedef Interval_traits<CORE::BigFloat> Self; 
+public:
+    typedef Interval_traits<CORE::BigFloat> Self;
     typedef CORE::BigFloat Type;
     typedef CORE::BigFloat Bound;
-    typedef CGAL::Tag_true Is_interval; 
-    typedef CGAL::Tag_true Is_bigfloat_interval; 
-  
- 
+    typedef CGAL::Tag_true Is_interval;
+    typedef CGAL::Tag_true Is_bigfloat_interval;
+
+
     struct Lower :public CGAL::cpp98::unary_function<Interval,Bound>{
-        Bound operator() ( Interval x ) const {   
+        Bound operator() ( Interval x ) const {
             CORE::BigFloat result = ::CORE::BigFloat(x.m()-x.err(),0,x.exp());
             CGAL_postcondition(result <= x);
-            return result; 
+            return result;
         }
     };
-    
+
     struct Upper :public CGAL::cpp98::unary_function<Interval,Bound>{
-        Bound operator() ( Interval x ) const {     
+        Bound operator() ( Interval x ) const {
             CORE::BigFloat result = ::CORE::BigFloat(x.m()+x.err(),0,x.exp());
             CGAL_postcondition(result >= x);
-            return result; 
+            return result;
         }
     };
 
     struct Width :public CGAL::cpp98::unary_function<Interval,Bound>{
-         
-        Bound operator() ( Interval x ) const {    
+
+        Bound operator() ( Interval x ) const {
             unsigned long err = 2*x.err();
             return Bound(CORE::BigInt(err),0,x.exp());
         }
     };
 
     struct Median :public CGAL::cpp98::unary_function<Interval,Bound>{
-         
-        Bound operator() ( Interval x ) const {   
+
+        Bound operator() ( Interval x ) const {
             return Bound(x.m(),0,x.exp());
         }
     };
@@ -83,38 +73,38 @@ public:
           return max BOOST_PREVENT_MACRO_SUBSTITUTION (Upper()(x).abs(),Lower()(x).abs());
         }
     };
-    
+
     struct Zero_in :public CGAL::cpp98::unary_function<Interval,bool>{
-        bool operator() ( Interval x ) const {      
-            return x.isZeroIn(); 
+        bool operator() ( Interval x ) const {
+            return x.isZeroIn();
         }
     };
 
     struct In :public CGAL::cpp98::binary_function<Bound,Interval,bool>{
-        bool operator()( Bound x, const Interval& a ) const {    
+        bool operator()( Bound x, const Interval& a ) const {
             CGAL_precondition(CGAL::singleton(x));
             return (Lower()(a) <= x && x <= Upper()(a));
         }
     };
 
     struct Equal :public CGAL::cpp98::binary_function<Interval,Interval,bool>{
-        bool operator()( const Interval& a, const Interval& b ) const { 
+        bool operator()( const Interval& a, const Interval& b ) const {
             return (Upper()(a) == Upper()(b) &&  Lower()(a) == Lower()(b));
         }
     };
-    
+
     struct Subset :public CGAL::cpp98::binary_function<Interval,Interval,bool>{
-        bool operator()( const Interval& a, const Interval& b ) const {   
+        bool operator()( const Interval& a, const Interval& b ) const {
             return Lower()(b) <= Lower()(a) && Upper()(a) <= Upper()(b);
         }
     };
-    
+
     struct Proper_subset :public CGAL::cpp98::binary_function<Interval,Interval,bool>{
-        bool operator()( const Interval& a, const Interval& b ) const { 
+        bool operator()( const Interval& a, const Interval& b ) const {
             return Subset()(a,b) && (!Equal()(a,b));
         }
     };
-    
+
     struct Intersection :public CGAL::cpp98::binary_function<Interval,Interval,Interval>{
       Interval operator()( const Interval& a, const Interval& b ) const {
             BOOST_USING_STD_MAX();
@@ -127,21 +117,21 @@ public:
             return Construct()(l,u);
         }
     };
- 
+
 
     struct Overlap :public CGAL::cpp98::binary_function<Interval,Interval,bool>{
-        bool operator() ( Interval x, Interval y ) const {       
+        bool operator() ( Interval x, Interval y ) const {
             Self::Zero_in Zero_in;
             bool result = Zero_in(x-y);
             return result;
         }
     };
-   
+
     struct Hull :public CGAL::cpp98::binary_function<Interval,Interval,Interval>{
 
       // for debugging
 /*      void print_bf(CORE::BigFloat bf, std::string s) const {
-        
+
         std::cout << s << ".m()=" << bf.m() << ","
                   << s << ".err()=" << bf.err() << ","
                   << s << ".exp()=" << bf.exp() << ","
@@ -155,50 +145,50 @@ public:
 #if 0
             // this is not possible since CORE::centerize has a bug.
             Interval result = CORE::centerize(x,y);
-#else 
+#else
 
             //print_bf(x,"x");
             //print_bf(y,"y");
-            
+
              CORE::BigFloat result;
-             
-            // Unfortunately, CORE::centerize(x,y) has bugs. 
-            if ((x.m() == y.m()) && (x.err() == y.err()) && (x.exp() == y.exp())) { 
+
+            // Unfortunately, CORE::centerize(x,y) has bugs.
+            if ((x.m() == y.m()) && (x.err() == y.err()) && (x.exp() == y.exp())) {
                 return x;
             }
-                         
+
             CORE::BigFloat lower = min BOOST_PREVENT_MACRO_SUBSTITUTION (CGAL::lower(x), CGAL::lower(y));
             CORE::BigFloat upper = max BOOST_PREVENT_MACRO_SUBSTITUTION (CGAL::upper(x), CGAL::upper(y));
 
             CORE::BigFloat mid = (lower + upper)/2;
-             
+
             //print_bf(lower,"lower");
             //print_bf(upper,"upper");
             //print_bf(mid,"mid");
 
             // Now we have to compute the error. The problem is that .err() is just a long
             CORE::BigFloat err = (upper - lower)/CORE::BigFloat(2);
-                   
+
             //print_bf(err,"err");
 
             //std::cout << "lower    " << lower << std::endl;
             //std::cout << "upper    " << upper << std::endl;
             //std::cout << "mid      " << mid << std::endl;
             //std::cout << "err I    " << err << std::endl;
-            
-            // shift such that err.m()+err.err() fits into long 
+
+            // shift such that err.m()+err.err() fits into long
             int digits_long = std::numeric_limits<long>::digits;
             if(::CORE::bitLength(err.m()+err.err()) >= digits_long){
-                long shift = ::CORE::bitLength(err.m()) - digits_long + 1 ; 
+                long shift = ::CORE::bitLength(err.m()) - digits_long + 1 ;
                 //std::cout << "shift " << shift<< std::endl;
-                long new_err = ((err.m()+err.err()) >> shift).longValue()+1; 
+                long new_err = ((err.m()+err.err()) >> shift).longValue()+1;
                 err = CORE::BigFloat(0,new_err,0) * CORE::BigFloat::exp2(err.exp()*CORE::CHUNK_BIT+shift);
-            }else{           
+            }else{
                 err = CORE::BigFloat(0,err.m().longValue()+err.err(),err.exp());
             }
             //print_bf(err,"new_err");
 
-            // TODO: This is a workaround for a bug in operator+ 
+            // TODO: This is a workaround for a bug in operator+
             // of CORE::Bigfloat. If the exponent difference is too big,
             // this might cause problems, since the error is a long
             if(mid.exp() > err.exp()) {
@@ -209,109 +199,109 @@ public:
                 mid = CORE::BigFloat(mid_m,mid_err,err.exp());
                 //print_bf(mid,"corr_mid");
             }
-            
-            //print_bf(result,"result");        
 
-            result = mid + err;  
-             
-#endif 
+            //print_bf(result,"result");
 
-            CGAL_postcondition( 
-                    CGAL::lower(result) 
+            result = mid + err;
+
+#endif
+
+            CGAL_postcondition(
+                    CGAL::lower(result)
                     <=  min BOOST_PREVENT_MACRO_SUBSTITUTION (CGAL::lower(x), CGAL::lower(y)));
-            CGAL_postcondition( 
-                    CGAL::upper(result) 
+            CGAL_postcondition(
+                    CGAL::upper(result)
                     >= max BOOST_PREVENT_MACRO_SUBSTITUTION (CGAL::upper(x), CGAL::upper(y)));
 
-            
+
 
             return result ;
         }
     };
 
     struct Singleton :public CGAL::cpp98::unary_function<Interval,bool> {
-        bool operator() ( Interval x ) const {       
-            return (x.err() == 0); 
+        bool operator() ( Interval x ) const {
+            return (x.err() == 0);
         }
     };
 
     struct Construct :public CGAL::cpp98::binary_function<Bound,Bound,Interval>{
         Interval operator()( const Bound& l,const Bound& r) const {
-            CGAL_precondition( l < r ); 
+            CGAL_precondition( l < r );
             return Hull()(l,r);
         }
     };
 };
 
 
-// ########### Bigfloat_interval_traits 
+// ########### Bigfloat_interval_traits
 
 
 // template<typename BFI> long relative_precision(BFI bfi);
 namespace internal{
 
-CORE::BigFloat 
-inline 
+CORE::BigFloat
+inline
 round(const CORE::BigFloat& x, long rel_prec = CORE::get_static_defRelPrec().toLong() ){
-    CGAL_postcondition(rel_prec >= 0);   
+    CGAL_postcondition(rel_prec >= 0);
 
     // since there is not rel prec defined if Zero_in(x)
-    if (x.isZeroIn()) return x; 
+    if (x.isZeroIn()) return x;
     // if (CGAL::get_significant_bits(x) <= rel_prec) return x;
-   
-// if 1 
+
+// if 1
 //    CORE::BigFloat xr;
 //    xr.approx(x,rel_prec,1024);
-//    typedef CORE::BigFloat BF; 
-// else       
-    typedef CORE::BigFloat BF; 
+//    typedef CORE::BigFloat BF;
+// else
+    typedef CORE::BigFloat BF;
     BF xr;
-   
+
     CORE::BigInt m = x.m();
     long         err = x.err();
-    long         exp = x.exp(); 
-   
+    long         exp = x.exp();
 
-//    std::cout <<"(" << m << "+-" <<err << ")*2^"<<(CORE::CHUNK_BIT*exp) << std::endl; 
-//    if (err != 0) 
+
+//    std::cout <<"(" << m << "+-" <<err << ")*2^"<<(CORE::CHUNK_BIT*exp) << std::endl;
+//    if (err != 0)
 //      std::cout <<"current prec: " <<  CGAL::relative_precision(x) << std::endl;
-//    else 
+//    else
 //      std::cout <<"current prec: " << " SINGLETON " << std::endl;
-//    std::cout <<"desired prec: " << rel_prec << std::endl; 
-//    std::cout <<"bitLength: " << CORE::bitLength(m) << std::endl; 
+//    std::cout <<"desired prec: " << rel_prec << std::endl;
+//    std::cout <<"bitLength: " << CORE::bitLength(m) << std::endl;
 //    long shift = ::CORE::bitLength(m) - rel_prec - 1;
-   
+
     long shift ;
     if (err == 0)
       shift = ::CORE::bitLength(m) - rel_prec - 3;
-    else      
-      shift = CGAL::relative_precision(x) - rel_prec -1; 
-    
-    if( shift > 0 ){    
-      m   >>= shift ; 
-      err >>= shift; 
-      xr = BF(m,err+1,0)*BF::exp2(exp*CORE::CHUNK_BIT+shift);     
+    else
+      shift = CGAL::relative_precision(x) - rel_prec -1;
+
+    if( shift > 0 ){
+      m   >>= shift ;
+      err >>= shift;
+      xr = BF(m,err+1,0)*BF::exp2(exp*CORE::CHUNK_BIT+shift);
     }else{    // noting to do
-        xr = x; 
+        xr = x;
     }
 
-//    std::cout <<"(" <<m << "+-" <<err+1 << ")*2^"<<(CORE::CHUNK_BIT*exp) << std::endl; 
-//    if (xr.err() != 0) 
+//    std::cout <<"(" <<m << "+-" <<err+1 << ")*2^"<<(CORE::CHUNK_BIT*exp) << std::endl;
+//    if (xr.err() != 0)
 //      std::cout <<"current prec: " <<  CGAL::relative_precision(xr) << std::endl;
-//    else 
+//    else
 //      std::cout <<"current prec: " << " SINGLETON "<< std::endl;
-//    std::cout <<"desired prec: " << rel_prec << std::endl; 
-    
-// endif     
-    CGAL_postcondition(singleton(xr) || CGAL::relative_precision(xr) - rel_prec >= 0); 
-    CGAL_postcondition(singleton(xr) || CGAL::relative_precision(xr) - rel_prec <= 32);   
+//    std::cout <<"desired prec: " << rel_prec << std::endl;
+
+// endif
+    CGAL_postcondition(singleton(xr) || CGAL::relative_precision(xr) - rel_prec >= 0);
+    CGAL_postcondition(singleton(xr) || CGAL::relative_precision(xr) - rel_prec <= 32);
     CGAL_postcondition(BF(xr.m()-xr.err(),0,xr.exp()) <= BF(x.m()-x.err(),0,x.exp()));
     CGAL_postcondition(BF(xr.m()+xr.err(),0,xr.exp()) >= BF(x.m()+x.err(),0,x.exp()));
-    return xr;     
+    return xr;
 }
 }
 
-template<> class Bigfloat_interval_traits<CORE::BigFloat> 
+template<> class Bigfloat_interval_traits<CORE::BigFloat>
 :public Interval_traits<CORE::BigFloat>
 {
 
@@ -319,45 +309,45 @@ template<> class Bigfloat_interval_traits<CORE::BigFloat>
     typedef CORE::BigFloat BF;
 public:
   typedef Bigfloat_interval_traits<NT> Self;
-  
+
    struct Relative_precision {
         // type for the \c AdaptableUnaryFunction concept.
         typedef NT  argument_type;
         // type for the \c AdaptableUnaryFunction concept.
         typedef long  result_type;
 
-        long operator()( NT x) const { 
+        long operator()( NT x) const {
           CGAL_precondition(!Singleton()(x));
           CGAL_precondition(!CGAL::zero_in(x));
-          
+
           x = x.abs();
           NT w = Width()(x);
-          w /= ::CORE::BigFloat(x.m()-x.err(),0,x.exp());    
+          w /= ::CORE::BigFloat(x.m()-x.err(),0,x.exp());
           w = w.abs();
           return -(CORE::ceilLg(w.m()+w.err())+w.exp()*CORE::CHUNK_BIT);
         }
     };
-       
+
     struct Set_precision {
         // type for the \c AdaptableUnaryFunction concept.
         typedef long  argument_type;
         // type for the \c AdaptableUnaryFunction concept.
-        typedef long  result_type;  
-     
-        long operator() ( long prec ) const {    
+        typedef long  result_type;
+
+        long operator() ( long prec ) const {
             long result =  ::CORE::get_static_defRelPrec().toLong();
-            ::CORE::get_static_defRelPrec() = prec; 
+            ::CORE::get_static_defRelPrec() = prec;
             ::CORE::get_static_defBFdivRelPrec() = prec;
-            return result; 
+            return result;
         }
     };
-     
+
     struct Get_precision {
         // type for the \c AdaptableGenerator concept.
-        typedef long  result_type;  
-     
+        typedef long  result_type;
+
         long operator() () const {
-            return  ::CORE::get_static_defRelPrec().toLong(); 
+            return  ::CORE::get_static_defRelPrec().toLong();
         }
     };
 };
@@ -379,24 +369,24 @@ template <> class Algebraic_structure_traits< CORE::BigFloat >
       : public CGAL::cpp98::unary_function< Type, Type > {
       public:
         Type operator()( const Type& x ) const {
-            // What I want is a sqrt computed with 
+            // What I want is a sqrt computed with
             // ::CORE::get_static_defRelPrec() bits.
-            // And not ::CORE::defBFsqrtAbsPrec as CORE does. 
-            
+            // And not ::CORE::defBFsqrtAbsPrec as CORE does.
+
             CGAL_precondition(::CORE::get_static_defRelPrec().toLong() > 0);
             CGAL_precondition(x > 0);
-            
+
             Type a = CGAL::internal::round(
               x, ::CORE::get_static_defRelPrec().toLong()*2);
-            CGAL_postcondition(a > 0); 
+            CGAL_postcondition(a > 0);
 
             Type tmp1 = CORE::BigFloat(
                 a.m(),0,0).sqrt(::CORE::get_static_defRelPrec().toLong());
-            Type err  =  
-                Type(0,long(std::sqrt(double(a.err()))),0) 
+            Type err  =
+                Type(0,long(std::sqrt(double(a.err()))),0)
                 * CORE::BigFloat::exp2(a.exp()*7);
             Type result = tmp1*CORE::BigFloat::exp2(a.exp()*7) + err;
-           
+
             CGAL_postcondition(result >= 0);
             CGAL_postcondition(CGAL::lower(result*result) <= CGAL::lower(x));
             CGAL_postcondition(CGAL::upper(result*result) >= CGAL::upper(x));
@@ -432,31 +422,31 @@ template <> class Real_embeddable_traits< CORE::BigFloat >
       : public CGAL::cpp98::unary_function< Type, Type > {
       public:
         Type operator()( const Type& x ) const {
-            Type result; 
-          
+            Type result;
+
             if(x.isZeroIn()){
-                CORE::BigInt m; 
+                CORE::BigInt m;
                 if(x.m() < 0 ){
                     m = -(x.m()-x.err());
                 }else{
                     m =  x.m()+x.err();
                 }
                 if(m % 2 == 1) m += 1;
-                
+
                 Type upper(m,0,x.exp());
                 result = CORE::centerize(CORE::BigFloat(0),upper);
-                
-                CGAL_postcondition(result.m()-result.err() <= 0); 
+
+                CGAL_postcondition(result.m()-result.err() <= 0);
                 if(result.m()-result.err() != 0){
                     result = this->operator()(result);
                 }
-                CGAL_postcondition(result.m()-result.err() == 0); 
+                CGAL_postcondition(result.m()-result.err() == 0);
             }else{
                 result = CORE::abs(x);
             }
-            CGAL_postcondition(result.m()-result.err() >= 0); 
-            CGAL_postcondition(Type(result.m()+result.err(),0,result.exp()) 
-                         >= Type(x.m()+x.err(),0,x.exp()));       
+            CGAL_postcondition(result.m()-result.err() >= 0);
+            CGAL_postcondition(Type(result.m()+result.err(),0,result.exp())
+                         >= Type(x.m()+x.err(),0,x.exp()));
             return result;
         }
     };
@@ -466,7 +456,7 @@ template <> class Real_embeddable_traits< CORE::BigFloat >
       public:
         ::CGAL::Sign operator()( const Type& x ) const {
             ::CGAL::Sign result =  sign( x.sign());
-            return result; 
+            return result;
         }
     };
 
@@ -478,7 +468,7 @@ template <> class Real_embeddable_traits< CORE::BigFloat >
                                             const Type& y ) const {
           return (Comparison_result) sign( (x-y).sign());
         }
-        CGAL_IMPLICIT_INTEROPERABLE_BINARY_OPERATOR_WITH_RT( Type, 
+        CGAL_IMPLICIT_INTEROPERABLE_BINARY_OPERATOR_WITH_RT( Type,
                 Comparison_result )
     };
 
@@ -496,22 +486,22 @@ template <> class Real_embeddable_traits< CORE::BigFloat >
       : public CGAL::cpp98::unary_function< Type, std::pair< double, double > > {
     public:
         std::pair<double, double> operator()( const Type& x ) const {
-                        
+
             double lb,ub;
-           
+
             Type x_lower = CGAL::lower(CGAL::internal::round(CGAL::lower(x),50));
             Type x_upper = CGAL::upper(CGAL::internal::round(CGAL::upper(x),50));
-            
-            // since matissa has 50 bits only, conversion to double is exact 
+
+            // since matissa has 50 bits only, conversion to double is exact
             lb = x_lower.doubleValue();
             CGAL_postcondition(lb == x_lower);
             ub = x_upper.doubleValue();
-            CGAL_postcondition(ub == x_upper);             
-            
+            CGAL_postcondition(ub == x_upper);
+
             std::pair<double, double> result(lb,ub);
             CGAL_postcondition( result.first  <=  CORE::Expr(CGAL::lower(x)));
             CGAL_postcondition( result.second >=  CORE::Expr(CGAL::upper(x)));
-            return result;      
+            return result;
         }
     };
 };
@@ -522,7 +512,6 @@ template <> class Real_embeddable_traits< CORE::BigFloat >
 #include <CGAL/CORE_Expr.h>
 #include <CGAL/CORE_BigInt.h>
 #include <CGAL/CORE_BigRat.h>
-#include <CGAL/CORE_BigFloat.h>
 #include <CGAL/CORE_arithmetic_kernel.h>
 
 namespace Eigen {
