@@ -1,25 +1,16 @@
-// Copyright (c) 2000,2001  
+// Copyright (c) 2000,2001
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Cartesian_kernel/include/CGAL/Cartesian/ConicCPA2.h $
+// $Id: ConicCPA2.h fdb17cb 2020-03-26T19:26:10+01:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Cartesian_kernel/include/CGAL/Cartesian/ConicCPA2.h $
-// $Id: ConicCPA2.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Bernd Gaertner, Sven Schoenherr <sven@inf.ethz.ch>
 
@@ -57,8 +48,8 @@ class ConicCPA2
     Conic_type          type;
     CGAL::Orientation   o;
     bool                empty, trivial, degenerate;
-    
-    
+
+
     void
     set_linear_combination (const FT& a1, const ConicCPA2<PT,DA>& c1,
                             const FT& a2, const ConicCPA2<PT,DA>& c2)
@@ -70,7 +61,7 @@ class ConicCPA2
         _v = a1 * c1.v() + a2 * c2.v();
         _w = a1 * c1.w() + a2 * c2.w();
     }
-    
+
     static void set_two_linepairs (const PT& p1,
                                    const PT& p2,
                                    const PT& p3,
@@ -84,7 +75,7 @@ class ConicCPA2
         da.get (p2, x2, y2);
         da.get (p3, x3, y3);
         da.get (p4, x4, y4);
-    
+
         CGAL::Orientation side1_24 = (CGAL::Orientation)(CGAL_NTS sign
                                        (-x1*y4+x2*y4
                                         +x4*y1-x2*y1
@@ -113,7 +104,7 @@ class ConicCPA2
             }
         }
     }
-    
+
     void set_ellipse (const ConicCPA2<PT,DA>& pair1,
                       const ConicCPA2<PT,DA>& pair2)
     {
@@ -122,14 +113,14 @@ class ConicCPA2
         set_linear_combination (pair2.det()-b, pair1,
                                 pair1.det()-b, pair2);
     }
-    
+
     void set (const ConicCPA2<PT,DA>& c1,
               const ConicCPA2<PT,DA>& c2,
               const PT& p)
     {
         set_linear_combination (c2.evaluate(p), c1, -c1.evaluate(p), c2);
     }
-    
+
     CGAL::Sign vol_derivative (FT dr, FT ds, FT dt,
                               FT du, FT dv, FT dw) const
     {
@@ -142,10 +133,10 @@ class ConicCPA2
            b0 = (FT(4)*r()*s()-t()*t())*w()
           -u()*u()*s()-v()*v()*r()+u()*v()*t(),
            c0 = -FT(2)*a0*b1 + FT(3)*a1*b0;
-    
+
         return CGAL_NTS sign ((int)-CGAL_NTS sign (c0)*o);
     }
-    
+
     double vol_minimum (FT dr, FT ds, FT dt, FT du, FT dv, FT dw) const
     {
         FT a2 = FT(4)*dr*ds-dt*dt,
@@ -165,7 +156,7 @@ class ConicCPA2
            c2 = -FT(6)*a0*b3 - a1*b2 + FT(4)*a2*b1,
            c1 = -FT(4)*a0*b2 + a1*b1 + FT(6)*a2*b0,
            c0 = -FT(2)*a0*b1 + FT(3)*a1*b0;
-    
+
            double roots[3];
            int nr_roots = solve_cubic
                                 (CGAL::to_double(c3), CGAL::to_double(c2),
@@ -178,15 +169,15 @@ class ConicCPA2
                                  CGAL::to_double(b2), CGAL::to_double(b1),
                                  CGAL::to_double(b0));
     }
-    
-    
+
+
 
   protected:
     FT det () const
     {
         return FT(4)*s()*r() - t()*t();
     }
-    
+
     void analyse( )
     {
         FT d = det();
@@ -198,8 +189,8 @@ class ConicCPA2
                 FT z_prime = d*w() - u()*u()*s() - v()*v()*r() + u()*v()*t();
                 o = (CGAL::Orientation)(CGAL_NTS sign (z_prime));
                 degenerate = (o == CGAL::ZERO);
-                
-                
+
+
             }
             break;
         case PARABOLA:
@@ -265,8 +256,8 @@ class ConicCPA2
                     else
                         o = CGAL::ZERO;
                 }
-                
-                
+
+
             }
             break;
         case ELLIPSE:
@@ -281,72 +272,69 @@ class ConicCPA2
                     empty ? o = CGAL::NEGATIVE : o = CGAL::POSITIVE;
                 }
                 degenerate = empty || CGAL_NTS is_zero (z_prime);
-                
-                
+
+
             }
             break;
         }
     }
-    
+
     FT evaluate (const PT& p) const
     {
         FT x, y;
         dao.get (p, x, y);
         return r()*x*x + s()*y*y + t()*x*y + u()*x + v()*y + w();
     }
-    
-    
+
+
 
   public:
     ConicCPA2 ( const DA& da = DA()) : dao( da) { }
-    
+
     ConicCPA2 (FT r, FT s, FT t, FT u, FT v, FT w, const DA& da = DA())
         : dao( da), _r(r), _s(s), _t(t), _u(u), _v(v), _w(w)
     {
         analyse();
     }
-    
+
     const DA&  da() const
     {
         return dao;
     }
-    
+
     FT r() const { return _r;}
     FT s() const { return _s;}
     FT t() const { return _t;}
     FT u() const { return _u;}
     FT v() const { return _v;}
     FT w() const { return _w;}
-    
+
     PT center () const
     {
         CGAL_kernel_precondition (type != PARABOLA);
-	// PT p;
-	// replaced previous line by following hack (no idea
-	// why original version doesn't work)
-        typename DA::Point p;
-        FT two = FT(2);
-        FT div = -det();
-        dao.set( p, (two*s()*u() - t()*v()) / div,
-                    (two*r()*v() - t()*u()) / div);
-        return p;
+
+        const FT two = FT(2);
+        const FT div = -det();
+
+        return PT((two*s()*u() - t()*v()) / div,
+                  (two*r()*v() - t()*u()) / div);
     }
-    
+
     Conic_type conic_type () const
     {
         return type;
     }
-    
+
     bool is_hyperbola () const
     {
         return (type == HYPERBOLA);
     }
-    
+
     bool is_parabola () const
     {
         return (type == PARABOLA);
     }
-    
+
     bool is_ellipse () const
     {
         return (type == ELLIPSE);
@@ -356,53 +344,53 @@ class ConicCPA2
     {
         return (type == ELLIPSE && (r()==s()) && CGAL_NTS is_zero (t()));
     }
-    
+
     bool is_empty () const
     {
         return empty;
     }
-    
+
     bool is_trivial () const
     {
         return trivial;
     }
-    
+
     bool is_degenerate () const
     {
         return degenerate;
     }
-    
+
     CGAL::Orientation orientation () const
     {
         return o;
     }
-    
+
     CGAL::Oriented_side oriented_side (const PT& p) const
     {
         return (CGAL::Oriented_side)(CGAL_NTS sign (evaluate (p)));
     }
-    
+
     bool has_on_positive_side (const PT& p) const
     {
         return (CGAL_NTS is_positive (evaluate(p)));
     }
-    
+
     bool has_on_negative_side (const PT& p) const
     {
         return (CGAL_NTS is_negative (evaluate(p)));
     }
-    
+
     bool has_on_boundary (const PT& p) const
     {
        return (CGAL_NTS is_zero (evaluate(p)));
     }
-    
+
     bool has_on (const PT& p) const
     {
        return (CGAL_NTS is_zero (evaluate(p)));
     }
-    
-    
+
+
     Convex_side convex_side (const PT& p) const
     {
         switch (o) {
@@ -416,17 +404,17 @@ class ConicCPA2
         // keeps g++ happy
         return( Convex_side( 0));
     }
-    
+
     bool has_on_convex_side (const PT& p) const
     {
         return (convex_side (p) == ON_CONVEX_SIDE);
     }
-    
+
     bool has_on_nonconvex_side (const PT& p) const
     {
         return (convex_side (p) == ON_NONCONVEX_SIDE);
     }
-    
+
     bool operator == ( const ConicCPA2<_PT,_DA>& c) const
     {
         // find coefficient != 0
@@ -438,7 +426,7 @@ class ConicCPA2
         if ( ! CGAL_NTS is_zero( v())) factor1 = v(); else
         if ( ! CGAL_NTS is_zero( w())) factor1 = w(); else
         CGAL_kernel_assertion_msg( false, "all coefficients zero");
-    
+
         // find coefficient != 0
         FT  factor2(0);
         if ( ! CGAL_NTS is_zero( c.r())) factor2 = c.r(); else
@@ -448,7 +436,7 @@ class ConicCPA2
         if ( ! CGAL_NTS is_zero( c.v())) factor2 = c.v(); else
         if ( ! CGAL_NTS is_zero( c.w())) factor2 = c.w(); else
         CGAL_kernel_assertion_msg( false, "all coefficients zero");
-    
+
         return(    ( r()*factor2 == c.r()*factor1)
                 && ( s()*factor2 == c.s()*factor1)
                 && ( t()*factor2 == c.t()*factor1)
@@ -456,27 +444,27 @@ class ConicCPA2
                 && ( v()*factor2 == c.v()*factor1)
                 && ( w()*factor2 == c.w()*factor1));
     }
-    
+
     void set (FT r_, FT s_, FT t_, FT u_, FT v_, FT w_)
     {
         _r = r_; _s = s_; _t = t_; _u = u_; _v = v_; _w = w_;
         analyse();
      }
-    
+
     void set_opposite ()
     {
         _r = -r(); _s = -s(); _t = -t(); _u = -u(); _v = -v(); _w = -w();
         o = CGAL::opposite(orientation());
     }
-    
-  void set_circle (const PT& p1, const PT& p2, const PT& p3) 
+
+  void set_circle (const PT& p1, const PT& p2, const PT& p3)
   {
      // the circle will have r = s = det, t=0
      FT x1, y1, x2, y2, x3, y3;
      dao.get (p1, x1, y1);
      dao.get (p2, x2, y2);
      dao.get (p3, x3, y3);
-    
+
      // precondition: p1, p2, p3 not collinear
      FT det = -x3*y2+x1*y2+x2*y3-x1*y3+x3*y1-x2*y1;
      CGAL_kernel_precondition (!CGAL_NTS is_zero (det));
@@ -492,7 +480,7 @@ class ConicCPA2
      _r = det;
      _s = det;
      _t = FT(0);
-     
+
      analyse();
      CGAL_kernel_postcondition(is_circle());
      CGAL_kernel_postcondition(has_on_boundary(p1));
@@ -507,76 +495,76 @@ class ConicCPA2
         dao.get (p2, x2, y2);
         dao.get (p3, x3, y3);
         dao.get (p4, x4, y4);
-    
+
         // precondition: p1 != p2, p3 != p4
         CGAL_kernel_precondition
             ( ((x1 != x2) || (y1 != y2)) &&
               ((x3 != x4) || (y3 != y4)) );
-    
+
         FT x2_x1 = x2-x1;
         FT x4_x3 = x4-x3;
         FT y1_y2 = y1-y2;
         FT y3_y4 = y3-y4;
         FT x1y2_y1x2 = x1*y2-y1*x2;
         FT x3y4_y3x4 = x3*y4-y3*x4;
-    
+
         _r = y1_y2 * y3_y4;
         _s = x2_x1 * x4_x3;
         _t = x2_x1 * y3_y4 + y1_y2 * x4_x3;
         _u = x1y2_y1x2 * y3_y4 + y1_y2 * x3y4_y3x4;
         _v = x1y2_y1x2 * x4_x3 + x2_x1 * x3y4_y3x4;
         _w = x1y2_y1x2 * x3y4_y3x4;
-    
+
         analyse();
     }
-    
+
     void set_ellipse (const PT& p1, const PT& p2, const PT& p3)
     {
         FT x1, y1, x2, y2, x3, y3;
         dao.get (p1, x1, y1);
         dao.get (p2, x2, y2);
         dao.get (p3, x3, y3);
-    
+
         // precondition: p1, p2, p3 not collinear
         FT det = -x3*y2+x1*y2+x2*y3-x1*y3+x3*y1-x2*y1;
         CGAL_kernel_precondition (!CGAL_NTS is_zero (det));
-    
+
         FT x1x1 = x1*x1, y1y1 = y1*y1,
            x2x2 = x2*x2, y2y2 = y2*y2,
            x3x3 = x3*x3, y3y3 = y3*y3,  // x_i^2, y_i^2
            two = FT(2);
-    
+
         _r = y1y1 - y1*y2 - y1*y3 +
              y2y2 - y2*y3 + y3y3;
-    
+
         _s = x1x1 - x1*x2 - x1*x3 +
              x2x2 - x2*x3 + x3x3;
-    
+
         _t = -two*x1*y1 + x1*y2 + x1*y3 +
                  y1*x2 -two*x2*y2 + x2*y3 +
                  y1*x3 + y2*x3 -two*x3*y3;
-    
+
         _u = -(y2y2*x3 - x2*y2*y3 - y2*x3*y3 +
                    x1*y3y3 + x2*y3y3 + y1y1*x2 +
                    y1y1*x3 - x1*y1*y2 - y1*x2*y2 -
                    x1*y1*y3 - y1*x3*y3 + x1*y2y2);
-    
+
         _v = -(x2x2*y3 - x2*y2*x3 - x2*x3*y3 +
                    y1*x3x3 + y2*x3x3 + x1x1*y2 +
                    x1x1*y3 - x1*y1*x2 - x1*x2*y2 -
                    x1*y1*x3 - x1*x3*y3 + y1*x2x2);
-    
+
         _w = y1y1*x2*x3 - x1*y1*y2*x3 - y1*x2*y2*x3 +
              y1*y2*x3x3 - x1*y1*x2*y3 + y1*x2x2*y3 -
              y1*x2*x3*y3 + x1*y2y2*x3 + x1x1*y2*y3 -
              x1*x2*y2*y3 - x1*y2*x3*y3 + x1*x2*y3y3;
-    
+
         type = ELLIPSE;
         degenerate = trivial = empty = false;
         o = CGAL::NEGATIVE;
         if (CGAL_NTS is_positive (det)) set_opposite();
     }
-    
+
     void set_ellipse (const PT& p1, const PT& p2,
                       const PT& p3, const PT& p4,
                       CGAL::Orientation _o = POSITIVE)
@@ -587,7 +575,7 @@ class ConicCPA2
         analyse();
         if (o != _o) set_opposite();
     }
-    
+
     void set (const PT& p1, const PT& p2, const PT& p3, const PT& p4,
               const PT& p5, CGAL::Orientation _o = POSITIVE)
     {
@@ -600,8 +588,8 @@ class ConicCPA2
         CGAL_kernel_precondition (!is_trivial());
         if (o != _o) set_opposite();
     }
-    
-    
+
+
 
  };
 
