@@ -1,25 +1,16 @@
-// Copyright (c) 2000  
+// Copyright (c) 2000
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Cartesian_kernel/include/CGAL/Cartesian/Scaling_rep_3.h $
+// $Id: Scaling_rep_3.h e73b8de 2021-04-22T21:17:24+01:00 Andreas Fabri
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Cartesian_kernel/include/CGAL/Cartesian/Scaling_rep_3.h $
-// $Id: Scaling_rep_3.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Herve Bronnimann
 
@@ -43,8 +34,9 @@ public:
   typedef typename Transformation_base_3::Point_3       Point_3;
   typedef typename Transformation_base_3::Vector_3      Vector_3;
   typedef typename Transformation_base_3::Direction_3   Direction_3;
+  typedef typename Transformation_base_3::Plane_3       Plane_3;
   typedef typename Transformation_base_3::Aff_transformation_3
-	                                                Aff_transformation_3;
+                                                        Aff_transformation_3;
 
   Scaling_repC3() {}
   Scaling_repC3(const FT &s) : scalefactor_(s) {}
@@ -68,6 +60,12 @@ public:
     return d;
   }
 
+  virtual Plane_3  transform(const Plane_3 &p) const
+  {
+    // direction ( which is (p.a(), p.b(), p.c())) does not change
+    return Plane_3(p.a(),p.b(),p.c(), p.d()*scalefactor_);
+  }
+
   virtual Aff_transformation_3 operator*(const Transformation_base_3 &t) const
   {
     return t.compose(*this);
@@ -79,12 +77,12 @@ public:
                                 scalefactor_ * t.t12,
                                 scalefactor_ * t.t13,
                                 t.t14,
-				
+
                                 scalefactor_ * t.t21,
                                 scalefactor_ * t.t22,
                                 scalefactor_ * t.t23,
                                 t.t24,
-				
+
                                 scalefactor_ * t.t31,
                                 scalefactor_ * t.t32,
                                 scalefactor_ * t.t33,
@@ -97,17 +95,17 @@ public:
     return Aff_transformation_3(scalefactor_,
                                 ft0,
                                 ft0,
-				t.translationvector_.x(),
-				
+                                t.translationvector_.x(),
+
                                 ft0,
-				scalefactor_,
+                                scalefactor_,
                                 ft0,
-				t.translationvector_.y(),
-				
+                                t.translationvector_.y(),
+
                                 ft0,
                                 ft0,
-				scalefactor_,
-				t.translationvector_.z());
+                                scalefactor_,
+                                t.translationvector_.z());
   }
 
   virtual Aff_transformation_3 compose(const Scaling_3 &t) const
@@ -130,6 +128,11 @@ public:
     return true;
   }
 
+  virtual bool is_scaling() const
+  {
+    return true;
+  }
+
   virtual FT cartesian(int i, int j) const
   {
     if (i!=j) return FT(0);
