@@ -1,25 +1,16 @@
-// Copyright (c) 2000,2001  
+// Copyright (c) 2000,2001
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Kernel_d/include/CGAL/Cartesian_d.h $
+// $Id: Cartesian_d.h 18ff1d4 2022-11-24T11:39:50+01:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Kernel_d/include/CGAL/Cartesian_d.h $
-// $Id: Cartesian_d.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Michael Seel
 
@@ -30,7 +21,7 @@
 #include <CGAL/representation_tags.h>
 #include <CGAL/Kernel_d/function_objects.h>
 #include <CGAL/Linear_algebraCd.h>
-#include <vector>
+#include <CGAL/Kernel/Same_uncertainty.h>
 
 #include <CGAL/Kernel_d/Kernel_classesCd.h>
 #include <CGAL/Kernel_d/PointCd.h>
@@ -65,7 +56,7 @@ public:
   enum { Has_filtered_predicates = false };
   typedef Boolean_tag<Has_filtered_predicates> Has_filtered_predicates_tag;
 
-  typedef PointCd2<RT,LA>             Point_d_base; 
+  typedef PointCd2<RT,LA>             Point_d_base;
   // renamed because of clash with Cartesian...
   typedef VectorCd<RT,LA>             Vector_d_base;
   typedef DirectionCd<RT,LA>          Direction_d_base;
@@ -80,7 +71,7 @@ public:
 
   typedef typename Point_d_base::Cartesian_const_iterator Cartesian_const_iterator_d;
 
-    // Boolean   had originally been Bool. It was renamed to avoid a conflict
+    // Boolean had originally been Bool. It was renamed to avoid a conflict
     // between a macro defined in Xlib.h poorly chosen to have the same name,
     // that is 'Bool'.
     typedef typename Same_uncertainty_nt<bool, FT>::type
@@ -112,7 +103,7 @@ public:
 
   template <typename K>
   class Construct_cartesian_const_iterator
-  {    
+  {
     typedef typename K::Point_d Point_d;
     typedef typename K::Cartesian_const_iterator_d  Cartesian_const_iterator_d;
 
@@ -124,7 +115,7 @@ public:
     {
       return p.cartesian_begin();
     }
-    
+
     Cartesian_const_iterator_d
     operator()( const Point_d& p, int) const
     {
@@ -135,7 +126,7 @@ public:
   // TODO: Make it work for the other values
  template <typename K>
   class Construct_vertex
-  {    
+  {
     typedef typename K::Point_d Point_d;
     typedef typename K::Iso_box_d Iso_box_d;
     typedef typename K::Cartesian_const_iterator_d  Cartesian_const_iterator_d;
@@ -145,16 +136,16 @@ public:
     Point_d operator()(const Iso_box_d&  b, int i)
     {
       if(i == 0){
-	return (b.min)();
+        return (b.min)();
       }
       return (b.max)();
     }
   };
-  
+
 
   typedef Construct_vertex<Self> Construct_vertex_d;
 
-    typedef Construct_cartesian_const_iterator<Self> 
+    typedef Construct_cartesian_const_iterator<Self>
                            Construct_cartesian_const_iterator_d;
 
   Construct_cartesian_const_iterator_d
@@ -165,7 +156,7 @@ public:
 
  template <typename K>
   class Construct_min_vertex
-  {    
+  {
     typedef typename K::Point_d Point_d;
     typedef typename K::Iso_box_d Iso_box_d;
   public:
@@ -187,7 +178,7 @@ public:
 
  template <typename K>
   class Construct_max_vertex
-  {    
+  {
     typedef typename K::Point_d Point_d;
     typedef typename K::Iso_box_d Iso_box_d;
   public:
@@ -250,9 +241,9 @@ public:
   Construct_sphere_d construct_sphere_d_object() const
   { return Construct_sphere_d(); }
 
-  typedef internal::Construct<Aff_transformation_d> 
+  typedef internal::Construct<Aff_transformation_d>
     Construct_aff_transformation_d;
-  Construct_aff_transformation_d 
+  Construct_aff_transformation_d
     construct_aff_transformation_d_object() const
   { return Construct_aff_transformation_d(); }
 
@@ -273,14 +264,14 @@ public:
   typedef Contained_in_affine_hullCd<Self> Contained_in_affine_hull_d;
   typedef Affine_rankCd<Self> Affine_rank_d;
   typedef Affinely_independentCd<Self> Affinely_independent_d;
-  typedef Compare_lexicographicallyCd<Self> Compare_lexicographically_d; 
+  typedef Compare_lexicographicallyCd<Self> Compare_lexicographically_d;
   typedef Lt_from_compare<Self> Less_lexicographically_d;
   typedef Le_from_compare<Self> Less_or_equal_lexicographically_d;
   typedef Less_coordinateCd<Self> Less_coordinate_d;
   typedef Point_dimensionCd<Self> Point_dimension_d;
   typedef Eq_from_method<Self> Equal_d;
   typedef Center_of_sphereCd<Self> Center_of_sphere_d;
-  typedef Contained_in_linear_hullCd<Self> Contained_in_linear_hull_d;  
+  typedef Contained_in_linear_hullCd<Self> Contained_in_linear_hull_d;
   typedef Linear_rankCd<Self> Linear_rank_d;
   typedef Linearly_independentCd<Self> Linearly_independent_d;
   typedef Linear_baseCd<Self> Linear_base_d;
@@ -317,7 +308,7 @@ public:
   { return Contained_in_simplex_d(); }
   Contained_in_affine_hull_d contained_in_affine_hull_d_object() const
   { return Contained_in_affine_hull_d(); }
-  Affine_rank_d affine_rank_d_object() const 
+  Affine_rank_d affine_rank_d_object() const
   { return Affine_rank_d(); }
   Affinely_independent_d affinely_independent_d_object() const
   { return Affinely_independent_d(); }
@@ -327,23 +318,23 @@ public:
   { return Compare_lexicographically_d(); }
   Less_lexicographically_d less_lexicographically_d_object() const
   { return Less_lexicographically_d(); }
-  Less_or_equal_lexicographically_d 
+  Less_or_equal_lexicographically_d
     less_or_equal_lexicographically_d_object() const
   { return Less_or_equal_lexicographically_d(); }
   Center_of_sphere_d center_of_sphere_d_object() const
   { return Center_of_sphere_d(); }
   Contained_in_linear_hull_d contained_in_linear_hull_d_object() const
   { return Contained_in_linear_hull_d(); }
-  Linear_rank_d linear_rank_d_object() const 
+  Linear_rank_d linear_rank_d_object() const
   { return Linear_rank_d(); }
   Linearly_independent_d linearly_independent_d_object() const
   { return Linearly_independent_d(); }
-  Linear_base_d linear_base_d_object() const 
+  Linear_base_d linear_base_d_object() const
   { return Linear_base_d(); }
 
   // Intersection objects:
   typedef CGAL::Line_line_intersectionCd<Self> Line_line_intersection_d;
-  typedef CGAL::Line_hyperplane_intersectionCd<Self> 
+  typedef CGAL::Line_hyperplane_intersectionCd<Self>
                                                Line_hyperplane_intersection_d;
   typedef CGAL::Line_d_Line_d_pair<Self> Line_d_Line_d_pair;
   typedef CGAL::Ray_d_Ray_d_pair<Self> Ray_d_Ray_d_pair;
@@ -356,7 +347,7 @@ public:
   typedef CGAL::Segment_d_Hyperplane_d_pair<Self> Segment_d_Hyperplane_d_pair;
 
   typedef internal::Intersect<Self> Intersect_d;
-  Intersect_d intersect_d_object() const 
+  Intersect_d intersect_d_object() const
   { return Intersect_d(); }
 
   typedef internal::Do_intersect<Self> Do_intersect_d;
@@ -367,13 +358,13 @@ public:
 
   static  FT make_FT(const RT & num, const RT& denom)
   { return num/denom; }
-  
+
   static  FT make_FT(const RT & num)
   { return FT(num); }
-  
+
   static  RT FT_numerator(const FT &r)
   { return r; }
-  
+
   static  RT FT_denominator(const FT & /*r*/)
   { return RT(1); }
 
@@ -418,7 +409,7 @@ public:
   };
   Vector_to_point_d vector_to_point_d_object() const
   { return Vector_to_point_d(); }
-  
+
   struct Orthogonal_vector_d {
     Vector_d operator()(const Hyperplane_d& h) const
     { return h.orthogonal_vector(); }
@@ -434,8 +425,8 @@ public:
   { return Point_of_sphere_d(); }
 
 }; // Cartesian_d<R>
- 
- 
+
+
 } //namespace CGAL
 
 #include <CGAL/Kernel_d/Point_d.h>
