@@ -2,24 +2,15 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Circular_kernel_3/include/CGAL/Circular_kernel_3/internal_functions_on_sphere_3.h $
-// $Id: internal_functions_on_sphere_3.h 0d3ac75 2018-02-17T12:37:15+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Circular_kernel_3/include/CGAL/Circular_kernel_3/internal_functions_on_sphere_3.h $
+// $Id: internal_functions_on_sphere_3.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Monique Teillaud, Sylvain Pion, Pedro Machado
 
-// Partially supported by the IST Programme of the EU as a 
-// STREP (FET Open) Project under Contract No  IST-006413 
+// Partially supported by the IST Programme of the EU as a
+// STREP (FET Open) Project under Contract No  IST-006413
 // (ACS -- Algorithms for Complex Shapes)
 
 #ifndef CGAL_SPHERICAL_KERNEL_PREDICATES_ON_SPHERE_3_H
@@ -29,6 +20,7 @@
 
 
 #include <CGAL/Circular_kernel_3/Intersection_traits.h>
+#include <CGAL/number_utils.h>
 #include <utility>
 #include <vector>
 
@@ -41,7 +33,7 @@ namespace CGAL {
     {
       typedef typename SK::Algebraic_kernel Algebraic_kernel;
       return Algebraic_kernel().construct_polynomials_for_line_3_object()
-	  (l.to_vector().x(), l.point().x(), 
+          (l.to_vector().x(), l.point().x(),
            l.to_vector().y(), l.point().y(),
            l.to_vector().z(), l.point().z());
     }
@@ -52,7 +44,7 @@ namespace CGAL {
     {
       typedef typename SK::Algebraic_kernel Algebraic_kernel;
       return Algebraic_kernel().construct_polynomial_1_3_object()
-	  ( s.a(), s.b(), s.c(), s.d() );
+          ( s.a(), s.b(), s.c(), s.d() );
     }
 
     template < class SK >
@@ -63,7 +55,7 @@ namespace CGAL {
       typedef typename SK::Algebraic_kernel   Algebraic_kernel;
       Point_3 center = s.center();
       return Algebraic_kernel().construct_polynomial_for_spheres_2_3_object()
-	  ( center.x(), center.y(), center.z(), s.squared_radius() );
+          ( center.x(), center.y(), center.z(), s.squared_radius() );
     }
 
     template < class SK >
@@ -72,7 +64,7 @@ namespace CGAL {
     {
       typedef typename SK::Algebraic_kernel Algebraic_kernel;
       return std::make_pair ( Algebraic_kernel().construct_polynomial_for_spheres_2_3_object()
-                               (c.center().x(), c.center().y(), 
+                               (c.center().x(), c.center().y(),
                                 c.center().z(), c.squared_radius()),
                               Algebraic_kernel().construct_polynomial_1_3_object()
                                (c.supporting_plane().a(),
@@ -90,7 +82,7 @@ namespace CGAL {
       return Sphere_3(Point_3(eq.a(),eq.b(),eq.c()),eq.r_sq());
     }
 
-   
+
     template < class SK >
     inline
     typename SK::Linear_kernel::Bounded_side_3::result_type
@@ -140,10 +132,10 @@ namespace CGAL {
     {
       // Should we compare anyway even if they are degenerated?
       CGAL_kernel_assertion(!(p1.is_degenerate() || p2.is_degenerate()));
-      if(is_zero(p1.a())) {
-        if(!is_zero(p2.a())) return false;
-        if(is_zero(p1.b())) {
-          if(!is_zero(p2.b())) return false;
+      if(CGAL::is_zero(p1.a())) {
+        if(!CGAL::is_zero(p2.a())) return false;
+        if(CGAL::is_zero(p1.b())) {
+          if(!CGAL::is_zero(p2.b())) return false;
           return p1.c() * p2.d() == p1.d() * p2.c();
         }
         return (p2.c() * p1.b() == p1.c() * p2.b()) &&
@@ -236,7 +228,7 @@ namespace CGAL {
      template<typename T>
      OutputIterator operator()(const T& t) { *it++ = RT(t); return it; }
 
-     OutputIterator operator()(const typename SK::Point_3& p) { 
+     OutputIterator operator()(const typename SK::Point_3& p) {
        // 2 multiplicities
        *it++ = RT(std::make_pair(typename SK::Circular_arc_point_3(p), 2u));
        return it;
@@ -248,24 +240,24 @@ namespace CGAL {
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Sphere_3 & s, 
-                const typename SK::Line_3 & l, 
-	        OutputIterator res)
+    intersect_3(const typename SK::Sphere_3 & s,
+                const typename SK::Line_3 & l,
+                OutputIterator res)
     {
       typedef typename SK3_Intersection_traits<SK, typename SK::Sphere_3, typename SK::Line_3>
         ::type result_type;
       typedef typename SK::Algebraic_kernel                          Algebraic_kernel;
-      typedef typename SK::Polynomial_for_spheres_2_3  Equation_sphere; 
-      typedef typename SK::Polynomials_for_line_3      Equation_line; 
+      typedef typename SK::Polynomial_for_spheres_2_3  Equation_sphere;
+      typedef typename SK::Polynomials_for_line_3      Equation_line;
       typedef typename SK::Root_for_spheres_2_3        Root_for_spheres_2_3;
       CGAL_kernel_precondition(!s.is_degenerate());
-      CGAL_kernel_precondition(!l.is_degenerate());      
+      CGAL_kernel_precondition(!l.is_degenerate());
       Equation_sphere e1 = get_equation<SK>(s);
       Equation_line e2 = get_equation<SK>(l);
-      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > > 
+      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > >
         solutions_container;
       solutions_container solutions;
-      Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions)); 
+      Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions));
 
       return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
     }
@@ -273,9 +265,9 @@ namespace CGAL {
     // The special 3 object functions
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Sphere_3 & s1, 
-                const typename SK::Sphere_3 & s2, 
-	        const typename SK::Sphere_3 & s3, 
+    intersect_3(const typename SK::Sphere_3 & s1,
+                const typename SK::Sphere_3 & s2,
+                const typename SK::Sphere_3 & s3,
                 OutputIterator res)
     {
        // circle_3, sphere_3, (circular_arc_point_3, uint)
@@ -292,67 +284,41 @@ namespace CGAL {
        CGAL_kernel_precondition(!s2.is_degenerate());
        CGAL_kernel_precondition(!s3.is_degenerate());
        if(non_oriented_equal<SK>(s1,s2) && non_oriented_equal<SK>(s2,s3)) {
-         #if CGAL_INTERSECTION_VERSION < 2
-         *res++ = make_object(s1);
-         #else
          *res++ = result_type(s1);
-         #endif
          return res;
        }
        if(non_oriented_equal<SK>(s1,s2)) {
-         if(typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v = 
+         if(typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(s1, s3)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           if( const Point_3* p = object_cast<Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(visitor,
              *v);
-           #endif
          }
          return res;
        }
        if(non_oriented_equal<SK>(s1,s3) || non_oriented_equal<SK>(s2,s3)) {
-         if(typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v = 
+         if(typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(s1, s2)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           if( const Point_3* p = object_cast<Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(
              visitor,
              *v);
-           #endif
          }
          return res;
        }
        if(SK().collinear_3_object()(s1.center(),s2.center(),s3.center())) {
-         typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v = 
+         typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v =
            SK().intersect_3_object()(s1, s2);
          if(!v) return res;
          if(const Point_3* p = CGAL::Intersections::internal::intersect_get<Point_3>(v)) {
             if(SK().has_on_3_object()(s3, *p)) {
-              #if CGAL_INTERSECTION_VERSION < 2
-              *res++ = make_object(std::make_pair(Circular_arc_point_3(*p),2u));
-              #else
               *res++ = result_type(std::make_pair(Circular_arc_point_3(*p),2u));
-              #endif
             }
              return res;
          }
          if(const Circle_3* c = CGAL::Intersections::internal::intersect_get<Circle_3>(v)) {
             if(SK().has_on_3_object()(s3, *c)) {
-              #if CGAL_INTERSECTION_VERSION < 2
-              *res++ = make_object(*c);
-              #else
               *res++ = result_type(*c);
-              #endif
             }
            return res;
          }
@@ -361,19 +327,19 @@ namespace CGAL {
        Equation_sphere e1 = get_equation<SK>(s1);
        Equation_sphere e2 = get_equation<SK>(s2);
        Equation_sphere e3 = get_equation<SK>(s3);
-       typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > > 
+       typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > >
          algebraic_solutions_container;
        algebraic_solutions_container solutions;
-       Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions)); 
+       Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions));
 
        return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
     }
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Plane_3 & p, 
-                const typename SK::Sphere_3 & s1, 
-	        const typename SK::Sphere_3 & s2, 
+    intersect_3(const typename SK::Plane_3 & p,
+                const typename SK::Sphere_3 & s1,
+                const typename SK::Sphere_3 & s2,
                 OutputIterator res)
     {
       typedef typename boost::variant< std::pair< typename SK::Circular_arc_point_3, unsigned int>,
@@ -384,65 +350,48 @@ namespace CGAL {
       typedef typename SK::Plane_3  Plane_3;
       typedef typename SK::Sphere_3 Sphere_3;
       typedef typename SK::Algebraic_kernel  Algebraic_kernel;
-      #if CGAL_INTERSECTION_VERSION < 2
-      typedef typename SK::Circular_arc_point_3  Circular_arc_point_3;
-      #endif
       CGAL_kernel_precondition(!p.is_degenerate());
       CGAL_kernel_precondition(!s1.is_degenerate());
       CGAL_kernel_precondition(!s2.is_degenerate());
       if(non_oriented_equal<SK>(s1,s2)) {
-        if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v = 
+        if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(p, s1)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           if( const typename SK::Point_3* p = CGAL::object_cast<typename SK::Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(
              visitor,
              *v);
-           #endif
          }
          return res;
       }
       Plane_3 radical_p = SK().construct_radical_plane_3_object()(s1,s2);
       if(non_oriented_equal<SK>(p,radical_p)) {
-        if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v = 
+        if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(p, s1)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           if( const typename SK::Point_3* p = CGAL::object_cast<typename SK::Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(
              visitor,
              *v);
-           #endif
          }
          return res;
       }
       Equation_sphere e1 = get_equation<SK>(s1);
       Equation_sphere e2 = get_equation<SK>(s2);
       Equation_plane e3 = get_equation<SK>(p);
-      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > > 
+      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > >
         algebraic_solutions_container;
       algebraic_solutions_container solutions;
-      Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions)); 
+      Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions));
       return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
     }
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Plane_3 & p1, 
-                const typename SK::Plane_3 & p2, 
-	        const typename SK::Sphere_3 & s, 
+    intersect_3(const typename SK::Plane_3 & p1,
+                const typename SK::Plane_3 & p2,
+                const typename SK::Sphere_3 & s,
                 OutputIterator res)
-    { 
-      typedef typename boost::variant< std::pair< typename SK::Circular_arc_point_3, unsigned int>, 
+    {
+      typedef typename boost::variant< std::pair< typename SK::Circular_arc_point_3, unsigned int>,
                                        typename SK::Circle_3 > result_type;
       typedef typename SK::Root_for_spheres_2_3  Root_for_spheres_2_3;
       typedef typename SK::Polynomial_for_spheres_2_3  Equation_sphere;
@@ -452,59 +401,51 @@ namespace CGAL {
       typedef typename SK::Sphere_3 Sphere_3;
       CGAL_kernel_precondition(!p1.is_degenerate());
       CGAL_kernel_precondition(!p2.is_degenerate());
-      CGAL_kernel_precondition(!s.is_degenerate());      
+      CGAL_kernel_precondition(!s.is_degenerate());
       if(non_oriented_equal<SK>(p1,p2)) {
-        if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v = 
+        if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(p1, s)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           typedef typename SK::Circular_arc_point_3  Circular_arc_point_3;
-           if( const typename SK::Point_3* p = CGAL::object_cast<typename SK::Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(
              visitor,
              *v);
-           #endif
          }
          return res;
       }
       Equation_plane e1 = get_equation<SK>(p1);
       Equation_plane e2 = get_equation<SK>(p2);
       Equation_sphere e3 = get_equation<SK>(s);
-      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > > 
+      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > >
         algebraic_solutions_container;
       algebraic_solutions_container solutions;
-      Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions)); 
+      Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions));
       return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
     }
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Circle_3 & c, 
+    intersect_3(const typename SK::Circle_3 & c,
                 const typename SK::Plane_3 & p,
                 OutputIterator res)
-    { 
+    {
       return intersect_3<SK>(p,c.supporting_plane(),c.diametral_sphere(),res);
     }
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Circle_3 & c, 
+    intersect_3(const typename SK::Circle_3 & c,
                 const typename SK::Sphere_3 & s,
                 OutputIterator res)
-    { 
+    {
       return intersect_3<SK>(c.supporting_plane(),s,c.diametral_sphere(),res);
     }
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Circle_3 & c1, 
+    intersect_3(const typename SK::Circle_3 & c1,
                 const typename SK::Circle_3 & c2,
                 OutputIterator res)
-    { 
+    {
       typedef typename SK::Root_for_spheres_2_3     Root_for_spheres_2_3;
       typedef typename SK::Polynomials_for_circle_3 Equation_circle;
       typedef typename SK::Algebraic_kernel         Algebraic_kernel;
@@ -519,19 +460,19 @@ namespace CGAL {
       }
       Equation_circle e1 = get_equation<SK>(c1);
       Equation_circle e2 = get_equation<SK>(c2);
-      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > > 
+      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > >
         algebraic_solutions_container;
       algebraic_solutions_container solutions;
-      Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions)); 
+      Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions));
       return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
     }
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Circle_3 & c, 
+    intersect_3(const typename SK::Circle_3 & c,
                 const typename SK::Line_3 & l,
                 OutputIterator res)
-    { 
+    {
       typedef typename SK::Root_for_spheres_2_3     Root_for_spheres_2_3;
       typedef typename SK::Polynomials_for_circle_3 Equation_circle;
       typedef typename SK::Polynomials_for_line_3   Equation_line;
@@ -544,10 +485,10 @@ namespace CGAL {
       CGAL_kernel_precondition(!l.is_degenerate());
       Equation_circle e1 = get_equation<SK>(c);
       Equation_line e2 = get_equation<SK>(l);
-      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > > 
+      typedef std::vector< std::pair < Root_for_spheres_2_3, unsigned > >
         algebraic_solutions_container;
       algebraic_solutions_container solutions;
-      Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions)); 
+      Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions));
       return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
     }
 
