@@ -1,25 +1,16 @@
-// Copyright (c) 1997  
+// Copyright (c) 1997
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Circulator/include/CGAL/Circulator/Circulator_adapters.h $
+// $Id: Circulator_adapters.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Circulator/include/CGAL/Circulator/Circulator_adapters.h $
-// $Id: Circulator_adapters.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Lutz Kettner  <kettner@inf.ethz.ch>
 
@@ -68,12 +59,12 @@ public:
 
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
-        return this->_ptr == NULL;
+        return this->_ptr == nullptr;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c)    const { return this->_ptr == c._ptr; }
     bool operator!=( const Self& c)    const { return !(*this == c); }
     reference  operator*()             const { return *(S*)this->_ptr;}
@@ -112,12 +103,12 @@ public:
 
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
-        return this->_ptr == NULL;
+        return this->_ptr == nullptr;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c)    const { return this->_ptr == c._ptr; }
     bool operator!=( const Self& c)    const { return !(*this == c); }
     reference  operator*()             const { return *(const S*)this->_ptr;}
@@ -160,12 +151,12 @@ public:
 
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
-        return this->_ptr == NULL;
+        return this->_ptr == nullptr;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c)    const { return this->_ptr == c._ptr; }
     bool operator!=( const Self& c)    const { return !(*this == c); }
     reference  operator*()             const { return *(S*)this->_ptr;}
@@ -213,12 +204,12 @@ public:
 
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
-        return this->_ptr == NULL;
+        return this->_ptr == nullptr;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c)    const { return this->_ptr == c._ptr; }
     bool operator!=( const Self& c)    const { return !(*this == c); }
     reference  operator*()             const { return *(const S*)this->_ptr;}
@@ -273,12 +264,12 @@ public:
 //
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
-        return this->_ptr == NULL;
+        return this->_ptr == nullptr;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c)    const { return this->_ptr == c._ptr; }
     bool operator!=( const Self& c)    const { return !(*this == c); }
     C&   operator*()                   const { return *(C*)this->_ptr;}
@@ -312,12 +303,12 @@ public:
 // OPERATIONS
 
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
-        return this->_ptr == NULL;
+        return this->_ptr == nullptr;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c)    const { return this->_ptr == c._ptr; }
     bool operator!=( const Self& c)    const { return !(*this == c); }
     const C&  operator*()              const { return *(C*)this->_ptr;}
@@ -350,12 +341,12 @@ public:
 //
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
-        return this->_ptr == NULL;
+        return this->_ptr == nullptr;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c)    const { return this->_ptr == c._ptr; }
     bool operator!=( const Self& c)    const { return !(*this == c); }
     C&   operator*()                   const { return *(C*)this->_ptr;}
@@ -400,12 +391,12 @@ public:
 //
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
-        return this->_ptr == NULL;
+        return this->_ptr == nullptr;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c)    const { return this->_ptr == c._ptr; }
     bool operator!=( const Self& c)    const { return !(*this == c); }
     const C&  operator*()              const { return *(C*)this->_ptr;}
@@ -473,12 +464,12 @@ public:
 
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
         return _i >= _size;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c) const {
         CGAL_assertion( this->_ptr  == c._ptr);  // belong to the same array?
         CGAL_assertion( _size == c._size); // same size when instantiated ?
@@ -486,17 +477,17 @@ public:
     }
     bool operator!=( const Self& c) const { return !(*this == c); }
     T&  operator*() const {
-        CGAL_assertion( this->_ptr != NULL);
+        CGAL_assertion( this->_ptr != nullptr);
         CGAL_assertion( _i < _size);
         return ((A*)this->_ptr)->operator[](_i);
     }
     T*  operator->() const {
-        CGAL_assertion( this->_ptr != NULL);
+        CGAL_assertion( this->_ptr != nullptr);
         CGAL_assertion( _i < _size);
         return &(((A*)this->_ptr)->operator[](_i));
     }
     Self& operator++() {
-        CGAL_assertion( this->_ptr != NULL);
+        CGAL_assertion( this->_ptr != nullptr);
         CGAL_assertion( _i < _size);
         ++ _i;
         if ( _i >= _size)
@@ -509,7 +500,7 @@ public:
         return tmp;
     }
     Self& operator--() {
-        CGAL_assertion( this->_ptr != NULL);
+        CGAL_assertion( this->_ptr != nullptr);
         CGAL_assertion( _i < _size);
         if ( _i <= 0)
             _i = _size - 1;
@@ -560,7 +551,7 @@ template < class A, class T, class U, class I>
 Circulator_over_array< A, T, U, I>&
 Circulator_over_array< A, T, U, I>::
 operator+=( I n) {
-    CGAL_assertion( this->_ptr != NULL);
+    CGAL_assertion( this->_ptr != nullptr);
     CGAL_assertion( _i < _size);
     _i = non_negative_mod( (I)(_i) + n, _size);
     CGAL_assertion( _i < _size);
@@ -598,12 +589,12 @@ public:
 //
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
-        CGAL_assertion( p == NULL);
+    bool operator==( std::nullptr_t p) const {
+        CGAL_assertion( p == nullptr);
         CGAL_USE(p);
         return _i >= _size;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c) const {
         CGAL_assertion( this->_ptr  == c._ptr);  // belong to the same array?
         CGAL_assertion( _size == c._size); // same size when instantiated ?
@@ -611,17 +602,17 @@ public:
     }
     bool operator!=( const Self& c) const { return !(*this == c); }
     const T&  operator*() const {
-        CGAL_assertion( this->_ptr != NULL);
+        CGAL_assertion( this->_ptr != nullptr);
         CGAL_assertion( _i < _size);
         return ((const A*)this->_ptr)->operator[](_i);
     }
     const T*  operator->() const {
-        CGAL_assertion( this->_ptr != NULL);
+        CGAL_assertion( this->_ptr != nullptr);
         CGAL_assertion( _i < _size);
         return &(((const A*)this->_ptr)->operator[](_i));
     }
     Self& operator++() {
-        CGAL_assertion( this->_ptr != NULL);
+        CGAL_assertion( this->_ptr != nullptr);
         CGAL_assertion( _i < _size);
         ++ _i;
         if ( _i >= _size)
@@ -634,7 +625,7 @@ public:
         return tmp;
     }
     Self& operator--() {
-        CGAL_assertion( this->_ptr != NULL);
+        CGAL_assertion( this->_ptr != nullptr);
         CGAL_assertion( _i < _size);
         if ( _i <= 0)
             _i = _size - 1;
@@ -689,7 +680,7 @@ template < class A, class T, class U, class I>
 Const_circulator_over_array< A, T, U, I>&
 Const_circulator_over_array< A, T, U, I>::
 operator+=( I n) {
-    CGAL_assertion( this->_ptr != NULL);
+    CGAL_assertion( this->_ptr != nullptr);
     CGAL_assertion( _i < _size);
     _i = non_negative_mod( (I)(_i) + n, _size);
     CGAL_assertion( _i < _size);
