@@ -1,29 +1,26 @@
 // Copyright (c) 2010-2011 CNRS and LIRIS' Establishments (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Combinatorial_map/include/CGAL/Combinatorial_map_iterators_base.h $
+// $Id: Combinatorial_map_iterators_base.h 7a62583 2022-11-14T19:14:33+01:00 albert-github
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
 //
 #ifndef CGAL_COMBINATORIAL_MAP_ITERATORS_BASE_HH
 #define CGAL_COMBINATORIAL_MAP_ITERATORS_BASE_HH 1
 
+#include <CGAL/disable_warnings.h>
+
 #include <CGAL/Compact_container.h>
+#include <CGAL/Compact_container_with_index.h>
+
 #include <queue>
 #include <boost/mpl/if.hpp>
-#include <boost/type_traits/is_same.hpp>
+
+#include <type_traits>
 
 namespace CGAL {
 
@@ -31,7 +28,7 @@ namespace CGAL {
    * Basic classes that serve as tools for definition of iterators.
    There are 3 classes:
    *  - CMap_dart_iterator<Map,Const> is the basic generic class defining
-   *    what is an interator on darts.
+   *    what is an iterator on darts.
    *  - CMap_extend_iterator<Map,Ite,Bi> to extend the given iterator by adding
    *    the involution Bi.
    *  - CMap_non_basic_iterator<Map_,Ite> to transform the basic iterator Ite
@@ -67,8 +64,11 @@ namespace CGAL {
    * Class CMap_dart_iterator is a generic iterator. All the combinatorial
    * map iterator classes inherit from this class (or one of its subclass).
    */
-  template < typename Map_,bool Const=false >
-  class CMap_dart_iterator: public boost::mpl::if_c< Const,
+  template < typename Map_,bool Const=false, typename UseIndex=typename Map_::Use_index >
+  class CMap_dart_iterator;
+
+  template < typename Map_,bool Const>
+  class CMap_dart_iterator<Map_, Const, Tag_false>: public boost::mpl::if_c< Const,
       typename Map_::Dart_container::const_iterator,
       typename Map_::Dart_container::iterator>::type
     //public internal::CC_iterator<typename Map_::Dart_container,Const>
@@ -79,11 +79,124 @@ namespace CGAL {
     typedef typename boost::mpl::if_c< Const,
           typename Map_::Dart_container::const_iterator,
           typename Map_::Dart_container::iterator>::type Base;
+    // typedef internal::CC_iterator<typename Map_::Dart_container,Const> Base;
 
     typedef typename boost::mpl::if_c< Const,
-                                       typename Map_::Dart_const_handle,
-                                       typename Map_::Dart_handle>::type
-                                     Dart_handle;
+                                       typename Map_::Dart_const_descriptor,
+                                       typename Map_::Dart_descriptor>::type
+                                     Dart_descriptor;
+    typedef typename boost::mpl::if_c< Const, const Map_, Map_>::type Map;
+
+    typedef std::input_iterator_tag iterator_category;
+    typedef typename Base::value_type value_type;
+    typedef typename Base::difference_type difference_type;
+    typedef typename Base::pointer pointer;
+    typedef typename Base::reference reference;
+
+    /// true iff this iterator is basic
+    typedef Tag_true Basic_iterator;
+
+    typedef typename Map::size_type size_type;
+
+  public:
+    /// Main constructor.
+    CMap_dart_iterator(Map& amap, Dart_descriptor adart):
+      Base(adart),
+      mmap(&amap),
+      mfirst_dart(adart),
+      mprev_op(OP_NONE)
+    {}
+
+    /// == operator.
+    bool operator==(const Self& aiterator) const
+    {
+      return ( ((*this==mmap->null_descriptor) && (aiterator==mmap->null_descriptor)) ||
+               (mfirst_dart == aiterator.mfirst_dart &&
+                static_cast<const Base&>(*this)==
+                static_cast<const Base&>(aiterator)) );
+    }
+
+    /// != operator.
+    bool operator!=(const Self& aiterator) const
+    { return !operator==(aiterator); }
+
+    /// Accessor to the initial dart of the iterator.
+    Dart_descriptor get_first_dart() const { return mfirst_dart; }
+
+    /// Accessor to the combinatorial map.
+    Map* get_combinatorial_map() const { return mmap; }
+
+    /// Rewind of the iterator to its beginning.
+    void rewind()
+    { set_current_dart(mfirst_dart); mprev_op = OP_NONE; }
+
+    /// Test if the iterator is at its end.
+    bool cont() const
+    { return static_cast<const Base&>(*this)!=mmap->null_descriptor; }
+
+    /// Get the previous operation used for the last ++.
+    OperationState prev_operation()  const { return mprev_op; }
+
+  protected:
+    /// Set the current dart to a given dart
+    void set_current_dart(Dart_descriptor adart)
+    { Base::operator=(adart); }
+
+  private:
+    /// operator -- in private to invalidate the base operator.
+    Self& operator--()
+    { return *this; }
+    /// operator -- in private to invalidate the base operator.
+    Self operator--(int)
+    { return *this; }
+
+  protected:
+    /// test if adart->beta(ai) exists and is not marked for amark
+    bool is_unmarked(Dart_descriptor adart, unsigned int ai, size_type amark) const
+    { return
+        !mmap->is_marked(mmap->beta(adart,ai), amark);
+    }
+
+    /// test if adart->beta(ai)->beta(aj) exists
+    bool exist_betaij(Dart_descriptor adart, unsigned int ai, unsigned int aj) const
+    { return !mmap->is_free(adart, ai) && !mmap->is_free(mmap->beta(adart, ai), aj); }
+
+    /// test if adart->beta(ai)->beta(aj) exists and is not marked for amark
+    bool is_unmarked2(Dart_descriptor adart, unsigned int ai, unsigned int aj,
+                      typename Map::size_type amark) const
+    { return
+        !mmap->is_marked(mmap->beta(adart, ai, aj), amark);
+    }
+  protected:
+    /// The map containing the darts to iterate on.
+    Map* mmap;
+
+    /// The initial dart of the iterator.
+    Dart_descriptor mfirst_dart;
+
+    /// The last operation used for the ++ operator.
+    OperationState mprev_op;
+  };
+
+  template < typename Map_,bool Const >
+  class CMap_dart_iterator<Map_, Const, Tag_true>:
+      /*public boost::mpl::if_c< Const,
+      typename Map_::Dart_container::const_iterator,
+      typename Map_::Dart_container::iterator>::type*/
+    public internal::CC_iterator_with_index<typename Map_::Dart_container,Const>
+  {
+  public:
+    typedef CMap_dart_iterator<Map_,Const> Self;
+
+    /*typedef typename boost::mpl::if_c< Const,
+          typename Map_::Dart_container::const_iterator,
+          typename Map_::Dart_container::iterator>::type Base;*/
+    typedef internal::CC_iterator_with_index<typename Map_::Dart_container,Const> Base;
+
+    typedef typename boost::mpl::if_c< Const,
+                                       typename Map_::Dart_const_descriptor,
+                                       typename Map_::Dart_descriptor>::type
+                                     Dart_descriptor;
     typedef typename boost::mpl::if_c< Const, const Map_,
                                        Map_>::type Map;
 
@@ -98,8 +211,8 @@ namespace CGAL {
 
   public:
     /// Main constructor.
-    CMap_dart_iterator(Map& amap, Dart_handle adart):
-      Base(adart),
+    CMap_dart_iterator(Map& amap, Dart_descriptor adart):
+      Base(&amap.mdarts, adart),
       mmap(&amap),
       mfirst_dart(adart),
       mprev_op(OP_NONE)
@@ -108,10 +221,10 @@ namespace CGAL {
     /// == operator.
     bool operator==(const Self& aiterator) const
     {
-      return ( ((*this==mmap->null_handle) && (aiterator==mmap->null_handle)) ||
-               (mfirst_dart == aiterator.mfirst_dart &&
-               static_cast<const Base&>(*this)==
-                static_cast<const Base&>(aiterator)) );
+      return ((*this==mmap->null_descriptor) && (aiterator==mmap->null_descriptor)) ||
+        (mfirst_dart == aiterator.mfirst_dart &&
+         static_cast<const Base&>(*this)==
+         static_cast<const Base&>(aiterator));
     }
 
     /// != operator.
@@ -119,7 +232,7 @@ namespace CGAL {
     { return !operator==(aiterator); }
 
     /// Accessor to the initial dart of the iterator.
-    Dart_handle get_first_dart() const { return mfirst_dart; }
+    Dart_descriptor get_first_dart() const { return mfirst_dart; }
 
     /// Accessor to the combinatorial map.
     Map* get_combinatorial_map() const { return mmap; }
@@ -130,15 +243,15 @@ namespace CGAL {
 
     /// Test if the iterator is at its end.
     bool cont() const
-    { return static_cast<const Base&>(*this)!=mmap->null_handle; }
+    { return this->get_current()!=mmap->null_descriptor; }
 
     /// Get the previous operation used for the last ++.
     OperationState prev_operation()  const { return mprev_op; }
 
   protected:
     /// Set the current dart to a given dart
-    void set_current_dart(Dart_handle adart)
-    { Base::operator=(adart); }
+    void set_current_dart(Dart_descriptor adart)
+    { this->set_current(adart); }
 
   private:
     /// operator -- in private to invalidate the base operator.
@@ -150,34 +263,24 @@ namespace CGAL {
 
   protected:
     /// test if adart->beta(ai) exists and is not marked for amark
-    bool is_unmarked(Dart_handle adart, unsigned int ai, unsigned amark) const
-    { return
-#ifdef CGAL_CMAP_DEPRECATED
-        !mmap->is_free(adart,ai) && // Pb with static null_dart_handle for windows
-#endif // CGAL_CMAP_DEPRECATED
-        !mmap->is_marked(mmap->beta(adart,ai), amark);
-    }
+    bool is_unmarked(Dart_descriptor adart, unsigned int ai, unsigned amark) const
+    { return !mmap->is_marked(mmap->beta(adart,ai), amark); }
 
     /// test if adart->beta(ai)->beta(aj) exists
-    bool exist_betaij(Dart_handle adart, unsigned int ai, unsigned int aj) const
+    bool exist_betaij(Dart_descriptor adart, unsigned int ai, unsigned int aj) const
     { return !mmap->is_free(adart, ai) && !mmap->is_free(mmap->beta(adart, ai), aj); }
 
     /// test if adart->beta(ai)->beta(aj) exists and is not marked for amark
-    bool is_unmarked2(Dart_handle adart, unsigned int ai, unsigned int aj,
+    bool is_unmarked2(Dart_descriptor adart, unsigned int ai, unsigned int aj,
                       unsigned amark) const
-    { return
-#ifdef CGAL_CMAP_DEPRECATED
-         exist_betaij(adart, ai, aj) && // Pb with static null_dart_handle for windows
-#endif // CGAL_CMAP_DEPRECATED
-        !mmap->is_marked(mmap->beta(adart, ai, aj), amark);
-    }
+    { return !mmap->is_marked(mmap->beta(adart, ai, aj), amark); }
 
   protected:
     /// The map containing the darts to iterate on.
     Map* mmap;
 
     /// The initial dart of the iterator.
-    Dart_handle mfirst_dart;
+    Dart_descriptor mfirst_dart;
 
     /// The last operation used for the ++ operator.
     OperationState mprev_op;
@@ -195,22 +298,24 @@ namespace CGAL {
     typedef CMap_extend_iterator<Map_,Ite,Bi, Ite_has_stack> Self;
     typedef Ite Base;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
     typedef Tag_true Use_mark;
 
+    typedef typename Map::size_type size_type;
+
     CGAL_static_assertion( (Bi<=Map::dimension &&
-                            boost::is_same<Ite_has_stack,Tag_false>::value) );
+                            std::is_same<Ite_has_stack,Tag_false>::value) );
 
   public:
     /// Main constructor.
-    CMap_extend_iterator(Map& amap, Dart_handle adart, int amark):
+    CMap_extend_iterator(Map& amap, Dart_descriptor adart, size_type amark):
       Base(amap, adart),
       mmark_number(amark),
       minitial_dart(adart)
     {
-      if ( minitial_dart!=amap.null_handle )
+      if ( minitial_dart!=amap.null_descriptor )
       {
         this->mmap->mark_null_dart(mmark_number);
         this->mmap->mark(minitial_dart, mmark_number);
@@ -218,7 +323,6 @@ namespace CGAL {
             this->mmap->beta(minitial_dart, Bi)!=minitial_dart )
         {
           mto_treat.push(this->mmap->beta(minitial_dart, Bi));
-          this->mmap->mark(this->mmap->beta(minitial_dart, Bi), mmark_number);
         }
       }
     }
@@ -226,23 +330,22 @@ namespace CGAL {
     /// Rewind of the iterator to its beginning.
     void rewind()
     {
-      CGAL_assertion(mmark_number != -1);
+      CGAL_assertion(mmark_number != Map::INVALID_MARK);
       Base::operator= ( Base(*this->mmap,minitial_dart) );
-      mto_treat = std::queue<Dart_handle>();
+      mto_treat = std::queue<Dart_descriptor>();
       this->mmap->mark(minitial_dart, mmark_number);
       this->mmap->mark_null_dart(mmark_number);
       if (!this->mmap->is_free(minitial_dart, Bi) &&
           this->mmap->beta(minitial_dart, Bi)!=minitial_dart)
       {
         mto_treat.push(this->mmap->beta(minitial_dart, Bi));
-        this->mmap->mark(this->mmap->beta(minitial_dart, Bi), mmark_number);
       }
     }
 
     /// Prefix ++ operator.
     Self& operator++()
     {
-      CGAL_assertion(mmark_number != -1);
+      CGAL_assertion(mmark_number != Map::INVALID_MARK);
       CGAL_assertion(this->cont());
 
       do
@@ -254,21 +357,24 @@ namespace CGAL {
 
       if ( !this->cont() )
       {
+        while ( !mto_treat.empty() &&
+                this->mmap->is_marked(mto_treat.front(), mmark_number))
+        {
+          mto_treat.pop();
+        }
+
         if ( !mto_treat.empty() )
         {
           Base::operator= ( Base(*this->mmap,mto_treat.front()) );
           mto_treat.pop();
           this->mprev_op = OP_POP;
-          CGAL_assertion( this->mmap->is_marked((*this), mmark_number) );
+          CGAL_assertion( !this->mmap->is_marked((*this), mmark_number) );
+          this->mmap->mark((*this), mmark_number);
 
           if (
-#ifdef CGAL_CMAP_DEPRECATED
-        !this->mmap->is_free(*this, Bi) && // Pb with static null_dart_handle for windows
-#endif // CGAL_CMAP_DEPRECATED
                !this->mmap->is_marked(this->mmap->beta(*this, Bi), mmark_number) )
           {
             mto_treat.push(this->mmap->beta(*this, Bi));
-            this->mmap->mark(this->mmap->beta(*this, Bi), mmark_number);
           }
         }
       }
@@ -276,13 +382,9 @@ namespace CGAL {
       {
         this->mmap->mark((*this), mmark_number);
         if (
-#ifdef CGAL_CMAP_DEPRECATED
-        !this->mmap->is_free(*this, Bi) && // Pb with static null_dart_handle for windows
-#endif // CGAL_CMAP_DEPRECATED
              !this->mmap->is_marked(this->mmap->beta(*this, Bi), mmark_number) )
         {
           mto_treat.push(this->mmap->beta(*this, Bi));
-          this->mmap->mark(this->mmap->beta(*this, Bi), mmark_number);
         }
       }
 
@@ -295,13 +397,13 @@ namespace CGAL {
 
   protected:
     /// Queue of darts to process.
-    std::queue<Dart_handle> mto_treat;
+    std::queue<Dart_descriptor> mto_treat;
 
     /// Index of the used mark.
-    int mmark_number;
+    size_type mmark_number;
 
     /// Initial dart
-    Dart_handle minitial_dart;
+    Dart_descriptor minitial_dart;
   };
   //****************************************************************************
   /* Class CMap_extend_iterator<Map,Ite,Bi> which extend a given iterator by
@@ -315,34 +417,34 @@ namespace CGAL {
     typedef CMap_extend_iterator<Map_,Ite,Bi,Tag_true> Self;
     typedef Ite Base;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
     typedef Tag_true Use_mark;
 
+    typedef typename Map::size_type size_type;
+
     /// Main constructor.
-    CMap_extend_iterator(Map& amap, Dart_handle adart, int amark):
+    CMap_extend_iterator(Map& amap, Dart_descriptor adart, size_type amark):
       Base(amap, adart, amark)
     {
-      if ( this->minitial_dart!=amap.null_handle &&
+      if ( this->minitial_dart!=amap.null_descriptor &&
            !this->mmap->is_free(this->minitial_dart, Bi) &&
            this->mmap->beta(this->minitial_dart, Bi)!=this->minitial_dart )
       {
         this->mto_treat.push(this->mmap->beta(this->minitial_dart, Bi));
-        this->mmap->mark(this->mmap->beta(this->minitial_dart, Bi), this->mmark_number);
       }
     }
 
     /// Rewind of the iterator to its beginning.
     void rewind()
     {
-      CGAL_assertion(this->mmark_number != -1);
+      CGAL_assertion(this->mmark_number != Map::INVALID_MARK);
       Base::rewind();
       if ( !this->mmap->is_free(this->minitial_dart, Bi) &&
            this->mmap->beta(this->minitial_dart, Bi)!=this->minitial_dart )
       {
         this->mto_treat.push(this->mmap->beta(this->minitial_dart, Bi));
-        this->mmap->mark(this->mmap->beta(this->minitial_dart, Bi), this->mmark_number);
       }
     }
 
@@ -356,13 +458,9 @@ namespace CGAL {
         CGAL_assertion( this->mmap->is_marked(*this, this->mmark_number) );
 
         if (
-#ifdef CGAL_CMAP_DEPRECATED
-            !this->mmap->is_free(*this, Bi) && // Pb with static null_dart_handle for windows
-#endif // CGAL_CMAP_DEPRECATED
             !this->mmap->is_marked(this->mmap->beta(*this, Bi), this->mmark_number) )
         {
           this->mto_treat.push(this->mmap->beta(*this, Bi));
-          this->mmap->mark(this->mmap->beta(*this, Bi), this->mmark_number);
         }
       }
       return *this;
@@ -388,28 +486,30 @@ namespace CGAL {
     typedef Base_ Base;
 
     typedef typename Base::Map Map;
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
 
     /// True iff this iterator is basic
     typedef Tag_false Basic_iterator;
 
-    CGAL_static_assertion( (boost::is_same<typename Base::Basic_iterator,
+    typedef typename Map::size_type size_type;
+
+    CGAL_static_assertion( (std::is_same<typename Base::Basic_iterator,
                             Tag_true>::value) );
 
     /// Main constructor.
-    CMap_non_basic_iterator(Map& amap, Dart_handle adart1):
+    CMap_non_basic_iterator(Map& amap, Dart_descriptor adart1):
       Base(amap, adart1, amap.get_new_mark())
     {}
 
     /// Destructor.
-    ~CMap_non_basic_iterator()
+    ~CMap_non_basic_iterator() noexcept(!CGAL_ASSERTIONS_ENABLED)
     {
-      CGAL_assertion( this->mmark_number!=-1 );
+      CGAL_destructor_assertion( this->mmark_number!=Map::INVALID_MARK );
       if (this->mmap->get_number_of_times_mark_reserved
           (this->mmark_number)==1)
         unmark_treated_darts();
       this->mmap->free_mark(this->mmark_number);
-      this->mmark_number = -1; // To avoid basic class to try to unmark darts.
+      this->mmark_number = Map::INVALID_MARK; // To avoid basic class to try to unmark darts.
     }
 
     /// Copy constructor.
@@ -426,7 +526,7 @@ namespace CGAL {
             (this->mmark_number)==1)
           unmark_treated_darts();
         this->mmap->free_mark(this->mmark_number);
-        this->mmark_number = -1;
+        this->mmark_number = Map::INVALID_MARK;
 
         Base::operator=(aiterator);
         this->mmap->share_a_mark(this->mmark_number);
@@ -474,16 +574,16 @@ namespace CGAL {
     typedef Base_ Base;
 
     typedef typename Base::Map Map;
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
 
     /// True iff this iterator is basic
     typedef Tag_false Basic_iterator;
 
-    CGAL_static_assertion( (boost::is_same<typename Base::Basic_iterator,
+    CGAL_static_assertion( (std::is_same<typename Base::Basic_iterator,
                             Tag_true>::value) );
 
     /// Main constructor.
-    CMap_non_basic_iterator(Map& amap, Dart_handle adart):
+    CMap_non_basic_iterator(Map& amap, Dart_descriptor adart):
       Base(amap, adart)
     {}
   };
@@ -494,13 +594,13 @@ namespace CGAL {
   {
     typedef It iterator;
     typedef Const_it const_iterator;
-    CMap_range(Map_ &amap, typename Map_::Dart_handle adart) :
+    CMap_range(Map_ &amap, typename Map_::Dart_descriptor adart) :
       mmap(amap), mdart(adart), msize(0)
     {}
     iterator begin()             { return iterator(mmap,mdart); }
-    iterator end()               { return iterator(mmap,mmap.null_handle); }
+    iterator end()               { return iterator(mmap,mmap.null_descriptor); }
     const_iterator begin() const { return const_iterator(mmap,mdart); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor); }
     typename Map_::size_type size() const
     {
       if (msize==0)
@@ -512,7 +612,7 @@ namespace CGAL {
     { return mmap.is_empty(); }
   private:
     Map_ & mmap;
-    typename Map_::Dart_handle mdart;
+    typename Map_::Dart_descriptor mdart;
     mutable typename Map_::size_type msize;
   };
   //****************************************************************************
@@ -522,13 +622,16 @@ namespace CGAL {
     typedef CMap_range<Map_,It,Const_it,Tag_true> Base_cmap_range;
     typedef It iterator;
     typedef Const_it const_iterator;
-    CMap_range(Map_ &amap, typename Map_::Dart_handle adart, int amark=-1):
+
+    typedef typename Map_::size_type size_type;
+
+    CMap_range(Map_ &amap, typename Map_::Dart_descriptor adart, size_type amark=Map_::INVALID_MARK):
       mmap(amap), mdart(adart), msize(0), mmark(amark)
     {}
     iterator begin()             { return iterator(mmap,mdart,mmark); }
-    iterator end()               { return iterator(mmap,mmap.null_handle,mmark); }
+    iterator end()               { return iterator(mmap,mmap.null_descriptor,mmark); }
     const_iterator begin() const { return const_iterator(mmap,mdart,mmark); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle,mmark); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor,mmark); }
     typename Map_::size_type size() const
     {
       if (msize==0)
@@ -541,9 +644,9 @@ namespace CGAL {
     { return mmap.is_empty(); }
   private:
     Map_ & mmap;
-    typename Map_::Dart_handle mdart;
+    typename Map_::Dart_descriptor mdart;
     mutable typename Map_::size_type msize;
-    int mmark;
+    size_type mmark;
   };
   //****************************************************************************
   template <typename Map_, typename Const_it,
@@ -551,11 +654,11 @@ namespace CGAL {
   struct CMap_const_range
   {
     typedef Const_it const_iterator;
-    CMap_const_range(const Map_ &amap, typename Map_::Dart_const_handle adart):
+    CMap_const_range(const Map_ &amap, typename Map_::Dart_const_descriptor adart):
       mmap(amap), mdart(adart), msize(0)
     {}
     const_iterator begin() const { return const_iterator(mmap,mdart); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor); }
     typename Map_::size_type size() const
     {
       if (msize==0)
@@ -567,7 +670,7 @@ namespace CGAL {
     { return mmap.is_empty(); }
   private:
     const Map_ & mmap;
-    typename Map_::Dart_const_handle mdart;
+    typename Map_::Dart_const_descriptor mdart;
     mutable typename Map_::size_type msize;
   };
   //****************************************************************************
@@ -575,12 +678,13 @@ namespace CGAL {
   struct CMap_const_range<Map_,Const_it,Tag_true>
   {
     typedef Const_it const_iterator;
-    CMap_const_range(const Map_ &amap, typename Map_::Dart_const_handle adart,
-                     int amark=-1):
+    typedef typename Map_::size_type size_type;
+    CMap_const_range(const Map_ &amap, typename Map_::Dart_const_descriptor adart,
+                     size_type amark=Map_::INVALID_MARK):
       mmap(amap), mdart(adart), msize(0), mmark(amark)
     {}
     const_iterator begin() const { return const_iterator(mmap,mdart,mmark); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle,mmark); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor,mmark); }
     typename Map_::size_type size() const
     {
       if (msize==0)
@@ -593,12 +697,15 @@ namespace CGAL {
     { return mmap.is_empty(); }
   private:
     const Map_ & mmap;
-    typename Map_::Dart_const_handle mdart;
+    typename Map_::Dart_const_descriptor mdart;
     mutable typename Map_::size_type msize;
-    int mmark;
+    size_type mmark;
   };
   //****************************************************************************
 } // namespace CGAL
+
+#include <CGAL/enable_warnings.h>
+
 //******************************************************************************
 #endif // CGAL_COMBINATORIAL_MAP_ITERATORS_BASE_HH
 //******************************************************************************
