@@ -2,36 +2,27 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Convex_hull_2/include/CGAL/Convex_hull_2/ch_melkman_impl.h $
+// $Id: ch_melkman_impl.h dc531cb 2022-09-27T08:40:26+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Convex_hull_2/include/CGAL/Convex_hull_2/ch_melkman_impl.h $
-// $Id: ch_melkman_impl.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Stefan Schirra
- 
+
 #ifndef CGAL_CH_MELKMAN_IMPL_H
 #define CGAL_CH_MELKMAN_IMPL_H
 
 #include <CGAL/license/Convex_hull_2.h>
 
-
 #ifndef CGAL_CH_NO_POSTCONDITIONS
 #include <CGAL/convexity_check_2.h>
 #endif // CGAL_CH_NO_POSTCONDITIONS
 
-#include <CGAL/Convex_hull_2/ch_assertions.h>
-#include <queue>
-#include <iterator>
+#include <CGAL/assertions.h>
+
+#include <algorithm>
+#include <deque>
 
 namespace CGAL {
 
@@ -41,24 +32,24 @@ ch_melkman( InputIterator first, InputIterator last,
             OutputIterator result, const Traits& ch_traits)
 {
   typedef typename Traits::Point_2      Point;
-  typedef typename Traits::Equal_2      Equal_2;   
-  
+  typedef typename Traits::Equal_2      Equal_2;
+
   typename Traits::Left_turn_2 left_turn  = ch_traits.left_turn_2_object();
   Equal_2  equal_points = ch_traits.equal_2_object();
-  
-  CGAL_ch_assertion_code( \
+
+  CGAL_assertion_code( \
   typename Traits::Less_xy_2 less       = ch_traits.less_xy_2_object(); )
-  
+
   std::deque< Point> Q;
-  
-  CGAL_ch_expensive_postcondition_code( std::deque< Point> IN; )
+
+  CGAL_expensive_postcondition_code( std::deque< Point> IN; )
   if (first == last) return result;           // 0 elements
   Point p = *first;
-  CGAL_ch_expensive_postcondition_code( IN.push_back(p); )
+  CGAL_expensive_postcondition_code( IN.push_back(p); )
   if (++first == last)
   { *result = p; ++result; return result; }   // 1 element
   Point q = *first;
-  CGAL_ch_expensive_postcondition_code( IN.push_back(q); )
+  CGAL_expensive_postcondition_code( IN.push_back(q); )
   if (++first == last)                        // 2 elements
   {
     *result = p; ++result;
@@ -67,25 +58,25 @@ ch_melkman( InputIterator first, InputIterator last,
     return result;
   }
   Q.push_back( p);
-  
+
   Point r;
   while (first != last)
   {
     r = *first;
-    CGAL_ch_expensive_postcondition_code( IN.push_back(r); )
+    CGAL_expensive_postcondition_code( IN.push_back(r); )
     // visited input sequence =  p,..., q, r
     if ( left_turn(p,q,r)) { Q.push_back( q);  break; }
     if ( left_turn(q,p,r)) { Q.push_front( q); break; }
-    CGAL_ch_assertion( less( p, q) ? less (p, r) : less( r, p));
+    CGAL_assertion( less( p, q) ? less (p, r) : less( r, p));
     q = r;
     ++first;
   }
-  
-  
+
+
   Point current = q;
   if (first != last)           // non-collinear point r exists
   {
-    
+
     current = r;
     // current, Q.front(), ..., Q.back()
     // ccw convex hull of visited points
@@ -93,11 +84,11 @@ ch_melkman( InputIterator first, InputIterator last,
     while ( ++first != last)
     {
       r = *first;
-      CGAL_ch_expensive_postcondition_code( IN.push_back(r); )
-      if (left_turn( current, r, Q.front()) || 
+      CGAL_expensive_postcondition_code( IN.push_back(r); )
+      if (left_turn( current, r, Q.front()) ||
           left_turn( Q.back(), r, current))
       // r outside cone Q.front(), current, Q.back() <=>
-      // right_turn( current, Q.front(), r) || 
+      // right_turn( current, Q.front(), r) ||
       // right_turn( Q.back(), current, r)
       {
         s = current;
@@ -112,20 +103,20 @@ ch_melkman( InputIterator first, InputIterator last,
         Q.push_back(s);
         current = r;
       }
-      
+
     }
-    
+
   }
-  
-  
+
+
   Q.push_back( current);       // add last point to Q
-  CGAL_ch_postcondition( \
+  CGAL_postcondition( \
   is_ccw_strongly_convex_2( Q.begin(), Q.end(), ch_traits));
-  CGAL_ch_expensive_postcondition( \
+  CGAL_expensive_postcondition( \
   ch_brute_force_check_2( IN.begin(),IN.end(), Q.begin(),Q.end(), ch_traits));
   std::copy( Q.begin(), Q.end(), result);
   return result;
-  
+
 }
 
 } //namespace CGAL
