@@ -1,20 +1,11 @@
 // Copyright (c) 2004-2008 Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Curve_renderer_traits.h $
-// $Id: Curve_renderer_traits.h ff26773 2017-11-11T20:20:26+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Curve_renderer_traits.h $
+// $Id: Curve_renderer_traits.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Pavel Emeliyanenko <asm@mpi-sb.mpg.de>
 //
@@ -25,16 +16,15 @@
 
 #include <CGAL/basic.h>
 #include <CGAL/function_objects.h>
-#include <boost/functional.hpp>
 
 /*! \file CGAL/Curved_kernel_via_analysis_2/gfx/Curve_renderer_traits.h
  * \brief
  * defines class Curve_renderer_traits.
- * 
+ *
  * provides specialisations of Curve_renderer_traits for different number
  * types compatible with the curve renderer
 */
- 
+
 namespace CGAL {
 
 // transformation routine
@@ -64,20 +54,20 @@ struct Max_coeff
     {
         typename CGAL::Polynomial<X>::const_iterator it = p.begin();
         Max_coeff<NT> max_coeff;
-        NT max(max_coeff(*it));
+        NT cur_max(max_coeff(*it));
         while(++it != p.end()) {
             NT tmp(max_coeff(*it));
-            if(max < CGAL_ABS(tmp))
-                max = CGAL_ABS(tmp);
+            if(cur_max < CGAL_ABS(tmp))
+                cur_max = CGAL_ABS(tmp);
         }
-        return max;
+        return cur_max;
     }
     NT operator()(const NT& x) const
     { return CGAL_ABS(x); }
 };
 
 /*!\brief
- * divides an input value by a contant
+ * divides an input value by a constant
  *
  * provided that there is a coercion between \c Input and \c Result types
  */
@@ -90,7 +80,7 @@ struct Reduce_by {
     Reduce_by(const Input& denom_) :
         denom(cast(denom_)) {
     }
-    
+
     Result operator()(const Input& x) {
         return (cast(x)/denom);
     }
@@ -116,11 +106,13 @@ struct Transform {
 
     template <class X>
     OutputPoly_2 operator()(const CGAL::Polynomial<X>& p, Op op = Op()) const {
-
-        Transform<typename OutputPoly_2::NT, typename InputPoly_2::NT, Op> tr;
+        typedef typename InputPoly_2::NT NT_in;
+        typedef typename OutputPoly_2::NT NT_out;
+        Transform<NT_out, NT_in, Op> tr;
+        auto fn = [&op, &tr](const NT_in& v){ return tr(v, op); };
         return OutputPoly_2(
-            ::boost::make_transform_iterator(p.begin(), boost::bind2nd(tr, op)),
-            ::boost::make_transform_iterator(p.end(), boost::bind2nd(tr, op)));
+            ::boost::make_transform_iterator(p.begin(), fn),
+            ::boost::make_transform_iterator(p.end(), fn));
     }
 
     OutputPoly_2 operator()(
@@ -137,16 +129,16 @@ struct Transform {
  *
  * this traits class prodives various number type conversions for the
  * curve renderer
- */              
+ */
 
 template <class Coeff_, class Integer_, class Rational_>
-struct Curve_renderer_traits_base 
-{ 
+struct Curve_renderer_traits_base
+{
     //! type of innermost polynomial coefficients
     typedef Coeff_ Coeff;
-    
+
     //! an integer number type
-    typedef Integer_ Integer; 
+    typedef Integer_ Integer;
 
     typedef Rational_ Rational;
 
@@ -156,32 +148,32 @@ struct Curve_renderer_traits_base
         typedef Float result_type;
 
         template <class X, class Y,class ACDE_TAG,class FP_TAG>
-        Float operator()(const Sqrt_extension<X, Y, ACDE_TAG, FP_TAG>& x) const { 
+        Float operator()(const Sqrt_extension<X, Y, ACDE_TAG, FP_TAG>& x) const {
             typename CGAL::Coercion_traits<Sqrt_extension<X, Y, ACDE_TAG, FP_TAG>, Float>::Cast
-                cast;        
-            return cast(x); 
+                cast;
+            return cast(x);
         }
 
-        Float operator()(const Rational& x) const { 
-            return static_cast<Float>(x); 
+        Float operator()(const Rational& x) const {
+            return static_cast<Float>(x);
         }
     };
-   
+
     //! provided for convenience when there exists an implicit coercion
     //! between number types
     template <class To>
     struct Implicit_coercion {
         typedef To result_type;
-        
-        template <class From> 
+
+        template <class From>
         To operator()(const From& x) const {
             return static_cast<To>(x);
         }
     };
-   
+
     struct Float_to_int {
         typedef int result_type;
-        
+
         template <class Float>
         int operator()(const Float& x) const
         { return static_cast<int>(std::floor(CGAL::to_double(x))); }
@@ -196,13 +188,13 @@ struct Curve_renderer_traits_base
      * \c FieldWithSqrt , etc. Provided that there is a type coercion between
      * \c Extended and \c Coeff
      */
-    struct Convert_poly { 
+    struct Convert_poly {
         typedef CGAL::Polynomial<CGAL::Polynomial<Coeff> > result_type;
-        
+
         template <class Extended>
-        inline result_type operator()(const 
+        inline result_type operator()(const
             CGAL::Polynomial<CGAL::Polynomial<Extended> >& poly) const {
-            
+
     //!@todo: use Rat_to_float functor instead of coercion traits ?
     //! need some sort of polymorphism..
 
@@ -215,64 +207,64 @@ struct Curve_renderer_traits_base
             return transform(poly);
         }
     };
-    
+
     //! converts polynomial coefficients to floating-point representation
     //! \c error_bounds is set if the result is not reliable
     struct Extract_eval {
         typedef Coeff argument_type;
         typedef Coeff result_type;
-        
-        Coeff operator()(const Coeff& x, 
-            bool *error_bounds = NULL) const { 
-            if(error_bounds != NULL)
+
+        Coeff operator()(const Coeff& x,
+            bool *error_bounds = nullptr) const {
+            if(error_bounds != nullptr)
                  *error_bounds = false;
             return x;
         }
     };
-    
+
     //! computes a 32-bit hash value from floating-point argument
     struct Hash_function {
         typedef std::size_t result_type;
         struct long_long {
             long low, high;
         };
-        
+
         template <class Float>
         std::size_t operator()(const Float& key) const {
             const long_long *hk = reinterpret_cast<const long_long *>(&key);
             return (hk->low ^ hk->high);
         }
     };
-    
+
     //! makes result exact after inexact operation such as div, sqrt, etc.
     //! (required for multi-precision arithmetic)
     struct Make_exact {
         typedef void result_type;
-        
+
         template <class Float>
-        void operator()(const Float& x) const
+        void operator()(const Float& /*x*/) const
         { }
     };
-    
+
     //! compares a given quantity with the precision limit a floating-point
     //! number type, returns \c true if this limit is exceeded
     struct Precision_limit {
         typedef bool result_type;
-        
+
         template <class Float>
-        bool operator()(const Float& x) const
+        bool operator()(const Float& /*x*/) const
         { return false;/*(CGAL_ABS(x) <= 1e-16)*/; }
     };
-    
+
     //! maximum subdivision level for the curve renderer by exceeding which
     //! an exception of type \c Insufficient_rasterize_precision_exception
     //! will be thrown, this is also limited by \c Integer number type, since
     //! the integer must be able to store numbers up to 2^MAX_SUBDIVISION_LEVEL
-    static const unsigned MAX_SUBDIVISION_LEVEL = 12;   
+    static const unsigned MAX_SUBDIVISION_LEVEL = 12;
 };
 
 template <class Float, class Rational>
-struct Curve_renderer_traits 
+struct Curve_renderer_traits
 {  };
 
 #ifdef CGAL_USE_CORE
@@ -281,15 +273,15 @@ template <>
 struct Curve_renderer_traits<CGAL::Interval_nt<true>, CORE::BigRat > :
         public Curve_renderer_traits_base<CGAL::Interval_nt<true>, int,
             CORE::BigRat> {
- 
+
     typedef double Float;
 
     struct Rat_to_float {
         typedef Float result_type;
-                
+
         template <class Extended>
         Float operator()(const Extended& x) const {
-            return CGAL::to_double(x); 
+            return CGAL::to_double(x);
         }
     };
 
@@ -307,20 +299,20 @@ struct Curve_renderer_traits<CGAL::Interval_nt<true>, CORE::BigRat > :
     struct Extract_eval {
         typedef Coeff argument_type;
         typedef Float result_type;
-        
-        Float operator()(const Coeff& x, 
-                    bool *error_bounds = NULL) const { 
+
+        Float operator()(const Coeff& x,
+                    bool *error_bounds = nullptr) const {
             bool err_bnd;
 //             err_bnd = (CGAL_ABS(l) < 1E-15 || CGAL_ABS(u) < 1E-15) ||
 //                 ((l <= 0 && u >= 0));
             Float l = x.inf(), u = x.sup(), mid = (l+u)/2;
             err_bnd = ((l < 0 && u > 0)||(l == 0 && u == 0));
-            if(error_bounds != NULL)
+            if(error_bounds != nullptr)
                 *error_bounds = err_bnd;
 //! ATTENTION!!! if smth is screwed up try to uncomment the line below
 //! this is very crucial for performance & stability
             if(err_bnd)  // &&  ABS(mid) < 1E-15)
-                return 0; 
+                return 0;
 //! ATTENTION!!!
             return mid;
         }
@@ -330,7 +322,7 @@ struct Curve_renderer_traits<CGAL::Interval_nt<true>, CORE::BigRat > :
     //! number type, returns \c true if this limit is exceeded
     struct Precision_limit {
         typedef bool result_type;
-        
+
         template <class Float>
         bool operator()(const Float& x) const
         { return (CGAL_ABS(x) <= 1e-16); }
@@ -341,7 +333,7 @@ struct Curve_renderer_traits<CGAL::Interval_nt<true>, CORE::BigRat > :
 
 //! Specialization for \c CORE::BigFloat
 template <>
-struct Curve_renderer_traits<CORE::BigFloat, class CORE::BigRat> 
+struct Curve_renderer_traits<CORE::BigFloat, class CORE::BigRat>
          : public Curve_renderer_traits_base<CORE::BigFloat, CORE::BigInt,
                 CORE::BigRat> {
 
@@ -350,37 +342,37 @@ struct Curve_renderer_traits<CORE::BigFloat, class CORE::BigRat>
     struct Rat_to_integer {
         typedef Rational argument_type;
         typedef Integer result_type;
-        
-        Integer operator()(const Rational& x) const { 
-            return x.BigIntValue(); 
+
+        Integer operator()(const Rational& x) const {
+            return x.BigIntValue();
         }
     };
 
     typedef Rat_to_float<Float> Rat_to_float;
-    
+
     struct Float_to_rat {
         typedef Float argument_type;
         typedef Rational result_type;
-        
+
         Rational operator()(const Float& x) const
         { return x.BigRatValue(); }
     };
-    
+
     struct Hash_function {
         typedef Float argument_type;
         typedef std::size_t result_type;
-        
+
         inline result_type operator()(const Float& key) const {
             const CORE::BigFloatRep& rep = key.getRep();
             std::size_t ret = reinterpret_cast<std::size_t>(&rep);
             return ret;
         }
     };
-    
+
     struct Make_exact {
         typedef Float argument_type;
         typedef void result_type;
-        
+
         inline void operator()(Float& x) const
         { x.makeExact(); }
     };
@@ -390,7 +382,7 @@ struct Curve_renderer_traits<CORE::BigFloat, class CORE::BigRat>
 
 //! Specialization for \c CORE::BigRat
 template <>
-struct Curve_renderer_traits<CORE::BigRat, CORE::BigRat> : 
+struct Curve_renderer_traits<CORE::BigRat, CORE::BigRat> :
     public Curve_renderer_traits_base<CORE::BigRat, CORE::BigInt,
         CORE::BigRat> {
 
@@ -403,16 +395,16 @@ struct Curve_renderer_traits<CORE::BigRat, CORE::BigRat> :
     struct Rat_to_integer {
         typedef Rational argument_type;
         typedef Integer result_type;
-        
-        Integer operator()(const Rational& x) const { 
-            return x.BigIntValue(); 
+
+        Integer operator()(const Rational& x) const {
+            return x.BigIntValue();
         }
     };
-    
+
     struct Hash_function {
         typedef Float argument_type;
         typedef std::size_t result_type;
-        
+
         inline result_type operator()(const Float& key) const {
             const CORE::BigRatRep& rep = key.getRep();
             std::size_t ret = reinterpret_cast<std::size_t>(&rep);
@@ -427,15 +419,15 @@ template <>
 struct Curve_renderer_traits<CGAL::Interval_nt<true>, leda::rational > :
         public Curve_renderer_traits_base<CGAL::Interval_nt<true>, int,
             leda::rational> {
- 
+
     typedef double Float;
 
     struct Rat_to_float {
         typedef Float result_type;
-                
+
         template <class Extended>
         Float operator()(const Extended& x) const {
-            return CGAL::to_double(x); 
+            return CGAL::to_double(x);
         }
     };
 
@@ -454,20 +446,20 @@ struct Curve_renderer_traits<CGAL::Interval_nt<true>, leda::rational > :
     struct Extract_eval {
         typedef Coeff argument_type;
         typedef Float result_type;
-        
-        Float operator()(const Coeff& x, 
-                    bool *error_bounds = NULL) const { 
+
+        Float operator()(const Coeff& x,
+                    bool *error_bounds = nullptr) const {
             bool err_bnd;
 //             err_bnd = (CGAL_ABS(l) < 1E-15 || CGAL_ABS(u) < 1E-15) ||
 //                 ((l <= 0 && u >= 0));
             Float l = x.inf(), u = x.sup(), mid = (l+u)/2;
             err_bnd = ((l < 0 && u > 0)||(l == 0 && u == 0));
-            if(error_bounds != NULL)
+            if(error_bounds != nullptr)
                 *error_bounds = err_bnd;
 //! ATTENTION!!! if smth is screwed up try to uncomment the line below
 //! this is very crucial for performance & stability
             if(err_bnd)  // &&  ABS(mid) < 1E-15)
-                return 0; 
+                return 0;
 //! ATTENTION!!!
             return mid;
         }
@@ -477,7 +469,7 @@ struct Curve_renderer_traits<CGAL::Interval_nt<true>, leda::rational > :
     //! number type, returns \c true if this limit is exceeded
     struct Precision_limit {
         typedef bool result_type;
-        
+
         template <class Float>
         bool operator()(const Float& x) const
         { return (CGAL_ABS(x) <= 1e-16); }
@@ -486,7 +478,7 @@ struct Curve_renderer_traits<CGAL::Interval_nt<true>, leda::rational > :
 
 //! Specialization for \c leda::bigfloat
 template <>
-struct Curve_renderer_traits<leda::bigfloat, class leda::rational> 
+struct Curve_renderer_traits<leda::bigfloat, class leda::rational>
          : public Curve_renderer_traits_base<leda::bigfloat, leda::integer,
                 leda::rational> {
 
@@ -495,9 +487,9 @@ struct Curve_renderer_traits<leda::bigfloat, class leda::rational>
     struct Rat_to_integer {
         typedef Rational argument_type;
         typedef Integer result_type;
-        
-        Integer operator()(const Rational& x) const { 
-            return leda::floor(x); 
+
+        Integer operator()(const Rational& x) const {
+            return leda::floor(x);
         }
     };
 
@@ -505,45 +497,45 @@ struct Curve_renderer_traits<leda::bigfloat, class leda::rational>
         typedef Float result_type;
 
         template <class X, class Y,class ACDE_TAG,class FP_TAG>
-        Float operator()(const Sqrt_extension<X, Y, ACDE_TAG, FP_TAG>& x) const { 
+        Float operator()(const Sqrt_extension<X, Y, ACDE_TAG, FP_TAG>& x) const {
             typename CGAL::Coercion_traits<Sqrt_extension<X, Y, ACDE_TAG, FP_TAG>, Float>::Cast
-                cast;        
-            return cast(x); 
+                cast;
+            return cast(x);
         }
         // no implicit coercion between leda rational and floats, therefore
         // decompose rational to compute the result
-        Float operator()(const Rational& x) const { 
-            return (static_cast<Float>(x.numerator()) / 
-                    static_cast<Float>(x.denominator())); 
+        Float operator()(const Rational& x) const {
+            return (static_cast<Float>(x.numerator()) /
+                    static_cast<Float>(x.denominator()));
         }
     };
-    
+
     struct Float_to_rat {
         typedef Float argument_type;
         typedef Rational result_type;
-        
+
         Rational operator()(const Float& x) const
         { return x.to_rational(); }
     };
-    
-    struct Convert_poly { 
+
+    struct Convert_poly {
         typedef CGAL::Polynomial<CGAL::Polynomial<Coeff> > result_type;
-        
+
         template <class Extended>
-        inline result_type operator()(const 
+        inline result_type operator()(const
             CGAL::Polynomial<CGAL::Polynomial<Extended> >& poly) const {
-            
+
             Transform<result_type,
                 CGAL::Polynomial<CGAL::Polynomial<Extended> >,
                     Rat_to_float> transform;
             return transform(poly);
         }
     };
-    
+
     struct Hash_function {
         typedef Float argument_type;
         typedef std::size_t result_type;
-        
+
         inline result_type operator()(const Float& key) const {
            return static_cast<std::size_t>(
                     key.get_significant_length());
@@ -553,7 +545,7 @@ struct Curve_renderer_traits<leda::bigfloat, class leda::rational>
 
 //! Specialization for \c leda::rational
 template <>
-struct Curve_renderer_traits<leda::rational, leda::rational> : 
+struct Curve_renderer_traits<leda::rational, leda::rational> :
     public Curve_renderer_traits_base<leda::rational, leda::integer,
         leda::rational> {
 
@@ -566,16 +558,16 @@ struct Curve_renderer_traits<leda::rational, leda::rational> :
     struct Rat_to_integer {
         typedef Rational argument_type;
         typedef Integer result_type;
-        
-        Integer operator()(const Rational& x) const { 
-            return leda::floor(x);  
+
+        Integer operator()(const Rational& x) const {
+            return leda::floor(x);
         }
     };
-    
+
     struct Hash_function {
         typedef Float argument_type;
         typedef std::size_t result_type;
-        
+
         inline result_type operator()(const Float& key) const {
             std::size_t ret = reinterpret_cast<std::size_t>(
                 key.numerator().word_vector());
@@ -586,7 +578,7 @@ struct Curve_renderer_traits<leda::rational, leda::rational> :
     struct Make_exact {
         typedef Float argument_type;
         typedef void result_type;
-        
+
         inline void operator()(Float& x) const
         { x.normalize(); }
     };
