@@ -1,21 +1,12 @@
 // Copyright (c) 2003-2007  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Mesher_level/include/CGAL/Double_map.h $
+// $Id: Double_map.h 393ae7d 2021-05-12T15:03:53+02:00 Maxime Gimeno
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesher_level/include/CGAL/Double_map.h $
-// $Id: Double_map.h a6b6fd6 2018-11-28T10:23:28+01:00 Andreas Fabri
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Laurent RINEAU
 
@@ -31,13 +22,7 @@
 #include <CGAL/function_objects.h> // for CGAL::Identity
 
 #include <boost/version.hpp>
-#if BOOST_VERSION >= 103500
 #  define CGAL_USE_BOOST_BIMAP
-#endif
-
-#if defined(CGAL_USE_BOOST_BIMAP) && BOOST_VERSION == 104100
-#include <CGAL/internal/container_fwd_fixed.hpp>
-#endif
 
 #ifdef CGAL_USE_BOOST_BIMAP
 #  if defined(BOOST_MSVC)
@@ -53,7 +38,7 @@
 
 namespace CGAL {
 
-template <class _Key, class _Data, class _Direct_compare = std::less<_Key>, 
+template <class _Key, class _Data, class _Direct_compare = std::less<_Key>,
           class _Reverse_compare = std::less<_Data> >
 class Double_map
 {
@@ -64,10 +49,10 @@ public:
   typedef _Reverse_compare Reverse_compare;
 
   typedef Double_map<Key, Data, Direct_compare, Reverse_compare> Self;
-  
+
 #ifdef CGAL_USE_BOOST_BIMAP
   typedef ::boost::bimap< ::boost::bimaps::set_of<Key, Direct_compare>,
-				 ::boost::bimaps::multiset_of<Data, Reverse_compare> > Boost_bimap;
+                                 ::boost::bimaps::multiset_of<Data, Reverse_compare> > Boost_bimap;
 
   typedef typename Boost_bimap::left_map Direct_func;
   typedef typename Boost_bimap::right_map Reverse_func;
@@ -87,7 +72,7 @@ public:
   typedef typename Self::Reverse_func::value_type right_value_type;
 #endif
   typedef typename Direct_func::value_type Direct_entry;
-               // std::pair<Key, reverse_iterator> 
+               // std::pair<Key, reverse_iterator>
   typedef typename Reverse_func::value_type Reverse_entry;
                // std::pair<Data, Key> ;
 
@@ -138,7 +123,6 @@ public :
 
   size_type size() const
   {
-    CGAL_assertion(is_valid());
     return direct_func().size();
   }
 
@@ -146,7 +130,7 @@ public :
   {
     return(direct_func().size()==reverse_func().size());
   }
-  
+
   void clear()
   {
 #ifdef CGAL_USE_BOOST_BIMAP
@@ -155,7 +139,7 @@ public :
     direct_func().clear();
     reverse_func().clear();
 #endif
-    
+
   }
 
   Self& operator=(const Self& dm)
@@ -171,14 +155,14 @@ public :
 
 #ifdef CGAL_USE_BOOST_BIMAP
     for(direct_const_iterator rit = dm.direct_func().begin();
-	rit != dm.direct_func().end();
+        rit != dm.direct_func().end();
         ++rit)
     {
       direct_func().insert(*rit);
     }
 #else
     reverse_func() = dm.reverse_func();
-    
+
     for(reverse_iterator rit = reverse_func().begin();
         rit != reverse_func().end();
         ++rit)
@@ -200,7 +184,7 @@ public :
       direct_iterator hint = boost_bimap.left.lower_bound(k);
 
       if(hint != boost_bimap.left.end() && hint->first == k)
-	return false;
+        return false;
 
       boost_bimap.left.insert(hint, Direct_entry(k, d));
       return true;
@@ -208,11 +192,11 @@ public :
       direct_iterator direct_hint = direct_func().lower_bound(k);
 
       if(direct_hint != direct_func().end() &&
-	 direct_hint->first == k)
+         direct_hint->first == k)
         return false;
-      
+
       reverse_iterator reverse_it = reverse_func().insert(Reverse_entry(d, k));
-      
+
       direct_func().insert(direct_hint, Direct_entry(k, reverse_it));
 
       CGAL_assertion(is_valid());
@@ -239,7 +223,7 @@ public :
       direct_iterator pos = direct_func().find(rit->second);
       CGAL_assertion(pos != direct_func().end());
       CGAL_assertion(pos->second == rit);
-      
+
       direct_func().erase(pos);
       reverse_func().erase(rit);
       CGAL_assertion(is_valid());
@@ -250,7 +234,7 @@ public :
   {
     return direct_func().begin();
   }
-    
+
   const_iterator end() const
   {
     return direct_func().end();
@@ -258,20 +242,20 @@ public :
 
   template <typename Func_key, typename Func_data>
   void dump_direct_func(std::ostream& out,
-			Func_key func_key,
-			Func_data func_data)
+                        Func_key func_key,
+                        Func_data func_data)
   {
     for(typename Direct_func::iterator it = direct_func().begin();
-	it != direct_func().end();
-	++it)
+        it != direct_func().end();
+        ++it)
     {
       out << func_key(it->first) << " -> "
 #ifdef CGAL_USE_BOOST_BIMAP
-	  << func_data(it->second)
+          << func_data(it->second)
 #else
-	  << func_data(it->second->first)
+          << func_data(it->second->first)
 #endif
-	  << std::endl;
+          << std::endl;
     }
   }
 
@@ -282,25 +266,25 @@ public :
 
   template <typename Func_key, typename Func_data>
   void dump_reverse_func(std::ostream& out,
-			 Func_key func_key,
-			 Func_data func_data)
+                         Func_key func_key,
+                         Func_data func_data)
   {
     for(typename Reverse_func::iterator it = reverse_func().begin();
-	it != reverse_func().end();
-	++it)
+        it != reverse_func().end();
+        ++it)
     {
       out << func_data(it->first) << " "
-	  << func_key(it->second) << std::endl;
+          << func_key(it->second) << std::endl;
     }
   }
 
-  void dump_reverse_func(std::ostream& out) 
+  void dump_reverse_func(std::ostream& out)
   {
     dump_reverse_func(out, CGAL::Identity<Data>(), CGAL::Identity<Key>());
   }
 };
 
-template <class _Key, class _Data, class _Direct_compare, 
+template <class _Key, class _Data, class _Direct_compare,
   class _Reverse_compare>
 bool
 Double_map<_Key, _Data, _Direct_compare, _Reverse_compare>::
