@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Heat_method_3/include/CGAL/Heat_method_3/Surface_mesh_geodesic_distances_3.h $
-// $Id: Surface_mesh_geodesic_distances_3.h 96ef7fa 2019-01-07T11:45:44+01:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Heat_method_3/include/CGAL/Heat_method_3/Surface_mesh_geodesic_distances_3.h $
+// $Id: Surface_mesh_geodesic_distances_3.h 83b0b0b 2022-11-07T14:23:29+01:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s) : Christina Vaz, Keenan Crane, Andreas Fabri
@@ -30,21 +21,22 @@
 #include <CGAL/property_map.h>
 #include <CGAL/double.h>
 #include <CGAL/boost/graph/properties.h>
+#include <CGAL/Default.h>
 #include <CGAL/Dynamic_property_map.h>
 #include <CGAL/squared_distance_3.h>
-#include <CGAL/Polygon_mesh_processing/measure.h>
 #include <CGAL/number_utils.h>
 #ifdef CGAL_EIGEN3_ENABLED
 #include <CGAL/Eigen_solver_traits.h>
 #endif
 
-#include <boost/foreach.hpp>
+#include <CGAL/Weights/utils.h>
 #include <boost/range/has_range_iterator.hpp>
 
 #include <vector>
 #include <set>
 
 namespace CGAL {
+
 namespace Heat_method_3 {
 
 /**
@@ -98,58 +90,56 @@ protected:
   Face_id_map face_id_map;
 
 public:
+  /*!
+    \brief Constructor
+  */
+  Surface_mesh_geodesic_distances_3(const TriangleMesh& tm,
+                                    VertexPointMap vpm)
+    : vertex_id_map(get(Vertex_property_tag(), tm)),
+      face_id_map(get(Face_property_tag(), tm)),
+      v2v(tm),
+      tm(tm),
+      vpm(vpm)
+  {
+    build();
+  }
 
   /*!
     \brief Constructor
   */
   Surface_mesh_geodesic_distances_3(const TriangleMesh& tm)
-    : vertex_id_map(get(Vertex_property_tag(),tm)), face_id_map(get(Face_property_tag(),tm)), v2v(tm), tm(tm), vpm(get(vertex_point,tm))
+    : Surface_mesh_geodesic_distances_3(tm, get(vertex_point, tm))
   {
     build();
   }
 
-
-  /*!
-    \brief Constructor
-  */
-  Surface_mesh_geodesic_distances_3(const TriangleMesh& tm, VertexPointMap vpm)
-    : v2v(tm), tm(tm), vpm(vpm)
-  {
-    build();
-  }
-
-
   /**
    * returns the triangle mesh the algorithm is running on.
    */
-  const TriangleMesh& triangle_mesh() const{
+  const TriangleMesh& triangle_mesh() const
+  {
     return tm;
   }
 
-
 private:
-
   const Matrix&
   mass_matrix() const
   {
     return m_mass_matrix;
   }
 
-
   const Matrix&
   cotan_matrix() const
   {
     return m_cotan_matrix;
   }
 
-
   const VertexPointMap&
   vertex_point_map() const
   {
     return vpm;
   }
 
-
   const Vertex_id_map&
   get_vertex_id_map() const
   {
@@ -157,7 +147,6 @@ private:
   }
 
 public:
-
   /**
    * adds `vd` to the source set, returning `false` iff `vd` is already in the set.
    */
@@ -179,12 +168,11 @@ public:
   {
     typedef typename std::iterator_traits<typename VertexConstRange::const_iterator>::value_type value_type;
     m_source_change_flag = true;
-    BOOST_FOREACH(value_type vd, vrange){
+    for(value_type vd : vrange){
       m_sources.insert(v2v(vd));
     }
   }
 
-
   /**
    * removes `vd` from the source set, returning `true` iff `vd` was in the set.
    */
@@ -196,7 +184,6 @@ public:
     return (m_sources.erase(v2v(vd)) == 1);
   }
 
-
   /**
    * clears the current source set.
    */
@@ -211,7 +198,6 @@ public:
   /**
    * returns the set of  source vertices.
    */
-
   const Vertex_const_range&
   sources() const
   {
@@ -219,14 +205,13 @@ public:
   }
 
 private:
-
   double
   summation_of_edges() const
   {
     typename Traits::Compute_squared_distance_3 squared_distance = Traits().compute_squared_distance_3_object();
     double edge_sum = 0;
     CGAL::Vertex_around_face_iterator<TriangleMesh> vbegin, vend, vmiddle;
-    BOOST_FOREACH(face_descriptor f, faces(tm)) {
+    for(face_descriptor f : faces(tm)) {
       halfedge_descriptor hd = halfedge(f,tm);
 
       vertex_descriptor neighbor_one = target(hd,tm);
@@ -245,14 +230,12 @@ private:
     return edge_sum;
   }
 
-
   double
   time_step() const
   {
     return m_time_step;
   }
 
-
   void
   update_kronecker_delta()
   {
@@ -263,7 +246,7 @@ private:
       i = 0;
       K.set_coef(i,0, 1, true);
     } else {
-      BOOST_FOREACH(vertex_descriptor vd, sources()){
+      for(vertex_descriptor vd : sources()){
         i = get(vertex_id_map, vd);
         K.set_coef(i,0, 1, true);
       }
@@ -271,14 +254,12 @@ private:
     m_kronecker.swap(K);
   }
 
-
   const Matrix&
   kronecker_delta() const
   {
     return m_kronecker;
   }
 
-
   void factor_cotan_laplace()
   {
     Matrix A, A0;
@@ -301,7 +282,6 @@ private:
     }
   }
 
-
   void
   compute_unit_gradient()
   {
@@ -314,7 +294,7 @@ private:
       m_X.resize(num_faces(tm));
     }
     CGAL::Vertex_around_face_iterator<TriangleMesh> vbegin, vend, vmiddle;
-    BOOST_FOREACH(face_descriptor f, faces(tm)) {
+    for(face_descriptor f : faces(tm)) {
       boost::tie(vbegin, vend) = vertices_around_face(halfedge(f,tm),tm);
       vertex_descriptor current = *(vbegin);
       vertex_descriptor neighbor_one = *(++vbegin);
@@ -360,16 +340,14 @@ private:
     }
   }
 
-
   void
   compute_divergence()
   {
-    typename Traits::Construct_cross_product_vector_3 cross_product = Traits().construct_cross_product_vector_3_object();
     typename Traits::Compute_scalar_product_3 scalar_product = Traits().compute_scalar_product_3_object();
     typename Traits::Construct_vector_3 construct_vector = Traits().construct_vector_3_object();
     Matrix indexD(dimension,1);
     CGAL::Vertex_around_face_iterator<TriangleMesh> vbegin, vend, vmiddle;
-    BOOST_FOREACH(face_descriptor f, faces(tm)) {
+    for(face_descriptor f : faces(tm)) {
       boost::tie(vbegin, vend) = vertices_around_face(halfedge(f,tm),tm);
       vertex_descriptor current = *(vbegin);
       vertex_descriptor neighbor_one = *(++vbegin);
@@ -377,36 +355,30 @@ private:
       Index i = get(vertex_id_map, current);
       Index j = get(vertex_id_map, neighbor_one);
       Index k = get(vertex_id_map, neighbor_two);
-      VertexPointMap_reference p_i = get(vpm,current);
+      VertexPointMap_reference p_i = get(vpm, current);
       VertexPointMap_reference p_j = get(vpm, neighbor_one);
       VertexPointMap_reference p_k = get(vpm, neighbor_two);
       Index face_i = get(face_id_map, f);
 
-      Vector_3 v_ij = construct_vector(p_i,p_j);
-      Vector_3 v_ik = construct_vector(p_i,p_k);
-      Vector_3 cross = cross_product(v_ij, v_ik);
-      double norm_cross = CGAL::sqrt(to_double(scalar_product(cross,cross)));
-      double dot = to_double(scalar_product(v_ij, v_ik));
-      double cotan_i = dot/norm_cross;
+      const Vector_3 v_ij = construct_vector(p_i, p_j);
+      const Vector_3 v_ik = construct_vector(p_i, p_k);
+      const Vector_3 v_ji = construct_vector(p_j, p_i);
+      const Vector_3 v_jk = construct_vector(p_j, p_k);
+      const Vector_3 v_ki = construct_vector(p_k, p_i);
+      const Vector_3 v_kj = construct_vector(p_k, p_j);
 
-      Vector_3 v_ji = construct_vector(p_j, p_i);
-      Vector_3 v_jk = construct_vector(p_j, p_k);
+      const Traits traits;
+      const FT cotan_i = CGAL::Weights::cotangent(p_k, p_i, p_j, traits);
+      const FT cotan_j = CGAL::Weights::cotangent(p_k, p_j, p_i, traits);
+      const FT cotan_k = CGAL::Weights::cotangent(p_j, p_k, p_i, traits);
 
-      cross = cross_product(v_ji, v_jk);
-      dot = to_double(scalar_product(v_ji, v_jk));
-      double cotan_j = dot/norm_cross;
-
-      Vector_3 v_ki = construct_vector(p_k,p_i);
-      Vector_3 v_kj = construct_vector(p_k,p_j);
-
-      cross = cross_product(v_ki, v_kj);
-      dot = to_double(scalar_product(v_ki,v_kj));
-      double cotan_k = dot/norm_cross;
-
-      const Vector_3& a  = m_X[face_i];
-      double i_entry = (to_double(scalar_product(a,v_ij)) * cotan_k) + (to_double(scalar_product(a,v_ik)) *  cotan_j);
-      double j_entry = (to_double(scalar_product(a,v_jk)) * cotan_i) + (to_double(scalar_product(a,v_ji)) * cotan_k);
-      double k_entry = (to_double(scalar_product(a,v_ki)) * cotan_j) + (to_double(scalar_product(a,v_kj)) * cotan_i);
+      const Vector_3& a = m_X[face_i];
+      const double i_entry = (CGAL::to_double(scalar_product(a, v_ij) * cotan_k)) +
+                             (CGAL::to_double(scalar_product(a, v_ik) * cotan_j));
+      const double j_entry = (CGAL::to_double(scalar_product(a, v_jk) * cotan_i)) +
+                             (CGAL::to_double(scalar_product(a, v_ji) * cotan_k));
+      const double k_entry = (CGAL::to_double(scalar_product(a, v_ki) * cotan_j)) +
+                             (CGAL::to_double(scalar_product(a, v_kj) * cotan_i));
 
       indexD.add_coef(i, 0, (1./2)*i_entry);
       indexD.add_coef(j, 0, (1./2)*j_entry);
@@ -415,7 +387,6 @@ private:
     indexD.swap(m_index_divergence);
   }
 
-
   // modifies m_solved_phi
   void
   value_at_source_set(const Vector& phi)
@@ -431,7 +402,7 @@ private:
         double min_val = (std::numeric_limits<double>::max)();
         Index vd_index;
         //go through the distances to the sources and leave the minimum distance;
-        BOOST_FOREACH(vertex_descriptor vd, sources()){
+        for(vertex_descriptor vd : sources()){
           vd_index = get(vertex_id_map, vd);
           double new_d = CGAL::abs(-phi.coeff(vd_index,0)+phi.coeff(i,0));
           if(phi.coeff(vd_index,0)==phi.coeff(i,0)) {
@@ -447,7 +418,6 @@ private:
     m_solved_phi.swap(source_set_val);
   }
 
-
   void
   factor_phi()
   {
@@ -458,12 +428,11 @@ private:
     }
   }
 
-  
   void
   solve_phi()
   {
     Vector phi;
-  
+
     if(! la_cotan.linear_solver(m_index_divergence, phi)) {
       // solving failed
       CGAL_error_msg("Eigen Solving in solve_phi() failed");
@@ -471,7 +440,6 @@ private:
     value_at_source_set(phi);
   }
 
-
   // this function returns a (number of vertices)x1 vector where
   // the ith index has the distance from the first vertex to the ith vertex
   const Vector&
@@ -481,7 +449,6 @@ private:
   }
 
 public:
-
   /**
    *  Updates the distance property map after changes in the source set.
    **/
@@ -501,7 +468,7 @@ public:
       solve_phi();              // depends on m_index_divergence
       m_source_change_flag = false;
     }
-    BOOST_FOREACH(vertex_descriptor vd, vertices(tm)){
+    for(vertex_descriptor vd : vertices(tm)){
       Index i_d = get(vertex_id_map, vd);
       d = m_solved_phi(i_d,0);
       put(vdm,vd,d);
@@ -509,7 +476,6 @@ public:
   }
 
 private:
-
   void
   build()
   {
@@ -522,13 +488,16 @@ private:
     }
     m_source_change_flag = false;
 
-    CGAL_precondition(is_triangle_mesh(tm));
     Index i = 0;
-    BOOST_FOREACH(vertex_descriptor vd, vertices(tm)){
+    for(vertex_descriptor vd : vertices(tm)){
       put(vertex_id_map, vd, i++);
     }
     Index face_i = 0;
-    BOOST_FOREACH(face_descriptor fd, faces(tm)){
+    for(face_descriptor fd : faces(tm)){
+      // Do not use BGL's version because `tm` is not a valid halfedge graph due to its weird vertex descriptor:
+      // it fails checks such as halfedge(target(h, g), g) == h
+      CGAL_assertion_code(halfedge_descriptor hd = halfedge(fd, tm);)
+      CGAL_assertion(hd == next(next(next(hd,tm),tm),tm));
       put(face_id_map, fd, face_i++);
     }
     dimension = static_cast<int>(num_vertices(tm));
@@ -542,7 +511,7 @@ private:
     }
     CGAL::Vertex_around_face_iterator<TriangleMesh> vbegin, vend, vmiddle;
 
-    BOOST_FOREACH(face_descriptor f, faces(tm)) {
+    for(face_descriptor f : faces(tm)) {
       boost::tie(vbegin, vend) = vertices_around_face(halfedge(f,tm),tm);
       vertex_descriptor current = *(vbegin);
       vertex_descriptor neighbor_one = *(++vbegin);
@@ -552,47 +521,36 @@ private:
       Index k = get(vertex_id_map, neighbor_two);
       Point_3 pi, pj, pk;
 
-      VertexPointMap_reference p_i = get(vpm,current);
+      const Traits traits;
+      VertexPointMap_reference p_i = get(vpm, current);
       VertexPointMap_reference p_j = get(vpm, neighbor_one);
       VertexPointMap_reference p_k = get(vpm, neighbor_two);
       pi = p_i;
       pj = p_j;
       pk = p_k;
 
-      Vector_3 v_ij = construct_vector(p_i,p_j);
-      Vector_3 v_ik = construct_vector(p_i,p_k);
+      const double cotan_i = CGAL::to_double(CGAL::Weights::cotangent(pk, pi, pj, traits));
+      m_cotan_matrix.add_coef(j, k, -(1./2) * cotan_i);
+      m_cotan_matrix.add_coef(k, j, -(1./2) * cotan_i);
+      m_cotan_matrix.add_coef(j, j,  (1./2) * cotan_i);
+      m_cotan_matrix.add_coef(k, k,  (1./2) * cotan_i);
 
-      Vector_3 cross = cross_product(v_ij, v_ik);
-      double dot = to_double(scalar_product(v_ij,v_ik));
+      const double cotan_j = CGAL::to_double(CGAL::Weights::cotangent(pk, pj, pi, traits));
+      m_cotan_matrix.add_coef(i, k, -(1./2) * cotan_j);
+      m_cotan_matrix.add_coef(k, i, -(1./2) * cotan_j);
+      m_cotan_matrix.add_coef(i, i,  (1./2) * cotan_j);
+      m_cotan_matrix.add_coef(k, k,  (1./2) * cotan_j);
 
-      double norm_cross = (CGAL::sqrt(to_double(scalar_product(cross,cross))));
+      const double cotan_k = CGAL::to_double(CGAL::Weights::cotangent(pj, pk, pi, traits));
+      m_cotan_matrix.add_coef(i, j, -(1./2) * cotan_k);
+      m_cotan_matrix.add_coef(j, i, -(1./2) * cotan_k);
+      m_cotan_matrix.add_coef(i, i,  (1./2) * cotan_k);
+      m_cotan_matrix.add_coef(j, j,  (1./2) * cotan_k);
 
-      double cotan_i = dot/norm_cross;
-      m_cotan_matrix.add_coef(j,k ,-(1./2)*cotan_i);
-      m_cotan_matrix.add_coef(k,j,-(1./2)* cotan_i);
-      m_cotan_matrix.add_coef(j,j,(1./2)*cotan_i);
-      m_cotan_matrix.add_coef(k,k,(1./2)* cotan_i);
-
-      Vector_3 v_ji = construct_vector(p_j,p_i);
-      Vector_3 v_jk = construct_vector(p_j,p_k);
-
-      cross = cross_product(v_ji, v_jk);
-      dot = to_double(scalar_product(v_ji, v_jk));
-      double cotan_j = dot/norm_cross;
-      m_cotan_matrix.add_coef(i,k ,-(1./2)*cotan_j);
-      m_cotan_matrix.add_coef(k,i,-(1./2)* cotan_j);
-      m_cotan_matrix.add_coef(i,i,(1./2)* cotan_j);
-      m_cotan_matrix.add_coef(k,k,(1./2)* cotan_j);
-
-      Vector_3 v_ki = construct_vector(p_k,p_i);
-      Vector_3 v_kj = construct_vector(p_k,p_j);
-      cross = cross_product(v_ki, v_kj);
-      dot = to_double(scalar_product(v_ki,v_kj));
-      double cotan_k = dot/norm_cross;
-      m_cotan_matrix.add_coef(i,j,-(1./2)*cotan_k);
-      m_cotan_matrix.add_coef(j,i,-(1./2)* cotan_k);
-      m_cotan_matrix.add_coef(i,i,(1./2)* cotan_k);
-      m_cotan_matrix.add_coef(j,j,(1./2)* cotan_k);
+      const Vector_3 v_ij = construct_vector(p_i, p_j);
+      const Vector_3 v_ik = construct_vector(p_i, p_k);
+      const Vector_3 cross = cross_product(v_ij, v_ik);
+      const double norm_cross = CGAL::sqrt(CGAL::to_double(scalar_product(cross, cross)));
 
       //double area_face = CGAL::Polygon_mesh_processing::face_area(f,tm);
       //cross is 2*area
@@ -666,6 +624,9 @@ struct Base_helper
   template <class VertexDistanceMap>
   void estimate_geodesic_distances(VertexDistanceMap vdm)
   {
+    CGAL_assertion(
+      !CGAL::Heat_method_3::internal::has_degenerate_faces(
+        base().triangle_mesh(), Traits()));
     base().estimate_geodesic_distances(vdm);
   }
 };
@@ -733,7 +694,7 @@ struct Base_helper<TriangleMesh, Traits, Intrinsic_Delaunay, LA, VertexPointMap>
 
 
 /**
- * \ingroup PkgHeatMethod
+ * \ingroup PkgHeatMethodRef
  *
  * Class `Surface_mesh_geodesic_distances_3` computes estimated geodesic distances for a set of source vertices where sources can be added and removed.
  * The class performs a preprocessing step that only depends on the mesh, so that the distance computation takes less
@@ -744,6 +705,7 @@ struct Base_helper<TriangleMesh, Traits, Intrinsic_Delaunay, LA, VertexPointMap>
  *                              or `Direct` to indicate that the input mesh should be used as is.
  *                              If `Intrinsic_Delaunay`, then the type `TriangleMesh` must have an internal property for `vertex_point`
  *                              and its value type must be the same as the value type of `VertexPointMap`.
+ *                              If `Direct`, then the input mesh should not have any degenerate faces.
  * \tparam VertexPointMap a model of `ReadablePropertyMap` with
  *         `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key and
  *         `Traits::Point_3` as value type.
@@ -753,7 +715,6 @@ struct Base_helper<TriangleMesh, Traits, Intrinsic_Delaunay, LA, VertexPointMap>
  *         is used as default
  * \tparam Traits a model of `HeatMethodTraits_3`. The default is the Kernel of the value type
  *         of the vertex point map (extracted using `Kernel_traits`).
- *
  */
 template <typename TriangleMesh,
           typename Mode = Direct,
@@ -776,14 +737,14 @@ class Surface_mesh_geodesic_distances_3
         >::Kernel
       >::type,
       Mode,
-      #ifdef CGAL_EIGEN3_ENABLED
+#ifdef CGAL_EIGEN3_ENABLED
       typename Default::Get<
         LA,
         Eigen_solver_traits<Eigen::SimplicialLDLT<typename Eigen_sparse_matrix<double>::EigenType > >
       >::type,
-      #else
+#else
       LA,
-      #endif
+#endif
       typename Default::Get<
         VertexPointMap,
         typename boost::property_map< TriangleMesh, vertex_point_t>::const_type
@@ -791,19 +752,23 @@ class Surface_mesh_geodesic_distances_3
     >
 #endif
 {
+  CGAL_static_assertion((std::is_same<Mode, Direct>::value) ||
+                        (std::is_same<Mode, Intrinsic_Delaunay>::value));
+
   // extract real types from Default
-  #ifdef CGAL_EIGEN3_ENABLED
+#ifdef CGAL_EIGEN3_ENABLED
   typedef typename Default::Get<
     LA,
     Eigen_solver_traits<Eigen::SimplicialLDLT<typename Eigen_sparse_matrix<double>::EigenType > >
   >::type LA_type;
-  #else
+#else
   typedef LA LA_type;
-  #endif
+#endif
 
   typedef typename Default::Get<
     VertexPointMap,
     typename boost::property_map< TriangleMesh, vertex_point_t>::const_type>::type Vertex_point_map;
+
   typedef
     typename Default::Get<Traits,
                           typename Kernel_traits<
@@ -824,7 +789,6 @@ class Surface_mesh_geodesic_distances_3
   }
 
 public:
-
   /// Vertex descriptor type
   typedef typename boost::graph_traits<TriangleMesh>::vertex_descriptor vertex_descriptor;
   #ifndef DOXYGEN_RUNNING
@@ -897,16 +861,6 @@ public:
     base().clear_sources();
   }
 
-  /**
-   * get estimated distance from the current source set to a vertex `vd`.
-   * \warning The return type is `double` even when used with an exact kernel.
-   */
-  double
-  estimate_geodesic_distance(vertex_descriptor vd) const
-  {
-    return base().estimate_geodesic_distance(vd);
-  }
-
   /**
    * returns the source set.
    */
@@ -916,12 +870,12 @@ public:
     return base().sources();
   }
 
-
   /**
    * fills the distance property map with the estimated geodesic distance of each vertex to the closest source vertex.
    * \tparam VertexDistanceMap a property map model of `WritablePropertyMap`
    * with `vertex_descriptor` as key type and `double` as value type.
    * \param vdm the vertex distance map to be filled
+   * \pre If `Mode` is `Direct`, the support triangle mesh does not have any degenerate faces
    * \warning The key type is `double` even when used with an exact kernel.
    **/
   template <class VertexDistanceMap>
@@ -932,7 +886,7 @@ public:
 };
 
 #if defined(DOXYGEN_RUNNING) || defined(CGAL_EIGEN3_ENABLED)
-/// \ingroup PkgHeatMethod
+/// \ingroup PkgHeatMethodRef
 /// computes for each vertex of the triangle mesh `tm` the estimated geodesic distance to a given source vertex.
 /// This function is provided only if \ref thirdpartyEigen "Eigen" 3.3 (or greater) is available and `CGAL_EIGEN3_ENABLED` is defined.
 /// \tparam TriangleMesh a triangulated surface mesh, model of `FaceListGraph` and `HalfedgeListGraph`.
@@ -942,6 +896,7 @@ public:
 /// \tparam Mode either the tag `Direct` or `Intrinsic_Delaunay`, which determines if the geodesic distance
 ///              is computed directly on the mesh or if the intrinsic Delaunay triangulation is applied first.
 ///              The default is `Intrinsic_Delaunay`.
+/// \pre If `Mode` is `Direct`, `tm` does not have any degenerate faces
 /// \warning The return type is `double` even when used with an exact kernel.
 ///
 /// \sa `CGAL::Heat_method_3::Surface_mesh_geodesic_distances_3`
@@ -972,7 +927,7 @@ estimate_geodesic_distances(const TriangleMesh& tm,
 #endif
 
 
-/// \ingroup PkgHeatMethod
+/// \ingroup PkgHeatMethodRef
 /// computes for each vertex  of the triangle mesh `tm` the estimated geodesic distance to a given set of source vertices.
 /// This function is provided only if \ref thirdpartyEigen "Eigen" 3.3 (or greater) is available and `CGAL_EIGEN3_ENABLED` is defined.
 /// \tparam TriangleMesh a triangulated surface mesh, model of `FaceListGraph` and `HalfedgeListGraph`
@@ -983,6 +938,7 @@ estimate_geodesic_distances(const TriangleMesh& tm,
 /// \tparam Mode either the tag `Direct` or `Intrinsic_Delaunay`, which determines if the geodesic distance
 ///              is computed directly on the mesh or if the intrinsic Delaunay triangulation is applied first.
 ///              The default is `Intrinsic_Delaunay`.
+/// \pre If `Mode` is `Direct`, `tm` mesh does not have any degenerate faces
 /// \warning The return type is `double` even when used with an exact kernel.
 /// \sa `CGAL::Heat_method_3::Surface_mesh_geodesic_distances_3`
 template <typename TriangleMesh, typename VertexDistanceMap, typename VertexConstRange, typename Mode>
@@ -992,9 +948,9 @@ estimate_geodesic_distances(const TriangleMesh& tm,
                             const VertexConstRange& sources,
                             Mode
 #ifndef DOXYGEN_RUNNING
-                            , typename boost::enable_if<
-                              typename boost::has_range_const_iterator<VertexConstRange>
-                                     >::type* = 0
+                            , std::enable_if_t<
+                                boost::has_range_const_iterator<VertexConstRange>::value
+                                     >* = 0
 #endif
 )
 {
@@ -1009,9 +965,9 @@ void
 estimate_geodesic_distances(const TriangleMesh& tm,
                             VertexDistanceMap vdm,
                             const VertexConstRange& sources,
-                            typename boost::enable_if<
-                              typename boost::has_range_const_iterator<VertexConstRange>
-                                     >::type* = 0)
+                            std::enable_if_t<
+                              boost::has_range_const_iterator<VertexConstRange>::value
+                                     >* = 0)
 {
   CGAL::Heat_method_3::Surface_mesh_geodesic_distances_3<TriangleMesh, Intrinsic_Delaunay> hm(tm);
   hm.add_sources(sources);
