@@ -1,25 +1,16 @@
-// Copyright (c) 1999  
+// Copyright (c) 1999
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Homogeneous_kernel/include/CGAL/Homogeneous/Iso_cuboidH3.h $
+// $Id: Iso_cuboidH3.h 22f5d89 2021-06-25T20:15:56+02:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Homogeneous_kernel/include/CGAL/Homogeneous/Iso_cuboidH3.h $
-// $Id: Iso_cuboidH3.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Stefan Schirra
 
@@ -41,7 +32,7 @@ class Iso_cuboidH3
   typedef typename R_::Point_3              Point_3;
   typedef typename R_::Aff_transformation_3 Aff_transformation_3;
 
-  typedef cpp11::array<Point_3, 2>          Rep;
+  typedef std::array<Point_3, 2>          Rep;
   typedef typename R_::template Handle<Rep>::type  Base;
 
   Base base;
@@ -66,7 +57,7 @@ public:
                const Point_3& far_,   const Point_3& close);
 
   Iso_cuboidH3(const RT& min_hx, const RT& min_hy, const RT& min_hz,
-               const RT& max_hx, const RT& max_hy, const RT& max_hz, 
+               const RT& max_hx, const RT& max_hy, const RT& max_hz,
                const RT& hw);
 
   Iso_cuboidH3(const RT& min_hx, const RT& min_hy, const RT& min_hz,
@@ -106,7 +97,7 @@ template < class R >
 CGAL_KERNEL_LARGE_INLINE
 Iso_cuboidH3<R>::
 Iso_cuboidH3(const typename Iso_cuboidH3<R>::Point_3& p,
-	     const typename Iso_cuboidH3<R>::Point_3& q)
+             const typename Iso_cuboidH3<R>::Point_3& q)
 {
   bool px_k_qx = ( p.hx()*q.hw() < q.hx()*p.hw() );
   bool py_k_qy = ( p.hy()*q.hw() < q.hy()*p.hw() );
@@ -190,7 +181,7 @@ template < class R >
 CGAL_KERNEL_LARGE_INLINE
 Iso_cuboidH3<R>::
 Iso_cuboidH3(const RT& min_hx, const RT& min_hy, const RT& min_hz,
-             const RT& max_hx, const RT& max_hy, const RT& max_hz, 
+             const RT& max_hx, const RT& max_hy, const RT& max_hz,
              const RT& hw)
   : base(CGAL::make_array(Point_3(min_hx, min_hy, min_hz, hw),
                            Point_3(max_hx, max_hy, max_hz, hw)))
@@ -262,7 +253,7 @@ template < class R >
 inline
 typename Iso_cuboidH3<R>::FT
 Iso_cuboidH3<R>::min_coord(int i) const
-{ 
+{
    CGAL_kernel_precondition(i == 0 || i == 1 || i == 2);
    if ( i == 0 )
        return xmin();
@@ -275,7 +266,7 @@ template < class R >
 inline
 typename Iso_cuboidH3<R>::FT
 Iso_cuboidH3<R>::max_coord(int i) const
-{ 
+{
    CGAL_kernel_precondition(i == 0 || i == 1 || i == 2);
    if ( i == 0 )
       return xmax();
@@ -299,17 +290,17 @@ Iso_cuboidH3<R>::vertex(int i) const
   {
     case 0: return (this->min)();
     case 1: return Point_3( (this->max)().hx(), (this->min)().hy(),
-		                   (this->min)().hz(), (this->min)().hw() );
+                                   (this->min)().hz(), (this->min)().hw() );
     case 2: return Point_3( (this->max)().hx(), (this->max)().hy(),
-		                   (this->min)().hz(), (this->min)().hw() );
+                                   (this->min)().hz(), (this->min)().hw() );
     case 3: return Point_3( (this->min)().hx(), (this->max)().hy(),
-		                   (this->min)().hz(), (this->min)().hw() );
+                                   (this->min)().hz(), (this->min)().hw() );
     case 4: return Point_3( (this->min)().hx(), (this->max)().hy(),
-		                   (this->max)().hz(), (this->min)().hw() );
+                                   (this->max)().hz(), (this->min)().hw() );
     case 5: return Point_3( (this->min)().hx(), (this->min)().hy(),
-		                   (this->max)().hz(), (this->min)().hw() );
+                                   (this->max)().hz(), (this->min)().hw() );
     case 6: return Point_3( (this->max)().hx(), (this->min)().hy(),
-		                   (this->max)().hz(), (this->min)().hw() );
+                                   (this->max)().hz(), (this->min)().hw() );
     default: /*case 7:*/ return (this->max)();
   }
 }
@@ -369,10 +360,7 @@ CGAL_KERNEL_INLINE
 bool
 Iso_cuboidH3<R>::
 has_on_unbounded_side(const typename Iso_cuboidH3<R>::Point_3& p) const
-{
-  return (   ( lexicographically_xyz_smaller(p,(this->min)() ))
-           ||( lexicographically_xyz_smaller((this->max)(),p ))  );
-}
+{ return ( bounded_side(p) == ON_UNBOUNDED_SIDE ); }
 
 template < class R >
 CGAL_KERNEL_INLINE
