@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Apollonius_graph_2/include/CGAL/Hyperbola_ray_2.h $
+// $Id: Hyperbola_ray_2.h 45b73ad 2021-05-12T15:45:07+02:00 Maxime Gimeno
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Apollonius_graph_2/include/CGAL/Hyperbola_ray_2.h $
-// $Id: Hyperbola_ray_2.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
@@ -53,20 +44,12 @@ public:
   using Base::f;
 
 protected:
-#if defined(__POWERPC__) && \
-  defined(__GNUC__) && (__GNUC__ == 3 ) && (__GNUC_MINOR__ == 4)
-  // hack to avoid nasty warning for G++ 3.4 on Darwin
-  static FT OFFSET()
-  {
-    return FT(10000);
-  }
-#else
+
   static const FT& OFFSET()
   {
     static const FT offset_(10000);
     return offset_;
   }
-#endif
 
   template< class Stream >
   inline
@@ -84,8 +67,8 @@ public:
 
 
   Hyperbola_ray_2(const Site_2 &f1, const Site_2 &f2,
-		  const Point_2 &p,
-		  const Hyperbola_direction& direction) :
+                  const Point_2 &p,
+                  const Hyperbola_direction& direction) :
     Hyperbola_segment_2< Gt >(f1, f2, p, p),
     _f1(f1), _f2(f2), _p(p), _dir(direction)
   {
@@ -121,7 +104,7 @@ public:
     } else {
       this->p2 = f(t1 - this->STEP * OFFSET());
     }
-    
+
     Hyperbola_segment_2< Gt >::draw(s);
   }
 
@@ -136,7 +119,7 @@ public:
 
     Hyperbola_segment_2< Gt >::draw(s);
   }
-  
+
 };
 
 
