@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Hyperbolic_triangulation_2/include/CGAL/Hyperbolic_Delaunay_triangulation_traits_2.h $
-// $Id: Hyperbolic_Delaunay_triangulation_traits_2.h 9792b24 2019-01-14T18:29:42+01:00 Iordan Iordanov
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Hyperbolic_triangulation_2/include/CGAL/Hyperbolic_Delaunay_triangulation_traits_2.h $
+// $Id: Hyperbolic_Delaunay_triangulation_traits_2.h d3fca65 2022-09-23T12:49:40+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Iordan Iordanov
 //                 Monique Teillaud
@@ -30,10 +21,10 @@
 #include <CGAL/Bbox_2.h>
 #include <CGAL/determinant.h>
 #include <CGAL/distance_predicates_2.h>
-#include <CGAL/internal/Exact_complex.h>
+#include <CGAL/Hyperbolic_triangulation_2/internal/Exact_complex.h>
 #include <CGAL/Origin.h>
 #include <CGAL/predicates_on_points_2.h>
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/utility.h>
 
 #include <boost/tuple/tuple.hpp>
@@ -41,7 +32,7 @@
 
 #include <utility>
 
-#include <CGAL/internal/Hyperbolic_Delaunay_triangulation_traits_2_functions.h>
+#include <CGAL/Hyperbolic_triangulation_2/internal/Hyperbolic_Delaunay_triangulation_traits_2_functions.h>
 
 namespace CGAL {
 
@@ -374,9 +365,9 @@ public:
                                   const Hyperbolic_point_2& r,
                                   const Hyperbolic_point_2& s) const
   {
-    CGAL_triangulation_precondition((_gt.orientation_2_object()(p, q, r) == ON_POSITIVE_SIDE) &&
+    CGAL_precondition((_gt.orientation_2_object()(p, q, r) == ON_POSITIVE_SIDE) &&
                                     (_gt.orientation_2_object()(p, s, q) == ON_POSITIVE_SIDE));
-    CGAL_triangulation_precondition((_gt.side_of_oriented_circle_2_object()(p, q, r,s) == ON_NEGATIVE_SIDE) &&
+    CGAL_precondition((_gt.side_of_oriented_circle_2_object()(p, q, r,s) == ON_NEGATIVE_SIDE) &&
                                     (_gt.side_of_oriented_circle_2_object()(p, s, q, r) == ON_NEGATIVE_SIDE));
 
     Construct_hyperbolic_circumcenter_2<Traits> chc(_gt);
@@ -414,7 +405,7 @@ public:
                                   const Hyperbolic_point_2& q,
                                   const Hyperbolic_point_2& r) const
   {
-    CGAL_triangulation_precondition(_gt.orientation_2_object()(p, q, r) == POSITIVE);
+    CGAL_precondition(_gt.orientation_2_object()(p, q, r) == POSITIVE);
 
     Construct_circle_or_line_supporting_bisector<Traits> cclsb(_gt);
     Construct_hyperbolic_circumcenter_2<Traits> chc(_gt);
@@ -463,7 +454,6 @@ private:
 
 } // end namespace internal
 
-//template<typename Kernel = CGAL::Cartesian<CORE::Expr> >
 
 template<typename Kernel = Exact_predicates_exact_constructions_kernel_with_sqrt>
 class Hyperbolic_Delaunay_triangulation_traits_2
