@@ -1,25 +1,16 @@
-// Copyright (c) 1997-2000  
+// Copyright (c) 1997-2000
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Kernel_d/include/CGAL/Kernel_d/Vector__.h $
+// $Id: Vector__.h 78ff918 2021-06-23T23:34:14+02:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Kernel_d/include/CGAL/Kernel_d/Vector__.h $
-// $Id: Vector__.h 095c27e 2018-04-17T16:42:25+02:00 Laurent Rineau
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
 
@@ -67,7 +58,7 @@ beyond the last element to be accepted).}*/
 
 /*{\Manpage {Vector}{}{Vectors with NT Entries}{v}}*/
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 class Vector_
 {
 /*{\Mdefinition An instance of data type |Vector_| is a vector of
@@ -81,14 +72,14 @@ typedef NT_*       pointer;
 typedef const NT_* const_pointer;
 
 typedef NT_    NT;
-/*{\Mtypemember the ring type of the components.}*/ 
+/*{\Mtypemember the ring type of the components.}*/
 typedef pointer iterator;
-/*{\Mtypemember the iterator type for accessing components.}*/ 
+/*{\Mtypemember the iterator type for accessing components.}*/
 typedef const_pointer const_iterator;
-/*{\Mtypemember the const iterator type for accessing components.}*/ 
+/*{\Mtypemember the const iterator type for accessing components.}*/
 
 typedef AL_ allocator_type;
-/*{\Xtypemember the allocator type.}*/ 
+/*{\Xtypemember the allocator type.}*/
 
 protected:
   friend class Matrix_<NT_,AL_>;
@@ -102,13 +93,13 @@ protected:
 
   inline void allocate_vec_space(NT*& vi, int di)
   {
-  /* We use this procedure to allocate memory. We first get an appropriate 
-     piece of memory from the allocator and then initialize each cell 
+  /* We use this procedure to allocate memory. We first get an appropriate
+     piece of memory from the allocator and then initialize each cell
      by an inplace new. */
 
     vi = allocator().allocate(di);
     NT* p = vi + di - 1;
-    while (p >= vi) { new (p) NT(0);  p--; }   
+    while (p >= vi) { new (p) NT(0);  p--; }
   }
 
   inline void deallocate_vec_space(NT*& vi, int di)
@@ -120,22 +111,18 @@ protected:
 
     NT* p = vi + di - 1;
     while (p >= vi)  {
-#ifdef CGAL_CXX11
       std::allocator_traits<allocator_type>::destroy(allocator(),p);
-#else
-      allocator().destroy(p);
-#endif
       p--;
     }  //af:  as proposed by sylvain
     allocator().deallocate(vi, di);
     vi = (NT*)0;
   }
 
-inline void 
+inline void
 check_dimensions(const Vector_<NT_,AL_>& vec) const
-{ 
+{
   CGAL_USE(vec);
-  CGAL_assertion_msg((d_ == vec.d_), 
+  CGAL_assertion_msg((d_ == vec.d_),
     "Vector_::check_dimensions: object dimensions disagree.");
 }
 
@@ -144,29 +131,29 @@ public:
 /*{\Mcreation v 3}*/
 
 Vector_() : v_(0),d_(0) {}
-/*{\Mcreate creates an instance |\Mvar| of type |\Mname|.}*/ 
+/*{\Mcreate creates an instance |\Mvar| of type |\Mname|.}*/
 
-Vector_(int d) 
-/*{\Mcreate creates an instance |\Mvar| of type |\Mname|. 
-|\Mvar| is initialized to a vector of dimension $d$.}*/ 
-{ CGAL_assertion_msg( d >= 0 , 
+Vector_(int d)
+/*{\Mcreate creates an instance |\Mvar| of type |\Mname|.
+|\Mvar| is initialized to a vector of dimension $d$.}*/
+{ CGAL_assertion_msg( d >= 0 ,
     "Vector_::constructor: negative dimension.");
-  d_ = d; 
+  d_ = d;
   v_ = (NT*)0;
-  if (d_ > 0){ 
+  if (d_ > 0){
     allocate_vec_space(v_,d_);
     while (d--) v_[d] = NT(0);
   }
 }
 
-Vector_(int d, const NT& x) 
-/*{\Mcreate creates an instance |\Mvar| of type |\Mname|. 
-|\Mvar| is initialized to a vector of dimension $d$ with entries |x|.}*/ 
-{ 
-  CGAL_assertion_msg( d >= 0 , 
+Vector_(int d, const NT& x)
+/*{\Mcreate creates an instance |\Mvar| of type |\Mname|.
+|\Mvar| is initialized to a vector of dimension $d$ with entries |x|.}*/
+{
+  CGAL_assertion_msg( d >= 0 ,
     "Vector_::constructor: negative dimension.");
   d_ = d; v_ = (NT*)0;
-  if (d_ > 0){ 
+  if (d_ > 0){
     allocate_vec_space(v_,d_);
     while (d--) v_[d] = x;
   }
@@ -174,10 +161,10 @@ Vector_(int d, const NT& x)
 
 template <class Forward_iterator>
 Vector_(Forward_iterator first, Forward_iterator last)
-/*{\Mcreate creates an instance |\Mvar| of type |\Mname|; 
+/*{\Mcreate creates an instance |\Mvar| of type |\Mname|;
 |\Mvar| is initialized to the vector with entries
 |set [first,last)|. \require |Forward_iterator| has value type |NT|.}*/
-{ 
+{
 #if defined _MSC_VER && _MSC_VER == 1300
   d_ = 0;
   Forward_iterator fit = first;
@@ -199,7 +186,7 @@ Vector_(const Vector_<NT_,AL_>& p)
 
 
 Vector_<NT_,AL_>& operator=(const Vector_<NT_,AL_>& vec)
-{ 
+{
   if (&vec == this)
     return *this;
 
@@ -215,29 +202,29 @@ Vector_<NT_,AL_>& operator=(const Vector_<NT_,AL_>& vec)
   return *this;
 }
 
-~Vector_() 
+~Vector_()
 { if (d_ > 0) deallocate_vec_space(v_,d_); }
 
 /*{\Moperations 3 4}*/
 
 int  dimension() const { return d_; }
-/*{\Mop returns the dimension of |\Mvar|.}*/ 
+/*{\Mop returns the dimension of |\Mvar|.}*/
 
-bool is_zero() const 
-/*{\Mop returns true iff |\Mvar| is the zero vector.}*/ 
-{ for(int i=0; i<d_; ++i) if (v_[i]!=NT(0)) return false; 
+bool is_zero() const
+/*{\Mop returns true iff |\Mvar| is the zero vector.}*/
+{ for(int i=0; i<d_; ++i) if (v_[i]!=NT(0)) return false;
   return true; }
-  
+
 NT& operator[](int i)
 /*{\Marrop returns $i$-th component of |\Mvar|.\\
            \precond $0\le i \le |v.dimension()-1|$. }*/
-{ CGAL_assertion_msg((0<=i && i<d_), 
+{ CGAL_assertion_msg((0<=i && i<d_),
     "Vector_::operator[]: index out of range.");
   return v_[i];
 }
-  
+
 const NT& operator[](int i) const
-{ CGAL_assertion_msg((0<=i && i<d_), 
+{ CGAL_assertion_msg((0<=i && i<d_),
     "Vector_::operator[]: index out of range.");
   return v_[i];
 }
@@ -247,7 +234,7 @@ iterator begin() { return v_; }
 iterator end() { return v_+d_; }
 /*{\Mop iterator beyond the last component.}*/
 
-/*{\Mtext The same operations |begin()|, |end()| exist for 
+/*{\Mtext The same operations |begin()|, |end()| exist for
 |const_iterator|.}*/
 
 const_iterator begin() const { return v_; }
@@ -279,51 +266,51 @@ Vector_<NT_,AL_>& operator*=(const NT& s);
 
 Vector_<NT_,AL_>& operator/=(const NT& s);
 /*{\Mbinop Scalar division plus assignment.}*/
- 
+
 
 bool     operator==(const Vector_<NT_,AL_>& w) const;
-bool     operator!=(const Vector_<NT_,AL_>& w) const 
+bool     operator!=(const Vector_<NT_,AL_>& w) const
 { return !(*this == w); }
 
-static int  compare(const Vector_<NT_,AL_>&, 
+static int  compare(const Vector_<NT_,AL_>&,
                     const Vector_<NT_,AL_>&);
 
 };
 
 
-template <class NT, class AL> 
+template <class NT, class AL>
 
 inline Vector_<NT,AL> operator*(const NT& r, const Vector_<NT,AL>& v)
 /*{\Mbinopfunc Componentwise multiplication with number $r$.}*/
 { return v.compmul(r); }
 
-template <class NT, class AL> 
+template <class NT, class AL>
 
 inline Vector_<NT,AL> operator*(const Vector_<NT,AL>& v, const NT& r)
 /*{\Mbinopfunc Componentwise multiplication with number $r$.}*/
 { return v.compmul(r); }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline Vector_<NT_,AL_>& Vector_<NT_,AL_>::
 operator+=(const Vector_<NT_,AL_>& vec)
-{ 
+{
   check_dimensions(vec);
   int n = d_;
   while (n--) v_[n] += vec.v_[n];
   return *this;
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline Vector_<NT_,AL_>& Vector_<NT_,AL_>::
 operator-=(const Vector_<NT_,AL_>& vec)
-{ 
+{
   check_dimensions(vec);
   int n = d_;
   while (n--) v_[n] -= vec.v_[n];
   return *this;
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline Vector_<NT_,AL_>& Vector_<NT_,AL_>::
 operator*=(const NT& s)
 { int n = d_;
@@ -339,10 +326,10 @@ operator/=(const NT& s)
   return *this;
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline Vector_<NT_,AL_> Vector_<NT_,AL_>::
 operator+(const Vector_<NT_,AL_>& vec) const
-{ 
+{
   check_dimensions(vec);
   int n = d_;
   Vector_<NT_,AL_> result(n);
@@ -350,10 +337,10 @@ operator+(const Vector_<NT_,AL_>& vec) const
   return result;
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline Vector_<NT_,AL_> Vector_<NT_,AL_>::
 operator-(const Vector_<NT_,AL_>& vec) const
-{ 
+{
   check_dimensions(vec);
   int n = d_;
   Vector_<NT_,AL_> result(n);
@@ -361,10 +348,10 @@ operator-(const Vector_<NT_,AL_>& vec) const
   return result;
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline Vector_<NT_,AL_> Vector_<NT_,AL_>::
 operator-() const  // unary minus
-{ 
+{
   int n = d_;
   Vector_<NT_,AL_> result(n);
   while (n--) result.v_[n] = -v_[n];
@@ -372,10 +359,10 @@ operator-() const  // unary minus
 }
 
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline Vector_<NT_,AL_> Vector_<NT_,AL_>::
 compmul(const NT& x) const
-{ 
+{
   int n = d_;
   Vector_<NT_,AL_> result(n);
   while (n--) result.v_[n] = v_[n] * x;
@@ -383,10 +370,10 @@ compmul(const NT& x) const
 }
 
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline NT_ Vector_<NT_,AL_>::
 operator*(const Vector_<NT_,AL_>& vec) const
-{ 
+{
   check_dimensions(vec);
   NT_ result=0;
   int n = d_;
@@ -394,7 +381,7 @@ operator*(const Vector_<NT_,AL_>& vec) const
   return result;
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 inline bool Vector_<NT_,AL_>::
 operator==(const Vector_<NT_,AL_>& vec)  const
 { if (vec.d_ != d_) return false;
@@ -403,7 +390,7 @@ operator==(const Vector_<NT_,AL_>& vec)  const
   return (i==d_);
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 int Vector_<NT_,AL_>::
 compare(const Vector_<NT_,AL_>& v1, const Vector_<NT_,AL_>& v2)
 { int i;
@@ -413,12 +400,12 @@ compare(const Vector_<NT_,AL_>& v1, const Vector_<NT_,AL_>& v2)
   return (v1[i] < v2[i]) ?  -1 : 1;
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 std::ostream& operator<<(std::ostream& os, const Vector_<NT_,AL_>& v)
 /*{\Xbinopfunc  writes |\Mvar| componentwise to the output stream $O$.}*/
 { /* syntax: d x_0 x_1 ... x_d-1 */
     int d = v.dimension();
-    switch (get_mode(os)) {
+    switch (IO::get_mode(os)) {
     case CGAL::IO::BINARY:
         CGAL::write( os, d);
         for ( int i = 0; i < d; ++i)
@@ -442,22 +429,22 @@ std::ostream& operator<<(std::ostream& os, const Vector_<NT_,AL_>& v)
     return os;
 }
 
-template <class NT_, class AL_> 
+template <class NT_, class AL_>
 std::istream& operator>>(std::istream& is, Vector_<NT_,AL_>& v)
 /*{\Xbinopfunc  reads |\Mvar| componentwise from the input stream $I$.}*/
 { /* syntax: d x_0 x_1 ... x_d-1 */
   int d;
-  switch (get_mode(is)) {
+  switch (IO::get_mode(is)) {
     case CGAL::IO::ASCII :
     case CGAL::IO::BINARY :
-      is >> d; 
+      is >> d;
       v = Vector_<NT_,AL_>(d);
       for ( int i = 0; i < d; ++i) {
           is >> v[i];
       }
       break;
     default:
-      std::cerr<<"\nStream must be in ascii or binary mode"<<std::endl;
+      std::cerr<<"\nStream must be in ASCII or binary mode"<<std::endl;
       break;
   }
   return is;
