@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Mesh_2/include/CGAL/Mesh_2/Refine_edges.h $
+// $Id: Refine_edges.h 8f703b5 2023-01-27T21:48:32+01:00 Mael
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_2/include/CGAL/Mesh_2/Refine_edges.h $
-// $Id: Refine_edges.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Laurent RINEAU
 
@@ -41,7 +32,7 @@ namespace CGAL {
 /**
  * \namespace Mesh_2
  *   Defines classes that are not yet documented.
- * 
+ *
  * \namespace Mesh_2::details
  *   Namespace for internal use.
  */
@@ -50,7 +41,7 @@ namespace Mesh_2 {
 
   namespace details {
 
-    /** This class defines several auxiliary types for \c Refine_edges. */
+    /** This class defines several auxiliary types for `Refine_edges`. */
     template <typename Tr>
     struct Refine_edges_base_types
     {
@@ -59,7 +50,7 @@ namespace Mesh_2 {
       typedef std::pair<Vertex_handle,
                         Vertex_handle> Constrained_edge;
 
-      /** Object predicate that tests if a given \c Constrained_Edge is
+      /** Object predicate that tests if a given `Constrained_Edge` is
           really an edge of the triangulation and is constrained.
       */
       class Is_a_constrained_edge {
@@ -107,7 +98,7 @@ namespace Mesh_2 {
     typedef typename Tr::Point Point;
     typedef typename Tr::Geom_traits Geom_traits;
 
-    /** Operator that takes an edge (\c fh, \c index). */
+    /** Operator that takes an edge (`fh`, `index`). */
     bool operator()(const Tr& tr,
                     const Face_handle& fh,
                     const int i) const
@@ -118,15 +109,15 @@ namespace Mesh_2 {
       const Vertex_handle& vi = fh->vertex(i);
       const Vertex_handle& mvi = tr.tds().mirror_vertex(fh, i);
 
-      return( ( tr.is_infinite(vi) || 
+      return( ( tr.is_infinite(vi) ||
                 this->operator()(tr, va, vb, vi->point()) )
               &&
-              ( tr.is_infinite(mvi) || 
+              ( tr.is_infinite(mvi) ||
                 this->operator()(tr, va, vb, mvi->point()) )
               );
     }
 
-    /** Operator that takes an edge (\c va, \c vb). */
+    /** Operator that takes an edge (`va`, `vb`). */
     bool operator()(const Tr& tr,
                     const Vertex_handle& va,
                     const Vertex_handle& vb) const
@@ -136,12 +127,12 @@ namespace Mesh_2 {
       CGAL_assume_code( bool should_be_true = )
       tr.is_edge(va, vb, fh, i);
       CGAL_assume( should_be_true == true );
-      
+
       return this->operator()(tr, fh, i);
     }
 
     /**
-     * Operator that takes an edge (\c fh, \c index) and a point \c p.
+     * Operator that takes an edge (`fh`, `index`) and a point `p`.
      * Tests if the point encroached the edge.
      */
     bool operator()(const Tr& tr,
@@ -156,7 +147,7 @@ namespace Mesh_2 {
     }
 
     /**
-     * Operator that takes an edge (\c va, \c vb) and a point \c p.
+     * Operator that takes an edge (`va`, `vb`) and a point `p`.
      * Tests if the point encroached the edge.
      */
     bool operator()(const Tr& tr,
@@ -188,7 +179,7 @@ namespace Mesh_2 {
     typedef typename Tr::Point Point;
     typedef typename Tr::Geom_traits Geom_traits;
 
-    /** Operator that takes an edge (\c fh, \c index). */
+    /** Operator that takes an edge (`fh`, `index`). */
     bool operator()(const Tr& tr,
                     const Face_handle& fh,
                     const int i) const
@@ -206,7 +197,7 @@ namespace Mesh_2 {
       return aux_outside_of_circle(tr, vi, vb, va, mvi);
     }
 
-    /** Operator that takes an edge (\c va, \c vb). */
+    /** Operator that takes an edge (`va`, `vb`). */
     bool operator()(const Tr& tr,
                     const Vertex_handle& va,
                     const Vertex_handle& vb) const
@@ -229,15 +220,15 @@ namespace Mesh_2 {
 
   private:
     /** Private function that computes the two vertex vi and mvi that are
-	one each side of the edge (fh, i) (vi is in fh and mvi is in
-	fh->neighbor(i)) and return true if one of them is infinite.
+        one each side of the edge (fh, i) (vi is in fh and mvi is in
+        fh->neighbor(i)) and return true if one of them is infinite.
     */
     bool
     aux_get_vi_mvi(const Tr& tr,
-		   const Face_handle& fh,
-		   const int i,
-		   Vertex_handle& vi,
-		   Vertex_handle& mvi) const
+                   const Face_handle& fh,
+                   const int i,
+                   Vertex_handle& vi,
+                   Vertex_handle& mvi) const
     {
       vi = fh->vertex(i);
       mvi = tr.tds().mirror_vertex(fh, i);
@@ -246,21 +237,21 @@ namespace Mesh_2 {
     }
 
     /** Private function that returns true if the vertex vs is outside the
-	oriented circle passing through vp, vq and vr.
+        oriented circle passing through vp, vq and vr.
     */
     bool
     aux_outside_of_circle(const Tr& tr,
-			  const Vertex_handle& vp,
-			  const Vertex_handle& vq,
-			  const Vertex_handle& vr,
-			  const Vertex_handle& vs) const
+                          const Vertex_handle& vp,
+                          const Vertex_handle& vq,
+                          const Vertex_handle& vr,
+                          const Vertex_handle& vs) const
     {
       typedef typename Geom_traits::Side_of_oriented_circle_2
         Side_of_oriented_circle_2;
 
       Side_of_oriented_circle_2 in_circle =
         tr.geom_traits().side_of_oriented_circle_2_object();
-      
+
       const Point& p = vp->point();
       const Point& q = vq->point();
       const Point& r = vr->point();
@@ -278,12 +269,12 @@ namespace Mesh_2 {
  * \param Is_locally_conform defines the locally conform criterion: Gabriel
  *        or Delaunay. It defaults to the Garbriel criterion.
  * \param Container is the type of container. It defaults to a filtered
- *        queue of \c Vertex_handle pair (see \c Filtered_queue_container).
+ *        queue of `Vertex_handle` pair (see `Filtered_queue_container`).
  */
 template <
   class Tr,
   class Is_locally_conform = Is_locally_conforming_Gabriel<Tr>,
-  class Container = 
+  class Container =
     typename details::Refine_edges_base_types<Tr>::Default_container
 >
 class Refine_edges_base :
@@ -294,7 +285,7 @@ class Refine_edges_base :
 public:
   typedef typename Tr::Finite_edges_iterator Finite_edges_iterator;
   typedef typename Tr::Face_circulator Face_circulator;
-  
+
   typedef typename Tr::Vertex_handle Vertex_handle;
   typedef typename Tr::Face_handle Face_handle;
   typedef typename Tr::Edge Edge;
@@ -310,7 +301,7 @@ public:
   template <class Faces_level>
   friend class Refine_edges_visitor;
 protected:
-  /* --- protected datas --- */
+  /* --- protected data --- */
 
   Tr& tr; /**< The triangulation itself. */
 
@@ -341,7 +332,7 @@ protected:
 
     for(Finite_edges_iterator ei = tr.finite_edges_begin();
         ei != tr.finite_edges_end();
-        ++ei) 
+        ++ei)
     {
       if(ei->first->is_constrained(ei->second) &&
          !is_locally_conform(tr, ei->first, ei->second) )
@@ -356,7 +347,7 @@ protected:
     // with constraint hierarchy
 
     for(typename Tr::Subconstraint_iterator it = tr.subconstraints_begin();
-        it != tr.subconstraints_end(); ++it) 
+        it != tr.subconstraints_end(); ++it)
     {
       const Vertex_handle& v1 = it->first.first;
       const Vertex_handle& v2 = it->first.second;
@@ -441,7 +432,7 @@ public:
     const bool n_does_conflict = (zone.locate_type == Tr::EDGE) ||
       triangulation_ref_impl().test_conflict(p, n);
 
-    CGAL_assertion(f_does_conflict || 
+    CGAL_assertion(f_does_conflict ||
                    n_does_conflict);
 
     const int ni = triangulation_ref_impl().tds().mirror_index(f, i);
@@ -456,7 +447,7 @@ public:
       *edges_out++ = std::make_pair(n, ni);
     }
 
-    std::pair<OutputItFaces,OutputItEdges> pit = 
+    std::pair<OutputItFaces,OutputItEdges> pit =
       std::make_pair(faces_out,edges_out);
 
     if(f_does_conflict) {
@@ -468,17 +459,17 @@ public:
       pit = triangulation_ref_impl().propagate_conflicts(p,n,Tr::ccw(ni),pit);
       pit = triangulation_ref_impl().propagate_conflicts(p,n,Tr:: cw(ni),pit);
     }
-    return zone; 
+    return zone;
   }
 
   Vertex_handle insert_impl(const Point& p, Zone& zone)
   {
     return triangulation_ref_impl().star_hole(p,
-					      zone.boundary_edges.begin(),
-					      zone.boundary_edges.end(),
-					      zone.faces.begin(),
-					      zone.faces.end()
-					      );
+                                              zone.boundary_edges.begin(),
+                                              zone.boundary_edges.end(),
+                                              zone.faces.begin(),
+                                              zone.faces.end()
+                                              );
   }
 
   /** Scans all constrained edges and put them in the queue if they are
@@ -502,10 +493,10 @@ public:
   /** This version computes the refinement point without handling
       clusters. The refinement point of an edge is just the middle point of
       the segment.
-      Saves the handles of the edge that will be splitted.
+      Saves the handles of the edge that will be split.
       This function is overridden in class Refine_edge_with_clusters.
   */
-  Point refinement_point_impl(const Edge& edge) 
+  Point refinement_point_impl(const Edge& edge)
   {
     typename Geom_traits::Construct_midpoint_2
       midpoint = tr.geom_traits().construct_midpoint_2_object();
@@ -513,6 +504,14 @@ public:
     va = edge.first->vertex(tr.cw (edge.second));
     vb = edge.first->vertex(tr.ccw(edge.second));
 
+#ifdef CGAL_MESH_2_DEBUG_REFINEMENT_POINTS
+    std::cerr << "refinement_point_impl("
+              << "#" << va->time_stamp() << ": " << va->point() << ", "
+              << "#" << vb->time_stamp() << ": " << vb->point() << ") = ";
+    auto p = midpoint(va->point(), vb->point());
+    std::cerr << p << '\n';
+    return p;
+#endif // CGAL_MESH_2_DEBUG_BAD_FACES
     return midpoint(va->point(), vb->point());
   }
 
@@ -527,20 +526,20 @@ public:
    */
   Mesher_level_conflict_status
   test_point_conflict_from_superior_impl(const Point& p,
-					 Zone& zone)
+                                         Zone& zone)
   {
     Mesher_level_conflict_status status = NO_CONFLICT;
-    
+
     for(typename Zone::Edges_iterator eit = zone.boundary_edges.begin();
         eit != zone.boundary_edges.end(); ++eit)
-      { 
+      {
         const Face_handle& fh = eit->first;
         const int& i = eit->second;
 
         if(fh->is_constrained(i) && !is_locally_conform(tr, fh, i, p))
           {
             add_constrained_edge_to_be_conformed(*eit);
-	    status = CONFLICT_BUT_ELEMENT_CAN_BE_RECONSIDERED;
+            status = CONFLICT_BUT_ELEMENT_CAN_BE_RECONSIDERED;
           }
       }
 
@@ -549,7 +548,7 @@ public:
 
   /** Unmark as constrained. */
   void before_insertion_impl(const Edge& e, const Point&,
-			     const Zone&)
+                             const Zone&)
   {
     const Face_handle& f = e.first;
     const int& i = e.second;
@@ -562,7 +561,7 @@ public:
    * Scans the edges of the star boundary, to test if they are both
    * locally conforming. If not, push them in the list of edges to be
    * conformed.
-   * 
+   *
    */
   void after_insertion_impl(const Vertex_handle& v)
   {
@@ -570,7 +569,7 @@ public:
     std::cerr << "E";
 #endif
     // @todo Perhaps we should remove destroyed edges too.
-    // @warning This code has been rewroten!
+    // @warning This code has been rewritten!
 
     Face_circulator fc = tr.incident_faces(v), fcbegin(fc);
     if( fc == 0 ) return;
@@ -585,9 +584,9 @@ public:
     } while( fc != fcbegin );
 
     Face_handle fh;
-    int index = 0; // Avoids a warning. 
+    int index = 0; // Avoids a warning.
                    // We know that is_edge must return true, and is_edge will assign something to index
-                   // but the compiler does not so it will issue a maybe uninitialized warning
+                   // but the compiler does not so it will issue a maybe-uninitialized warning
 
     CGAL_assume_code(bool is_edge = )
     tr.is_edge(va, v, fh, index);
@@ -608,7 +607,7 @@ public:
 
     if(!is_locally_conform(tr, va, v))
       add_constrained_edge_to_be_conformed(va, v);
-    
+
     if(!is_locally_conform(tr, vb, v))
       add_constrained_edge_to_be_conformed(vb, v);
   } // end after_insertion_impl
@@ -616,7 +615,7 @@ public:
 protected:
   /** \name Auxiliary functions */
 
-  /** Add an \c Edge \c e in the queue. */
+  /** Add an edge `e` in the queue. */
   void add_constrained_edge_to_be_conformed(const Edge& e)
   {
     const Vertex_handle& va = e.first->vertex(tr. cw(e.second));
@@ -625,7 +624,7 @@ protected:
                                                    // base class
   }
 
-  /** Add an edge (\c va,\c  vb) in the queue. */
+  /** Add an edge `(va, vb)` in the queue. */
   void add_constrained_edge_to_be_conformed(const Vertex_handle& va,
                                             const Vertex_handle& vb)
   {
@@ -633,8 +632,8 @@ protected:
                                                    // base class
   }
 
-private: /** \name DEBUGGING TYPES AND DATAS */
-  class From_pair_of_vertex_to_edge 
+private: /** \name DEBUGGING TYPES AND DATA */
+  class From_pair_of_vertex_to_edge
     : public CGAL::cpp98::unary_function<Constrained_edge, Edge>
   {
     Tr& tr;
@@ -692,31 +691,31 @@ public:  /** \name DEBUGGING FUNCTIONS */
       typedef Triangulation_mesher_level_traits_2<Tr> Triangulation_traits;
 
       typedef Mesher_level <
-	Tr,
+        Tr,
         Self,
         typename Tr::Edge,
         Null_mesher_level,
-	Triangulation_traits> Edges_mesher_level;
+        Triangulation_traits> Edges_mesher_level;
     }; // end Refine_edges_types
   } // end namespace details
 
 template <typename Tr,
           typename Is_locally_conform = Is_locally_conforming_Gabriel<Tr>,
           typename Base = Refine_edges_base<Tr, Is_locally_conform> >
-struct Refine_edges : 
-  public Base, 
-  public details::Refine_edges_types<Tr, 
+struct Refine_edges :
+  public Base,
+  public details::Refine_edges_types<Tr,
     Refine_edges<Tr, Is_locally_conform, Base> >::Edges_mesher_level
 {
   typedef Refine_edges<Tr, Is_locally_conform, Base> Self;
 
   typedef typename details::Refine_edges_types<Tr,
-					       Self> Types;
+                                               Self> Types;
 
   typedef typename Types::Edges_mesher_level Mesher;
 public:
-  Refine_edges(Tr& t, 
-	       Null_mesher_level& null_level)
+  Refine_edges(Tr& t,
+               Null_mesher_level& null_level)
     : Base(t), Mesher(null_level)
   {
   }
