@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_3/polylines_to_protect.h $
-// $Id: polylines_to_protect.h 40c2575 2019-08-01T17:25:10+02:00 Laurent Rineau
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Mesh_3/include/CGAL/Mesh_3/polylines_to_protect.h $
+// $Id: polylines_to_protect.h c0b76f2 2023-02-24T17:08:06+01:00 Jane Tournois
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Laurent Rineau
@@ -24,23 +15,30 @@
 
 #include <CGAL/license/Mesh_3.h>
 
-
 #include <vector>
 #include <map>
 #include <utility> // std::swap
+#include <algorithm> // std::min
+
 #include <CGAL/tuple.h>
 #include <CGAL/Image_3.h>
+#include <CGAL/number_utils.h>
+#include <CGAL/squared_distance_3.h>
+
 #include <CGAL/boost/graph/split_graph_into_polylines.h>
-#include <CGAL/internal/Mesh_3/Graph_manipulations.h>
+#include <CGAL/Mesh_3/internal/Graph_manipulations.h>
 #include <boost/graph/adjacency_list.hpp>
-#include <CGAL/Labeled_mesh_domain_3.h> // for CGAL::Null_subdomain_index
+
 #include <boost/utility.hpp> // for boost::prior
-#include <boost/foreach.hpp>
 #include <boost/optional.hpp>
 
 #include <CGAL/Search_traits_3.h>
 #include <CGAL/Orthogonal_incremental_neighbor_search.h>
 
+#include <CGAL/Mesh_3/Null_subdomain_index.h>
+
+#include <type_traits>
+
 namespace CGAL {
 namespace Mesh_3 {
 namespace internal {
@@ -218,7 +216,6 @@ private:
       v_int = g_manip.get_vertex(inter_p, false);
       g_manip.try_add_edge(old, v_int);
 
-#ifndef CGAL_CFG_NO_CPP0X_LAMBDAS
       CGAL_assertion_msg(max_squared_distance == 0 ||
                          CGAL::squared_distance(g_manip.g[old].point,
                                                 g_manip.g[v_int].point) <
@@ -230,19 +227,11 @@ private:
                            << this->g_manip.g[v_int].point << ")";
                          return s.str();
                        }().c_str()));
-#else // no C++ lamdbas
-      CGAL_assertion(max_squared_distance == 0 ||
-                     CGAL::squared_distance(g_manip.g[old].point,
-                                            g_manip.g[v_int].point) <
-                     max_squared_distance);
-#endif // no C++ lamdbas
-
       old = v_int;
     }
     if(null_vertex != v_int) {
       // v_int can be null if the curve is degenerated into one point.
       g_manip.try_add_edge(v_int, end_v);
-#ifndef CGAL_CFG_NO_CPP0X_LAMBDAS
       CGAL_assertion_msg(max_squared_distance == 0 ||
                          CGAL::squared_distance(g_manip.g[end_v].point,
                                                 g_manip.g[v_int].point) <
@@ -254,13 +243,6 @@ private:
                              << this->g_manip.g[v_int].point << ")";
                            return s.str();
                          }().c_str()));
-#else // no C++ lamdbas
-      CGAL_assertion(max_squared_distance == 0 ||
-                     CGAL::squared_distance(g_manip.g[end_v].point,
-                                            g_manip.g[v_int].point) <
-                     max_squared_distance);                   
-#endif // no C++ lamdbas
-
     }
   }
 };
@@ -275,6 +257,7 @@ struct Enriched_pixel {
   Domain_type domain;
   Image_word_type word;
   bool on_edge_of_the_cube;
+  bool on_corner_of_the_cube;
 }; // end struct template Enriched_pixel<Pix,P,D,C>
 
 } // end namespace internal
@@ -290,17 +273,17 @@ struct Polyline_visitor
 
   ~Polyline_visitor()
   {//DEBUG
-#if CGAL_MESH_3_PROTECTION_DEBUG > 1
+#if CGAL_MESH_3_PROTECTION_DEBUG & 2
     std::ofstream og("polylines_graph.polylines.txt");
     og.precision(17);
-    BOOST_FOREACH(const std::vector<P>& poly, polylines)
+    for(const std::vector<P>& poly : polylines)
     {
       og << poly.size() << " ";
-      BOOST_FOREACH(const P& p, poly)
+      for(const P& p : poly)
         og << p << " ";
       og << std::endl;
     }
-#endif // CGAL_MESH_3_PROTECTION_DEBUG > 1
+#endif // CGAL_MESH_3_PROTECTION_DEBUG & 2
   }
 
   void start_new_polyline()
@@ -326,6 +309,16 @@ struct Polyline_visitor
 template <typename Kernel>
 struct Angle_tester
 {
+  const double m_angle_sq_cosine;// squared cosine of `std:max(90, angle_deg)`
+
+  Angle_tester()
+    : m_angle_sq_cosine(0)
+  {}
+
+  Angle_tester(const double angle_deg)//angle given in degrees for readability
+    : m_angle_sq_cosine(CGAL::square(std::cos((std::max)(90.,angle_deg) * CGAL_PI / 180.)))
+  {}
+
   template <typename vertex_descriptor, typename Graph>
   bool operator()(vertex_descriptor& v, const Graph& g) const
   {
@@ -345,15 +338,22 @@ struct Angle_tester
       const typename Kernel::Point_3& p1 = g[v1].point;
       const typename Kernel::Point_3& p2 = g[v2].point;
 
-      if(CGAL::angle(p1, p, p2) == CGAL::ACUTE) {
-        // const typename Kernel::Vector_3 e1 = p1 - p;
-        // const typename Kernel::Vector_3 e2 = p2 - p;
-        // std::cerr << "At point " << p << ": the angle is "
-        //           << ( std::acos(e1 * e2
-        //                          / CGAL::sqrt(e1*e1)
-        //                          / CGAL::sqrt(e2*e2))
-        //                * 180 / CGAL_PI ) << std::endl;
+      //if angle at v is acute, v must be considered as a terminal vertex
+      // to ensure termination
+      if (CGAL::angle(p1, p, p2) == CGAL::ACUTE)
         return true;
+      else if (m_angle_sq_cosine > 0.)//check angle only if angle is > 90.
+      {
+        const typename Kernel::Vector_3 e1 = p1 - p;
+        const typename Kernel::Vector_3 e2 = p2 - p;
+
+        const auto scalar_product = e1 * e2;
+        if (CGAL::is_positive(scalar_product))
+          return true;
+
+        const auto sq_scalar_product = CGAL::square(scalar_product);
+        if (sq_scalar_product <= m_angle_sq_cosine * (e1 * e1) * (e2 * e2))
+          return true;
       }
     }
     return false;
@@ -394,8 +394,8 @@ void snap_graph_vertices(Graph& graph,
   }
   if(tree.size() == 0) return;
 
-  BOOST_FOREACH(typename boost::graph_traits<Graph>::vertex_descriptor v,
-                vertices(graph))
+  for(typename boost::graph_traits<Graph>::vertex_descriptor v :
+                make_range(vertices(graph)))
   {
     const typename K::Point_3 p = graph[v].point;
     NN_search nn(tree, p);
@@ -518,9 +518,9 @@ polylines_to_protect
         for(int k = 0; k < zdim; k+= (axis == 2 ? (std::max)(1, zdim-1) : 1 ) )
         {
 
-          using CGAL::cpp11::array;
-          using CGAL::cpp11::tuple;
-          using CGAL::cpp11::get;
+          using std::array;
+          using std::tuple;
+          using std::get;
 
           typedef array<int, 3> Pixel;
 
@@ -550,10 +550,10 @@ polylines_to_protect
                                  Image_word_type> Enriched_pixel;
 
           array<array<Enriched_pixel, 2>, 2> square =
-            {{ {{ { pix00, Point_3(), Domain_type(), 0, false },
-                  { pix01, Point_3(), Domain_type(), 0, false } }},
-               {{ { pix10, Point_3(), Domain_type(), 0, false },
-                  { pix11, Point_3(), Domain_type(), 0, false } }} }};
+            {{ {{ { pix00, Point_3(), Domain_type(), 0, false, false },
+                  { pix01, Point_3(), Domain_type(), 0, false, false } }},
+               {{ { pix10, Point_3(), Domain_type(), 0, false, false },
+                  { pix11, Point_3(), Domain_type(), 0, false, false } }} }};
 
           std::map<Domain_type, int> pixel_values_set;
           for(int ii = 0; ii < 2; ++ii) {
@@ -562,17 +562,21 @@ polylines_to_protect
               double x = pixel[0] * vx + tx;
               double y = pixel[1] * vy + ty;
               double z = pixel[2] * vz + tz;
-              square[ii][jj].on_edge_of_the_cube =
-                ( ( ( 0 == pixel[0] || (xdim - 1) == pixel[0] ) ? 1 : 0 )
-                  +
-                  ( ( 0 == pixel[1] || (ydim - 1) == pixel[1] ) ? 1 : 0 )
-                  +
-                  ( ( 0 == pixel[2] || (zdim - 1) == pixel[2] ) ? 1 : 0 ) > 1 );
+              short sum_faces = ((0 == pixel[0] || (xdim - 1) == pixel[0]) ? 1 : 0)
+                              + ((0 == pixel[1] || (ydim - 1) == pixel[1]) ? 1 : 0)
+                              + ((0 == pixel[2] || (zdim - 1) == pixel[2]) ? 1 : 0);
+              square[ii][jj].on_edge_of_the_cube = (sum_faces > 1);
+              square[ii][jj].on_corner_of_the_cube = (sum_faces > 2);
+
 #ifdef CGAL_MESH_3_DEBUG_POLYLINES_TO_PROTECT
               if(square[ii][jj].on_edge_of_the_cube) {
                 std::cerr << "  Pixel(" << pixel[0] << ", " << pixel[1] << ", "
                           << pixel[2] << ") is on edge\n";
               }
+              if (square[ii][jj].on_corner_of_the_cube) {
+                std::cerr << "  Pixel(" << pixel[0] << ", " << pixel[1] << ", "
+                  << pixel[2] << ") is on corner\n";
+              }
 #endif // CGAL_MESH_3_DEBUG_POLYLINES_TO_PROTECT
 
               square[ii][jj].point = Point_3(x, y, z);
@@ -589,6 +593,7 @@ polylines_to_protect
                                   (*scalar_interpolation_value));
               }
               ++pixel_values_set[square[ii][jj].domain];
+
             }
           }
 
@@ -608,10 +613,10 @@ polylines_to_protect
             bool out01 = null(square[0][1].domain);
             bool out11 = null(square[1][1].domain);
 
-            bool on_edge00 = square[0][0].on_edge_of_the_cube;
-            bool on_edge10 = square[1][0].on_edge_of_the_cube;
-            bool on_edge01 = square[0][1].on_edge_of_the_cube;
-            bool on_edge11 = square[1][1].on_edge_of_the_cube;
+            bool is_corner00 = square[0][0].on_corner_of_the_cube;
+            bool is_corner10 = square[1][0].on_corner_of_the_cube;
+            bool is_corner01 = square[0][1].on_corner_of_the_cube;
+            bool is_corner11 = square[1][1].on_corner_of_the_cube;
 
             //
             // Protect the edges of the cube
@@ -619,26 +624,26 @@ polylines_to_protect
             if(pix00[axis_xx] == 0 &&
                ! ( out00 && out01 ) )
             {
-              g_manip.try_add_edge(g_manip.get_vertex(p00, on_edge00),
-                                   g_manip.get_vertex(p01, on_edge01));
+              g_manip.try_add_edge(g_manip.get_vertex(p00, is_corner00),
+                                   g_manip.get_vertex(p01, is_corner01));
             }
             if(pix11[axis_xx] == image_dims[axis_xx]-1 &&
                ! ( out10 && out11 ) )
             {
-              g_manip.try_add_edge(g_manip.get_vertex(p10, on_edge10),
-                                   g_manip.get_vertex(p11, on_edge11));
+              g_manip.try_add_edge(g_manip.get_vertex(p10, is_corner10),
+                                   g_manip.get_vertex(p11, is_corner11));
             }
             if(pix00[axis_yy] == 0 &&
                ! ( out00 && out10 ) )
             {
-              g_manip.try_add_edge(g_manip.get_vertex(p00, on_edge00),
-                                   g_manip.get_vertex(p10, on_edge10));
+              g_manip.try_add_edge(g_manip.get_vertex(p00, is_corner00),
+                                   g_manip.get_vertex(p10, is_corner10));
             }
             if(pix11[axis_yy] == image_dims[axis_yy]-1 &&
                ! ( out01 && out11 ) )
             {
-              g_manip.try_add_edge(g_manip.get_vertex(p01, on_edge01),
-                                   g_manip.get_vertex(p11, on_edge11));
+              g_manip.try_add_edge(g_manip.get_vertex(p01, is_corner01),
+                                   g_manip.get_vertex(p11, is_corner11));
             }
           } // end of scope for outIJ and on_edgeIJ
 
@@ -1018,7 +1023,8 @@ template <typename P,
 void
 polylines_to_protect(std::vector<std::vector<P> >& polylines,
                      PolylineInputIterator existing_polylines_begin,
-                     PolylineInputIterator existing_polylines_end)
+                     PolylineInputIterator existing_polylines_end,
+                     const double& angle = 90.)//when not provided, check only for acute angles
 {
   typedef P Point_3;
   typedef typename Kernel_traits<P>::Kernel K;
@@ -1038,11 +1044,11 @@ polylines_to_protect(std::vector<std::vector<P> >& polylines,
   for (PolylineInputIterator poly_it = existing_polylines_begin;
        poly_it != existing_polylines_end; ++poly_it)
   {
-    Polyline polyline = *poly_it;
+    const Polyline& polyline = *poly_it;
     if (polyline.size() < 2)
       continue;
 
-    typename Polyline::iterator pit = polyline.begin();
+    typename Polyline::const_iterator pit = polyline.begin();
     while (boost::next(pit) != polyline.end())
     {
       vertex_descriptor v = g_manip.get_vertex(*pit, false);
@@ -1056,8 +1062,9 @@ polylines_to_protect(std::vector<std::vector<P> >& polylines,
   Less_for_Graph_vertex_descriptors<Graph> less(graph);
   const Graph& const_graph = graph;
   typedef typename Kernel_traits<P>::Kernel K;
+  Mesh_3::Angle_tester<K> angle_tester(angle);
   split_graph_into_polylines(const_graph, visitor,
-                             Mesh_3::Angle_tester<K>(), less);
+                             angle_tester, less);
 }
 
 template <typename P, typename Image_word_type, typename Null_subdomain_index>
@@ -1127,6 +1134,79 @@ polylines_to_protect(const CGAL::Image_3& cgal_image,
      existing_polylines_end);
 }
 
+template <typename P,
+          typename Image_word_type,
+          typename PolylineInputIterator>
+void
+polylines_to_protect_on_bbox(const CGAL::Image_3& cgal_image,
+                     std::vector<std::vector<P> >& polylines,
+                     PolylineInputIterator existing_polylines_begin,
+                     PolylineInputIterator existing_polylines_end)
+{
+  polylines_to_protect<P, Image_word_type>(cgal_image,
+                                           polylines,
+                                           existing_polylines_begin,
+                                           existing_polylines_end);
+}
+
+
+
+template <typename PolylineRange1, typename PolylineRange2>
+void
+merge_and_snap_polylines(const CGAL::Image_3& image,
+                         PolylineRange1& polylines_to_snap,
+                         const PolylineRange2& existing_polylines)
+{
+  static_assert(std::is_same<typename PolylineRange1::value_type::value_type,
+                             typename PolylineRange2::value_type::value_type>::value,
+                "Polyline ranges should have same point type");
+  using P = typename PolylineRange1::value_type::value_type;
+  using K = typename Kernel_traits<P>::Kernel;
+
+  using CGAL::internal::polylines_to_protect_namespace::Vertex_info;
+  using Graph = boost::adjacency_list<boost::setS, boost::vecS, boost::undirectedS,
+                                      Vertex_info<P> >;
+  using vertex_descriptor = typename boost::graph_traits<Graph>::vertex_descriptor;
+
+  // build graph of polylines_to_snap
+  Graph graph;
+  typedef Mesh_3::internal::Returns_midpoint<K, int> Midpoint_fct;
+  Mesh_3::internal::Graph_manipulations<Graph,
+    P,
+    int,
+    Midpoint_fct> g_manip(graph);
+
+  for (const auto& polyline : polylines_to_snap)
+  {
+    if (polyline.size() < 2)
+      continue;
+
+    auto pit = polyline.begin();
+    while (boost::next(pit) != polyline.end())
+    {
+      vertex_descriptor v = g_manip.get_vertex(*pit, false);
+      vertex_descriptor w = g_manip.get_vertex(*boost::next(pit), false);
+      g_manip.try_add_edge(v, w);
+      ++pit;
+    }
+  }
+
+  // snap graph to existing_polylines
+  snap_graph_vertices(graph,
+    image.vx(), image.vy(), image.vz(),
+    boost::begin(existing_polylines), boost::end(existing_polylines),
+    K());
+
+  // rebuild polylines_to_snap
+  polylines_to_snap.clear();
+  Mesh_3::Polyline_visitor<P, Graph> visitor(polylines_to_snap, graph);
+  Less_for_Graph_vertex_descriptors<Graph> less(graph);
+  const Graph& const_graph = graph;
+  Mesh_3::Angle_tester<K> angle_tester(90.);
+  split_graph_into_polylines(const_graph, visitor, angle_tester, less);
+}
+
+
 } // namespace CGAL
 
 #endif // CGAL_MESH_3_POLYLINES_TO_PROTECT_H
