@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_error_code.h $
-// $Id: Mesh_error_code.h ba21ecb 2018-07-18T18:26:08+02:00 Laurent Rineau
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Mesh_3/include/CGAL/Mesh_error_code.h $
+// $Id: Mesh_error_code.h 54a6462 2022-09-26T20:09:58+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Laurent Rineau
 
@@ -23,17 +14,13 @@
 
 #include <CGAL/license/Mesh_3.h>
 
+#include <CGAL/STL_Extension/internal/mesh_option_classes.h>
+
 #include <string>
 #include <sstream>
 
 namespace CGAL {
 
-enum Mesh_error_code {
-  CGAL_MESH_3_NO_ERROR = 0,
-  CGAL_MESH_3_MAXIMAL_NUMBER_OF_VERTICES_REACHED,
-  CGAL_MESH_3_STOPPED
-};
-
 inline
 std::string mesh_error_string(const Mesh_error_code& error_code) {
   switch(error_code) {
