@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_facet_criteria_3.h $
-// $Id: Mesh_facet_criteria_3.h 0fcc6c0 2017-12-08T11:31:30+01:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Mesh_3/include/CGAL/Mesh_facet_criteria_3.h $
+// $Id: Mesh_facet_criteria_3.h 9fd54ba 2022-12-05T15:33:08+01:00 Jane Tournois
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Stéphane Tayeb
@@ -32,18 +23,19 @@
 
 #include <CGAL/Mesh_3/mesh_standard_facet_criteria.h>
 #include <CGAL/Mesh_facet_topology.h>
+#include <CGAL/Mesh_3/Is_mesh_domain_field_3.h>
 
 namespace CGAL {
-  
+
 template<typename Tr,
-         typename Visitor_ = Mesh_3::Facet_criterion_visitor_with_features<Tr> >
+         typename Visitor_ = Mesh_3::Facet_criterion_visitor_with_radius_lower_bound<Tr> >
 class Mesh_facet_criteria_3
 {
 public:
   typedef Visitor_ Visitor;
   typedef typename Visitor::Facet_quality Facet_quality;
   typedef typename Visitor::Is_facet_bad  Is_facet_bad;
-  
+
   typedef Mesh_3::Abstract_criterion<Tr,Visitor> Abstract_criterion;
 private:
   typedef Mesh_3::Criteria<Tr,Visitor> Criteria;
@@ -59,83 +51,24 @@ public:
   /**
    * @brief Constructor
    */
-  Mesh_facet_criteria_3(const FT& angle_bound,
-                        const FT& radius_bound,
-                        const FT& distance_bound,
-                        const Mesh_facet_topology topology =
-                          FACET_VERTICES_ON_SURFACE)
-  {
-    if ( FT(0) != angle_bound )
-      init_aspect(angle_bound);
-    
-    if ( FT(0) != radius_bound )
-      init_radius_bound(radius_bound);
-    
-    if ( FT(0) != distance_bound )
-      init_distance_bound(distance_bound);
-    
-    init_topo(topology);
-  }
-
-  // Nb: SFINAE (dummy) to avoid wrong matches with built-in numerical types
-  // as int.
-  template < typename Sizing_field >
-  Mesh_facet_criteria_3(const FT& angle_bound,
-                        const Sizing_field& radius_bound,
-                        const FT& distance_bound,
-                        const Mesh_facet_topology topology = 
-                          FACET_VERTICES_ON_SURFACE,
-                        typename Sizing_field::FT /*dummy*/ = 0)
-  {
-    if ( FT(0) != angle_bound )
-      init_aspect(angle_bound);
-    
-    init_radius_field(radius_bound);
-    
-    if ( FT(0) != distance_bound )
-      init_distance_bound(distance_bound);
-    
-    init_topo(topology);  
-  }
-  
-  // Nb: SFINAE (dummy) to avoid wrong matches with built-in numerical types
-  // as int.
-  template < typename Sizing_field >
-  Mesh_facet_criteria_3(const FT& angle_bound,
-                        const FT& radius_bound,
-                        const Sizing_field& distance_bound,
-                        const Mesh_facet_topology topology =
-                          FACET_VERTICES_ON_SURFACE,
-                        typename Sizing_field::FT /*dummy*/ = 0)
-  {
-    if ( FT(0) != angle_bound )
-      init_aspect(angle_bound);
-
-    if ( FT(0) != radius_bound )
-      init_radius_bound(radius_bound);
-
-    init_distance_field(distance_bound);
-
-    init_topo(topology);
-  }
-
-  // Nb: SFINAE (dummy) to avoid wrong matches with built-in numerical types
-  // as int.
   template < typename Sizing_field, typename Sizing_field2 >
   Mesh_facet_criteria_3(const FT& angle_bound,
                         const Sizing_field & radius_bound,
                         const Sizing_field2& distance_bound,
-                        const Mesh_facet_topology topology =
-                          FACET_VERTICES_ON_SURFACE,
-                        typename Sizing_field::FT /*dummy*/ = 0,
-                        typename Sizing_field2::FT /*dummy*/ = 0)
+                        const Mesh_facet_topology topology = FACET_VERTICES_ON_SURFACE,
+                        const FT& min_radius_bound = 0.)
   {
+    if (FT(0) != min_radius_bound)
+      init_min_radius(min_radius_bound);
+
     if ( FT(0) != angle_bound )
       init_aspect(angle_bound);
 
-    init_radius_field(radius_bound);
+    init_radius(radius_bound,
+                Mesh_3::Is_mesh_domain_field_3<Tr, Sizing_field>());
 
-    init_distance_field(distance_bound);
+    init_distance(distance_bound,
+                  Mesh_3::Is_mesh_domain_field_3<Tr, Sizing_field2>());
 
     init_topo(topology);
   }
@@ -144,15 +77,15 @@ public:
   ~Mesh_facet_criteria_3() { }
 
    /**
-   * @brief returns whether the facet \c facet is bad or not.
-   * @param tr the triangulation within which \c facet lives
+   * @brief returns whether the facet `facet` is bad or not.
+   * @param tr the triangulation within which `facet` lives
    * @param facet the facet
    */
   Is_facet_bad operator()(const Tr& tr, const Facet& facet) const
   {
     return criteria_(tr, facet);
   }
-  
+
   void add(Abstract_criterion* criterion)
   {
     criteria_.add(criterion);
@@ -168,35 +101,43 @@ private:
     typedef Mesh_3::Aspect_ratio_criterion<Tr,Visitor> Aspect_criterion;
     criteria_.add(new Aspect_criterion(angle_bound));
   }
-  
-  void init_radius_bound(const FT& radius_bound)
+
+  void init_radius(const FT& radius_bound, Tag_false)
   {
+    if(FT(0) == radius_bound) return;
     typedef Mesh_3::Uniform_size_criterion<Tr,Visitor> Uniform_size_criterion;
     criteria_.add(new Uniform_size_criterion(radius_bound));
   }
-  
+
   template <typename Sizing_field>
-  void init_radius_field(const Sizing_field& radius_bound)
+  void init_radius(const Sizing_field& radius_bound, Tag_true)
   {
     typedef Mesh_3::Variable_size_criterion<Tr,Visitor,Sizing_field> Variable_size_criterion;
     criteria_.add(new Variable_size_criterion(radius_bound));
   }
-  
-  void init_distance_bound(const FT& distance_bound)
+
+  void init_min_radius(const FT& min_radius_bound)
   {
+    typedef Mesh_3::Uniform_size_criterion<Tr, Visitor> Uniform_size_criterion;
+    criteria_.add(new Uniform_size_criterion(min_radius_bound, true/*lower bound*/));
+  }
+
+  void init_distance(const FT& distance_bound, Tag_false)
+  {
+    if(FT(0) == distance_bound) return;
     typedef Mesh_3::Uniform_curvature_size_criterion<Tr,Visitor> Criterion;
     criteria_.add(new Criterion(distance_bound));
   }
-  
+
   template <typename Sizing_field>
-  void init_distance_field(const Sizing_field& distance_bound)
+  void init_distance(const Sizing_field& distance_bound, Tag_true)
   {
     typedef Mesh_3::Variable_curvature_size_criterion<Tr,
                                                       Visitor,
                                                       Sizing_field> Criterion;
     criteria_.add(new Criterion(distance_bound));
   }
-  
+
   void init_topo(const Mesh_facet_topology topology)
   {
     topology_ = topology;
@@ -208,7 +149,7 @@ private:
         criteria_.add(new On_surface_criterion());
         break;
       }
-        
+
       case FACET_VERTICES_ON_SAME_SURFACE_PATCH:
       case FACET_VERTICES_ON_SAME_SURFACE_PATCH_WITH_ADJACENCY_CHECK:
         // @TODO: Implement adjacency check !
@@ -219,7 +160,7 @@ private:
       }
     }
   }
-  
+
 private:
   Criteria criteria_;
   Mesh_facet_topology topology_;
