@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Nef_3/include/CGAL/Nef_3/Exact_triangulation_euclidean_traits_yz_3.h $
+// $Id: Exact_triangulation_euclidean_traits_yz_3.h 5ea5e93 2021-01-20T15:17:41+00:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Nef_3/include/CGAL/Nef_3/Exact_triangulation_euclidean_traits_yz_3.h $
-// $Id: Exact_triangulation_euclidean_traits_yz_3.h 8cdfad0 2017-11-15T22:58:57+01:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Ralf Osbild <osbild@mpi-sb.mpg.de>
 
@@ -37,13 +28,16 @@ template<class R, class Tag> struct Exact_intersect_yz_2;
 template <class R>
 struct Exact_intersect_yz_2 <R,Cartesian_tag>
 {
-   typedef typename R::Point_2     Point_2; 
-   typedef typename R::Segment_2   Segment_2; 
+   typedef typename R::Point_2     Point_2;
+   typedef typename R::Segment_2   Segment_2;
 
-   typedef typename R::Point_3     Point_3; 
-   typedef typename R::Segment_3   Segment_3; 
+   typedef typename R::Point_3     Point_3;
+   typedef typename R::Segment_3   Segment_3;
 
-   CGAL::Object operator() (Segment_3 s3, Segment_3 t3)
+   typedef  boost::variant<Point_3, Segment_3> variant_type;
+
+   boost::optional<variant_type>
+   operator() (const Segment_3& s3, const Segment_3& t3)
    {  Point_2 p2, q2;
       Point_3 p3, q3;
 
@@ -58,31 +52,37 @@ struct Exact_intersect_yz_2 <R,Cartesian_tag>
 
       // convert intersection from Object_2 to Object_3
       // Note: there is not necessarily a spartial intersection,
-      //       so all first components are faked!
-      CGAL::Object obj = intersection (s2,t2);
-      if ( CGAL::assign(p2, obj) )
-      {  obj = make_object (Point_3 (0,p2.x(),p2.y()));
+      //       so all third components are faked!
+      auto obj = intersection (s2,t2);
+      if(! obj){
+        return boost::none;
       }
-      else if ( CGAL::assign(s2, obj) )
-      {  p2 = s2.source();
-	 q2 = s2.target();
-	 obj = make_object( Segment_3(
-	       Point_3(0,p2.x(),p2.y()), Point_3(0,q2.x(),q2.y()) ) );
+      if (const Point_2* pi =  boost::get<Point_2>(&*obj))
+      {
+        return boost::make_optional(variant_type(Point_3(0,p2.x(),p2.y())));
       }
-      return obj;
+
+      const Segment_2* si = boost::get<Segment_2>(&*obj);
+      p2 = si->source();
+      q2 = si->target();
+
+      return boost::make_optional(variant_type(Segment_3(Point_3(0,p2.x(),p2.y()),
+                                                         Point_3(0,q2.x(),q2.y()) ) ));
    }
 };
 
 template <class R>
 struct Exact_intersect_yz_2 <R,Homogeneous_tag>
 {  // Homogeneous
-   typedef typename R::Point_2     Point_2; 
-   typedef typename R::Segment_2   Segment_2; 
+   typedef typename R::Point_2     Point_2;
+   typedef typename R::Segment_2   Segment_2;
 
-   typedef typename R::Point_3     Point_3; 
-   typedef typename R::Segment_3   Segment_3; 
+   typedef typename R::Point_3     Point_3;
+   typedef typename R::Segment_3   Segment_3;
 
-   CGAL::Object operator() (Segment_3 s3, Segment_3 t3)
+   typedef  boost::variant<Point_3, Segment_3> variant_type;
+
+   boost::optional<variant_type> operator() (Segment_3 s3, Segment_3 t3)
    {  Point_2 p2, q2;
       Point_3 p3, q3;
 
@@ -99,19 +99,22 @@ struct Exact_intersect_yz_2 <R,Homogeneous_tag>
 
       // convert intersection from Object_2 to Object_3
       // Note: there is not necessarily a spartial intersection,
-      //       so all first components are faked!
-      CGAL::Object obj = intersection (s2,t2);
-      if ( CGAL::assign(p2, obj) )
-      {  obj = make_object (Point_3 (0,p2.hx(),p2.hy(),p2.hw()));
+      //       so all third components are faked!
+      auto obj = intersection (s2,t2);
+      if(! obj){
+        return boost::none;
       }
-      else if ( CGAL::assign(s2, obj) )
-      {  p2 = s2.source();
-	 q2 = s2.target();
-	 obj = make_object( Segment_3(
-	    Point_3 (0,p2.hx(),p2.hy(),p2.hw()),
-	    Point_3 (0,q2.hx(),q2.hy(),q2.hw()) ) );
+      if (const Point_2* pi =  boost::get<Point_2>(&*obj))
+      {
+        return boost::make_optional(variant_type(Point_3(0,p2.hx(),p2.hy(),p2.hw())));
       }
-      return obj;
+
+      const Segment_2* si = boost::get<Segment_2>(&*obj);
+      p2 = si->source();
+      q2 = si->target();
+
+      return boost::make_optional(variant_type(Segment_3(Point_3 (0,p2.hx(),p2.hy(),p2.hw()),
+                                                         Point_3 (0,q2.hx(),q2.hy(),q2.hw())) ));
    }
 };
 
