@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Principal_component_analysis/include/CGAL/PCA_util.h $
-// $Id: PCA_util.h f3baef9 2018-07-06T10:10:19+02:00 Simon Giraudot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Principal_component_analysis/include/CGAL/PCA_util.h $
+// $Id: PCA_util.h 246cc9b 2023-04-04T11:16:52+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Pierre Alliez and Sylvain Pion and Ankit Gupta
 
@@ -42,26 +33,26 @@ init_matrix(const int n,
 
   Matrix m(n);
   int i,j;
-  for(i = 0; i < n; i++) 
+  for(i = 0; i < n; i++)
     for(j = 0; j < n; j++)
       m[i][j] = entries[i*n+j];
 
   return m;
 } // end initialization of matrix
 
-// assemble covariance matrix from a point set 
+// assemble covariance matrix from a point set
 template < typename InputIterator,
            typename K,
-	   typename DiagonalizeTraits >
+           typename DiagonalizeTraits >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& k,                    // kernel
                              const typename K::Point_3*,   // used for indirection
                              const CGAL::Dimension_tag<0>&,
-			     const DiagonalizeTraits&)
+                             const DiagonalizeTraits&)
 {
   typedef typename K::FT       FT;
   typedef typename K::Point_3  Point;
@@ -70,8 +61,8 @@ assemble_covariance_matrix_3(InputIterator first,
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
-  covariance[0] = covariance[1] = covariance[2] = 
+  //     5
+  covariance[0] = covariance[1] = covariance[2] =
   covariance[3] = covariance[4] = covariance[5] = (FT)0.0;
   for(InputIterator it = first;
       it != beyond;
@@ -88,38 +79,38 @@ assemble_covariance_matrix_3(InputIterator first,
   }
 }
 
-// assemble covariance matrix from a triangle set 
+// assemble covariance matrix from a triangle set
 template < typename InputIterator,
            typename K,
-	   typename DiagonalizeTraits >
+           typename DiagonalizeTraits >
 void
 assemble_covariance_matrix_3(InputIterator first,
                              InputIterator beyond,
-			     typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
+                             typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K&,                    // kernel
                              const typename K::Triangle_3*,// used for indirection
                              const CGAL::Dimension_tag<2>&,
-			     const DiagonalizeTraits&)
+                             const DiagonalizeTraits&)
 {
   // Use FT from the DiagonalizeTraits to avoid warnings if the Kernel
   // uses double but the user wants to compute diagonalization using floats
   typedef typename DiagonalizeTraits::Vector::value_type FT;
-  
+
   typedef typename K::Triangle_3  Triangle;
   typedef typename CGAL::Linear_algebraCd<FT> LA;
   typedef typename LA::Matrix Matrix;
-  
 
-  // assemble covariance matrix as a semi-definite matrix. 
+
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all triangles and their combined mass
   FT mass = FT(0.0);
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[9] = {FT(1.0/12.0), FT(1.0/24.0), FT(1.0/24.0),
                 FT(1.0/24.0), FT(1.0/12.0), FT(1.0/24.0),
                 FT(1.0/24.0), FT(1.0/24.0), FT(1.0/12.0)};
@@ -134,21 +125,21 @@ assemble_covariance_matrix_3(InputIterator first,
     const Triangle& t = *it;
 
     // defined for convenience.
-    FT delta[9] = {FT(t[0].x()), FT(t[1].x()), FT(t[2].x()), 
+    FT delta[9] = {FT(t[0].x()), FT(t[1].x()), FT(t[2].x()),
                    FT(t[0].y()), FT(t[1].y()), FT(t[2].y()),
                    FT(t[0].z()), FT(t[1].z()), FT(t[2].z())};
     Matrix transformation = init_matrix<FT>(3,delta);
     FT area = FT(std::sqrt(t.squared_area()));
 
-		// skip zero measure primitives
+                // skip zero measure primitives
     if(area == (FT)0.0)
-			continue;
+                        continue;
 
     // Find the 2nd order moment for the triangle wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = 2 * area * transformation * moment * LA::transpose(transformation);
-    
+
     // and add to covariance matrix
     covariance[0] += transformation[0][0];
     covariance[1] += transformation[1][0];
@@ -171,36 +162,36 @@ assemble_covariance_matrix_3(InputIterator first,
 
 }
 
-// assemble covariance matrix from a cuboid set 
+// assemble covariance matrix from a cuboid set
 template < typename InputIterator,
            typename K,
-	   typename DiagonalizeTraits >
+           typename DiagonalizeTraits >
 void
 assemble_covariance_matrix_3(InputIterator first,
                              InputIterator beyond,
-			     typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
+                             typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& ,                    // kernel
                              const typename K::Iso_cuboid_3*,// used for indirection
                              const CGAL::Dimension_tag<3>&,
-			     const DiagonalizeTraits&)
+                             const DiagonalizeTraits&)
 {
   typedef typename K::FT          FT;
   typedef typename K::Iso_cuboid_3    Iso_cuboid;
   typedef typename CGAL::Linear_algebraCd<FT> LA;
   typedef typename LA::Matrix Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   // final combined covariance matrix for all cuboids and their combined mass
   FT mass = (FT)0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[9] = {(FT)(1.0/3.0), (FT)(1.0/4.0), (FT)(1.0/4.0),
-								(FT)(1.0/4.0), (FT)(1.0/3.0), (FT)(1.0/4.0),
+                                                                (FT)(1.0/4.0), (FT)(1.0/3.0), (FT)(1.0/4.0),
                 (FT)(1.0/4.0), (FT)(1.0/4.0), (FT)(1.0/3.0)};
   Matrix moment = init_matrix<FT>(3,temp);
 
@@ -217,21 +208,21 @@ assemble_covariance_matrix_3(InputIterator first,
     FT x0 = t[0].x();
     FT y0 = t[0].y();
     FT z0 = t[0].z();
-    FT delta[9] = {t[1].x()-x0, t[3].x()-x0, t[5].x()-x0, 
+    FT delta[9] = {t[1].x()-x0, t[3].x()-x0, t[5].x()-x0,
                    t[1].y()-y0, t[3].y()-y0, t[5].y()-y0,
                    t[1].z()-z0, t[3].z()-z0, t[5].z()-z0};
     Matrix transformation = init_matrix<FT>(3,delta);
     FT volume = t.volume();
 
-		// skip zero measure primitives
+                // skip zero measure primitives
     if(volume == (FT)0.0)
-			continue;
+                        continue;
 
     // Find the 2nd order moment for the cuboid wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = volume * transformation * moment * LA::transpose(transformation);
-    
+
     // Translate the 2nd order moment to the minimum corner (x0,y0,z0) of the cuboid.
     FT xav0 = (delta[0] + delta[1] + delta[2])/4.0;
     FT yav0 = (delta[3] + delta[4] + delta[5])/4.0;
@@ -258,34 +249,34 @@ assemble_covariance_matrix_3(InputIterator first,
   covariance[5] += mass * (- c.z() * c.z());
 }
 
-// assemble covariance matrix from a cuboid set 
+// assemble covariance matrix from a cuboid set
 template < typename InputIterator,
            typename K,
-	   typename DiagonalizeTraits >
+           typename DiagonalizeTraits >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
-			     typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
+                             InputIterator beyond,
+                             typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& ,                    // kernel
                              const typename K::Iso_cuboid_3*,// used for indirection
                              const CGAL::Dimension_tag<2>&,
-			     const DiagonalizeTraits&)
+                             const DiagonalizeTraits&)
 {
   typedef typename K::FT FT;
   typedef typename K::Iso_cuboid_3 Iso_cuboid;
   typedef typename CGAL::Linear_algebraCd<FT> LA;
   typedef typename LA::Matrix Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all cuboids and their combined mass
   FT mass = (FT)0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[9] = {(FT)(7.0/3.0), (FT)1.5,       (FT)1.5,
                 (FT)1.5,       (FT)(7.0/3.0), (FT)1.5,
                 (FT)1.5,       (FT)1.5,       (FT)(7.0/3.0)};
@@ -303,7 +294,7 @@ assemble_covariance_matrix_3(InputIterator first,
     FT x0 = t[0].x();
     FT y0 = t[0].y();
     FT z0 = t[0].z();
-    FT delta[9] = {t[1].x()-x0, t[3].x()-x0, t[5].x()-x0, 
+    FT delta[9] = {t[1].x()-x0, t[3].x()-x0, t[5].x()-x0,
                    t[1].y()-y0, t[3].y()-y0, t[5].y()-y0,
                    t[1].z()-z0, t[3].z()-z0, t[5].z()-z0};
     Matrix transformation = init_matrix<FT>(3,delta);
@@ -317,15 +308,15 @@ assemble_covariance_matrix_3(InputIterator first,
                   delta[7]*delta[7],1/3.0)*std::pow(delta[2]*delta[2] +
                   delta[5]*delta[5] + delta[8]*delta[8],1/3.0)*2;
 
-		// skip zero measure primitives
+                // skip zero measure primitives
     if(area == (FT)0.0)
-			continue;
+                        continue;
 
     // Find the 2nd order moment for the cuboid wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = area * transformation * moment * LA::transpose(transformation);
-    
+
     // Translate the 2nd order moment to the minimum corner (x0,y0,z0) of the cuboid.
     FT xav0 = (delta[0] + delta[1] + delta[2])/4.0;
     FT yav0 = (delta[3] + delta[4] + delta[5])/4.0;
@@ -353,34 +344,34 @@ assemble_covariance_matrix_3(InputIterator first,
 
 }
 
-// assemble covariance matrix from a sphere set 
+// assemble covariance matrix from a sphere set
 template < typename InputIterator,
            typename K,
-	   typename DiagonalizeTraits >
+           typename DiagonalizeTraits >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
-			     typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
+                             InputIterator beyond,
+                             typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K&,                     // kernel
                              const typename K::Sphere_3*,  // used for indirection
                              const CGAL::Dimension_tag<3>&,
-			     const DiagonalizeTraits&)
+                             const DiagonalizeTraits&)
 {
   typedef typename K::FT          FT;
   typedef typename K::Sphere_3  Sphere;
   typedef typename CGAL::Linear_algebraCd<FT> LA;
   typedef typename LA::Matrix Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all spheres and their combined mass
   FT mass = 0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[9] = {4.0/15.0, 0.0,      0.0,
                 0.0,      4.0/15.0, 0.0,
                 0.0,      0.0,      4.0/15.0};
@@ -396,21 +387,22 @@ assemble_covariance_matrix_3(InputIterator first,
 
     // defined for convenience.
     FT radius = std::sqrt(t.squared_radius());
-    FT delta[9] = {radius, 0.0, 0.0, 
+    FT delta[9] = {radius, 0.0, 0.0,
                    0.0, radius, 0.0,
                    0.0, 0.0, radius};
     Matrix transformation = init_matrix<FT>(3,delta);
-    FT volume = (FT)(4.0/3.0) * radius * t.squared_radius();
+    FT volume = radius * t.squared_radius();
 
-		// skip zero measure primitives
+                // skip zero measure primitives
     if(volume == (FT)0.0)
-			continue;
+                        continue;
 
     // Find the 2nd order moment for the sphere wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
-    transformation = (3.0/4.0) * volume * transformation * moment * LA::transpose(transformation);
-    
+    transformation = volume * transformation * moment * LA::transpose(transformation);
+
+    volume *= FT(4.0/3.0);
     // Translate the 2nd order moment to the center of the sphere.
     FT x0 = t.center().x();
     FT y0 = t.center().y();
@@ -437,34 +429,34 @@ assemble_covariance_matrix_3(InputIterator first,
   covariance[5] += mass * (-1.0 * c.z() * c.z());
 
 }
-// assemble covariance matrix from a sphere set 
+// assemble covariance matrix from a sphere set
 template < typename InputIterator,
            typename K,
-	   typename DiagonalizeTraits >
+           typename DiagonalizeTraits >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
-			     typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
+                             InputIterator beyond,
+                             typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K&,                     // kernel
                              const typename K::Sphere_3*,  // used for indirection
                              const CGAL::Dimension_tag<2>&,
-			     const DiagonalizeTraits&)
+                             const DiagonalizeTraits&)
 {
   typedef typename K::FT          FT;
   typedef typename K::Sphere_3  Sphere;
   typedef typename CGAL::Linear_algebraCd<FT> LA;
   typedef typename LA::Matrix Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all spheres and their combined mass
   FT mass = 0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[9] = {4.0/3.0, 0.0,     0.0,
                 0.0,     4.0/3.0, 0.0,
                 0.0,     0.0,     4.0/3.0};
@@ -481,21 +473,22 @@ assemble_covariance_matrix_3(InputIterator first,
     // defined for convenience.
     // FT example = CGAL::to_double(t[0].x());
     FT radius = std::sqrt(t.squared_radius());
-    FT delta[9] = {radius, 0.0,    0.0, 
+    FT delta[9] = {radius, 0.0,    0.0,
                    0.0,    radius, 0.0,
                    0.0,    0.0,    radius};
     Matrix transformation = init_matrix<FT>(3,delta);
-    FT area = (FT)4.0 * t.squared_radius();
+    FT area = t.squared_radius();
 
-		// skip zero measure primitives
+                // skip zero measure primitives
     if(area == (FT)0.0)
-			continue;
+                        continue;
 
     // Find the 2nd order moment for the sphere wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
-    transformation = (1.0/4.0) * area * transformation * moment * LA::transpose(transformation);
-    
+    transformation = area * transformation * moment * LA::transpose(transformation);
+
+    area *= FT(4.0);
     // Translate the 2nd order moment to the center of the sphere.
     FT x0 = t.center().x();
     FT y0 = t.center().y();
@@ -523,34 +516,34 @@ assemble_covariance_matrix_3(InputIterator first,
 
 }
 
-// assemble covariance matrix from a tetrahedron set 
+// assemble covariance matrix from a tetrahedron set
 template < typename InputIterator,
            typename K,
-	   typename DiagonalizeTraits >
+           typename DiagonalizeTraits >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
-			     typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
+                             InputIterator beyond,
+                             typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& ,                    // kernel
                              const typename K::Tetrahedron_3*,// used for indirection
                              const CGAL::Dimension_tag<3>&,
-			     const DiagonalizeTraits&)
+                             const DiagonalizeTraits&)
 {
   typedef typename K::FT          FT;
   typedef typename K::Tetrahedron_3  Tetrahedron;
   typedef typename CGAL::Linear_algebraCd<FT> LA;
   typedef typename LA::Matrix Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all tetrahedrons and their combined mass
   FT mass = 0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[9] = {1.0/60.0,  1.0/120.0, 1.0/120.0,
                 1.0/120.0, 1.0/60.0,  1.0/120.0,
                 1.0/120.0, 1.0/120.0, 1.0/60.0};
@@ -569,21 +562,21 @@ assemble_covariance_matrix_3(InputIterator first,
     FT y0 = t[0].y();
     FT z0 = t[0].z();
 
-    FT delta[9] = {t[1].x()-x0, t[2].x()-x0, t[3].x()-x0, 
+    FT delta[9] = {t[1].x()-x0, t[2].x()-x0, t[3].x()-x0,
                    t[1].y()-y0, t[2].y()-y0, t[3].y()-y0,
                    t[1].z()-z0, t[2].z()-z0, t[3].z()-z0};
     Matrix transformation = init_matrix<FT>(3,delta);
     FT volume = t.volume();
 
-		// skip zero measure primitives
+                // skip zero measure primitives
     if(volume == (FT)0.0)
-			continue;
+                        continue;
 
     // Find the 2nd order moment for the tetrahedron wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = 6 * volume * transformation * moment * LA::transpose(transformation);
-    
+
     // Translate the 2nd order moment to the center of the tetrahedron.
     FT xav0 = (delta[0]+delta[1]+delta[2])/4.0;
     FT yav0 = (delta[3]+delta[4]+delta[5])/4.0;
@@ -610,34 +603,34 @@ assemble_covariance_matrix_3(InputIterator first,
   covariance[5] += mass * (-1.0 * c.z() * c.z());
 }
 
-// assemble covariance matrix from a segment set 
+// assemble covariance matrix from a segment set
 template < typename InputIterator,
            typename K,
-	   typename DiagonalizeTraits >
+           typename DiagonalizeTraits >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
-			     typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
+                             InputIterator beyond,
+                             typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& ,                    // kernel
                              const typename K::Segment_3*,// used for indirection
                              const CGAL::Dimension_tag<1>&,
-			     const DiagonalizeTraits&)
+                             const DiagonalizeTraits&)
 {
   typedef typename K::FT          FT;
   typedef typename K::Segment_3  Segment;
   typedef typename CGAL::Linear_algebraCd<FT> LA;
   typedef typename LA::Matrix Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all segments and their combined mass
   FT mass = 0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[9] = {1.0, 0.5, 0.0,
                 0.5, 1.0, 0.0,
                 0.0, 0.0, 0.0};
@@ -653,18 +646,19 @@ assemble_covariance_matrix_3(InputIterator first,
 
     // defined for convenience.
     // FT example = CGAL::to_double(t[0].x());
-    FT delta[9] = {t[0].x(), t[1].x(), 0.0, 
+    FT delta[9] = {t[0].x(), t[1].x(), 0.0,
        t[0].y(), t[1].y(), 0.0,
                    t[0].z(), t[1].z(), 1.0};
     Matrix transformation = init_matrix<FT>(3,delta);
-    FT length = std::sqrt(t.squared_length());
+    using std::sqrt;
+    FT length = sqrt(t.squared_length());
 
-		// skip zero measure primitives
+                // skip zero measure primitives
     if(length == (FT)0.0)
-			continue;
+                        continue;
 
     // Find the 2nd order moment for the segment wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = length * transformation * moment * LA::transpose(transformation);
 
@@ -691,7 +685,7 @@ assemble_covariance_matrix_3(InputIterator first,
 }
 
 
-// compute the eigen values and vectors of the covariance 
+// compute the eigen values and vectors of the covariance
 // matrix and deduces the best linear fitting plane.
 // returns fitting quality
 template < typename K, typename DiagonalizeTraits >
@@ -700,42 +694,46 @@ fitting_plane_3(typename DiagonalizeTraits::Covariance_matrix& covariance, // co
                 const typename K::Point_3& c,       // centroid
                 typename K::Plane_3& plane,         // best fit plane
                 const K&,                           // kernel
-		const DiagonalizeTraits& )                 // Diagonalize traits
+                const DiagonalizeTraits& )                 // Diagonalize traits
 {
   typedef typename K::FT       FT;
   typedef typename K::Plane_3  Plane;
   typedef typename K::Vector_3 Vector;
 
   // solve for eigenvalues and eigenvectors.
-  // eigen values are sorted in ascending order, 
+  // eigen values are sorted in ascending order,
   // eigen vectors are sorted in accordance.
   typename DiagonalizeTraits::Vector eigen_values = {{ 0. , 0., 0. }};
   typename DiagonalizeTraits::Matrix eigen_vectors = {{ 0., 0., 0.,
-							0., 0., 0.,
-							0., 0., 0. }};
+                                                        0., 0., 0.,
+                                                        0., 0., 0. }};
   DiagonalizeTraits::diagonalize_selfadjoint_covariance_matrix
     (covariance, eigen_values, eigen_vectors);
 
-  // degenerate case 
-  if(eigen_values[0] == eigen_values[1] && 
+  // degenerate case
+  if(eigen_values[0] == eigen_values[1] &&
      eigen_values[1] == eigen_values[2])
   {
     // assemble a default horizontal plane that goes
     // through the centroid.
     plane = Plane(c,Vector(FT(0),FT(0),FT(1)));
     return FT(0);
-  } 
+  }
   else // regular and line case
   {
     Vector normal(eigen_vectors[0],
                   eigen_vectors[1],
                   eigen_vectors[2]);
     plane = Plane(c,normal);
-    return FT(1) - eigen_values[0] / eigen_values[1];
+
+    if (eigen_values[1] == 0)
+        return FT(0); // line case
+    else
+        return FT(1) - eigen_values[0] / eigen_values[1]; // regular case
   } // end regular case
 }
 
-// compute the eigen values and vectors of the covariance 
+// compute the eigen values and vectors of the covariance
 // matrix and deduces the best linear fitting line
 // (this is an internal function)
 // returns fitting quality
@@ -744,25 +742,25 @@ typename K::FT
 fitting_line_3(typename DiagonalizeTraits::Covariance_matrix& covariance, // covariance matrix
                const typename K::Point_3& c,       // centroid
                typename K::Line_3& line,           // best fit line
-	       const K&,                           // kernel
-	       const DiagonalizeTraits& )                 // Diagonalize traits
+               const K&,                           // kernel
+               const DiagonalizeTraits& )                 // Diagonalize traits
 {
   typedef typename K::FT       FT;
   typedef typename K::Line_3   Line;
   typedef typename K::Vector_3 Vector;
 
   // solve for eigenvalues and eigenvectors.
-  // eigen values are sorted in ascending order, 
+  // eigen values are sorted in ascending order,
   // eigen vectors are sorted in accordance.
   typename DiagonalizeTraits::Vector eigen_values = {{ 0. , 0., 0. }};
   typename DiagonalizeTraits::Matrix eigen_vectors = {{ 0., 0., 0.,
-							0., 0., 0.,
-							0., 0., 0. }};
+                                                        0., 0., 0.,
+                                                        0., 0., 0. }};
   DiagonalizeTraits::diagonalize_selfadjoint_covariance_matrix
     (covariance, eigen_values, eigen_vectors);
 
     // isotropic case (infinite number of directions)
-  if(eigen_values[0] == eigen_values[1] && 
+  if(eigen_values[0] == eigen_values[1] &&
      eigen_values[0] == eigen_values[2])
   {
     // assemble a default line along x axis which goes
@@ -776,7 +774,7 @@ fitting_line_3(typename DiagonalizeTraits::Covariance_matrix& covariance, // cov
     Vector direction(eigen_vectors[6],eigen_vectors[7],eigen_vectors[8]);
     line = Line(c,direction);
     return (FT)1.0 - eigen_values[1] / eigen_values[2];
-  } 
+  }
 }
 
 } // end namespace internal
