@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_Delaunay_triangulation_traits_2.h $
-// $Id: Periodic_4_hyperbolic_Delaunay_triangulation_traits_2.h c143c65 2019-01-23T16:45:55+01:00 Maxime Gimeno
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_Delaunay_triangulation_traits_2.h $
+// $Id: Periodic_4_hyperbolic_Delaunay_triangulation_traits_2.h 5c8df66 2020-09-25T14:25:14+02:00 Jane Tournois
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     :   Iordan Iordanov
 //                   Monique Teillaud
@@ -31,7 +22,6 @@
 
 #include <CGAL/Bbox_2.h>
 #include <CGAL/Cartesian.h>
-#include <CGAL/CORE_Expr.h>
 
 #include <boost/tuple/tuple.hpp>
 #include <boost/variant.hpp>
@@ -60,23 +50,7 @@ class Hyperbolic_traits_with_translations_2_adaptor
 public:
   typedef typename Predicate::result_type                 result_type;
 
-#ifndef CGAL_CFG_MATCHING_BUG_6
   using Predicate::operator();
-#else
-  result_type operator()(const Point& p0, const Point& p1) const
-  {
-	  return Predicate()(p0, p1);
-  }
-  result_type operator()(const Point& p0, const Point& p1, const Point& p2) const
-  {
-    return Predicate()(p0,p1,p2);
-  }
-
-  result_type operator()(const Point& p0, const Point& p1, const Point& p2, const Point& p3) const
-  {
-    return Predicate()(p0,p1,p2,p3);
-  }
-#endif
 
   Hyperbolic_traits_with_translations_2_adaptor(const Predicate_ pred = Predicate_()) : Predicate_(pred) {}
 
@@ -136,16 +110,9 @@ private:
 
 public:
   typedef Point                                           result_type;
- 
-#ifndef CGAL_CFG_MATCHING_BUG_6
+
   using Construct_point_base::operator();
-#else
-  Point operator()(const NT& x, const NT& y) const
-  {
-    return Construct_point_base()(x,y);
-  }
-#endif
-  
+
   Periodic_4_construct_hyperbolic_point_2() { }
 
   Point operator()(const Point& pt, const Hyperbolic_translation& tr) const
@@ -628,7 +595,7 @@ class Side_of_original_octagon
   };
 
 
-} // end namespace internal 
+} // end namespace internal
 
 
 template <typename Kernel = Exact_predicates_exact_constructions_kernel_with_sqrt,
