@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_triangulation_2.h $
-// $Id: Periodic_4_hyperbolic_triangulation_2.h 2dec5c9 2019-01-10T08:51:11+01:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_triangulation_2.h $
+// $Id: Periodic_4_hyperbolic_triangulation_2.h d3fca65 2022-09-23T12:49:40+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Iordan Iordanov  <Iordan.Iordanov@loria.fr>
 //
@@ -34,7 +25,7 @@
 
 #include <CGAL/NT_converter.h>
 #include <CGAL/Triangulation_utils_2.h>
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/utility.h>
 #include <CGAL/use.h>
 
@@ -75,9 +66,9 @@ public:
   typedef typename GT::Hyperbolic_segment_2                       Hyperbolic_segment;
   typedef typename GT::Hyperbolic_triangle_2                      Hyperbolic_triangle;
 
-  typedef std::pair<Point, Hyperbolic_translation>                Periodic_point;
-  typedef array< std::pair<Point, Hyperbolic_translation>, 2 >    Periodic_segment;
-  typedef array< std::pair<Point, Hyperbolic_translation>, 3 >    Periodic_triangle;
+  typedef std::pair<Point, Hyperbolic_translation>                     Periodic_point;
+  typedef std::array< std::pair<Point, Hyperbolic_translation>, 2 >    Periodic_segment;
+  typedef std::array< std::pair<Point, Hyperbolic_translation>, 3 >    Periodic_triangle;
 
   typedef typename TDS::Vertex                                    Vertex;
   typedef typename TDS::Edge                                      Edge;
@@ -119,7 +110,7 @@ public:
   Periodic_4_hyperbolic_triangulation_2(const Periodic_4_hyperbolic_triangulation_2& tr)
     : _gt(tr.geom_traits())
   {
-    CGAL_triangulation_expensive_postcondition(*this == tr);
+    CGAL_expensive_postcondition(*this == tr);
   }
 
   Periodic_4_hyperbolic_triangulation_2& operator=(Periodic_4_hyperbolic_triangulation_2 tr)
@@ -184,7 +175,7 @@ public:
 
   Periodic_point periodic_point(const Face_handle c, int i) const
   {
-    CGAL_triangulation_precondition(i >= 0 && i <= 2);
+    CGAL_precondition(i >= 0 && i <= 2);
     return std::make_pair(c->vertex(i)->point(), c->translation(i));
   }
 
@@ -203,8 +194,8 @@ public:
 
   Periodic_segment periodic_segment(const Face_handle c, int i, int j) const
   {
-    CGAL_triangulation_precondition(i != j);
-    CGAL_triangulation_precondition((i >= 0 && i <= 2) && (j >= 0 && j <= 2));
+    CGAL_precondition(i != j);
+    CGAL_precondition((i >= 0 && i <= 2) && (j >= 0 && j <= 2));
     return periodic_segment(c->vertex(i)->point(), c->vertex(j)->point(),
                             c->translation(i), c->translation(j));
   }
@@ -272,14 +263,14 @@ public:
 
   Hyperbolic_segment construct_hyperbolic_segment(const Face_handle & fh, int idx) const
   {
-    CGAL_triangulation_precondition(idx >= 0 && idx <= 2);
+    CGAL_precondition(idx >= 0 && idx <= 2);
     return construct_hyperbolic_segment(fh->vertex(ccw(idx))->point(), fh->vertex(cw(idx))->point(),
                                         fh->translation(ccw(idx)), fh->translation(cw(idx)));
   }
 
   Hyperbolic_segment construct_hyperbolic_segment(const std::pair<Face_handle, int> & edge) const
   {
-    CGAL_triangulation_precondition(edge.second >= 0 && edge.second <= 2);
+    CGAL_precondition(edge.second >= 0 && edge.second <= 2);
     return construct_hyperbolic_segment(edge.first, ccw(edge.second));
   }
 
@@ -532,7 +523,7 @@ public:
 
   Hyperbolic_translation neighbor_translation(const Face_handle fh, int i) const
   {
-    CGAL_triangulation_precondition(i >= 0 && i <= 2);
+    CGAL_precondition(i >= 0 && i <= 2);
     int myi = ccw(i);
     Hyperbolic_translation myof = fh->translation(myi);
 
@@ -617,15 +608,15 @@ protected:
     }
 
     // Now we know that all vertices lie in different regions.
-    Hyperbolic_translation min(7, 2, 5);
+    Hyperbolic_translation vmin(7, 2, 5);
     Hyperbolic_translation trans;
     for(int i=0; i<3; ++i)
     {
       int j = (i + 1) % 3; // the index of the 'next' vertex
       Hyperbolic_translation tmp = fh->translation(i).inverse() * fh->translation(j);
-      if(tmp < min)
+      if(tmp < vmin)
       {
-        min = tmp;
+        vmin = tmp;
         trans = fh->translation(i).inverse();
       }
     }
@@ -654,9 +645,9 @@ inline bool
 Periodic_4_hyperbolic_triangulation_2<GT, TDS>::
 has_self_edges(typename TDS::Face_handle c) const
 {
-  CGAL_triangulation_assertion((c->vertex(0) != c->vertex(1)) || (c->translation(0) != c->translation(1)));
-  CGAL_triangulation_assertion((c->vertex(0) != c->vertex(2)) || (c->translation(0) != c->translation(2)));
-  CGAL_triangulation_assertion((c->vertex(1) != c->vertex(2)) || (c->translation(1) != c->translation(2)));
+  CGAL_assertion((c->vertex(0) != c->vertex(1)) || (c->translation(0) != c->translation(1)));
+  CGAL_assertion((c->vertex(0) != c->vertex(2)) || (c->translation(0) != c->translation(2)));
+  CGAL_assertion((c->vertex(1) != c->vertex(2)) || (c->translation(1) != c->translation(2)));
 
   return ((c->vertex(0) == c->vertex(1)) ||
           (c->vertex(0) == c->vertex(2)) ||
@@ -680,7 +671,7 @@ has_cycles_length_2(typename TDS::Vertex_handle v) const
   return false;
 }
 
-/*! \brief Tests if the triangulation is valid.
+/*! \brief tests if the triangulation is valid.
  *
  * A triangulation is valid if
  * - A cell is not its own neighbor.
@@ -700,11 +691,11 @@ is_valid(bool verbose) const {
   {
     for(int i=0; i<3; ++i)
     {
-      CGAL_triangulation_assertion(cit != cit->neighbor(i));
+      CGAL_assertion(cit != cit->neighbor(i));
       for(int j=i+1; j<3; ++j)
       {
-        CGAL_triangulation_assertion(cit->neighbor(i) != cit->neighbor(j));
-        CGAL_triangulation_assertion(cit->vertex(i) != cit->vertex(j));
+        CGAL_assertion(cit->neighbor(i) != cit->neighbor(j));
+        CGAL_assertion(cit->vertex(i) != cit->vertex(j));
       }
     }
 
@@ -744,9 +735,9 @@ is_valid(bool verbose) const {
 
   if(!error)
   {
-    CGAL_triangulation_assertion(!has_self_edges());
-    CGAL_triangulation_assertion(!has_cycles_length_2());
-    CGAL_triangulation_assertion(_tds.number_of_vertices() + _tds.number_of_faces() + 2 == _tds.number_of_edges());
+    CGAL_assertion(!has_self_edges());
+    CGAL_assertion(!has_cycles_length_2());
+    CGAL_assertion(_tds.number_of_vertices() + _tds.number_of_faces() + 2 == _tds.number_of_edges());
     return true;
   }
   else
@@ -999,8 +990,8 @@ hyperbolic_periodic_locate(const Point& p,
     Point np0 = construct_point(construct_point(nf->vertex(0)->point(), nf->translation(0)) , tr);
     Point np1 = construct_point(construct_point(nf->vertex(1)->point(), nf->translation(1)) , tr);
     Point np2 = construct_point(construct_point(nf->vertex(2)->point(), nf->translation(2)) , tr);
-    CGAL_triangulation_assertion_code(Oriented_side os1 = side_of_hyperbolic_triangle(np0, np1, np2, p, lt, li));
-    CGAL_triangulation_assertion(os1 == ON_POSITIVE_SIDE);
+    CGAL_assertion_code(Oriented_side os1 = side_of_hyperbolic_triangle(np0, np1, np2, p, lt, li));
+    CGAL_assertion(os1 == ON_POSITIVE_SIDE);
     lo = tr;
     return nf;
   }
