@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Poisson_surface_reconstruction_3/include/CGAL/Poisson_reconstruction_function.h $
-// $Id: Poisson_reconstruction_function.h 2f9408f 2018-09-04T12:01:27+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Poisson_surface_reconstruction_3/include/CGAL/Poisson_reconstruction_function.h $
+// $Id: Poisson_reconstruction_function.h d3fca65 2022-09-23T12:49:40+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Laurent Saboret, Pierre Alliez
 
@@ -36,8 +27,9 @@
 #include <algorithm>
 #include <cmath>
 #include <iterator>
+#include <type_traits>
 
-#include <CGAL/trace.h>
+#include <CGAL/IO/trace.h>
 #include <CGAL/Reconstruction_triangulation_3.h>
 #include <CGAL/spatial_sort.h>
 #ifdef CGAL_EIGEN3_ENABLED
@@ -46,18 +38,18 @@
 #endif
 #include <CGAL/centroid.h>
 #include <CGAL/property_map.h>
-#include <CGAL/surface_reconstruction_points_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/poisson_refine_triangulation.h>
-#include <CGAL/Robust_circumcenter_filtered_traits_3.h>
+#include <CGAL/Robust_weighted_circumcenter_filtered_traits_3.h>
 #include <CGAL/compute_average_spacing.h>
 #include <CGAL/Timer.h>
 
-#include <boost/shared_ptr.hpp>
+#include <memory>
 #include <boost/array.hpp>
 #include <boost/type_traits/is_convertible.hpp>
-#include <boost/utility/enable_if.hpp>
+#include <boost/iterator/indirect_iterator.hpp>
 
-/*! 
+/*!
   \file Poisson_reconstruction_function.h
 */
 
@@ -113,48 +105,37 @@ struct Poisson_visitor {
   {}
 };
 
-struct Poisson_skip_vertices { 
-  double ratio;
-  Random& m_random;
-  Poisson_skip_vertices(const double ratio, Random& random)
-    : ratio(ratio), m_random(random) {}
-
-  template <typename Iterator>
-  bool operator()(Iterator) const {
-    return m_random.get_double() < ratio;
-  }
-};
-
 // Given f1 and f2, two sizing fields, that functor wrapper returns
 //   max(f1, f2*f2)
 // The wrapper stores only pointers to the two functors.
 template <typename F1, typename F2>
 struct Special_wrapper_of_two_functions_keep_pointers {
+  typedef typename F2::FT FT;
   F1 *f1;
   F2 *f2;
-  Special_wrapper_of_two_functions_keep_pointers(F1* f1, F2* f2) 
+  Special_wrapper_of_two_functions_keep_pointers(F1* f1, F2* f2)
     : f1(f1), f2(f2) {}
 
   template <typename X>
-  double operator()(const X& x) const {
+  FT operator()(const X& x) const {
     return (std::max)((*f1)(x), CGAL::square((*f2)(x)));
   }
 
   template <typename X>
-  double operator()(const X& x) {
+  FT operator()(const X& x) {
     return (std::max)((*f1)(x), CGAL::square((*f2)(x)));
   }
 }; // end struct Special_wrapper_of_two_functions_keep_pointers<F1, F2>
-/// \endcond 
+/// \endcond
 
 
 /*!
 \ingroup PkgPoissonSurfaceReconstruction3Ref
 
 \brief Implementation of the Poisson Surface Reconstruction method.
-  
+
 Given a set of 3D points with oriented normals sampled on the boundary
-of a 3D solid, the Poisson Surface Reconstruction method \cgalCite{Kazhdan06} 
+of a 3D solid, the Poisson Surface Reconstruction method \cgalCite{Kazhdan06}
 solves for an approximate indicator function of the inferred
 solid, whose gradient best matches the input normals. The output
 scalar function, represented in an adaptive octree, is then
@@ -164,7 +145,7 @@ iso-contoured using an adaptive marching cubes.
 algorithm which solves for a piecewise linear function on a 3D
 Delaunay triangulation instead of an adaptive octree.
 
-\tparam Gt Geometric traits class. 
+\tparam Gt Geometric traits class.
 
 \cgalModels `ImplicitFunction`
 
@@ -175,7 +156,7 @@ class Poisson_reconstruction_function
 // Public types
 public:
 
-  /// \name Types 
+  /// \name Types
   /// @{
 
   typedef Gt Geom_traits; ///< Geometric traits class
@@ -189,7 +170,7 @@ public:
   typedef typename Geom_traits::FT FT; ///< number type.
   typedef typename Geom_traits::Point_3 Point; ///< point type.
   typedef typename Geom_traits::Vector_3 Vector; ///< vector type.
-  typedef typename Geom_traits::Sphere_3 Sphere; 
+  typedef typename Geom_traits::Sphere_3 Sphere;
 
   /// @}
 
@@ -225,6 +206,67 @@ private:
   typedef typename Triangulation::All_cells_iterator       All_cells_iterator;
   typedef typename Triangulation::Locate_type Locate_type;
 
+  enum Cache_state { UNINITIALIZED, BUSY, INITIALIZED };
+  // Thread-safe cache for barycentric coordinates of a cell
+  class Cached_bary_coord
+  {
+  private:
+    std::atomic<Cache_state> m_state;
+    std::array<FT, 9> m_bary;
+  public:
+    Cached_bary_coord() : m_state (UNINITIALIZED) { }
+
+    // Copy operator to satisfy vector, shouldn't be used
+    Cached_bary_coord(const Cached_bary_coord&)
+    {
+      CGAL_error();
+    }
+
+    bool is_initialized()
+    {
+      Cache_state s = m_state;
+      if (s == UNINITIALIZED)
+      {
+        // If the following line successfully replaces UNINITIALIZED
+        // by BUSY, then the current thread in charge of initialization
+        if (m_state.compare_exchange_weak(s, BUSY))
+          return false;
+      }
+      // Otherwise, either the thread is BUSY by another thread, or
+      // it's already INITIALIZED. Either way, we way until it's INITIALIZED
+      else
+        while (m_state != INITIALIZED) { }
+
+      // At this point, it's always INITIALIZED
+      return true;
+    }
+
+    void set_initialized() { m_state = INITIALIZED; }
+
+    const FT& operator[] (const std::size_t& idx) const { return m_bary[idx]; }
+    FT& operator[] (const std::size_t& idx) { return m_bary[idx]; }
+  };
+
+  // Wrapper for thread safety of maintained cell hint for fast
+  // locate, with conversions atomic<Cell*>/Cell_handle
+  class Cell_hint
+  {
+    std::atomic<Cell*> m_cell;
+  public:
+
+    Cell_hint() : m_cell(nullptr) { }
+
+    // Poisson_reconstruction_function should be copyable, although we
+    // don't need to copy that
+    Cell_hint(const Cell_hint&) : m_cell(nullptr) { }
+
+    Cell_handle get() const
+    {
+      return Triangulation_data_structure::Cell_range::s_iterator_to(*m_cell);
+    }
+    void set (Cell_handle ch) { m_cell = ch.operator->(); }
+  };
+
 // Data members.
 // Warning: the Surface Mesh Generation package makes copies of implicit functions,
 // thus this class must be lightweight and stateless.
@@ -232,15 +274,14 @@ private:
 
   // operator() is pre-computed on vertices of *m_tr by solving
   // the Poisson equation Laplacian(f) = divergent(normals field).
-  boost::shared_ptr<Triangulation> m_tr;
-
-  mutable boost::shared_ptr<std::vector<boost::array<double,9> > > m_Bary;
+  std::shared_ptr<Triangulation> m_tr;
+  mutable std::shared_ptr<std::vector<Cached_bary_coord> > m_bary;
   mutable std::vector<Point> Dual;
   mutable std::vector<Vector> Normal;
 
   // contouring and meshing
   Point m_sink; // Point with the minimum value of operator()
-  mutable Cell_handle m_hint; // last cell found = hint for next search
+  mutable Cell_hint m_hint; // last cell found = hint for next search
 
   FT average_spacing;
 
@@ -278,22 +319,22 @@ private:
 // Public methods
 public:
 
-  /// \name Creation 
+  /// \name Creation
   /// @{
 
 
-  /*! 
-    Creates a Poisson implicit function from the  range of points `[first, beyond)`. 
+  /*!
+    Creates a Poisson implicit function from the  range of points `[first, beyond)`.
 
-    \tparam InputIterator iterator over input points. 
+    \tparam InputIterator iterator over input points.
 
     \tparam PointPMap is a model of `ReadablePropertyMap` with
       a `value_type = Point`.  It can be omitted if `InputIterator`
-      `value_type` is convertible to `Point`. 
-    
+      `value_type` is convertible to `Point`.
+
     \tparam NormalPMap is a model of `ReadablePropertyMap`
       with a `value_type = Vector`.
-  */ 
+  */
   template <typename InputIterator,
             typename PointPMap,
             typename NormalPMap
@@ -304,7 +345,7 @@ public:
     PointPMap point_pmap, ///< property map: `value_type of InputIterator` -> `Point` (the position of an input point).
     NormalPMap normal_pmap ///< property map: `value_type of InputIterator` -> `Vector` (the *oriented* normal of an input point).
   )
-    : m_tr(new Triangulation), m_Bary(new std::vector<boost::array<double,9> > )
+    : m_tr(new Triangulation), m_bary(new std::vector<Cached_bary_coord>)
     , average_spacing(CGAL::compute_average_spacing<CGAL::Sequential_tag>
                       (CGAL::make_range(first, beyond), 6,
                        CGAL::parameters::point_map(point_pmap)))
@@ -324,7 +365,7 @@ public:
     PointPMap point_pmap, ///< property map: `value_type of InputIterator` -> `Point` (the position of an input point).
     NormalPMap normal_pmap, ///< property map: `value_type of InputIterator` -> `Vector` (the *oriented* normal of an input point).
     Visitor visitor)
-    : m_tr(new Triangulation), m_Bary(new std::vector<boost::array<double,9> > )
+    : m_tr(new Triangulation), m_bary(new std::vector<Cached_bary_coord>)
     , average_spacing(CGAL::compute_average_spacing<CGAL::Sequential_tag>(CGAL::make_range(first, beyond), 6,
                                                                           CGAL::parameters::point_map(point_pmap)))
   {
@@ -339,14 +380,14 @@ public:
     InputIterator first,  ///< iterator over the first input point.
     InputIterator beyond, ///< past-the-end iterator over the input points.
     NormalPMap normal_pmap, ///< property map: `value_type of InputIterator` -> `Vector` (the *oriented* normal of an input point).
-    typename boost::enable_if<
-      boost::is_convertible<typename std::iterator_traits<InputIterator>::value_type, Point>
-    >::type* = 0
+    std::enable_if_t<
+      boost::is_convertible<typename std::iterator_traits<InputIterator>::value_type, Point>::value
+    >* = 0
   )
-  : m_tr(new Triangulation), m_Bary(new std::vector<boost::array<double,9> > )
+    : m_tr(new Triangulation), m_bary(new std::vector<Cached_bary_coord>)
   , average_spacing(CGAL::compute_average_spacing<CGAL::Sequential_tag>(CGAL::make_range(first, beyond), 6))
   {
-    forward_constructor(first, beyond, 
+    forward_constructor(first, beyond,
       make_identity_property_map(
       typename std::iterator_traits<InputIterator>::value_type()),
       normal_pmap, Poisson_visitor());
@@ -364,12 +405,12 @@ public:
   {
     return m_tr->bounding_sphere();
   }
-  
+
   /// \cond SKIP_IN_MANUAL
   const Triangulation& tr() const {
     return *m_tr;
   }
-  
+
   // This variant requires all parameters.
   template <class SparseLinearAlgebraTraits_d,
             class Visitor>
@@ -377,7 +418,7 @@ public:
                                  SparseLinearAlgebraTraits_d solver,// = SparseLinearAlgebraTraits_d(),
                                  Visitor visitor,
                                  double approximation_ratio = 0,
-                                 double average_spacing_ratio = 5) 
+                                 double average_spacing_ratio = 5)
   {
     CGAL::Timer task_timer; task_timer.start();
     CGAL_TRACE_STREAM << "Delaunay refinement...\n";
@@ -391,7 +432,7 @@ public:
 
     internal::Poisson::Constant_sizing_field<Triangulation> sizing_field(CGAL::square(cell_radius_bound));
 
-    std::vector<int> NB; 
+    std::vector<int> NB;
 
     NB.push_back( delaunay_refinement(radius_edge_ratio_bound,sizing_field,max_vertices,enlarge_ratio));
 
@@ -400,7 +441,7 @@ public:
       NB.push_back( delaunay_refinement(radius_edge_ratio_bound,sizing_field,max_vertices,enlarge_ratio));
     }
 
-    if(approximation_ratio > 0. && 
+    if(approximation_ratio > 0. &&
        approximation_ratio * std::distance(m_tr->input_points_begin(),
                                            m_tr->input_points_end()) > 20) {
 
@@ -424,38 +465,39 @@ public:
       // then the cell is considered as small enough, and the first sizing
       // field, more costly, is not evaluated.
 
-      typedef Filter_iterator<typename Triangulation::Input_point_iterator,
-                              Poisson_skip_vertices> Some_points_iterator;
       //make it deterministic
       Random random(0);
-      Poisson_skip_vertices skip(1.-approximation_ratio,random);
-      
+      double ratio = 1.-approximation_ratio;
+
+      std::vector<typename Triangulation::Input_point_iterator> some_points;
+      for (typename Triangulation::Input_point_iterator
+             it = m_tr->input_points_begin(); it != m_tr->input_points_end(); ++ it)
+        if (random.get_double() >= ratio)
+          some_points.push_back (it);
+
       CGAL_TRACE_STREAM << "SPECIAL PASS that uses an approximation of the result (approximation ratio: "
                 << approximation_ratio << ")" << std::endl;
       CGAL::Timer approximation_timer; approximation_timer.start();
 
       CGAL::Timer sizing_field_timer; sizing_field_timer.start();
-      Poisson_reconstruction_function<Geom_traits> 
-        coarse_poisson_function(Some_points_iterator(m_tr->input_points_end(),
-                                                     skip,
-                                                     m_tr->input_points_begin()),
-                                Some_points_iterator(m_tr->input_points_end(),
-                                                     skip),
+      Poisson_reconstruction_function<Geom_traits>
+        coarse_poisson_function(boost::make_indirect_iterator (some_points.begin()),
+                                boost::make_indirect_iterator (some_points.end()),
                                 Normal_of_point_with_normal_map<Geom_traits>() );
       coarse_poisson_function.compute_implicit_function(solver, Poisson_visitor(),
                                                         0.);
-      internal::Poisson::Constant_sizing_field<Triangulation> 
+      internal::Poisson::Constant_sizing_field<Triangulation>
         min_sizing_field(CGAL::square(average_spacing));
-      internal::Poisson::Constant_sizing_field<Triangulation> 
+      internal::Poisson::Constant_sizing_field<Triangulation>
         sizing_field_ok(CGAL::square(average_spacing*average_spacing_ratio));
 
       Special_wrapper_of_two_functions_keep_pointers<
         internal::Poisson::Constant_sizing_field<Triangulation>,
         Poisson_reconstruction_function<Geom_traits> > sizing_field2(&min_sizing_field,
                                                                      &coarse_poisson_function);
-        
+
       sizing_field_timer.stop();
-      std::cerr << "Construction time of the sizing field: " << sizing_field_timer.time() 
+      std::cerr << "Construction time of the sizing field: " << sizing_field_timer.time()
                 << " seconds" << std::endl;
 
       NB.push_back( delaunay_refinement(radius_edge_ratio_bound,
@@ -467,12 +509,12 @@ public:
       CGAL_TRACE_STREAM << "SPECIAL PASS END (" << approximation_timer.time() <<  " seconds)" << std::endl;
     }
 
-    
+
     // Prints status
     CGAL_TRACE_STREAM << "Delaunay refinement: " << "added ";
     for(std::size_t i = 0; i < NB.size()-1; i++){
-      CGAL_TRACE_STREAM << NB[i] << " + "; 
-    } 
+      CGAL_TRACE_STREAM << NB[i] << " + ";
+    }
     CGAL_TRACE_STREAM << NB.back() << " Steiner points, "
                       << task_timer.time() << " seconds, "
                       << std::endl;
@@ -519,12 +561,12 @@ public:
     If \ref thirdpartyEigen "Eigen" 3.1 (or greater) is available and `CGAL_EIGEN3_ENABLED`
     is defined, an overload with \link Eigen_solver_traits <tt>Eigen_solver_traits<Eigen::ConjugateGradient<Eigen_sparse_symmetric_matrix<double>::EigenType> ></tt> \endlink
     as default solver is provided.
-  
+
     \param solver sparse linear solver.
     \param smoother_hole_filling controls if the Delaunay refinement is done for the input points, or for an approximation of the surface obtained from a first pass of the algorithm on a sample of the points.
 
-    \return `false` if the linear solver fails. 
-  */ 
+    \return `false` if the linear solver fails.
+  */
   template <class SparseLinearAlgebraTraits_d>
   bool compute_implicit_function(SparseLinearAlgebraTraits_d solver, bool smoother_hole_filling = false)
   {
@@ -546,46 +588,50 @@ public:
 
   boost::tuple<FT, Cell_handle, bool> special_func(const Point& p) const
   {
-    m_hint = m_tr->locate(p  ,m_hint  ); // no hint when we use hierarchy
+    Cell_handle hint = m_hint.get();
+    hint = m_tr->locate(p, hint); // no hint when we use hierarchy
+    m_hint.set(hint);
 
-    if(m_tr->is_infinite(m_hint)) {
-      int i = m_hint->index(m_tr->infinite_vertex());
-      return boost::make_tuple(m_hint->vertex((i+1)&3)->f(),
-                               m_hint, true);
+    if(m_tr->is_infinite(hint)) {
+      int i = hint->index(m_tr->infinite_vertex());
+      return boost::make_tuple(hint->vertex((i+1)&3)->f(),
+                               hint, true);
     }
 
     FT a,b,c,d;
-    barycentric_coordinates(p,m_hint,a,b,c,d);
-    return boost::make_tuple(a * m_hint->vertex(0)->f() +
-                             b * m_hint->vertex(1)->f() +
-                             c * m_hint->vertex(2)->f() +
-                             d * m_hint->vertex(3)->f(),
-                             m_hint, false);
+    barycentric_coordinates(p,hint,a,b,c,d);
+    return boost::make_tuple(a * hint->vertex(0)->f() +
+                             b * hint->vertex(1)->f() +
+                             c * hint->vertex(2)->f() +
+                             d * hint->vertex(3)->f(),
+                             hint, false);
   }
   /// \endcond
 
-  /*! 
-    `ImplicitFunction` interface: evaluates the implicit function at a 
-    given 3D query point. The function `compute_implicit_function()` must be 
-    called before the first call to `operator()`. 
-  */ 
+  /*!
+    `ImplicitFunction` interface: evaluates the implicit function at a
+    given 3D query point. The function `compute_implicit_function()` must be
+    called before the first call to `operator()`.
+  */
   FT operator()(const Point& p) const
   {
-    m_hint = m_tr->locate(p ,m_hint); 
+    Cell_handle hint = m_hint.get();
+    hint = m_tr->locate(p, hint);
+    m_hint.set(hint);
 
-    if(m_tr->is_infinite(m_hint)) {
-      int i = m_hint->index(m_tr->infinite_vertex());
-      return m_hint->vertex((i+1)&3)->f();
+    if(m_tr->is_infinite(hint)) {
+      int i = hint->index(m_tr->infinite_vertex());
+      return hint->vertex((i+1)&3)->f();
     }
 
     FT a,b,c,d;
-    barycentric_coordinates(p,m_hint,a,b,c,d);
-    return a * m_hint->vertex(0)->f() +
-           b * m_hint->vertex(1)->f() +
-           c * m_hint->vertex(2)->f() +
-           d * m_hint->vertex(3)->f();
+    barycentric_coordinates(p,hint,a,b,c,d);
+    return a * hint->vertex(0)->f() +
+           b * hint->vertex(1)->f() +
+           c * hint->vertex(2)->f() +
+           d * hint->vertex(3)->f();
   }
-  
+
   /// \cond SKIP_IN_MANUAL
   void initialize_cell_indices()
   {
@@ -599,11 +645,8 @@ public:
 
   void initialize_barycenters() const
   {
-    m_Bary->resize(m_tr->number_of_cells());
-
-    for(std::size_t i=0; i< m_Bary->size();i++){
-      (*m_Bary)[i][0]=-1;
-    }
+    m_bary->clear();
+    m_bary->resize(m_tr->number_of_cells());
   }
 
   void initialize_cell_normals() const
@@ -625,7 +668,7 @@ public:
 
   void initialize_duals() const
   {
-    Dual.resize(m_tr->number_of_cells());    
+    Dual.resize(m_tr->number_of_cells());
     int i = 0;
     for(Finite_cells_iterator fcit = m_tr->finite_cells_begin();
         fcit != m_tr->finite_cells_end();
@@ -646,23 +689,33 @@ public:
 
   void initialize_matrix_entry(Cell_handle ch) const
   {
-    boost::array<double,9> & entry = (*m_Bary)[ch->info()];
+    Cached_bary_coord& bary = (*m_bary)[ch->info()];
+
+    if (bary.is_initialized())
+      return;
+
+    // If the cache was uninitialized, this thread is in charge of
+    // initializing it
     const Point& pa = ch->vertex(0)->point();
     const Point& pb = ch->vertex(1)->point();
     const Point& pc = ch->vertex(2)->point();
     const Point& pd = ch->vertex(3)->point();
-    
+
     Vector va = pa - pd;
     Vector vb = pb - pd;
     Vector vc = pc - pd;
-    
+
     internal::invert(va.x(), va.y(), va.z(),
-           vb.x(), vb.y(), vb.z(),
-           vc.x(), vc.y(), vc.z(),
-           entry[0],entry[1],entry[2],entry[3],entry[4],entry[5],entry[6],entry[7],entry[8]);
+                     vb.x(), vb.y(), vb.z(),
+                     vc.x(), vc.y(), vc.z(),
+                     bary[0],bary[1],bary[2],
+                     bary[3],bary[4],bary[5],
+                     bary[6],bary[7],bary[8]);
+
+    bary.set_initialized();
   }
   /// \endcond
-  
+
   /// Returns a point located inside the inferred surface.
   Point get_inner_point() const
   {
@@ -693,7 +746,7 @@ private:
                                internal::Poisson::Constant_sizing_field<Triangulation>());
   }
 
-  template <typename Sizing_field, 
+  template <typename Sizing_field,
             typename Second_sizing_field>
   unsigned int delaunay_refinement(FT radius_edge_ratio_bound, ///< radius edge ratio bound (ignored if zero)
                                    Sizing_field sizing_field, ///< cell radius bound (ignored if zero)
@@ -710,14 +763,13 @@ private:
   /// Poisson reconstruction.
   /// Returns false on error.
   ///
-  /// @commentheading Template parameters:
-  /// @param SparseLinearAlgebraTraits_d Symmetric definite positive sparse linear solver.
+  /// @tparam SparseLinearAlgebraTraits_d Symmetric definite positive sparse linear solver.
   template <class SparseLinearAlgebraTraits_d>
   bool solve_poisson(
     SparseLinearAlgebraTraits_d solver, ///< sparse linear solver
     double lambda)
   {
-    CGAL_TRACE("Calls solve_poisson()\n");
+    CGAL_TRACE_STREAM << "Calls solve_poisson()\n";
 
     double time_init = clock();
 
@@ -733,7 +785,7 @@ private:
     m_tr->index_unconstrained_vertices();
     unsigned int nb_variables = static_cast<unsigned int>(m_tr->number_of_vertices()-1);
 
-    CGAL_TRACE("  Number of variables: %ld\n", (long)(nb_variables));
+    CGAL_TRACE_STREAM  << "  Number of variables: " <<  nb_variables << std::endl;
 
     // Assemble linear system A*X=B
     typename SparseLinearAlgebraTraits_d::Matrix A(nb_variables); // matrix is symmetric definite positive
@@ -762,19 +814,19 @@ private:
     clear_duals();
     clear_normals();
     duration_assembly = (clock() - time_init)/CLOCKS_PER_SEC;
-    CGAL_TRACE("  Creates matrix: done (%.2lf s)\n", duration_assembly);
+    CGAL_TRACE_STREAM << "  Creates matrix: done (" << duration_assembly << "sec.)\n";
 
-    CGAL_TRACE("  Solve sparse linear system...\n");
+    CGAL_TRACE_STREAM << "  Solve sparse linear system...\n";
 
     // Solve "A*X = B". On success, solution is (1/D) * X.
     time_init = clock();
     double D;
     if(!solver.linear_solver(A, B, X, D))
       return false;
-    CGAL_surface_reconstruction_points_assertion(D == 1.0);
+    CGAL_assertion(D == 1.0);
     duration_solve = (clock() - time_init)/CLOCKS_PER_SEC;
 
-    CGAL_TRACE("  Solve sparse linear system: done (%.2lf s)\n", duration_solve);
+    CGAL_TRACE_STREAM << "  Solve sparse linear system: done (" << duration_solve << "sec.)\n";
 
     // copy function's values to vertices
     unsigned int index = 0;
@@ -782,7 +834,7 @@ private:
       if(!m_tr->is_constrained(v))
         v->f() = X[index++];
 
-    CGAL_TRACE("End of solve_poisson()\n");
+    CGAL_TRACE_STREAM << "End of solve_poisson()\n";
 
     return true;
   }
@@ -803,12 +855,12 @@ private:
     // it is closed using the smallest part of the sphere).
     std::vector<Vertex_handle> convex_hull;
     m_tr->adjacent_vertices (m_tr->infinite_vertex (),
-			     std::back_inserter (convex_hull));
+                             std::back_inserter (convex_hull));
     unsigned int nb_negative = 0;
     for (std::size_t i = 0; i < convex_hull.size (); ++ i)
       if (convex_hull[i]->f() < 0.0)
         ++ nb_negative;
-    
+
     if(nb_negative > convex_hull.size () / 2)
       flip_f();
 
@@ -825,7 +877,7 @@ private:
     Finite_vertices_iterator v, e;
     for(v = m_tr->finite_vertices_begin(),
         e= m_tr->finite_vertices_end();
-        v != e; 
+        v != e;
         v++)
       if(v->type() == Triangulation::INPUT)
         values.push_back(v->f());
@@ -866,10 +918,9 @@ private:
     //       vb.x(), vb.y(), vb.z(),
     //       vc.x(), vc.y(), vc.z(),
     //       i00, i01, i02, i10, i11, i12, i20, i21, i22);
-    const boost::array<double,9> & i = (*m_Bary)[cell->info()];
-    if(i[0]==-1){
-      initialize_matrix_entry(cell);
-    }
+    initialize_matrix_entry(cell);
+    const Cached_bary_coord& i = (*m_bary)[cell->info()];
+
     //    UsedBary[cell->info()] = true;
     a = i[0] * vp.x() + i[3] * vp.y() + i[6] * vp.z();
     b = i[1] * vp.x() + i[4] * vp.y() + i[7] * vp.z();
@@ -944,14 +995,14 @@ private:
 
   // TODO: Some entities are computed too often
   // - nn and area should not be computed for the face and its opposite face
-  // 
+  //
   // divergent
   FT div_normalized(Vertex_handle v)
   {
     std::vector<Cell_handle> cells;
     cells.reserve(32);
     m_tr->incident_cells(v,std::back_inserter(cells));
-  
+
     FT div = 0;
     typename std::vector<Cell_handle>::iterator it;
     for(it = cells.begin(); it != cells.end(); it++)
@@ -997,7 +1048,7 @@ private:
     std::vector<Cell_handle> cells;
     cells.reserve(32);
     m_tr->incident_cells(v,std::back_inserter(cells));
-  
+
     FT div = 0.0;
     typename std::vector<Cell_handle>::iterator it;
     for(it = cells.begin(); it != cells.end(); it++)
@@ -1005,14 +1056,14 @@ private:
       Cell_handle cell = *it;
       if(m_tr->is_infinite(cell))
         continue;
-      
+
       const int index = cell->index(v);
       const Point& a = cell->vertex(m_tr->vertex_triple_index(index, 0))->point();
       const Point& b = cell->vertex(m_tr->vertex_triple_index(index, 1))->point();
       const Point& c = cell->vertex(m_tr->vertex_triple_index(index, 2))->point();
       const Vector nn = CGAL::cross_product(b-a,c-a);
 
-      div+= nn * (//v->normal() + 
+      div+= nn * (//v->normal() +
                   cell->vertex((index+1)%4)->normal() +
                   cell->vertex((index+2)%4)->normal() +
                   cell->vertex((index+3)%4)->normal());
@@ -1078,7 +1129,7 @@ private:
 
     if(voronoi_points.size() < 3)
     {
-      CGAL_surface_reconstruction_points_assertion(false);
+      CGAL_assertion(false);
       return 0.0;
     }
 
@@ -1151,8 +1202,7 @@ private:
 
   /// Assemble vi's row of the linear system A*X=B
   ///
-  /// @commentheading Template parameters:
-  /// @param SparseLinearAlgebraTraits_d Symmetric definite positive sparse linear solver.
+  /// @tparam SparseLinearAlgebraTraits_d Symmetric definite positive sparse linear solver.
   template <class SparseLinearAlgebraTraits_d>
   void assemble_poisson_row(typename SparseLinearAlgebraTraits_d::Matrix& A,
                             Vertex_handle vi,
@@ -1209,7 +1259,7 @@ private:
       A.set_coef(vi->index(),vi->index(), diagonal, true /*new*/);
     }
   }
-  
+
 
   /// Computes enlarged geometric bounding sphere of the embedded triangulation.
   Sphere enlarged_bounding_sphere(FT ratio) const
