@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Segment_Delaunay_graph_Linf_2/include/CGAL/Polychain_2.h $
+// $Id: Polychain_2.h 4e519a3 2021-05-05T13:15:37+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Segment_Delaunay_graph_Linf_2/include/CGAL/Polychain_2.h $
-// $Id: Polychain_2.h 6596ba9 2019-01-17T19:34:22+01:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Panagiotis Cheilaris, Sandeep Kumar Dey, Evanthia Papadopoulou
 //philaris@gmail.com, sandeep.kr.dey@gmail.com, evanthia.papadopoulou@usi.ch
@@ -106,7 +97,7 @@ operator<<(std::ostream &os,
               ::Vertex_const_iterator
            i;
 
-  switch(get_mode(os)) {
+  switch(IO::get_mode(os)) {
     case IO::ASCII :
       os << p.size() << ' ';
       for (i = p.vertices_begin(); i != p.vertices_end(); ++i) {
@@ -206,7 +197,7 @@ public:
 
     template <class InputIterator>
     Polychainray_2(InputIterator first, InputIterator last,
-	           OutgoingDirection d,
+                   OutgoingDirection d,
                    Traits p_traits = Traits())
         : Base(first, last, p_traits), outgoing(d)
     {
@@ -216,7 +207,7 @@ public:
     // get_outgoing
 
     OutgoingDirection get_outgoing() const {
-	return outgoing;
+        return outgoing;
     }
 
 
@@ -227,7 +218,7 @@ public:
       typedef typename K::Segment_2 K_Segment_2;
       typedef typename K::Ray_2 K_Ray_2;
       typedef typename
-	  Polychainray_2<Traits_P,Container_P>::Vertex_const_iterator VI;
+          Polychainray_2<Traits_P,Container_P>::Vertex_const_iterator VI;
 
       CGAL_assertion( this->size() > 0 );
 
@@ -249,7 +240,7 @@ public:
       typedef typename Traits_P::Segment_2 Segment_2;
       typedef typename Traits_P::Ray_2 Ray_2;
       typedef typename
-	  Polychainray_2<Traits_P,Container_P>::Vertex_const_iterator VI;
+          Polychainray_2<Traits_P,Container_P>::Vertex_const_iterator VI;
 
       CGAL_assertion( this->size() > 0 );
 
@@ -277,7 +268,7 @@ operator<<(std::ostream &os,
 {
   typename Polychainray_2<Traits_P,Container_P>::Vertex_const_iterator i;
 
-  switch(get_mode(os)) {
+  switch(IO::get_mode(os)) {
     case IO::ASCII :
       os << p.size() << ' ';
       for (i = p.vertices_begin(); i != p.vertices_end(); ++i) {
@@ -369,8 +360,8 @@ public:
 
     template <class InputIterator>
     Polychainline_2(IncomingDirection dinc,
-	            InputIterator first, InputIterator last,
-	            OutgoingDirection dout,
+                    InputIterator first, InputIterator last,
+                    OutgoingDirection dout,
                     Traits p_traits = Traits())
         : Base(first, last, dout, p_traits), incoming(dinc),
           is_line_optimization(false)
@@ -386,7 +377,7 @@ public:
     // get_incoming
 
     IncomingDirection get_incoming() const {
-	return incoming;
+        return incoming;
     }
 
 
@@ -455,7 +446,7 @@ public:
       Line_2 line((*this)[0], this->get_outgoing());
 
       typedef typename
-	  Polychainline_2<Traits_P,Container_P>::
+          Polychainline_2<Traits_P,Container_P>::
                      Vertex_const_iterator
           VI;
 
@@ -510,7 +501,7 @@ public:
           << *this << " pcl=" << pcl << std::endl;);
 
       typedef typename
-	  Polychainline_2<Traits_P,Container_P>::
+          Polychainline_2<Traits_P,Container_P>::
                      Vertex_const_iterator
           VI;
 
@@ -730,7 +721,7 @@ public:
       typedef typename K::Segment_2 K_Segment_2;
       typedef typename K::Ray_2 K_Ray_2;
       typedef typename
-	  Polychainline_2<Traits_P,Container_P>::Vertex_const_iterator VI;
+          Polychainline_2<Traits_P,Container_P>::Vertex_const_iterator VI;
 
       CGAL_assertion( this->size() > 0 );
 
@@ -755,7 +746,7 @@ public:
     template< class Stream >
     void draw(Stream & stream) const {
       typedef typename
-	  Polychainline_2<Traits_P,Container_P>::Vertex_const_iterator VI;
+          Polychainline_2<Traits_P,Container_P>::Vertex_const_iterator VI;
 
       CGAL_assertion( this->size() > 0 );
 
@@ -788,7 +779,7 @@ operator<<(std::ostream &os,
 {
   typename Polychainline_2<Traits_P,Container_P>::Vertex_const_iterator i;
 
-  switch(get_mode(os)) {
+  switch(IO::get_mode(os)) {
     case IO::ASCII :
       os << p.size() << ' ';
       os << ", dinc=" << p.get_incoming() << ", ";
