@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Corefinement/Output_builder_for_autorefinement.h $
-// $Id: Output_builder_for_autorefinement.h 7db3d26 2019-02-08T11:05:12+01:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Corefinement/Output_builder_for_autorefinement.h $
+// $Id: Output_builder_for_autorefinement.h dbccebf 2023-02-06T18:32:41+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Sebastien Loriot
@@ -43,9 +34,6 @@ namespace CGAL {
 namespace Polygon_mesh_processing {
 namespace Corefinement {
 
-namespace PMP=Polygon_mesh_processing;
-namespace params=PMP::parameters;
-
 template <class TriangleMesh,
           class VertexPointMap,
           class FaceIdMap,
@@ -100,10 +88,10 @@ class Output_builder_for_autorefinement
 
   // to maintain the two halfedges on each polyline
   typedef std::map< Node_id_pair, Shared_halfedges >   An_edge_per_polyline_map;
-  typedef boost::unordered_map<vertex_descriptor, Node_id> Node_id_map;
-  // typedef boost::unordered_map<edge_descriptor,
-  //                              edge_descriptor>               Edge_map;
-  typedef boost::unordered_map<Node_id_pair, Shared_halfedges> All_intersection_edges_map;
+  typedef std::unordered_map<vertex_descriptor, Node_id> Node_id_map;
+  // typedef std::unordered_map<edge_descriptor,
+  //                            edge_descriptor>               Edge_map;
+  typedef std::unordered_map<Node_id_pair, Shared_halfedges, boost::hash<Node_id_pair>> All_intersection_edges_map;
 //Data members
   TriangleMesh &tm;
   // property maps of input mesh
@@ -141,7 +129,7 @@ class Output_builder_for_autorefinement
     if ( is_node_of_degree_one.test(src_id) )
     {
       bool res=true;
-      BOOST_FOREACH(halfedge_descriptor h, halfedges_around_source(hedge, tm))
+      for(halfedge_descriptor h : halfedges_around_source(hedge, tm))
         if (is_border(h, tm))
         {
           res = false;
@@ -151,7 +139,7 @@ class Output_builder_for_autorefinement
     }
     if ( is_node_of_degree_one.test(tgt_id) )
     {
-      BOOST_FOREACH(halfedge_descriptor h, halfedges_around_target(hedge, tm))
+      for(halfedge_descriptor h : halfedges_around_target(hedge, tm))
         if (is_border(h, tm))
           return false;
       return true;
@@ -170,7 +158,7 @@ public:
     , fids(fids)
     , ecm(ecm)
     , is_tm_closed( is_closed(tm))
-    , is_tm_inside_out( is_tm_closed && !PMP::is_outward_oriented(tm) )
+    , is_tm_inside_out( is_tm_closed && !is_outward_oriented(tm) )
     , NID((std::numeric_limits<Node_id>::max)())
     , all_fixed(true)
   {}
@@ -223,16 +211,13 @@ public:
     const boost::dynamic_bitset<>& is_node_of_degree_one,
     const Mesh_to_map_node&)
   {
-    // this will initialize face indices if the face index map is writable.
-    helpers::init_face_indices(tm, fids);
-
     // first build an unordered_map mapping a vertex to its node id + a set
     // of all intersection edges
-    typedef boost::unordered_set<edge_descriptor> Intersection_edge_map;
+    typedef std::unordered_set<edge_descriptor> Intersection_edge_map;
     Intersection_edge_map intersection_edges;
 
     typedef std::pair<const Node_id_pair, Shared_halfedges> Pair_type;
-    BOOST_FOREACH(const Pair_type& p, all_intersection_edges_map)
+    for(const Pair_type& p : all_intersection_edges_map)
     {
       CGAL_assertion(p.second.h1!=boost::graph_traits<TriangleMesh>::null_halfedge());
     // p.second.h2 might be the null halfedge in case two faces sharing an edge
@@ -248,11 +233,16 @@ public:
       intersection_edges.insert(edge(p.second.h2, tm));
     }
 
-    // this will initialize face indices if the face index map is writable.
-    helpers::init_face_indices(tm, fids);
+    // The property map must be either writable or well-initialized
+    if( CGAL::internal::Is_writable_property_map<FaceIdMap>::value &&
+        !BGL::internal::is_index_map_valid(fids, num_faces(tm), faces(tm)) )
+    {
+      BGL::internal::initialize_face_index_map(fids, tm);
+    }
+    CGAL_assertion(BGL::internal::is_index_map_valid(fids, num_faces(tm), faces(tm)));
 
     // bitset to identify coplanar faces
-    boost::dynamic_bitset<> tm_coplanar_faces(num_faces(tm), 0);
+    std::vector<face_descriptor> tm_coplanar_faces;
 
     // In the following loop we filter intersection edges that are strictly inside a patch
     // of coplanar facets so that we keep only the edges on the border of the patch.
@@ -264,7 +254,7 @@ public:
     typename An_edge_per_polyline_map::iterator
       epp_it=input_have_coplanar_faces ? an_edge_per_polyline.begin()
                                        : epp_it_end;
-    boost::unordered_set<edge_descriptor> inter_edges_to_remove;
+    std::unordered_set<edge_descriptor> inter_edges_to_remove;
     for (;epp_it!=epp_it_end;)
     {
       halfedge_descriptor h1  = epp_it->second.h1;
@@ -284,11 +274,6 @@ public:
       else{
         halfedge_descriptor h2_opp = opposite(h2, tm);
 
-        if (is_border_edge(h1,tm) || is_border_edge(h2,tm)){
-          ++epp_it;
-          continue;
-        }
-
         //vertices from tm1
         vertex_descriptor p1 = target(next(h1_opp, tm), tm);
         vertex_descriptor p2 = target(next(h1, tm), tm);
@@ -322,20 +307,20 @@ public:
 
         //mark coplanar facets if any
         if (p1_eq_q1){
-          tm_coplanar_faces.set(get(fids, face(h1_opp, tm)));
-          tm_coplanar_faces.set(get(fids, face(h2_opp, tm)));
+          tm_coplanar_faces.push_back(face(h1_opp, tm));
+          tm_coplanar_faces.push_back(face(h2_opp, tm));
         }
         if (p1_eq_q2){
-          tm_coplanar_faces.set(get(fids, face(h1_opp, tm)));
-          tm_coplanar_faces.set(get(fids, face(h2, tm)));
+          tm_coplanar_faces.push_back(face(h1_opp, tm));
+          tm_coplanar_faces.push_back(face(h2, tm));
         }
         if (p2_eq_q1){
-          tm_coplanar_faces.set(get(fids, face(h1, tm)));
-          tm_coplanar_faces.set(get(fids, face(h2_opp, tm)));
+          tm_coplanar_faces.push_back(face(h1, tm));
+          tm_coplanar_faces.push_back(face(h2_opp, tm));
         }
         if (p2_eq_q2){
-          tm_coplanar_faces.set(get(fids, face(h1, tm)));
-          tm_coplanar_faces.set(get(fids, face(h2, tm)));
+          tm_coplanar_faces.push_back(face(h1, tm));
+          tm_coplanar_faces.push_back(face(h2, tm));
         }
         if ( (p1_eq_q1 || p1_eq_q2) && (p2_eq_q1 || p2_eq_q2) )
           to_remove = true;
@@ -353,21 +338,20 @@ public:
         ++epp_it;
     }
 
-    BOOST_FOREACH(edge_descriptor ed, inter_edges_to_remove)
+    for(edge_descriptor ed : inter_edges_to_remove)
       intersection_edges.erase(ed);
 
     // (1) Assign a patch id to each face indicating in which connected
     // component limited by intersection edges of the surface they are.
     // ... for tm
     std::vector<std::size_t> patch_ids( num_faces(tm),NID );
-    Boolean_property_map< boost::unordered_set<edge_descriptor> >
+    Boolean_property_map< std::unordered_set<edge_descriptor> >
       is_intersection(intersection_edges);
     std::size_t nb_patches =
-      PMP::connected_components(tm,
-                                bind_property_maps(fids,make_property_map(patch_ids)),
-                                params::edge_is_constrained_map(
-                                    is_intersection)
-                                .face_index_map(fids));
+      connected_components(tm,
+                           make_compose_property_map(fids,make_property_map(patch_ids)),
+                           parameters::edge_is_constrained_map(is_intersection)
+                                      .face_index_map(fids));
 
     // (2-a) Use the orientation around an edge to classify a patch
     boost::dynamic_bitset<> patches_to_keep(nb_patches);
@@ -375,6 +359,12 @@ public:
     boost::dynamic_bitset<> coplanar_patches(nb_patches,false);
     patches_to_keep.set();
     patch_status_not_set.set();
+
+    // set coplanar patches flags
+    for (face_descriptor f : tm_coplanar_faces)
+      coplanar_patches.set( patch_ids[get(fids,f)] );
+
+
     // use a union-find on patches to track the incidence between patches kept
     typedef Union_find<std::size_t> UF;
     UF uf;
@@ -411,10 +401,25 @@ public:
       if ( is_border_edge(h1, tm) ){
         if ( is_border_edge(h2,tm) )
         {
+        // CASE h1 and h2 are boundary edge
           if ( is_border(h1,tm) == is_border(h2,tm) )
           {
-            //Orientation issue, nothing done
-            all_fixed = false;
+            std::size_t pid1 =
+              patch_ids[ get(fids, face( is_border(h1,tm)?opposite(h1,tm):h1 ,tm)) ];
+            if (coplanar_patches[pid1])
+            {
+              std::size_t pid2 =
+                patch_ids[ get(fids, face( is_border(h2,tm)?opposite(h2,tm):h2 ,tm)) ];
+              CGAL_assertion(coplanar_patches[pid2]);
+              // the face of p and the face of q1 have the same orientation: remove both patches
+              patches_to_keep.reset(pid1);
+              patches_to_keep.reset(pid2);
+            }
+            else
+            {
+              //Orientation issue, nothing done
+              all_fixed = false;
+            }
           }
           else
           {
@@ -422,22 +427,42 @@ public:
             {
               std::size_t pid1=patch_ids[ get(fids, face(opposite(h1,tm),tm)) ],
                           pid2=patch_ids[ get(fids, face(h2,tm)) ];
-              uf.unify_sets(patch_handles[pid1], patch_handles[pid2]);
-              patch_status_not_set.reset(pid1);
-              patch_status_not_set.reset(pid2);
+
+              if (coplanar_patches[pid1])
+              {
+                CGAL_assertion(coplanar_patches[pid2]);
+                // arbitrarily remove the patch with the smallest id
+                patches_to_keep.reset(pid1<pid2?pid1:pid2);
+              }
+              else
+              {
+                uf.unify_sets(patch_handles[pid1], patch_handles[pid2]);
+                patch_status_not_set.reset(pid1);
+                patch_status_not_set.reset(pid2);
+              }
             }
             else
             {
               std::size_t pid1=patch_ids[ get(fids, face(h1,tm)) ],
                           pid2=patch_ids[ get(fids, face(opposite(h2,tm),tm)) ];
-              uf.unify_sets(patch_handles[pid1], patch_handles[pid2]);
-              patch_status_not_set.reset(pid1);
-              patch_status_not_set.reset(pid2);
+              if (coplanar_patches[pid1])
+              {
+                CGAL_assertion(coplanar_patches[pid2]);
+                // arbitrarily remove the patch with the smallest id
+                patches_to_keep.reset(pid1<pid2?pid1:pid2);
+              }
+              else
+              {
+                uf.unify_sets(patch_handles[pid1], patch_handles[pid2]);
+                patch_status_not_set.reset(pid1);
+                patch_status_not_set.reset(pid2);
+              }
             }
           }
         }
         else
         {
+        // CASE h1 is a boundary edge and h2 is an interior edge
           halfedge_descriptor h = is_border(h1, tm) ? opposite(h1, tm) : h1;
 
           //Sort the three triangle faces around their common edge
@@ -459,29 +484,98 @@ public:
           patch_status_not_set.reset(patch_id_q1);
           patch_status_not_set.reset(patch_id_q2);
 
-          bool p_is_between_q1q2 = sorted_around_edge(
-            ids.first, ids.second,
-            index_q1, index_q2, index_p,
-            q1, q2, p,
-            vpm, vpm,
-            nodes);
-
-          if (p_is_between_q1q2)
+          if (coplanar_patches.test(patch_id_p))
           {
-            uf.unify_sets(patch_handles[patch_id_q1], patch_handles[patch_id_q2]);
-            patches_to_keep.reset(patch_id_p); // even if badly oriented we can
-          }                                     // simply discard the patch
-          else
-          {
-            if (h==h1)
+            if (index_p == index_q1)
             {
-              //Orientation issue, nothing done for the incident patches
-              all_fixed = false;
+              if ( h!=h1 )
+              {
+                // the face of p and the face of q1 have the same orientation: remove both patches
+                patches_to_keep.reset(patch_id_p);
+                patches_to_keep.reset(patch_id_q1);
+              }
+              else
+              {
+                // arbitrarily remove the patch on the border
+                patches_to_keep.reset(patch_id_p);
+              }
             }
             else
             {
-              uf.unify_sets(patch_handles[patch_id_p], patch_handles[patch_id_q2]);
-              patches_to_keep.reset(patch_id_q1);
+              CGAL_assertion(index_p == index_q2);
+              if ( h==h1 )
+              {
+                // the face of p and the face of q2 have the same orientation: remove both patches
+                patches_to_keep.reset(patch_id_p);
+                patches_to_keep.reset(patch_id_q2);
+              }
+              else
+              {
+                // arbitrarily remove the patch on the border
+                patches_to_keep.reset(patch_id_p);
+              }
+            }
+          }
+          else
+          {
+            bool p_is_between_q1q2 = sorted_around_edge(
+              ids.first, ids.second,
+              index_q1, index_q2, index_p,
+              q1, q2, p,
+              vpm, vpm,
+              nodes);
+
+            if (p_is_between_q1q2)
+            {
+              uf.unify_sets(patch_handles[patch_id_q1], patch_handles[patch_id_q2]);
+              patches_to_keep.reset(patch_id_p); // even if badly oriented we can
+            }                                     // simply discard the patch
+            else
+            {
+              // look for a face amongst those containing q1/q2 with an orientation
+              // compatible with the border face containing p. Then if those two
+              // faces "contains" the third one, we can stitch them.
+              if ( h!=h1 )
+              {
+                CGAL_assertion(h==opposite(h1,tm));
+                // check if we keep p - q2
+                bool q1_is_between_pq2 = sorted_around_edge(
+                  ids.first, ids.second,
+                  index_p, index_q2, index_q1,
+                  p, q2, q1,
+                  vpm, vpm,
+                  nodes);
+                if (q1_is_between_pq2)
+                {
+                  uf.unify_sets(patch_handles[patch_id_p], patch_handles[patch_id_q2]);
+                  patches_to_keep.reset(patch_id_q1);
+                }
+                else
+                {
+                  //Orientation issue, nothing done for the incident patches
+                  all_fixed = false;
+                }
+              }
+              else
+              {
+                // check if we keep p - q1
+                bool q2_is_between_q1p = sorted_around_edge(
+                  ids.first, ids.second,
+                  index_q1, index_p, index_q2,
+                  q1, p, q2,
+                  vpm, vpm,
+                  nodes);
+                if (q2_is_between_q1p)
+                {
+                  uf.unify_sets(patch_handles[patch_id_p], patch_handles[patch_id_q1]);
+                  patches_to_keep.reset(patch_id_q2);
+                }
+                else
+                {
+                  //Orientation issue, nothing done for the incident patches
+                  all_fixed = false;
+                }
+              }
             }
           }
         }
@@ -489,6 +583,7 @@ public:
       else
         if ( is_border_edge(h2,tm) )
         {
+          // CASE h2 is a boundary edge and h1 is an interior edge
           halfedge_descriptor h = is_border(h2, tm) ? opposite(h2, tm) : h2;
 
           //Sort the three triangle faces around their common edge
@@ -510,34 +605,104 @@ public:
           patch_status_not_set.reset(patch_id_p2);
           patch_status_not_set.reset(patch_id_q);
 
-          bool q_is_between_p1p2 = sorted_around_edge(
-            ids.first, ids.second,
-            index_p1, index_p2, index_q,
-            p1, p2, q,
-            vpm, vpm,
-            nodes);
-
-          if (q_is_between_p1p2)
+          if (coplanar_patches.test(patch_id_q))
           {
-            uf.unify_sets(patch_handles[patch_id_p1], patch_handles[patch_id_p2]);
-            patches_to_keep.reset(patch_id_q); // even if badly oriented we can
-          }                                     // simply discard the patch
-          else
-          {
-            if (h==h2)
+            if (index_q == index_p1)
             {
-              //Orientation issue, nothing done for the incident patches
-              all_fixed = false;
+              if ( h!=h2 )
+              {
+                // the face of q and the face of p1 have the same orientation: remove both patches
+                patches_to_keep.reset(patch_id_q);
+                patches_to_keep.reset(patch_id_p1);
+              }
+              else
+              {
+                // arbitrarily remove the patch on the border
+                patches_to_keep.reset(patch_id_q);
+              }
             }
             else
             {
-              uf.unify_sets(patch_handles[patch_id_q], patch_handles[patch_id_p2]);
-              patches_to_keep.reset(patch_id_p1);
+              CGAL_assertion(index_q == index_p2);
+              if ( h==h2 )
+              {
+                // the face of q and the face of p2 have the same orientation: remove both patches
+                patches_to_keep.reset(patch_id_q);
+                patches_to_keep.reset(patch_id_p2);
+              }
+              else
+              {
+                // arbitrarily remove the patch on the border
+                patches_to_keep.reset(patch_id_q);
+              }
+            }
+          }
+          else
+          {
+            bool q_is_between_p1p2 = sorted_around_edge(
+              ids.first, ids.second,
+              index_p1, index_p2, index_q,
+              p1, p2, q,
+              vpm, vpm,
+              nodes);
+
+            if (q_is_between_p1p2)
+            {
+              uf.unify_sets(patch_handles[patch_id_p1], patch_handles[patch_id_p2]);
+              patches_to_keep.reset(patch_id_q); // even if badly oriented we can
+            }                                     // simply discard the patch
+            else
+            {
+              // look for a face amongst those containing p1/p2 with an orientation
+              // compatible with the border face  containing q. Then if those two
+              // faces contains the third one, we can stitch them.
+              if ( h!=h2 )
+              {
+                // check if we keep q - p2
+                CGAL_assertion(h==opposite(h2,tm));
+                bool p1_is_between_qp2 = sorted_around_edge(
+                  ids.first, ids.second,
+                  index_q, index_p2, index_p1,
+                  q, p2, p1,
+                  vpm, vpm,
+                  nodes);
+                if (p1_is_between_qp2)
+                {
+                  uf.unify_sets(patch_handles[patch_id_q], patch_handles[patch_id_p2]);
+                  patches_to_keep.reset(patch_id_p1);
+                }
+                else
+                {
+                  //Orientation issue, nothing done for the incident patches
+                  all_fixed = false;
+                }
+              }
+              else
+              {
+                // check if we keep q - p1
+                bool p2_is_between_p1q = sorted_around_edge(
+                  ids.first, ids.second,
+                  index_p1, index_q, index_p2,
+                  p1, q, p2,
+                  vpm, vpm,
+                  nodes);
+                if (p2_is_between_p1q)
+                {
+                  uf.unify_sets(patch_handles[patch_id_q], patch_handles[patch_id_p1]);
+                  patches_to_keep.reset(patch_id_p2);
+                }
+                else
+                {
+                  //Orientation issue, nothing done for the incident patches
+                  all_fixed = false;
+                }
+              }
             }
           }
         }
         else
         {
+          // CASE h1 and h2 are both interior edges
           //Sort the four triangle faces around their common edge
           //  we assume that the exterior of the volume is indicated by
           //  counterclockwise oriented faces
@@ -566,6 +731,14 @@ public:
           std::size_t patch_id_q1=patch_ids[ get(fids, face(opposite(h2,tm),tm)) ];
           std::size_t patch_id_q2=patch_ids[ get(fids, face(h2,tm)) ];
 
+          if (patch_id_p1==patch_id_p2 || patch_id_q1==patch_id_q2)
+          {
+            // polyline in the middle of a patch is always impossible to fix but
+            // removing the whole all the patch
+            all_fixed = false;
+            continue;
+          }
+
           //indicates that patch status will be updated
           patch_status_not_set.reset(patch_id_p1);
           patch_status_not_set.reset(patch_id_p2);
@@ -900,7 +1073,7 @@ public:
     std::vector<edge_descriptor> edges_no_longer_on_intersection;
     std::vector< std::pair<halfedge_descriptor, halfedge_descriptor> > hedge_pairs_to_stitch;
     hedge_pairs_to_stitch.reserve(all_intersection_edges_map.size());
-    BOOST_FOREACH(const Pair_type& p, all_intersection_edges_map)
+    for(const Pair_type& p : all_intersection_edges_map)
     {
       halfedge_descriptor h1 = p.second.h1;
       halfedge_descriptor h2 = p.second.h2;
@@ -915,7 +1088,6 @@ public:
           if ( !patches_to_keep.test(patch_id) )
           {
             edges_no_longer_on_intersection.push_back(edge(h1, tm));
-            edges_no_longer_on_intersection.push_back(edge(h2, tm));
             continue;
           }
         }
@@ -925,7 +1097,6 @@ public:
           if ( !patches_to_keep.test(patch_id) )
           {
             edges_no_longer_on_intersection.push_back(edge(h1, tm));
-            edges_no_longer_on_intersection.push_back(edge(h2, tm));
             continue;
           }
           std::swap(h1, h1_opp);
@@ -957,7 +1128,6 @@ public:
           std::size_t patch_id = patch_ids[get(fids,face(opposite(h2,tm),tm))];
           if ( !patches_to_keep.test(patch_id) )
           {
-            edges_no_longer_on_intersection.push_back(edge(h1, tm));
             edges_no_longer_on_intersection.push_back(edge(h2, tm));
             continue;
           }
@@ -967,7 +1137,6 @@ public:
           std::size_t patch_id = patch_ids[get(fids,face(h2,tm))];
           if ( !patches_to_keep.test(patch_id) )
           {
-            edges_no_longer_on_intersection.push_back(edge(h1, tm));
             edges_no_longer_on_intersection.push_back(edge(h2, tm));
             continue;
           }
@@ -996,7 +1165,7 @@ public:
 
     // Merge patches to keep only 2: one we keep (1) and one we remove (0)
     const std::size_t PATCH_ID_KEPT = 1;
-    BOOST_FOREACH(std::size_t& patch_id, patch_ids)
+    for(std::size_t& patch_id : patch_ids)
       if (patch_id != NID)
         patch_id = patches_to_keep.test(patch_id) ? 1 : 0;
     nb_patches=2;
@@ -1005,7 +1174,7 @@ public:
 
     // remove from the set of intersection edges if the patches on both side have
     // the same status.
-    BOOST_FOREACH(edge_descriptor e, edges_no_longer_on_intersection)
+    for(edge_descriptor e : edges_no_longer_on_intersection)
       intersection_edges.erase(e);
 
     //store the patch description in a container to avoid recomputing it several times
@@ -1016,12 +1185,13 @@ public:
     //remove the extra patch
     remove_patches(tm, ~patches_to_keep,patches, ecm);
 
-    PMP::stitch_borders(tm, hedge_pairs_to_stitch, params::vertex_point_map(vpm));
+    stitch_borders(tm, hedge_pairs_to_stitch, parameters::vertex_point_map(vpm));
   }
 };
 
-
-} } } // CGAL::Corefinement
+} // namespace Corefinement
+} // namespace Polygon_mesh_processing
+} // namespace CGAL
 
 #include <CGAL/enable_warnings.h>
 
