@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licenseges holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/QP_solver/include/CGAL/QP_solution.h $
+// $Id: QP_solution.h eed54a0 2022-11-15T18:45:39+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/QP_solver/include/CGAL/QP_solution.h $
-// $Id: QP_solution.h d0b8fc5 2019-01-24T18:17:46+01:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Kaspar Fischer
 //               : Bernd Gaertner <gaertner@inf.ethz.ch>
@@ -36,8 +27,6 @@
 #include <CGAL/function_objects.h>
 #include <CGAL/Algebraic_structure_traits.h>
 #include <CGAL/QP_solver/assertions.h>
-#include <boost/bind.hpp>
-#include <boost/function.hpp>
 
 #include <CGAL/boost/iterator/counting_iterator.hpp>
 #include <CGAL/boost/iterator/transform_iterator.hpp>
@@ -51,7 +40,7 @@ class QP_solver;
 namespace QP_solution_detail {
   template <typename ET>
   class Quotient_normalizer;
-  
+
   template <typename ET>
   class Value_by_index;
 
@@ -63,12 +52,12 @@ namespace QP_solution_detail {
 }
 
 // global status type
-enum Quadratic_program_status 
-  { 
-    QP_UPDATE, 
-    QP_INFEASIBLE, 
-    QP_UNBOUNDED, 
-    QP_OPTIMAL 
+enum Quadratic_program_status
+  {
+    QP_UPDATE,
+    QP_INFEASIBLE,
+    QP_UNBOUNDED,
+    QP_OPTIMAL
   };
 
 // abstract base class of all QP-solvers
@@ -81,19 +70,19 @@ public:
   typedef  CGAL::Creator_2< ET, ET, Quotient<ET> >
   U_Quotient_creator;  // unnormalized quotient creator ET x ET -> (ET, ET)
 
-  typedef QP_solution_detail::Quotient_normalizer<ET> 
+  typedef QP_solution_detail::Quotient_normalizer<ET>
   Quotient_normalizer; // normalizer (ET, ET) -> (ET, ET)
 
-  typedef boost::function1< Quotient<ET>, ET > 
+  typedef std::function< Quotient<ET>(const ET&) >
   Quotient_maker;
 
-  typedef std::vector<int> 
+  typedef std::vector<int>
   Indices;
 
-  typedef Indices::iterator    
+  typedef Indices::iterator
   Index_mutable_iterator;
 
-  typedef Indices::const_iterator    
+  typedef Indices::const_iterator
   Index_const_iterator;
 
   typedef typename QP_solution_detail::Value_by_index<ET> Value_by_index;
@@ -106,16 +95,16 @@ public:
   <Quotient_maker, Variable_numerator_iterator>
   Variable_value_iterator;
 
-  typedef typename QP_solution_detail::Unbounded_direction_by_index<ET> 
+  typedef typename QP_solution_detail::Unbounded_direction_by_index<ET>
   Unbounded_direction_by_index;
 
   typedef boost::transform_iterator
   <Unbounded_direction_by_index, boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t> >
   Unbounded_direction_iterator;
 
-  typedef typename QP_solution_detail::Lambda_by_index<ET> 
+  typedef typename QP_solution_detail::Lambda_by_index<ET>
   Lambda_by_index;
-  
+
   typedef boost::transform_iterator
   <Lambda_by_index, boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t> >
   Lambda_numerator_iterator;
@@ -126,7 +115,7 @@ public:
 
 public:
 
-  // virtual access functions to solution that will 
+  // virtual access functions to solution that will
   // be overridden by QP_solver below
 
   // Solution
@@ -134,15 +123,12 @@ public:
   virtual ET solution_numerator() const = 0;
   virtual ET solution_denominator() const = 0;
   Quotient<ET> solution( ) const
-  { 
-    // workaround to please Boost 1.33.1: 
+  {
+    // workaround to please Boost 1.33.1:
     ET n = solution_numerator();
     ET d = solution_denominator();
-    return 
-      boost::bind 
-      (Quotient_normalizer(), boost::bind
-       (U_Quotient_creator(), _1, _2))
-      (n, d);
+    return
+      Quotient_normalizer()( U_Quotient_creator()(n,d) );
       // (solution_numerator(), solution_denominator());
   }
   virtual Quadratic_program_status status() const = 0;
@@ -150,55 +136,57 @@ public:
 
   // Variable values
   // ---------------
-  virtual ET variable_numerator_value (int i) const = 0; 
+  virtual ET variable_numerator_value (int i) const = 0;
   virtual const ET& variables_common_denominator( ) const = 0;
   virtual int number_of_variables() const = 0;
 
   // value type ET
   Variable_numerator_iterator
   original_variables_numerator_begin( ) const
-  { return Variable_numerator_iterator 
-      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(0), 
+  { return Variable_numerator_iterator
+      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(0),
        Value_by_index(this));}
-				  
-    
+
+
   Variable_numerator_iterator
   original_variables_numerator_end  ( ) const
-  { return Variable_numerator_iterator 
-      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(number_of_variables()) , 
-       Value_by_index(this));} 
+  { return Variable_numerator_iterator
+      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(number_of_variables()) ,
+       Value_by_index(this));}
 
-  // value type Quotient<ET>   
+  // value type Quotient<ET>
   Variable_value_iterator
   original_variable_values_begin( ) const
   { return Variable_value_iterator
       (original_variables_numerator_begin(),
-       boost::bind 
-       (boost::bind 
-	(Quotient_normalizer(), boost::bind
-	 (U_Quotient_creator(), _1, _2)), _1, variables_common_denominator()));
+       [this](const ET& n)
+       {
+         return Quotient_normalizer()(
+           U_Quotient_creator()(n, this->variables_common_denominator()));
+       });
   }
-    
+
   Variable_value_iterator
   original_variable_values_end  ( ) const
   { return Variable_value_iterator
       (original_variables_numerator_end(),
-       boost::bind 
-       (boost::bind 
-	(Quotient_normalizer(), boost::bind
-	 (U_Quotient_creator(), _1, _2)), _1, variables_common_denominator()));
+       [this](const ET& n)
+       {
+         return Quotient_normalizer()(
+           U_Quotient_creator()(n, this->variables_common_denominator()));
+       });
   }
-    
+
   // Basic variables and constraints
   // -------------------------------
-  virtual Index_const_iterator 
+  virtual Index_const_iterator
   basic_original_variable_indices_begin() const = 0;
-  virtual Index_const_iterator 
+  virtual Index_const_iterator
   basic_original_variable_indices_end() const = 0;
   virtual int number_of_basic_original_variables() const = 0;
-  virtual Index_const_iterator 
+  virtual Index_const_iterator
   basic_constraint_indices_begin() const = 0;
-  virtual Index_const_iterator 
+  virtual Index_const_iterator
   basic_constraint_indices_end() const = 0;
   virtual int number_of_basic_constraints() const = 0;
 
@@ -206,16 +194,16 @@ public:
   // -------------
   virtual ET unbounded_direction_value(int i) const = 0;
 
-  Unbounded_direction_iterator unbounded_direction_begin() const 
-  { return Unbounded_direction_iterator 
-      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(0), 
+  Unbounded_direction_iterator unbounded_direction_begin() const
+  { return Unbounded_direction_iterator
+      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(0),
        Unbounded_direction_by_index(this));}
 
   // Returns the past-the-end iterator corresponding to
   // unbounded_direction_begin().
   Unbounded_direction_iterator unbounded_direction_end() const
-  { return Unbounded_direction_iterator 
-      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(number_of_variables()), 
+  { return Unbounded_direction_iterator
+      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(number_of_variables()),
        Unbounded_direction_by_index(this));}
 
 
@@ -225,16 +213,16 @@ public:
   virtual int number_of_constraints() const = 0;
 
   // value type ET
-  Lambda_numerator_iterator 
-  lambda_numerator_begin() const 
-  { return Lambda_numerator_iterator 
-      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(0), 
+  Lambda_numerator_iterator
+  lambda_numerator_begin() const
+  { return Lambda_numerator_iterator
+      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(0),
        Lambda_by_index(this));}
 
-  Lambda_numerator_iterator 
+  Lambda_numerator_iterator
   lambda_numerator_end() const
-  { return Lambda_numerator_iterator 
-      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(number_of_constraints()), 
+  { return Lambda_numerator_iterator
+      (boost::counting_iterator<std::size_t,boost::use_default,std::ptrdiff_t>(number_of_constraints()),
        Lambda_by_index(this));}
 
   // value type Quotient<ET>
@@ -243,10 +231,11 @@ public:
   {
     return Lambda_iterator
      (lambda_numerator_begin(),
-      boost::bind 
-      (boost::bind 
-       (Quotient_normalizer(), boost::bind
-	(U_Quotient_creator(), _1, _2)), _1, variables_common_denominator()));
+       [this](const ET& n)
+       {
+         return Quotient_normalizer()(
+           U_Quotient_creator()(n, this->variables_common_denominator()));
+       });
   }
 
   Lambda_iterator
@@ -254,10 +243,11 @@ public:
   {
     return Lambda_iterator
      (lambda_numerator_end(),
-      boost::bind 
-      (boost::bind 
-       (Quotient_normalizer(), boost::bind
-	(U_Quotient_creator(), _1, _2)), _1, variables_common_denominator()));
+       [this](const ET& n)
+       {
+         return Quotient_normalizer()(
+           U_Quotient_creator()(n, this->variables_common_denominator()));
+       });
   }
 
   // destruction
@@ -267,9 +257,9 @@ public:
 
 
 // Quadratic_program_solution class: a handle for QP_solver_base<ET>
-// ----------------------------------------------------------------- 
+// -----------------------------------------------------------------
 template <class ET_>
-class Quadratic_program_solution: Handle_for<const QP_solver_base<ET_>*> 
+class Quadratic_program_solution: Handle_for<const QP_solver_base<ET_>*>
 {
 public:
   typedef ET_ ET;
@@ -291,11 +281,11 @@ public:
   // ------------
   typedef typename QP_solver_base<ET>::Unbounded_direction_iterator
   Unboundedness_certificate_iterator;
-  
-  typedef 
+
+  typedef
   typename QP_solver_base<ET>::Lambda_numerator_iterator
   Optimality_certificate_numerator_iterator;
-  
+
   typedef typename QP_solver_base<ET>::Lambda_iterator
   Optimality_certificate_iterator;
 
@@ -307,7 +297,7 @@ public:
   Quadratic_program_solution ()
     : Handle_for<const QP_solver_base<ET>*>(), et0(0)
   {
-    *(this->ptr()) = 0; // unitialized solution
+    *(this->ptr()) = 0; // uninitialized solution
   }
 
   Quadratic_program_solution (const QP_solver_base<ET>* s)
@@ -319,8 +309,8 @@ public:
   {
     *this = rhs;
   }
- 
-  Quadratic_program_solution& 
+
+  Quadratic_program_solution&
   operator= (const Quadratic_program_solution& sol)
   {
     if (this != &sol) {
@@ -337,13 +327,13 @@ public:
   }
 
 private:
-  const QP_solver_base<ET>* solver() const 
+  const QP_solver_base<ET>* solver() const
   {
     return *(this->Ptr());
   }
 
 public:
-  bool is_void() const 
+  bool is_void() const
   {
     return solver() == 0;
   }
@@ -391,7 +381,7 @@ public:
   }
 
   int number_of_iterations() const
-  { 
+  {
     CGAL_qpe_assertion_msg(!is_void(), "Solution not initialized");
     return solver()->iterations();
   }
@@ -462,7 +452,7 @@ public:
     return solver()->number_of_basic_constraints();
   }
 
-  Optimality_certificate_numerator_iterator 
+  Optimality_certificate_numerator_iterator
   optimality_certificate_numerators_begin() const
   {
     CGAL_qpe_assertion_msg(!is_void(), "Solution not initialized");
@@ -470,7 +460,7 @@ public:
     return solver()->lambda_numerator_begin();
   }
 
-  Optimality_certificate_numerator_iterator 
+  Optimality_certificate_numerator_iterator
   optimality_certificate_numerators_end() const
   {
     CGAL_qpe_assertion_msg(!is_void(), "Solution not initialized");
@@ -478,7 +468,7 @@ public:
     return solver()->lambda_numerator_end();
   }
 
-  Optimality_certificate_iterator 
+  Optimality_certificate_iterator
   optimality_certificate_begin() const
   {
     CGAL_qpe_assertion_msg(!is_void(), "Solution not initialized");
@@ -486,7 +476,7 @@ public:
     return solver()->lambda_begin();
   }
 
-  Optimality_certificate_iterator 
+  Optimality_certificate_iterator
   optimality_certificate_end() const
   {
     CGAL_qpe_assertion_msg(!is_void(), "Solution not initialized");
@@ -496,7 +486,7 @@ public:
 
   // infeasibility
   // -------------
-  Infeasibility_certificate_iterator 
+  Infeasibility_certificate_iterator
   infeasibility_certificate_begin() const
   {
     CGAL_qpe_assertion_msg(!is_void(), "Solution not initialized");
@@ -504,14 +494,14 @@ public:
     return solver()->lambda_numerator_begin();
   }
 
-  Infeasibility_certificate_iterator 
+  Infeasibility_certificate_iterator
   infeasibility_certificate_end() const
   {
     CGAL_qpe_assertion_msg(!is_void(), "Solution not initialized");
     CGAL_qpe_assertion(status() == QP_INFEASIBLE);
     return solver()->lambda_numerator_end();
   }
-  
+
   // unboundedness
   // -------------
   Unboundedness_certificate_iterator unboundedness_certificate_begin() const
@@ -533,12 +523,12 @@ private:
 
   // validity
   // --------
-  
+
   // error message returned by failing validation
   std::string err_msg;
 
   // the error message is set by the following function
-  bool error (const std::string& message) 
+  bool error (const std::string& message)
   {
     err_msg = message;
     return false;
@@ -559,86 +549,86 @@ public:
   // of all four program types; in case this fails, the solution becomes
   // invalid (and this explains why the methods are non-const)
   template <class QuadraticProgram>
-  bool solves_quadratic_program 
+  bool solves_quadratic_program
   (const QuadraticProgram& qp)
   { return solves_program(qp, Tag_false(), Tag_false()); }
 
   template <class LinearProgram>
-  bool solves_linear_program 
+  bool solves_linear_program
   (const LinearProgram& lp)
   { return solves_program(lp, Tag_true(), Tag_false()); }
 
   template <class NonnegativeQuadraticProgram>
-  bool solves_nonnegative_quadratic_program 
+  bool solves_nonnegative_quadratic_program
   (const NonnegativeQuadraticProgram& qp)
   { return solves_program(qp, Tag_false(), Tag_true()); }
 
   template <class NonnegativeLinearProgram>
-  bool solves_nonnegative_linear_program 
+  bool solves_nonnegative_linear_program
   (const NonnegativeLinearProgram& lp)
   { return solves_program(lp, Tag_true(), Tag_true()); }
 
   // helper used by all four validation methods above; see
-  // QP_solver/QP_solution_impl.h for its implementation 
+  // QP_solver/QP_solution_impl.h for its implementation
   template <class Program, typename Is_linear, typename Is_nonnegative>
-  bool solves_program (const Program& p, 
-		       Is_linear is_linear, Is_nonnegative is_nonnegative);
+  bool solves_program (const Program& p,
+                       Is_linear is_linear, Is_nonnegative is_nonnegative);
 
 private:
-  // helpers used by the previous method 
+  // helpers used by the previous method
   template <typename Program>
-  bool is_feasible (const Program& p, 
-		    typename std::vector<ET>& ax_minus_b,
-		    Tag_true /*is_nonnegative*/);
+  bool is_feasible (const Program& p,
+                    typename std::vector<ET>& ax_minus_b,
+                    Tag_true /*is_nonnegative*/);
   template <typename Program>
-  bool is_feasible (const Program& p, 
-		    typename std::vector<ET>& ax_minus_b,
-		    Tag_false /*is_nonnegative*/);
+  bool is_feasible (const Program& p,
+                    typename std::vector<ET>& ax_minus_b,
+                    Tag_false /*is_nonnegative*/);
 
   template <typename Program>
   bool is_optimal_1 (const Program& p);
 
   template <typename Program>
-  bool is_optimal_2 (const Program& p, 
-		     const typename std::vector<ET>& ax_minus_b);
+  bool is_optimal_2 (const Program& p,
+                     const typename std::vector<ET>& ax_minus_b);
 
   template <typename Program>
   bool is_optimal_3 (const Program& p, typename std::vector<ET>& two_Dx,
-		     Tag_true /*is_linear*/, Tag_true /*is_nonnegative*/);
+                     Tag_true /*is_linear*/, Tag_true /*is_nonnegative*/);
   template <typename Program>
   bool is_optimal_3 (const Program& p, typename std::vector<ET>& two_Dx,
-		     Tag_false /*is_linear*/, Tag_true /*is_nonnegative*/);
+                     Tag_false /*is_linear*/, Tag_true /*is_nonnegative*/);
   template <typename Program>
   bool is_optimal_3 (const Program& p, typename std::vector<ET>& two_Dx,
-		     Tag_true /*is_linear*/, Tag_false /*is_nonnegative*/);
+                     Tag_true /*is_linear*/, Tag_false /*is_nonnegative*/);
   template <typename Program>
   bool is_optimal_3 (const Program& p, typename std::vector<ET>& two_Dx,
-		     Tag_false /*is_linear*/, Tag_false /*is_nonnegative*/);
+                     Tag_false /*is_linear*/, Tag_false /*is_nonnegative*/);
 
   template <typename Program>
   bool is_infeasible_1 (const Program& p);
 
   template <typename Program>
-  bool is_infeasible_2 (const Program& p, 
-			typename std::vector<ET>& lambda_a,
-			Tag_true /*is_nonnegative*/);
+  bool is_infeasible_2 (const Program& p,
+                        typename std::vector<ET>& lambda_a,
+                        Tag_true /*is_nonnegative*/);
   template <typename Program>
-  bool is_infeasible_2 (const Program& p, 
-			typename std::vector<ET>& lambda_a,
-			Tag_false /*is_nonnegative*/);
+  bool is_infeasible_2 (const Program& p,
+                        typename std::vector<ET>& lambda_a,
+                        Tag_false /*is_nonnegative*/);
 
   template <typename Program>
-  bool is_infeasible_3 (const Program& p, 
-			const typename std::vector<ET>& /*lambda_a*/,
-			Tag_true /*is_nonnegative*/); 
+  bool is_infeasible_3 (const Program& p,
+                        const typename std::vector<ET>& /*lambda_a*/,
+                        Tag_true /*is_nonnegative*/);
   template <typename Program>
-  bool is_infeasible_3 (const Program& p, 
-			const typename std::vector<ET>& lambda_a,
-			Tag_false /*is_nonnegative*/);
- 
+  bool is_infeasible_3 (const Program& p,
+                        const typename std::vector<ET>& lambda_a,
+                        Tag_false /*is_nonnegative*/);
+
   template <typename Program>
   bool is_unbounded_1 (const Program& p);
- 
+
   template <typename Program>
   bool is_unbounded_2 (const Program& p, Tag_true /*is_nonnegative*/);
   template <typename Program>
@@ -650,41 +640,41 @@ private:
   bool is_unbounded_3 (const Program& p, Tag_false /*is_linear*/);
 
   template <typename Program>
-  bool is_value_correct 
-  (const Program& p, typename std::vector<ET>& /*two_Dx*/, 
-   Tag_true /*is_linear*/); 
-  
-  template <typename Program>
-  bool is_value_correct 
-  (const Program& p, typename std::vector<ET>& two_Dx,
-   Tag_false /*is_linear*/); 
+  bool is_value_correct
+  (const Program& p, typename std::vector<ET>& /*two_Dx*/,
+   Tag_true /*is_linear*/);
 
   template <typename Program>
-  bool are_constraints_feasible 
+  bool is_value_correct
+  (const Program& p, typename std::vector<ET>& two_Dx,
+   Tag_false /*is_linear*/);
+
+  template <typename Program>
+  bool are_constraints_feasible
   (const Program& p, typename std::vector<ET>& ax);
 
   template <typename Program>
   bool are_bounds_feasible (const Program& p,  Tag_true /*is_nonnegative*/);
   template <typename Program>
   bool are_bounds_feasible (const Program& p,  Tag_false /*is_nonnegative*/);
-  
+
   template <typename Program, typename Z_iterator >
-  void add_Az 
+  void add_Az
   (const Program& p, Z_iterator z, typename std::vector<ET>& v);
 
   template <typename Program, typename Z_iterator >
-  void add_two_Dz 
+  void add_two_Dz
   (const Program& p, Z_iterator z, typename std::vector<ET>& v);
-  
+
   template <typename Program, typename Z_iterator >
-  void add_zA 
+  void add_zA
   (const Program& p, Z_iterator z, typename std::vector<ET>& v);
 
   template <typename Program>
   void add_c
   (const Program& p, typename std::vector<ET>& v);
 
-}; 
+};
 
 // output
 template <typename ET>
@@ -706,11 +696,11 @@ std::ostream& operator<<
   o << "objective value: " << s.objective_value() << "\n";
   o << "variable values:\n";
   int j=0;
-  for ( typename Quadratic_program_solution<ET>::Variable_value_iterator 
-	  it = s.variable_values_begin(); 
-	it < s.variable_values_end(); ++it, ++j)
+  for ( typename Quadratic_program_solution<ET>::Variable_value_iterator
+          it = s.variable_values_begin();
+        it < s.variable_values_end(); ++it, ++j)
     o << "  " << j << ": " << *it << "\n";
-  return o; 
+  return o;
 }
 
 // Details
@@ -721,51 +711,51 @@ namespace QP_solution_detail {
   class Quotient_normalizer {
   public:
     typedef CGAL::Quotient<ET> result_type;
-   
+
   private:
       typedef CGAL::Algebraic_structure_traits<ET> AST;
-      typedef typename AST::Algebraic_category Category; 
-    
+      typedef typename AST::Algebraic_category Category;
+
   public:
       typedef CGAL::Boolean_tag<
-      CGAL::is_same_or_derived<CGAL::Unique_factorization_domain_tag,Category>::value> 
+      CGAL::is_same_or_derived<CGAL::Unique_factorization_domain_tag,Category>::value>
       Has_gcd;
-    
+
       typedef CGAL::Boolean_tag<
-      CGAL::is_same_or_derived<CGAL::Integral_domain_tag,Category>::value> 
+      CGAL::is_same_or_derived<CGAL::Integral_domain_tag,Category>::value>
       Has_exact_division;
 
-    CGAL::Quotient<ET> normalize 
-    (const CGAL::Quotient<ET>& q, 
+    CGAL::Quotient<ET> normalize
+    (const CGAL::Quotient<ET>& q,
      Tag_true /*has_gcd*/,
      Tag_true /*has_exact_division*/) const
     {
       if (CGAL::is_zero (q.numerator()))
-	return CGAL::Quotient<ET>(ET(0), ET(1));
+        return CGAL::Quotient<ET>(ET(0), ET(1));
       ET gcd = CGAL::gcd (q.numerator(), q.denominator());
-      return CGAL::Quotient<ET> 
-	(CGAL::integral_division (q.numerator(), gcd),
-	 CGAL::integral_division (q.denominator(), gcd));
-    }  
+      return CGAL::Quotient<ET>
+        (CGAL::integral_division (q.numerator(), gcd),
+         CGAL::integral_division (q.denominator(), gcd));
+    }
 
-    CGAL::Quotient<ET> normalize 
-    (const CGAL::Quotient<ET>& q, 
+    CGAL::Quotient<ET> normalize
+    (const CGAL::Quotient<ET>& q,
      Tag_true /*has_gcd*/,
      Tag_false /*has_exact_division*/) const
     {
       return q;
     }
-  
-    CGAL::Quotient<ET> normalize 
-    (const CGAL::Quotient<ET>& q, 
+
+    CGAL::Quotient<ET> normalize
+    (const CGAL::Quotient<ET>& q,
      Tag_false /*has_gcd*/,
      Tag_true /*has_exact_division*/) const
     {
       return q;
     }
 
-    CGAL::Quotient<ET> normalize 
-    (const CGAL::Quotient<ET>& q, 
+    CGAL::Quotient<ET> normalize
+    (const CGAL::Quotient<ET>& q,
      Tag_false /*has_gcd*/,
      Tag_false /*has_exact_division*/) const
     {
@@ -791,12 +781,12 @@ namespace QP_solution_detail {
       : s (solver)
     {}
 
-    // returns value * denominator 
+    // returns value * denominator
     result_type operator () ( std::size_t i) const
     {
       return s->variable_numerator_value(static_cast<int>(i));
     }
-    
+
     const QP* s;
   };
 
@@ -817,7 +807,7 @@ namespace QP_solution_detail {
     {
       return s->unbounded_direction_value(static_cast<int>(i));
     }
-      
+
     const QP* s;
   };
 
@@ -838,7 +828,7 @@ namespace QP_solution_detail {
     {
       return s->lambda_numerator(static_cast<int>(i));
     }
-      
+
     const QP* s;
   };
 }
