@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/GraphicsView/include/CGAL/Qt/Converter.h $
+// $Id: Converter.h 42752d0 2023-03-29T11:39:37-03:00 Luiz Georg
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/GraphicsView/include/CGAL/Qt/Converter.h $
-// $Id: Converter.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Andreas Fabri <Andreas.Fabri@geometryfactory.com>
 //                 Laurent Rineau <Laurent.Rineau@geometryfactory.com>
@@ -73,7 +64,7 @@ public:
 private:
   bool clippingRectIsInitialized;
   CGAL_Iso_rectangle_2 clippingRect;
-  
+
 
 public:
 
@@ -108,18 +99,18 @@ public:
     return QPointF(to_double(p.x()), to_double(p.y()));
   }
 
-      
+
   CGAL_Segment_2 operator()(const QLineF& qs) const
   {
     return CGAL_Segment_2(operator()(qs.p1()), operator()(qs.p2()));
   }
- 
+
   QLineF operator()(const CGAL_Segment_2 &s) const
   {
     return QLineF(operator()(s.source()), operator()(s.target()));
   }
 
-  
+
   CGAL_Iso_rectangle_2 operator()(const QRectF& qr) const
   {
     return CGAL_Iso_rectangle_2(operator()(qr.bottomLeft()), operator()(qr.topRight()));
@@ -135,12 +126,12 @@ public:
   QRectF operator()(const CGAL::Bbox_2& bb) const
   {
     return QRectF(bb.xmin(),
-		  bb.ymin(),
-		  bb.xmax()-bb.xmin(),
-		  bb.ymax()-bb.ymin());
+                  bb.ymin(),
+                  bb.xmax()-bb.xmin(),
+                  bb.ymax()-bb.ymin());
   }
 
-     
+
   QLineF operator()(const CGAL_Ray_2 &r) const
   {
     CGAL_assertion(clippingRectIsInitialized);
@@ -176,6 +167,15 @@ public:
     return qp;
   }
 
+  QPolygonF operator()(const std::list< CGAL_Point_2 >& p) const
+  {
+    QPolygonF qp;
+    for(int i = 0; i < p.size(); i++){
+      qp << operator()(p[i]);
+    }
+    return qp;
+  }
+
 
   void operator()(std::list< CGAL_Point_2 >& p, const QPolygonF& qp) const
   {
