@@ -4,19 +4,11 @@
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
  This file is part of a fork of the QGLViewer library version 2.7.0.
- http://www.libqglviewer.com - contact@libqglviewer.com
-
- This file may be used under the terms of the GNU General Public License 
- version 3.0 as published by the Free Software Foundation and
- appearing in the LICENSE file included in the packaging of this file.
-
- This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/GraphicsView/include/CGAL/Qt/qglviewer.h $
-// $Id: qglviewer.h bace158 2018-07-04T13:34:26+01:00 Jane
-// SPDX-License-Identifier: GPL-3.0
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/GraphicsView/include/CGAL/Qt/qglviewer.h $
+// $Id: qglviewer.h 4547818 2022-11-15T13:39:40+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-only
 
 #ifndef QGLVIEWER_QGLVIEWER_H
 #define QGLVIEWER_QGLVIEWER_H
@@ -36,7 +28,7 @@
 #include <QOpenGLBuffer>
 #include <QMap>
 #include <QVector>
-#include <QTime>
+#include <QElapsedTimer>
 #include <QTimer>
 #include <QGLContext>
 #include <QOpenGLWidget>
@@ -78,11 +70,14 @@ implementation.
 class CGAL_QT_EXPORT QGLViewer : public QOpenGLWidget, public QOpenGLFunctions {
   Q_OBJECT
 
-public:  
-  explicit QGLViewer(QGLContext* context, QWidget *parent = 0,
-                     ::Qt::WindowFlags flags = 0);
-  explicit QGLViewer(QWidget *parent = 0,
-                     ::Qt::WindowFlags flags = 0);
+public:
+  //todo check if this is used. If not remove it
+  explicit QGLViewer(QGLContext* context, QWidget *parent = nullptr,
+                     ::Qt::WindowFlags flags = ::Qt::WindowType(0));
+  explicit QGLViewer(QOpenGLContext* context, QWidget *parent = nullptr,
+                     ::Qt::WindowFlags flags = ::Qt::WindowType(0));
+  explicit QGLViewer(QWidget *parent = nullptr,
+                     ::Qt::WindowFlags flags = ::Qt::WindowType(0));
 
   virtual ~QGLViewer();
 
@@ -122,7 +117,12 @@ public:
   qglviewer::Camera::drawAllPaths(). Actual camera and path edition will be
   implemented in the future. */
   bool cameraIsEdited() const { return cameraIsEdited_; }
-  
+
+  /*!
+   * \brief isSharing returns true if the viewer was created from an existing one,
+   * and therefore is sharing its context with it.
+   */
+  bool isSharing() const;
 public Q_SLOTS:
   /*! Sets the state of axisIsDrawn(). Emits the axisIsDrawnChanged() signal.
    * See also toggleAxisIsDrawn(). */
@@ -138,8 +138,8 @@ public Q_SLOTS:
   void setGridIsDrawn(bool draw = true) {
     if(!draw)
     {
-      grid_size=0;
-      g_axis_size=0;
+      grid_size = 0;
+      grid_axis_size = 0;
     }
     gridIsDrawn_ = draw;
     Q_EMIT gridIsDrawnChanged(draw);
@@ -179,9 +179,7 @@ public:
   /*! Returns the background color of the viewer.
 
   This method is provided for convenience since the background color is an
-  OpenGL state variable set with \c glClearColor(). However, this internal
-  representation has the advantage that it is saved (resp. restored) with
-  saveStateToFile() (resp. restoreStateFromFile()).
+  OpenGL state variable set with \c glClearColor().
 
   Use setBackgroundColor() to define and activate a background color.
 
@@ -284,7 +282,7 @@ public Q_SLOTS:
   /*! @name Associated objects */
   //@{
 public:
-  /*! Returns the associated qglviewer::Camera, never \c NULL. */
+  /*! Returns the associated qglviewer::Camera, never \c nullptr. */
   qglviewer::Camera *camera() const { return camera_; }
 
   /*! Returns the viewer's qglviewer::ManipulatedFrame.
@@ -296,7 +294,7 @@ public:
   See the <a href="../examples/manipulatedFrame.html">manipulatedFrame
   example</a> for a complete implementation.
 
-  Default value is \c NULL, meaning that no qglviewer::ManipulatedFrame is set.
+  Default value is \c nullptr, meaning that no qglviewer::ManipulatedFrame is set.
 */
   qglviewer::ManipulatedFrame *manipulatedFrame() const {
     return manipulatedFrame_;
@@ -310,7 +308,7 @@ public Q_SLOTS:
   /*! @name Mouse grabbers */
   //@{
 public:
-  /*! Returns the current qglviewer::MouseGrabber, or \c NULL if no
+  /*! Returns the current qglviewer::MouseGrabber, or \c nullptr if no
   qglviewer::MouseGrabber currently grabs mouse events.
 
   When qglviewer::MouseGrabber::grabsMouse(), the different mouse events are
@@ -378,26 +376,26 @@ public:
   Note that if the QGLViewer is embedded in an other QWidget, it returns \c true
   when the top level widget is in full screen mode. */
   bool isFullScreen() const { return fullScreen_; }
-  
+
   /*! Returns the recommended size for the QGLViewer. Default value is 600x400
    * pixels. */
   virtual QSize sizeHint() const { return QSize(600, 400); }
   /*!
-   * Sets the offset of the scene. The offset is the difference between the origin 
+   * Sets the offset of the scene. The offset is the difference between the origin
    * of the world and the origin of the scene. It is relevant when the whole scene is translated
    * of a big number, because there is a useless loss of precision when drawing.
-   * 
-   * The offset must be added to the drawn coordinates, and substracted from the computation 
+   *
+   * The offset must be added to the drawn coordinates, and subtracted from the computation
    * \attention  the result of pointUnderPixel is the real item translated by the offset.
-   * 
+   *
    */
   void setOffset(qglviewer::Vec offset);
-  
+
   /*!
    * returns the offset of the scene.
    * \see `setOffset()`
    */
-  qglviewer::Vec offset()const;
+  const qglviewer::Vec& offset() const;
 
 public Q_SLOTS:
   void setFullScreen(bool fullScreen = true);
@@ -413,7 +411,8 @@ protected:
   //@{
 public:
   void drawArrow(double r, double R, int prec,
-                        qglviewer::Vec from, qglviewer::Vec to, qglviewer::Vec color, std::vector<float> &data);
+                 const qglviewer::Vec& from, const qglviewer::Vec& to,
+                 std::vector<float> &data);
   void drawAxis(qreal l = 1.0);
   void drawGrid(qreal size= 1.0, int nbSubdivisions = 10);
 
@@ -428,7 +427,7 @@ protected:
 
 protected:
   void displayFPS();
-  
+
 
 //@}
 
@@ -463,6 +462,7 @@ public Q_SLOTS:
   virtual void resize(int width, int height);
   /*! Sets the hasMouseTracking() value. */
   virtual void setMouseTracking(bool enable);
+  //@}
 #endif
 
   /*! @name Buffer to texture */
@@ -564,6 +564,21 @@ public:
    */
   void saveSnapshot();
 
+  /*!
+   * Takes a snapshot without any dialog
+   */
+  void saveSnapshot(const QString& fileName,
+                    const qreal finalWidth,
+                    const qreal finalHeight,
+                    const bool expand = false,
+                    const double oversampling = 1.,
+                    qglviewer::SnapShotBackground background_color = qglviewer::CURRENT_BACKGROUND);
+
+  void saveSnapshot(const QString& fileName)
+  {
+    return saveSnapshot(fileName, this->width(), this->height());
+  }
+
 public:
 Q_SIGNALS:
   /*! Signal emitted by the default init() method.
@@ -613,10 +628,12 @@ Q_SIGNALS:
   /*! Signal emitted by setMouseGrabber() when the mouseGrabber() is changed.
 
   \p mouseGrabber is a pointer to the new MouseGrabber. Note that this signal is
-  emitted with a \c NULL parameter each time a MouseGrabber stops grabbing
+  emitted with a \c nullptr parameter each time a MouseGrabber stops grabbing
   mouse. */
   void mouseGrabberChanged(qglviewer::MouseGrabber *mouseGrabber);
 
+  //! Signal emitted by the viewer when its OpenGL context is destroyed.
+  void contextIsDestroyed();
   /*! @name Help window */
   //@{
 public:
@@ -664,9 +681,8 @@ protected:
   initialize some of the OpenGL flags. The default implementation is empty. See
   initializeGL().
 
-  Typical usage include camera() initialization (showEntireScene()), previous
-  viewer state restoration (restoreStateFromFile()), OpenGL state modification
-  and display list creation.
+  Typical usage include camera() initialization (showEntireScene()),
+ OpenGL state modification and display list creation.
 
   Note that initializeGL() modifies the standard OpenGL context. These values
   can be restored back in this method.
@@ -716,7 +732,6 @@ protected:
   virtual void keyPressEvent(QKeyEvent *);
   virtual void keyReleaseEvent(QKeyEvent *);
   virtual void timerEvent(QTimerEvent *);
-  virtual void closeEvent(QCloseEvent *);
   //@}
 
   /*! @name Object selection */
@@ -834,8 +849,26 @@ public:
 
 public Q_SLOTS:
   void setShortcut(qglviewer::KeyboardAction action, unsigned int key);
+  void setShortcut(qglviewer::KeyboardAction action, ::Qt::Modifier modifier, ::Qt::Key key)
+  {
+    setShortcut(action,
+                static_cast<unsigned int>(modifier)+
+                static_cast<unsigned int>(key));
+  }
 
   void setKeyDescription(unsigned int key, QString description);
+  void setKeyDescription(::Qt::KeyboardModifier modifier, ::Qt::Key key, QString description)
+  {
+    setKeyDescription(static_cast<unsigned int>(modifier) +
+                      static_cast<unsigned int>(key),
+                      description);
+  }
+  void setKeyDescription(::Qt::Modifier modifier, ::Qt::Key key, QString description)
+  {
+    setKeyDescription(static_cast<unsigned int>(modifier) +
+                      static_cast<unsigned int>(key),
+                      description);
+  }
   void clearShortcuts();
 
 // Key Frames shortcut keys
@@ -918,42 +951,18 @@ protected:
   //@{
 public:
   QString stateFileName() const;
-  virtual QDomElement domElement(const QString &name,
-                                 QDomDocument &document) const;
 Q_SIGNALS:
   void needNewContext();
 
-public Q_SLOTS:
-  virtual void initFromDOMElement(const QDomElement &element);
-  virtual void saveStateToFile(); // cannot be const because of QMessageBox
-  virtual bool restoreStateFromFile();
-
-  /*! Defines the stateFileName() used by saveStateToFile() and
-    restoreStateFromFile().
-
-    The file name can have an optional prefix directory (no prefix meaning
-    current directory). If the directory does not exist, it will be created by
-    saveStateToFile().
-
-    \code
-    // Name depends on the displayed 3D model. Saved in current directory.
-    setStateFileName(3DModelName() + ".xml");
-
-    // Files are stored in a dedicated directory under user's home directory.
-    setStateFileName(QDir::homeDirPath + "/.config/myApp.xml");
-    \endcode */
-  void setStateFileName(const QString &name) { stateFileName_ = name; }
-
 
 protected:
-  static void saveStateToFileForAllViewers();
   //@}
 
   /*! @name QGLViewer pool */
   //@{
 public:
   /*! Returns a \c QList that contains pointers to all the created QGLViewers.
-    Note that this list may contain \c NULL pointers if the associated viewer
+    Note that this list may contain \c nullptr pointers if the associated viewer
   has been deleted.
 
   Can be useful to apply a method or to connect a signal to all the viewers:
@@ -968,7 +977,7 @@ public:
   index in unique and can be used to identify the different created QGLViewers
   (see stateFileName() for an application example).
 
-  When a QGLViewer is deleted, the QGLViewers' indexes are preserved and NULL is
+  When a QGLViewer is deleted, the QGLViewers' indexes are preserved and nullptr is
   set for that index. When a QGLViewer is created, it is placed in the first
   available position in that list. Returns -1 if the QGLViewer could not be
   found (which should not be possible). */
@@ -983,7 +992,8 @@ public:
 public:
   virtual void setVisualHintsMask(int mask, int delay = 2000);
   virtual void drawVisualHints();
-  QOpenGLFramebufferObject* getStoredFrameBuffer();
+  QOpenGLFramebufferObject* getStoredFrameBuffer() const;
+  void setStoredFrameBuffer(QOpenGLFramebufferObject*);
 
 public Q_SLOTS:
   virtual void resetVisualHints();
@@ -1034,7 +1044,7 @@ protected:
   int animationTimerId_;
 
   // F P S    d i s p l a y
-  QTime fpsTime_;
+  QElapsedTimer fpsTime_;
   unsigned int fpsCounter_;
   QString fpsString_;
   qreal f_p_s_;
@@ -1163,54 +1173,61 @@ protected:
   QMap<WheelBindingPrivate, MouseActionPrivate> wheelBinding_;
   QMap<ClickBindingPrivate, qglviewer::ClickAction> clickBinding_;
   ::Qt::Key currentlyPressedKey_;
-  
-  // S t a t e   F i l e
-  QString stateFileName_;
 
   // H e l p   w i n d o w
   QTabWidget *helpWidget_;
-  
+
   //internal drawing buffers
   enum VBO
   {
     Grid = 0,
-    Grid_axis,
-    Axis,
+    Grid_axis_x, Grid_axis_y,
+    Axis_x, Axis_y, Axis_z,
     Pivot_point,
     VBO_size
   };
+
   enum VAO
   {
     GRID = 0,
-    GRID_AXIS,
-    AXIS,
+    GRID_AXIS_X, GRID_AXIS_Y,
+    AXIS_X, AXIS_Y, AXIS_Z,
     PIVOT_POINT,
     VAO_size
   };
+
   QOpenGLShaderProgram rendering_program;
-  QOpenGLShaderProgram rendering_program_light;
   QOpenGLVertexArrayObject vaos[VAO_size];
   QVector<QOpenGLBuffer> vbos;
+
   std::size_t grid_size;
-  std::size_t g_axis_size;
+  std::size_t grid_axis_size;
   std::size_t axis_size;
+
   QOpenGLFramebufferObject* stored_fbo;
+
   //S n a p s h o t
-  QImage* takeSnapshot(qglviewer::SnapShotBackground  background_color, 
+  QImage* takeSnapshot(qglviewer::SnapShotBackground  background_color,
                        QSize finalSize, double oversampling, bool expand);
-  
+
   //Internal Projection Matrix
-  
+
   // O f f s e t
   qglviewer::Vec _offset;
   //C o n t e x t
   bool is_ogl_4_3;
+  bool is_sharing;
+  bool is_linked;
+  QOpenGLContext* shared_context;
+  // Zoom
+  bool _first_tick;
+
 public:
   //! Is used to know if the openGL context is 4.3 or ES 2.0.
   //! @returns `true` if the context is 4.3.
-  //! @returns `false` if the context is ES 2.0.  
+  //! @returns `false` if the context is ES 2.0.
   bool isOpenGL_4_3()const {return is_ogl_4_3; }
-  
+
 };
 
 } //end CGAL
