@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Polygon_mesh_processing/include/CGAL/Rigid_triangle_mesh_collision_detection.h $
-// $Id: Rigid_triangle_mesh_collision_detection.h aa47744 2019-07-28T22:30:17+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Polygon_mesh_processing/include/CGAL/Rigid_triangle_mesh_collision_detection.h $
+// $Id: Rigid_triangle_mesh_collision_detection.h 9242a81 2023-02-07T11:31:55+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Maxime Gimeno and Sebastien Loriot
@@ -46,7 +37,7 @@
 namespace CGAL {
 
 /*!
- * \ingroup PkgPolygonMeshProcessing
+ * \ingroup PkgPolygonMeshProcessingRef
  * This class provides methods to perform some intersection tests between triangle meshes
  * that undergo affine transformations (rotation, translation, and scaling).
  * Meshes are added to an internal set and are referenced using an id assigned when added to the set.
@@ -117,7 +108,7 @@ class Rigid_triangle_mesh_collision_detection
       m_id_pool.push_back(m_free_id);
       ++m_free_id;
       m_own_aabb_trees.resize(m_free_id);
-      m_aabb_trees.resize(m_free_id, NULL);
+      m_aabb_trees.resize(m_free_id, nullptr);
       m_is_closed.resize(m_free_id);
       m_points_per_cc.resize(m_free_id);
       m_traversal_traits.resize(m_free_id);
@@ -143,7 +134,7 @@ class Rigid_triangle_mesh_collision_detection
     typename K::Construct_vector_3  vector_functor;
     typedef typename Traversal_traits::Transformed_tree_helper Helper;
 
-    BOOST_FOREACH(const typename K::Point_3& q, m_points_per_cc[id_B])
+    for(const typename K::Point_3& q : m_points_per_cc[id_B])
     {
       if( internal::Point_inside_vertical_ray_cast<K, Tree, Helper>(m_traversal_traits[id_A].get_helper())(
             m_traversal_traits[id_B].transformation()( q ), *m_aabb_trees[id_A],
@@ -185,6 +176,14 @@ public:
     : m_free_id(0)
   {}
 
+  Rigid_triangle_mesh_collision_detection(const Rigid_triangle_mesh_collision_detection&) = default;
+
+  //! move constructor
+  Rigid_triangle_mesh_collision_detection(Rigid_triangle_mesh_collision_detection&& other)
+  {
+    *this = std::move(other);
+  }
+
   ~Rigid_triangle_mesh_collision_detection()
   {
     for (std::size_t k=0; k<m_free_id; ++k)
@@ -194,51 +193,71 @@ public:
     }
   }
 
+  Rigid_triangle_mesh_collision_detection& operator=(Rigid_triangle_mesh_collision_detection& other) = default;
+
+  //! move assignment operator
+  Rigid_triangle_mesh_collision_detection& operator=(Rigid_triangle_mesh_collision_detection&& other)
+  {
+    m_own_aabb_trees = std::move(other.m_own_aabb_trees);
+    m_aabb_trees = std::move(other.m_aabb_trees);
+    m_is_closed = std::move(other.m_is_closed);
+    m_points_per_cc = std::move(other.m_points_per_cc);
+    m_traversal_traits = std::move(other.m_traversal_traits);
+    m_free_id = std::move(other.m_free_id);
+    m_id_pool = std::move(other.m_id_pool);
+
+    for(std::size_t i = 0; i< other.m_own_aabb_trees.size(); ++i)
+      other.m_own_aabb_trees[i]= false;
+
+    return *this;
+  }
+
  /*!
   * adds mesh `tm` to the set of meshes to be considered for intersection.
   *
-  * @tparam NamedParameters a sequence of \ref pmp_namedparameters "Named Parameters"
+  * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
   *
   * \return the id of `tm` used to refer to that mesh.
   *
   * @param tm triangulated surface mesh to add
-  * @param np optional sequence of \ref pmp_namedparameters "Named Parameters" among the ones listed below
+  * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
   *
   * \cgalNamedParamsBegin
-  *   \cgalParamBegin{vertex_point_map}
-  *     the property map with the points associated to the vertices of `tm`.
-  *     If this parameter is omitted, an internal property map for
-  *     `CGAL::vertex_point_t` must be available in `TriangleMesh`
-  *   \cgalParamEnd
-  *   \cgalParamBegin{face_index_map}
-  *      a property map containing the index of each face of `tm`. It must be initialized
-  *      and the value must be unique per face and in the range `[0, num_faces(tm)[`.
-  *   \cgalParamEnd
-  *   \cgalParamBegin{apply_per_connected_component}
-  *     if `false`, `tm` is assumed to have only one connected component, avoiding
-  *     the extraction of connected components. Default is `true`.
-  *   \cgalParamEnd
+  *   \cgalParamNBegin{vertex_point_map}
+  *     \cgalParamDescription{a property map associating points to the vertices of `tm`}
+  *     \cgalParamType{a class model of `ReadablePropertyMap` with `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key type and `%Point_3` as value type}
+  *     \cgalParamDefault{`boost::get(CGAL::vertex_point, tm)`}
+  *     \cgalParamExtra{If this parameter is omitted, an internal property map for `CGAL::vertex_point_t`
+  *                     should be available for the vertices of `tm`.}
+  *   \cgalParamNEnd
+  *
+  *   \cgalParamNBegin{face_index_map}
+  *     \cgalParamDescription{a property map associating to each face of `tm` a unique index between `0` and `num_faces(tm) - 1`}
+  *     \cgalParamType{a class model of `ReadablePropertyMap` with `boost::graph_traits<PolygonMesh>::%face_descriptor` as key type and `std::size_t` as value type}
+  *     \cgalParamDefault{an automatically indexed internal map}
+  *   \cgalParamNEnd
+  *
+  *   \cgalParamNBegin{apply_per_connected_component}
+  *     \cgalParamDescription{If `false`, `tm` is assumed to have only one connected component, avoiding the extraction of connected components.}
+  *     \cgalParamType{Boolean}
+  *     \cgalParamDefault{`true`}
+  *   \cgalParamNEnd
   * \cgalNamedParamsEnd
   */
-  template <class NamedParameters>
+  template <class NamedParameters = parameters::Default_named_parameters>
   std::size_t add_mesh(const TriangleMesh& tm,
-                       const NamedParameters& np)
+                       const NamedParameters& np = parameters::default_values())
   {
-  // handle vpm
-    using Polygon_mesh_processing::GetVertexPointMap;
-    typedef typename GetVertexPointMap<TriangleMesh,
-                                       NamedParameters>::const_type Local_vpm;
-    CGAL_USE_TYPE(Local_vpm);
-    CGAL_assertion_code(
-      static const bool same_vpm = (boost::is_same<Local_vpm,Vpm>::value); )
-    CGAL_static_assertion(same_vpm);
+    // handle vpm
+    typedef typename CGAL::GetVertexPointMap<TriangleMesh, NamedParameters>::const_type Local_vpm;
+    CGAL_static_assertion( (std::is_same<Local_vpm,Vpm>::value) );
 
     Vpm vpm =
       parameters::choose_parameter(parameters::get_parameter(np, internal_np::vertex_point),
-                          get_const_property_map(boost::vertex_point, tm) );
+                                   get_const_property_map(boost::vertex_point, tm) );
   // now add the mesh
     std::size_t id = get_id_for_new_mesh();
-    CGAL_assertion( m_aabb_trees[id] == NULL );
+    CGAL_assertion( m_aabb_trees[id] == nullptr );
     m_is_closed[id] = is_closed(tm);
     m_own_aabb_trees[id] = true;
     Tree* t = new Tree(boost::begin(faces(tm)), boost::end(faces(tm)), tm, vpm);
@@ -254,35 +273,41 @@ public:
   * adds an instance of a triangulated surface mesh using an external tree of its faces.
   * \warning The tree is not copied and the lifetime of `tree` must be longer than that of this class.
   *
-  * @tparam NamedParameters a sequence of \ref pmp_namedparameters "Named Parameters"
+  * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
   *
   * \return the id of `tm` used to refer to that mesh.
   *
   * @param tree an AABB-tree of faces of a mesh
   * @param tm triangulated surface mesh
-  * @param np optional sequence of \ref pmp_namedparameters "Named Parameters" among the ones listed below
+  * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
   *
   * \cgalNamedParamsBegin
-  *   \cgalParamBegin{vertex_point_map}
-  *     the property map with the points associated to the vertices of `tm`.
-  *     If this parameter is omitted, an internal property map for
-  *     `CGAL::vertex_point_t` must be available in `TriangleMesh`
-  *   \cgalParamEnd
-  *   \cgalParamBegin{face_index_map}
-  *      a property map containing the index of each face of `tm`. It must be initialized
-  *      and the value must be unique per face and in the range `[0, num_faces(tm)[`.
-  *   \cgalParamEnd
-  *   \cgalParamBegin{apply_per_connected_component}
-  *     if `false`, `tm` is assumed to have only one connected component, avoiding
-  *     the extraction of connected components. Default is `true`.
-  *   \cgalParamEnd
+  *   \cgalParamNBegin{vertex_point_map}
+  *     \cgalParamDescription{a property map associating points to the vertices of `tm`}
+  *     \cgalParamType{a class model of `ReadWritePropertyMap` with `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key type and `%Point_3` as value type}
+  *     \cgalParamDefault{`boost::get(CGAL::vertex_point, tm)`}
+  *     \cgalParamExtra{If this parameter is omitted, an internal property map for `CGAL::vertex_point_t`
+  *                     should be available for the vertices of `tm`.}
+  *   \cgalParamNEnd
+  *
+  *   \cgalParamNBegin{face_index_map}
+  *     \cgalParamDescription{a property map associating to each face of `tm` a unique index between `0` and `num_faces(tm) - 1`}
+  *     \cgalParamType{a class model of `ReadablePropertyMap` with `boost::graph_traits<PolygonMesh>::%face_descriptor` as key type and `std::size_t` as value type}
+  *     \cgalParamDefault{an automatically indexed internal map}
+  *   \cgalParamNEnd
+  *
+  *   \cgalParamNBegin{apply_per_connected_component}
+  *     \cgalParamDescription{If `false`, `tm` is assumed to have only one connected component, avoiding the extraction of connected components}
+  *     \cgalParamType{Boolean}
+  *     \cgalParamDefault{`true`}
+  *   \cgalParamNEnd
   * \cgalNamedParamsEnd
   */
-  template <class NamedParameters>
-  std::size_t add_mesh(const AABB_tree& tree, const TriangleMesh& tm, const NamedParameters& np)
+  template <class NamedParameters = parameters::Default_named_parameters>
+  std::size_t add_mesh(const AABB_tree& tree, const TriangleMesh& tm, const NamedParameters& np = parameters::default_values())
   {
     std::size_t id = get_id_for_new_mesh();
-    CGAL_assertion( m_aabb_trees[id] == NULL );
+    CGAL_assertion( m_aabb_trees[id] == nullptr );
     m_is_closed[id] = is_closed(tm);
     m_own_aabb_trees[id] = false ;
     m_aabb_trees[id] = const_cast<Tree*>(&tree);
@@ -296,7 +321,7 @@ public:
    */
   void set_transformation(std::size_t mesh_id, const Aff_transformation_3<K>& aff_trans)
   {
-    CGAL_assertion(m_aabb_trees[mesh_id] != NULL);
+    CGAL_assertion(m_aabb_trees[mesh_id] != nullptr);
     m_traversal_traits[mesh_id].set_transformation(aff_trans);
 #if CGAL_RMCD_CACHE_BOXES
     m_bboxes_is_invalid.set(mesh_id);
@@ -327,7 +352,7 @@ public:
   std::vector<std::size_t>
   get_all_intersections(std::size_t mesh_id, const MeshIdRange& ids) const
   {
-    CGAL_assertion(m_aabb_trees[mesh_id] != NULL);
+    CGAL_assertion(m_aabb_trees[mesh_id] != nullptr);
     CGAL::Interval_nt_advanced::Protector protector;
 #if CGAL_RMCD_CACHE_BOXES
     update_bboxes();
@@ -335,9 +360,9 @@ public:
     std::vector<std::size_t> res;
 
     // TODO: use a non-naive version
-    BOOST_FOREACH(std::size_t k, ids)
+    for(std::size_t k : ids)
     {
-      CGAL_assertion(m_aabb_trees[k] != NULL);
+      CGAL_assertion(m_aabb_trees[k] != nullptr);
       if(k==mesh_id) continue;
 
       if (does_A_intersect_B(mesh_id, k))
@@ -381,7 +406,7 @@ public:
   std::vector<std::pair<std::size_t, bool> >
   get_all_intersections_and_inclusions(std::size_t mesh_id, const MeshIdRange& ids) const
   {
-    CGAL_assertion(m_aabb_trees[mesh_id] != NULL);
+    CGAL_assertion(m_aabb_trees[mesh_id] != nullptr);
     CGAL::Interval_nt_advanced::Protector protector;
 #if CGAL_RMCD_CACHE_BOXES
     update_bboxes();
@@ -389,9 +414,9 @@ public:
     std::vector<std::pair<std::size_t, bool> > res;
 
     // TODO: use a non-naive version
-    BOOST_FOREACH(std::size_t k, ids)
+    for(std::size_t k : ids)
     {
-      CGAL_assertion(m_aabb_trees[k] != NULL);
+      CGAL_assertion(m_aabb_trees[k] != nullptr);
       if(k==mesh_id) continue;
 
       if (does_A_intersect_B(mesh_id, k))
@@ -457,7 +482,7 @@ public:
 
     if (m_own_aabb_trees[mesh_id]) delete m_aabb_trees[mesh_id];
     m_points_per_cc[mesh_id].clear();
-    m_aabb_trees[mesh_id] = NULL;
+    m_aabb_trees[mesh_id] = nullptr;
     if (m_id_pool[m_free_id-1]!=mesh_id)
       std::swap(m_id_pool[m_free_id-1], *itf);
     --m_free_id;
@@ -487,7 +512,7 @@ public:
   bool is_valid_index(std::size_t mesh_id)
   {
     if (mesh_id >= m_id_pool.size()) return false;
-    return m_aabb_trees[mesh_id] != NULL;
+    return m_aabb_trees[mesh_id] != nullptr;
   }
 
 /// \name Helper Static Function
@@ -497,53 +522,51 @@ public:
   * intended to be used before calling the `add_mesh()` overload taking an AABB-tree instead of a mesh
   * as input parameter.
   *
-  * @tparam NamedParameters a sequence of \ref pmp_namedparameters "Named Parameters"
+  * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
   *
   * @param tm input triangulated surface mesh
   * @param [out] points will contain one point per connected component of `tm`
-  * @param np optional sequence of \ref pmp_namedparameters "Named Parameters" among the ones listed below
+  * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
   *
   * \cgalNamedParamsBegin
-  *   \cgalParamBegin{vertex_point_map}
-  *     the property map with the points associated to the vertices of `tm`.
-  *     If this parameter is omitted, an internal property map for
-  *     `CGAL::vertex_point_t` must be available in `TriangleMesh`
-  *   \cgalParamEnd
-  *   \cgalParamBegin{face_index_map}
-  *      a property map containing the index of each face of `tm`. It must be initialized
-  *      and the value must be unique per face and in the range `[0, num_faces(tm)[`.
-  *   \cgalParamEnd
-  *   \cgalParamBegin{apply_per_connected_component}
-  *     if `false`, `tm` is assumed to have only one connected component, avoiding
-  *     the extraction of connected components. %Default is `true`.
-  *   \cgalParamEnd
+  *   \cgalParamNBegin{vertex_point_map}
+  *     \cgalParamDescription{a property map associating points to the vertices of `tm`}
+  *     \cgalParamType{a class model of `ReadWritePropertyMap` with `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key type and `%Point_3` as value type}
+  *     \cgalParamDefault{`boost::get(CGAL::vertex_point, tm)`}
+  *     \cgalParamExtra{If this parameter is omitted, an internal property map for `CGAL::vertex_point_t`
+  *                     should be available for the vertices of `tm`.}
+  *   \cgalParamNEnd
+  *
+  *   \cgalParamNBegin{face_index_map}
+  *     \cgalParamDescription{a property map associating to each face of `tm` a unique index between `0` and `num_faces(tm) - 1`}
+  *     \cgalParamType{a class model of `ReadablePropertyMap` with `boost::graph_traits<PolygonMesh>::%face_descriptor` as key type and `std::size_t` as value type}
+  *     \cgalParamDefault{an automatically indexed internal map}
+  *   \cgalParamNEnd
+  *
+  *   \cgalParamNBegin{apply_per_connected_component}
+  *     \cgalParamDescription{If `false`, `tm` is assumed to have only one connected component, avoiding the extraction of connected components}
+  *     \cgalParamType{Boolean}
+  *     \cgalParamDefault{`true`}
+  *   \cgalParamNEnd
   * \cgalNamedParamsEnd
   */
-  template <class NamedParameters>
+  template <class NamedParameters = parameters::Default_named_parameters>
   static
   void collect_one_point_per_connected_component(
     const TriangleMesh& tm,
           std::vector<Point_3>& points,
-    const NamedParameters& np)
+    const NamedParameters& np = parameters::default_values())
   {
-    using Polygon_mesh_processing::GetVertexPointMap;
-    using Polygon_mesh_processing::GetFaceIndexMap;
-
     const bool maybe_several_cc =
       parameters::choose_parameter(
         parameters::get_parameter(np, internal_np::apply_per_connected_component), true);
 
-    typedef typename GetVertexPointMap<TriangleMesh,
-                                       NamedParameters>::const_type Local_vpm;
-    CGAL_USE_TYPE(Local_vpm);
-
-    CGAL_assertion_code(
-      static const bool same_vpm = (boost::is_same<Local_vpm,Vpm>::value); )
-    CGAL_static_assertion(same_vpm);
+    typedef typename CGAL::GetVertexPointMap<TriangleMesh, NamedParameters>::const_type Local_vpm;
+    CGAL_static_assertion((std::is_same<Local_vpm,Vpm>::value));
 
     Vpm vpm =
       parameters::choose_parameter(parameters::get_parameter(np, internal_np::vertex_point),
-                          get_const_property_map(boost::vertex_point, tm) );
+                                   get_const_property_map(boost::vertex_point, tm) );
 
     if (maybe_several_cc)
     {
@@ -551,16 +574,12 @@ public:
       std::vector<std::size_t> cc_ids(num_faces(tm));
 
       // face index map
-      typedef typename GetFaceIndexMap<TriangleMesh,
-                                       NamedParameters>::type Fid_map;
-
-      Fid_map fid_map =
-        parameters::choose_parameter(parameters::get_parameter(np, internal_np::face_index),
-                            get_const_property_map(boost::face_index, tm));
+      typedef typename GetInitializedFaceIndexMap<TriangleMesh, NamedParameters>::const_type FaceIndexMap;
+      FaceIndexMap fid_map = CGAL::get_initialized_face_index_map(tm, np);
 
       std::size_t nb_cc =
         Polygon_mesh_processing::connected_components(
-          tm, bind_property_maps(fid_map, make_property_map(cc_ids)),
+          tm, make_compose_property_map(fid_map, make_property_map(cc_ids)),
           parameters::face_index_map(fid_map));
       if (nb_cc != 1)
       {
@@ -568,7 +587,7 @@ public:
         std::vector<typename GrTr::vertex_descriptor>
           vertex_per_cc(nb_cc, GrTr::null_vertex());
 
-        BOOST_FOREACH(typename GrTr::face_descriptor f, faces(tm))
+        for(typename GrTr::face_descriptor f : faces(tm))
         {
           std::size_t cc_id = cc_ids[get(fid_map, f)];
           if  (vertex_per_cc[cc_id] == GrTr::null_vertex())
@@ -601,7 +620,7 @@ public:
                        const std::vector<Point_3>& points_per_cc)
   {
     std::size_t id = get_id_for_new_mesh();
-    CGAL_assertion( m_aabb_trees[id] == NULL );
+    CGAL_assertion( m_aabb_trees[id] == nullptr );
     m_is_closed[id] = is_closed;
     m_own_aabb_trees[id] = false ;
     m_aabb_trees[id] = const_cast<Tree*>(&tree);
@@ -610,25 +629,6 @@ public:
 
     return id;
   }
-
-  // versions without NP
-  static
-  void collect_one_point_per_connected_component(
-    const TriangleMesh& tm,
-          std::vector<typename K::Point_3>& points)
-  {
-    collect_one_point_per_connected_component(tm, points, parameters::all_default());
-  }
-
-  std::size_t add_mesh(const TriangleMesh& tm)
-  {
-    return add_mesh(tm, parameters::all_default());
-  }
-
-  std::size_t add_mesh(const AABB_tree& tree, const TriangleMesh& tm)
-  {
-    return add_mesh(tree, tm, parameters::all_default());
-  }
 #endif
 };
 
