@@ -1,22 +1,11 @@
 // Copyright (C) 2013 INRIA - Sophia Antipolis (France).
 // Copyright (c) 2017 GeometryFactory Sarl (France).
 //
-//This program is free software: you can redistribute it and/or modify
-//it under the terms of the GNU General Public License as published by
-//the Free Software Foundation, either version 3 of the License, or
-//(at your option) any later version.
+// This file is part of CGAL (www.cgal.org).
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
-//
-//You should have received a copy of the GNU General Public License
-//along with this program.  If not, see <http://www.gnu.org/licenses/>.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Scale_space_reconstruction_3/include/CGAL/Scale_space_reconstruction_3/Alpha_shape_mesher.h $
-// $Id: Alpha_shape_mesher.h 8cdfad0 2017-11-15T22:58:57+01:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Scale_space_reconstruction_3/include/CGAL/Scale_space_reconstruction_3/Alpha_shape_mesher.h $
+// $Id: Alpha_shape_mesher.h 46969d6 2022-10-14T10:34:54+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s):      Thijs van Lankveld, Simon Giraudot
 
@@ -35,12 +24,12 @@ namespace CGAL
 
 namespace Scale_space_reconstruction_3
 {
-  
+
 /** \ingroup PkgScaleSpaceReconstruction3Classes
  *
  *  Surface mesher for scale space reconstruction based on
  *  `CGAL::Alpha_shape_3`.
- * 
+ *
  *  The surface can be constructed either for a fixed neighborhood
  *  radius, or for a dynamic radius. When constructing the surface for
  *  exactly one neighborhood radius, it is faster to set
@@ -53,7 +42,7 @@ namespace Scale_space_reconstruction_3
  *  changing the radius of a dynamic surface. In either case, it is possible to
  *  change the point set while maintaining the same radius.
  *
- *  The surface can be stored either as an unordered collection of triangles, 
+ *  The surface can be stored either as an unordered collection of triangles,
  *  or as a collection ordered by shells. A shell is a maximally connected
  *  component of the surface where connected facets are locally oriented
  *  towards the same side of the surface.
@@ -76,8 +65,8 @@ class Alpha_shape_mesher
 public:
   typedef typename Geom_traits::FT FT;
   typedef typename Geom_traits::Point_3                        Point;          ///< defines the point type.
-  
-  typedef CGAL::cpp11::array< unsigned int, 3 >       Facet;                 ///< defines a triple of point indices indicating a triangle of the surface.
+
+  typedef std::array< unsigned int, 3 >       Facet;                 ///< defines a triple of point indices indicating a triangle of the surface.
 private:
   typedef std::list< Facet >                         Facetset;              ///< defines a collection of triples.
   // Note that this is a list for two reasons: iterator validity for the shell iterators, and memory requirements for the expected huge collections.
@@ -95,7 +84,7 @@ private:
   typedef std::vector< Facet_iterator >              FacetIterSet;
 
 private:
-  
+
   // Constructing the surface.
   typedef CGAL::Shape_construction_3<Geom_traits, FixedSurface> Shape_construction_3;
 
@@ -107,7 +96,7 @@ private:
   typedef typename Shape::Facet                       SFacet;
   typedef typename Shape::Edge                        Edge;
   typedef std::pair<Vertex_handle, Vertex_handle>     VEdge;
-    
+
   typedef typename Shape::Vertex_iterator             Vertex_iterator;
   typedef typename Shape::Cell_iterator               Cell_iterator;
   typedef typename Shape::Facet_iterator              SFacet_iterator;
@@ -119,13 +108,13 @@ private:
   typedef typename Shape::Finite_vertices_iterator    Finite_vertices_iterator;
 
   typedef typename Shape::Facet_circulator            SFacet_circulator;
-  
+
   typedef typename Shape::All_cells_iterator          All_cells_iterator;
 
   typedef typename Shape::Classification_type         Classification_type;
-  
+
   typedef std::map<SFacet, unsigned int> Map_facet_to_shell;
-  typedef typename CGAL::cpp11::array<std::set<SFacet>, 2 >   Bubble;
+  typedef typename std::array<std::set<SFacet>, 2 >   Bubble;
 
   bool _separate_shells;
   bool _force_manifold;
@@ -155,14 +144,14 @@ private:
   std::map<SFacet, std::size_t> _map_f2b;
 
   FT _squared_radius;
-  
+
 public:
 
   /**
    *  Constructs an alpha shape mesher.
    *
    *  \param squared_radius \f$\alpha\f$ parameter of the alpha shape algorithm.
-   *  \param separate_shells determines whether to collect the surface per shell. 
+   *  \param separate_shells determines whether to collect the surface per shell.
    *  \param force_manifold determines if the surface is forced to be 2-manifold.
    *  \param border_angle sets the maximal angle between two facets
    *  such that the edge is seen as a border.
@@ -185,12 +174,17 @@ public:
     : _separate_shells (separate_shells),
       _force_manifold (force_manifold),
       _border_angle (border_angle),
-      _shape (NULL),
+      _shape (nullptr),
       _squared_radius (squared_radius)
   {
 
   }
 
+  ~Alpha_shape_mesher ()
+  {
+    clear_surface();
+  }
+
   /// \cond SKIP_IN_MANUAL
   template <typename InputIterator, typename OutputIterator>
   void operator() (InputIterator begin, InputIterator end, OutputIterator output)
@@ -198,7 +192,7 @@ public:
     clear_surface();
 
     _shape = Shape_construction_3().construct (begin, end, _squared_radius);
-    
+
     // If shells are not separated and no manifold constraint is given,
     // then the quick collection of facets can be applied
     if (!_separate_shells && !_force_manifold)
@@ -235,7 +229,7 @@ public:
 
     for (Facet_iterator it = _surface.begin(); it != _surface.end(); ++ it)
     {
-      cpp11::array<std::size_t, 3> f = {{ std::size_t((*it)[0]), std::size_t((*it)[1]), std::size_t((*it)[2]) }};
+      std::array<std::size_t, 3> f = {{ std::size_t((*it)[0]), std::size_t((*it)[1]), std::size_t((*it)[2]) }};
       *(output ++) = f;
     }
   }
@@ -250,7 +244,7 @@ public:
   /** \warning Changes to the surface may change its topology.
    */
   Facet_iterator surface_begin() { return _surface.begin(); }
-    
+
   /// gives a past-the-end iterator of the triples in the surface.
   Facet_const_iterator surface_end() const { return _surface.end(); }
   /// gives a past-the-end iterator of the triples in the surface.
@@ -271,7 +265,7 @@ public:
    */
   Facet_const_iterator shell_begin( std::size_t shell ) const
   {
-    CGAL_assertion( shell >= 0 && shell < _shells.size() );
+    CGAL_assertion( shell < _shells.size() );
     return _shells[ shell ];
   }
   /// gives an iterator to the first triple in a given shell.
@@ -283,7 +277,7 @@ public:
    */
   Facet_iterator shell_begin( std::size_t shell )
   {
-    CGAL_assertion( shell >= 0 && shell < _shells.size() );
+    CGAL_assertion( shell < _shells.size() );
     return _shells[ shell ];
   }
 
@@ -294,7 +288,7 @@ public:
    */
   Facet_const_iterator shell_end( std::size_t shell ) const
   {
-    CGAL_assertion( shell >= 0 && shell < _shells.size() );
+    CGAL_assertion( shell < _shells.size() );
     if( shell == _shells.size()-1 )
       return _surface.end();
     return _shells[ shell+1 ];
@@ -309,19 +303,19 @@ public:
    */
   Facet_iterator shell_end( std::size_t shell )
   {
-    CGAL_assertion( shell >= 0 && shell < _shells.size() );
+    CGAL_assertion( shell < _shells.size() );
     if( shell == _shells.size()-1 )
         return _surface.end();
     return _shells[ shell+1 ];
   }
-  
+
   /// gives an iterator to the first triple of the garbage facets
   /// that may be discarded if 2-manifold output is required.
   Facet_const_iterator garbage_begin() const { return _garbage.begin(); }
   /// gives an iterator to the first triple of the garbage facets
   /// that may be discarded if 2-manifold output is required.
   Facet_iterator garbage_begin() { return _garbage.begin(); }
-    
+
   /// gives a past-the-end iterator of the triples of the garbage facets
   /// that may be discarded if 2-manifold output is required.
   Facet_const_iterator garbage_end() const { return _garbage.end(); }
@@ -330,16 +324,16 @@ public:
   Facet_iterator garbage_end() { return _garbage.end(); }
 
 private:
-  
+
   void deinit_shape()
   {
-    if (_shape != NULL)
+    if (_shape != nullptr)
     {
       delete _shape;
-      _shape = NULL;
+      _shape = nullptr;
     }
   }
-  
+
   void clear_surface()
   {
     _shells.clear();
@@ -347,7 +341,7 @@ private:
     _garbage.clear();
     deinit_shape();
   }
-  
+
   void collect_facets ()
   {
     // We check each of the facets: if it is not handled and either regular or singular,
@@ -398,7 +392,7 @@ private:
       }
     }
   }
-  
+
   inline bool is_handled( Cell_handle c, unsigned int li ) const
   {
     switch( li ) {
@@ -421,7 +415,7 @@ private:
     }
   }
   inline void mark_handled( SFacet f ) { mark_handled( f.first, f.second ); }
- 
+
   inline void mark_opposite_handled( SFacet f )
   {
 
@@ -438,30 +432,30 @@ private:
     else if (cl == Shape::REGULAR)
     {
       SFacet fac = (_shape->classify (f.first) == Shape::EXTERIOR)
-	? f
-	: _shape->mirror_facet (f);
+        ? f
+        : _shape->mirror_facet (f);
 
       typename std::map<SFacet, std::size_t>::iterator
-	search = _map_f2b.find (fac);
+        search = _map_f2b.find (fac);
 
       if (search == _map_f2b.end ())
-	return;
-      
+        return;
+
       unsigned int layer = (_bubbles[search->second][0].find (fac) == _bubbles[search->second][0].end ())
-	? 0 : 1;
+        ? 0 : 1;
 
       typename std::set<SFacet>::iterator it = _bubbles[search->second][layer].begin ();
 
       // If bubble has already been handled, no need to do it again
       if (is_handled (*it))
-	return;
-      
+        return;
+
       for (;it != _bubbles[search->second][layer].end (); ++ it)
       {
         _garbage.push_back (ordered_facet_indices (*it));
         mark_handled (*it);
       }
-      
+
     }
 
 
@@ -531,7 +525,7 @@ private:
       // the opposite layer should be ignored
       if (_force_manifold)
         mark_opposite_handled (f);
-		
+
       // Pivot over each of the facet's edges and continue the surface at the next regular or singular facet.
       for( int i = 0; i < 4; ++i ) {
         // Skip the current facet.
@@ -543,7 +537,7 @@ private:
         ni = i;
         a = f.first->vertex( f.second );
         cl = _shape->classify( SFacet(n, ni) );
-	    
+
         while( cl != Shape::REGULAR && cl != Shape::SINGULAR ) {
           p = n;
           n = n->neighbor(ni);
@@ -565,17 +559,14 @@ private:
   {
     std::set<Cell_handle> done;
 
-    unsigned int nb_facets_removed = 0;
-  
-    unsigned int nb_skipped = 0;
     for (Cell_iterator cit = _shape->cells_begin (); cit != _shape->cells_end (); ++ cit)
     {
       if (_shape->is_infinite (cit))
-	continue;
+        continue;
       if (_shape->classify (cit) != Shape::INTERIOR)
-	continue;
+        continue;
       if (done.find (cit) != done.end ())
-	continue;
+        continue;
 
       std::set<VEdge> borders;
       std::vector<Cell_handle> cells;
@@ -644,7 +635,7 @@ private:
               if (_shape->classify (f0) != Shape::REGULAR
                   || _shape->classify (f1) != Shape::REGULAR)
                 continue;
-		      
+
               double angle = Geom_traits().compute_approximate_dihedral_angle_3_object()(vedge.first->point (),
                                                                                          vedge.second->point (),
                                                                                          c->vertex (i)->point (),
@@ -678,7 +669,7 @@ private:
             continue;
 
           ++ layer;
-	      
+
           std::stack<SFacet> stack;
           stack.push (start);
 
@@ -708,7 +699,6 @@ private:
               }
               else
               {
-                nb_facets_removed ++;
                 mark_handled (f);
                 _garbage.push_back (ordered_facet_indices (f));
               }
@@ -722,7 +712,6 @@ private:
               }
               else
               {
-                nb_facets_removed ++;
                 mark_handled (_shape->mirror_facet (f));
                 _garbage.push_back (ordered_facet_indices (_shape->mirror_facet (f)));
               }
@@ -766,7 +755,7 @@ private:
               // If the edge is a border, propagation stops in this direction.
               if (borders.find (vedge) != borders.end ())
                 continue;
-		      
+
               while( cl != Shape::REGULAR && cl != Shape::SINGULAR ) {
                 p = n;
                 n = n->neighbor(ni);
@@ -775,7 +764,7 @@ private:
                 a = n->vertex(pi);
                 cl = _shape->classify( SFacet(n, ni) );
               }
-		      
+
               stack.push (SFacet (n, ni));
 
             }
@@ -784,11 +773,10 @@ private:
         }
 
       }
-            
+
       // If number of layers is != 2, ignore volume and discard bubble
       if (layer != 1)
       {
-        nb_skipped ++;
         for (unsigned int i = 0; i < 2; ++ i)
           for (typename std::set<SFacet>::iterator fit = _bubbles.back()[i].begin ();
                fit != _bubbles.back()[i].end (); ++ fit)
@@ -796,14 +784,13 @@ private:
             mark_handled (*fit);
             _map_f2b.erase (*fit);
             _garbage.push_back (ordered_facet_indices (*fit));
-            nb_facets_removed ++;
           }
         _bubbles.pop_back ();
       }
-      
+
     }
   }
-  
+
 
   void fix_nonmanifold_edges()
   {
@@ -811,27 +798,23 @@ private:
     typedef std::map<std::pair<VEdge, unsigned int>, std::set<Facet> > Edge_shell_map_triples;
     typedef typename Edge_shell_map_triples::iterator Edge_shell_map_triples_iterator;
 
-    unsigned int nb_facets_removed = 0;
-
-    unsigned int nb_nm_edges = 0;
-
     // Store for each pair edge/shell the incident facets
     Edge_shell_map_triples eshell_triples;
     std::map<Facet, SFacet> map_t2f;
-  
+
     for (typename Map_facet_to_shell::iterator fit = _map_f2s.begin ();
          fit != _map_f2s.end (); ++ fit)
     {
       SFacet f = fit->first;
       Facet t = ordered_facet_indices (f);
       map_t2f[t] = f;
-	      
+
       for (unsigned int k = 0; k < 3; ++ k)
       {
         Vertex_handle v0 = f.first->vertex ((f.second + k + 1)%4);
         Vertex_handle v1 = f.first->vertex ((f.second + (k+1)%3 + 1)%4);
         VEdge vedge = (v0 < v1) ? std::make_pair (v0, v1) : std::make_pair (v1, v0);
-		  
+
         std::pair<Edge_shell_map_triples_iterator, bool>
           search = eshell_triples.insert (std::make_pair (std::make_pair (vedge, fit->second),
                                                           std::set<Facet>()));
@@ -845,13 +828,11 @@ private:
     {
       // If an edge has more than 2 incident facets for one shell, it is non-manifold
       if (eit->second.size () < 3)
-	continue;
-
-      ++ nb_nm_edges;
+        continue;
 
       Facet_iterator tit = _shells[eit->first.second];
       Facet_iterator end = (eit->first.second == _shells.size () - 1)
-	? _surface.end () : _shells[eit->first.second + 1];
+        ? _surface.end () : _shells[eit->first.second + 1];
 
       // Remove facets until the edge is manifold in this shell
       while (tit != end && eit->second.size () > 2)
@@ -869,12 +850,11 @@ private:
           _map_f2s.erase (map_t2f[*current]);
           _surface.erase (current);
 
-          ++ nb_facets_removed;
           eit->second.erase (search);
         }
 
       }
-	  
+
     }
   }
 
@@ -893,7 +873,7 @@ private:
   {
     Vertex_handle vother = f.first->vertex (f.second);
     bool v1found = false;
-  
+
     for (unsigned int i = 0; i < 4; ++ i)
     {
       Vertex_handle vi = f.first->vertex (i);
@@ -912,7 +892,7 @@ private:
       }
     }
   }
-  
+
   void fix_nonmanifold_vertices()
   {
 
@@ -928,32 +908,30 @@ private:
     {
       Facet_iterator begin = _shells[i];
       Facet_iterator end = (i+1 == _shells.size ()) ? _surface.end () : _shells[i+1];
-      
+
       Facetset tmp;
       tmp.splice (tmp.end(), _surface, begin, end);
-      
+
       tmp.sort();
-      _shells[i] = tmp.begin ();      
+      _shells[i] = tmp.begin ();
       _surface.splice(end, tmp, tmp.begin(), tmp.end());
     }
 
-    unsigned int nb_facets_removed = 0;
     unsigned int nb_nm_vertices = 0;
     // Removing facets to fix non-manifold vertices might make some other vertices
     // become non-manifold, therefore we iterate until no facet needs to be removed.
     do
     {
       nb_nm_vertices = 0;
-      nb_facets_removed = 0;
 
       // Store for each pair vertex/shell the incident facets
       Vertex_shell_map_facets vshell_facets;
 
       for (typename Map_facet_to_shell::iterator fit = _map_f2s.begin ();
-	   fit != _map_f2s.end (); ++ fit)
+           fit != _map_f2s.end (); ++ fit)
       {
         SFacet f = fit->first;
-	  
+
         for (unsigned int k = 0; k < 3; ++ k)
         {
           Vertex_handle v = f.first->vertex ((f.second+k+1)%4);
@@ -964,11 +942,11 @@ private:
           search.first->second.push_back (f);
 
         }
-	  
+
       }
 
       for (Vertex_shell_map_facet_iterator fit = vshell_facets.begin ();
-	   fit != vshell_facets.end (); ++ fit)
+           fit != vshell_facets.end (); ++ fit)
       {
         if (fit->second.size () < 2)
           continue;
@@ -978,12 +956,12 @@ private:
 
         UF uf;
         std::map<SFacet, UF_handle> map_f2h;
-	  
+
         for (unsigned int i = 0; i < fit->second.size (); ++ i)
           map_f2h.insert (std::make_pair (fit->second[i], uf.make_set (fit->second[i])));
 
         std::map<Vertex_handle, SFacet> map_v2f;
-	    
+
         for (unsigned int i = 0; i < fit->second.size (); ++ i)
         {
           Vertex_handle v1, v2;
@@ -1045,7 +1023,7 @@ private:
             ? _surface.end () : _shells[shell + 1];
 
           unsigned int tindex = 0;
-	      
+
           while (tit != end && tindex < triples.size ())
           {
             Facet_iterator current = tit ++;
@@ -1058,7 +1036,6 @@ private:
               _garbage.push_back (*current);
               _surface.erase (current);
 
-              ++ nb_facets_removed;
               ++ tindex;
             }
 
@@ -1074,7 +1051,7 @@ private:
 
 };
 
-  
+
 } // namespace Scale_space_reconstruction_3
 
 } // namespace CGAL
