@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Segment_Delaunay_graph_Linf_2/include/CGAL/Segment_Delaunay_graph_Linf_2/Segment_Delaunay_graph_Linf_2_impl.h $
+// $Id: Segment_Delaunay_graph_Linf_2_impl.h 7ea0f8b 2022-10-21T09:14:58+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Segment_Delaunay_graph_Linf_2/include/CGAL/Segment_Delaunay_graph_Linf_2/Segment_Delaunay_graph_Linf_2_impl.h $
-// $Id: Segment_Delaunay_graph_Linf_2_impl.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Panagiotis Cheilaris, Sandeep Kumar Dey, Evanthia Papadopoulou
 //philaris@gmail.com, sandeep.kr.dey@gmail.com, evanthia.papadopoulou@usi.ch
@@ -27,7 +18,7 @@ template<class Gt, class ST, class D_S, class LTag>
 void
 Segment_Delaunay_graph_Linf_2<Gt,ST,D_S,LTag>::
 face_output(const char *before, Face_handle f,
-	    const char *after) const
+            const char *after) const
 {
   std::cout << before;
   if (is_infinite(f->vertex(0))) {
@@ -114,6 +105,7 @@ find_faces_to_split(const Vertex_handle& v, const Site_2& t,
     Face_circulator fc_start = fc;
     int n_inf = 0;
     int n_faces = 0;
+    CGAL_USE(n_faces);
     do {
       if ( is_infinite(fc) ) { n_inf++; }
       fc++;
@@ -297,7 +289,7 @@ find_faces_to_split(const Vertex_handle& v, const Site_2& t,
     // before it was:
     //   os1 == ON_POSITIVE_SIDE && os2 != ON_POSITIVE_SIDE
     if ( !found_f2 &&
-	 os1 != ON_NEGATIVE_SIDE && os2 == ON_NEGATIVE_SIDE ) {
+         os1 != ON_NEGATIVE_SIDE && os2 == ON_NEGATIVE_SIDE ) {
       f2 = ff2;
       found_f2 = true;
       count_pon_zeros = count_zeros;
@@ -485,7 +477,7 @@ template<class Gt, class ST, class D_S, class LTag>
 typename Segment_Delaunay_graph_Linf_2<Gt,ST,D_S,LTag>::Vertex_triple
 Segment_Delaunay_graph_Linf_2<Gt,ST,D_S,LTag>::
 insert_exact_point_on_segment(const Storage_site_2& ss, const Site_2& t,
-			      Vertex_handle v)
+                              Vertex_handle v)
 {
   // splits the segment site v->site() in two and inserts represented by t
   // on return the three vertices are, respectively, the vertex
@@ -624,7 +616,7 @@ template<class Gt, class ST, class D_S, class LTag>
 typename Segment_Delaunay_graph_Linf_2<Gt,ST,D_S,LTag>::Vertex_triple
 Segment_Delaunay_graph_Linf_2<Gt,ST,D_S,LTag>::
 insert_point_on_segment(const Storage_site_2& ss, const Site_2& ,
-			Vertex_handle v, const Tag_true&)
+                        Vertex_handle v, const Tag_true&)
 {
   // splits the segment site v->site() in two and inserts the point of
   // intersection of t and v->site()
