@@ -1,19 +1,10 @@
 // Copyright (c) 2005, 2006 Fernando Luis Cacciola Carballal. All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Straight_skeleton_2/include/CGAL/Straight_skeleton_2/Polygon_offset_builder_2_impl.h $
-// $Id: Polygon_offset_builder_2_impl.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Straight_skeleton_2/include/CGAL/Straight_skeleton_2/Polygon_offset_builder_2_impl.h $
+// $Id: Polygon_offset_builder_2_impl.h b3523fd 2023-02-23T11:14:48+01:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
 //
@@ -22,6 +13,8 @@
 
 #include <CGAL/license/Straight_skeleton_2.h>
 
+#include <algorithm>
+#include <vector>
 
 namespace CGAL {
 
@@ -57,12 +50,13 @@ Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::Polygon_offset_builder_2( Ss const
 template<class Ss, class Gt, class Cont, class Visitor>
 typename Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::Halfedge_const_handle
 Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateHook( FT                    aTime
-                                                        , Halfedge_const_handle aBisector 
+                                                        , Halfedge_const_handle aBisector
                                                         , bool                  aIncludeLastBisector
                                                         , Hook_position&        rPos
                                                         )
 {
-  CGAL_POLYOFFSET_TRACE(2,"Searching for hook at " << aTime ) ;
+  CGAL_POLYOFFSET_TRACE(2,"Locate hook at T=" << aTime ) ;
+  CGAL_POLYOFFSET_TRACE(2,"Start halfedge: " << e2str(*aBisector) ) ;
 
   Halfedge_const_handle rHook ;
 
@@ -70,11 +64,11 @@ Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateHook( FT
   {
     Halfedge_const_handle lPrev = aBisector->prev();
     Halfedge_const_handle lNext = aBisector->next();
-    
+
     CGAL_POLYOFFSET_TRACE(2,"Testing hook on " << e2str(*aBisector) ) ;
-                          
-    CGAL_POLYOFFSET_TRACE(4, "Next: " << e2str(*lNext) << " - Prev: " << e2str(*lPrev) ) ;
-                          
+    CGAL_POLYOFFSET_TRACE(4, "Next: " << e2str(*lNext) ) ;
+    CGAL_POLYOFFSET_TRACE(4, "Prev: " << e2str(*lPrev) ) ;
+
     if ( !IsVisited(aBisector) )
     {
       if ( aBisector->slope() != ZERO )
@@ -86,11 +80,14 @@ Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateHook( FT
         //
         //  (src-time <= time <= tgt-time ) || ( tgt-time <= time <= src-time )
         //
-        
+
         Comparison_result lTimeWrtSrcTime = lPrev->is_bisector() ? Compare_offset_against_event_time(aTime,lPrev    ->vertex()) : LARGER ;
         Comparison_result lTimeWrtTgtTime = lNext->is_bisector() ? Compare_offset_against_event_time(aTime,aBisector->vertex()) : LARGER ;
+        CGAL_POLYOFFSET_TRACE(3,"  lPrev->is_bisector(): " << lPrev->is_bisector() << " lNext->is_bisector(): " << lNext->is_bisector());
+        CGAL_POLYOFFSET_TRACE(3,"  lPrev->vertex()->time(): " << lPrev->vertex()->time());
+        CGAL_POLYOFFSET_TRACE(3,"  aBisector->vertex()->time(): " << aBisector->vertex()->time());
         CGAL_POLYOFFSET_TRACE(3,"  TimeWrtSrcTime: " << lTimeWrtSrcTime << " TimeWrtTgtTime: " << lTimeWrtTgtTime ) ;
-        
+
         //
         // The above test expressed in terms of comparisons of src/tgt time against aTime is:
         //
@@ -104,60 +101,38 @@ Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateHook( FT
         //     && ( time-wrt-src-time == ZERO || time-wrt-src-time == LARGER  )
         // )
         //
-        // But since bisectors of slope zero are skipped, both comparisons cannot be zero, thus, the test above is really: 
+        // But since bisectors of slope zero are skipped, both comparisons cannot be zero, thus, the test above is really:
         //
         //    ( ( time-wrt-src-time == ZERO || time-wrt-src-time == SMALLER )  && (                              time-wrt-tgt-time == LARGER ) )
         // || ( (                              time-wrt-src-time == SMALLER )  && ( time-wrt-tgt-time == ZERO || time-wrt-tgt-time == LARGER ) )
         // || ( ( time-wrt-tgt-time == ZERO || time-wrt-tgt-time == SMALLER )  && (                              time-wrt-src-time == LARGER ) )
         // || ( (                              time-wrt-tgt-time == SMALLER )  && ( time-wrt-src-time == ZERO || time-wrt-src-time == LARGER ) )
-        // 
+        //
         // Which actually boils down to this:
         //
         if ( lTimeWrtSrcTime != lTimeWrtTgtTime )
         {
-          CGAL_stskel_intrinsic_test_assertion( !CGAL_SS_i::is_time_clearly_not_within_possibly_inexact_bisector_time_interval(aTime,aBisector) ) ;
-          
-          bool lLocalPeak = false ;
-          
-          if ( aBisector->slope() == POSITIVE && lTimeWrtSrcTime == EQUAL )
-          {
-            Halfedge_const_handle lPrev = aBisector->prev();
-            while ( lPrev->is_bisector() && ( lPrev->slope() == ZERO ) )
-             lPrev = lPrev->prev();
-             
-            lLocalPeak = ( lPrev->slope() == NEGATIVE ) ;
-          }   
-        
-          if ( !lLocalPeak )
-          {
-            rPos = ( lTimeWrtTgtTime == EQUAL ? TARGET : lTimeWrtSrcTime == EQUAL ? SOURCE : INSIDE ) ; 
-            
-            rHook = aBisector ;
-            
-            CGAL_POLYOFFSET_TRACE(2, "  Hook found here at " << Hook_position2Str(rPos) ) ;
-            
-            break ;
-          }
-          else
-          {
-            CGAL_POLYOFFSET_TRACE(2, "  Hook found here local peak. Ignored." ) ;
-          }
+          rPos = ( lTimeWrtTgtTime == EQUAL ? TARGET : lTimeWrtSrcTime == EQUAL ? SOURCE : INSIDE ) ;
+
+          rHook = aBisector ;
+
+          CGAL_POLYOFFSET_TRACE(2, "  Hook found here on " << e2str(*aBisector) << "(" << Hook_position2Str(rPos) << ")" ) ;
+
+          break ;
         }
         else
         {
-          CGAL_stskel_intrinsic_test_assertion( !CGAL_SS_i::is_time_clearly_within_possibly_inexact_bisector_time_interval(aTime,aBisector) ) ;
-          
-          CGAL_POLYOFFSET_TRACE(2, "  Hook not found here.") ;
+          CGAL_POLYOFFSET_TRACE(2, "  Hook not found on." << e2str(*aBisector) ) ;
         }
-      }  
+      }
       else
       {
-        CGAL_POLYOFFSET_TRACE(2,"Bisector is a roof peak.");  
+        CGAL_POLYOFFSET_TRACE(2, e2str(*aBisector) << " is a roof peak (zero slope).");
       }
     }
     else
     {
-      CGAL_POLYOFFSET_TRACE(2,"Bisector already visited");  
+      CGAL_POLYOFFSET_TRACE(2,"Bisector already visited");
     }
     aBisector = lPrev ;
   }
@@ -169,8 +144,8 @@ template<class Ss, class Gt, class Cont, class Visitor>
 typename Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::Halfedge_const_handle
 Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateSeed( FT aTime, Halfedge_const_handle aBorder )
 {
-  CGAL_POLYOFFSET_TRACE(2,"\nLocating seed for face " << e2str(*aBorder) ) ;
-    
+  CGAL_POLYOFFSET_TRACE(2,"\nSearching for a starting seed in face " << e2str(*aBorder) ) ;
+
   Hook_position lPos ;
   Halfedge_const_handle rSeed = LocateHook(aTime,aBorder->prev(),false,lPos);
   if ( handle_assigned(rSeed) )
@@ -178,14 +153,15 @@ Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateSeed( FT aTime, Halfedge_con
     if ( !IsUsedSeed(rSeed) )
     {
       SetIsUsedSeed(rSeed);
-      
-      CGAL_postcondition( rSeed->prev()->is_bisector() ) ;
-      
-      // If a seed hook is found right at a bisector source, 
-      // the next hook will be found right at the prev bisector's target, which would be a mistake,
-      // so we ajust the seed as the (target) of the prev 
+
+      CGAL_postcondition( handle_assigned(rSeed->prev()) && rSeed->prev()->is_bisector() ) ;
+
+      // If a seed hook is found at a bisector's source,
+      // the next hook will be found at the previous bisector's target, which would be a mistake.
+      // So, we modify the seed to be the target() of the previous halfedge instead.
       if ( lPos == SOURCE )
         rSeed = rSeed->prev() ;
+      CGAL_POLYOFFSET_TRACE(2,"Pos at source switched to pos at target on " << e2str(*rSeed) ) ;
     }
     else
     {
@@ -201,7 +177,7 @@ template<class Ss, class Gt, class Cont, class Visitor>
 typename Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::Halfedge_const_handle
 Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateSeed( FT aTime )
 {
-  CGAL_POLYOFFSET_TRACE(2,"Searching for seed at " << aTime ) ;
+  CGAL_POLYOFFSET_TRACE(2,"Searching for a starting seed at T=" << aTime ) ;
 
   Halfedge_const_handle rSeed ;
 
@@ -210,9 +186,9 @@ Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateSeed( FT aTime )
        ; ++ f
       )
     rSeed = LocateSeed(aTime,*f);
-  
-  CGAL_POLYOFFSET_TRACE(2,"Seed:" << eh2str(rSeed) ) ;
-  
+
+  CGAL_POLYOFFSET_TRACE(2,"Found seed: " << eh2str(rSeed) ) ;
+
   return rSeed;
 }
 
@@ -220,24 +196,21 @@ Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::LocateSeed( FT aTime )
 template<class Ss, class Gt, class Cont, class Visitor>
 void Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::AddOffsetVertex( FT                    aTime
                                                                   , Halfedge_const_handle aHook
-                                                                  , ContainerPtr          aPoly 
+                                                                  , ContainerPtr          aPoly
                                                                   )
 {
-  Visit(aHook);
-
   OptionalPoint_2 lP = Construct_offset_point(aTime,aHook);
 
   if ( !lP )
     lP = mVisitor.on_offset_point_overflowed(aHook) ;
-    
+
   CGAL_postcondition(bool(lP));
-  
+
   CGAL_POLYOFFSET_TRACE(1,"Found offset point p=" << p2str(*lP) << " at offset " << aTime << " along bisector " << e2str(*aHook) << " reaching " << v2str(*aHook->vertex()) ) ;
-  
-  mVisitor.on_offset_point(*lP);
-  
+
   if ( lP != mLastPoint )
   {
+    mVisitor.on_offset_point(*lP,aHook);
     aPoly->push_back(*lP);
     mLastPoint = lP ;
   }
@@ -258,41 +231,56 @@ OutputIterator Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::TraceOffsetPolygon(
   ContainerPtr lPoly( new Container() ) ;
 
   mVisitor.on_offset_contour_started();
-  
+
   Halfedge_const_handle lHook = aSeed ;
   std::vector <Halfedge_const_handle > visited_hooks;
   do
   {
     CGAL_POLYOFFSET_TRACE(1,"STEP " << mStepID ) ;
-    
+
     Halfedge_const_handle lLastHook = lHook ;
+
     Hook_position lPos ;
     lHook = LocateHook(aTime,lHook->prev(),true,lPos) ;
-    Visit(lLastHook);
-    
-    if ( handle_assigned(lHook) ) 
+
+    if ( handle_assigned(lHook) )
     {
+      CGAL_POLYOFFSET_TRACE(4, "returned Hook: " << e2str(*lHook));
+
+      CGAL_assertion( lHook->slope() != ZERO );
       AddOffsetVertex(aTime,lHook, lPoly);
-      CGAL_POLYOFFSET_TRACE(1,"B" << lLastHook->id() << " and B" << lHook->id() << " visited." ) ;
+
+      Visit(lHook);
+      visited_hooks.push_back(lHook);
+
+      CGAL_POLYOFFSET_TRACE(2,"Marking hook, B" << lHook->id() << ", as visited." ) ;
 
       lHook = lHook->opposite();
-      
-      visited_hooks.push_back(lLastHook);
     }
-    
+
+    Visit(lLastHook);
+    visited_hooks.push_back(lLastHook);
+
+    CGAL_POLYOFFSET_TRACE(2,"Marking last hook, B" << lLastHook->id() << ", as visited." ) ;
   }
-  while ( handle_assigned(lHook) && lHook != aSeed  && !IsVisited(lHook)) ;
+  while ( handle_assigned(lHook) && lHook != aSeed && !IsVisited(lHook)) ;
 
   bool lComplete = ( lHook == aSeed )  ;
-  
+
   CGAL_POLYOFFSET_TRACE(1,"Offset polygon of " << lPoly->size() << " vertices traced." << ( lComplete ? "COMPLETE" : "INCOMPLETE" ) ) ;
-  
-  CGAL_assertion ( !lComplete || ( lComplete && lPoly->size() >= 3 ) ) ;
-  
+
+  // On paper, lComplete == true should imply that lPoly->size() >= 3, but since the constructions
+  // might not be exact, you can have cases where the offset points are actually duplicates
+  // and so the end polygon has size < 3. It is ignored in that case.
+  if ( lComplete && lPoly->size() < 3 )
+    lComplete = false;
+
   mVisitor.on_offset_contour_finished( lComplete );
-  
+
   if ( lComplete )
+  {
     *aOut++ = lPoly ;
+  }
   else
   {
     for (std::size_t k=0;k<visited_hooks.size();++k)
@@ -314,117 +302,44 @@ template<class Ss, class Gt, class Cont, class Visitor>
 template<class OutputIterator>
 OutputIterator Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::construct_offset_contours( FT aTime, OutputIterator aOut )
 {
-  CGAL_precondition( aTime > static_cast<FT>(0.0) ) ;
+  CGAL_precondition( aTime > static_cast<FT>(0) ) ;
 
   CGAL_POLYOFFSET_DEBUG_CODE( mStepID = 0 ) ;
 
   mVisitor.on_construction_started(aTime);
-  
+
   mLastPoint = boost::none ;
-  
+
   ResetBisectorData();
 
   CGAL_POLYOFFSET_TRACE(1,"Constructing offset polygons for offset: " << aTime ) ;
   for ( Halfedge_const_handle lSeed = LocateSeed(aTime); handle_assigned(lSeed); lSeed = LocateSeed(aTime) )
     aOut = TraceOffsetPolygon(aTime,lSeed,aOut);
-  
+
   mVisitor.on_construction_finished();
-  
+
   return aOut ;
 }
 
 template<class Ss, class Gt, class Cont, class Visitor>
 typename Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::Trisegment_2_ptr
-Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::CreateTrisegment ( Vertex_const_handle aNode ) const
+Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::GetTrisegment ( Vertex_const_handle aNode ) const
 {
   CGAL_precondition(handle_assigned(aNode));
-  
+
   Trisegment_2_ptr r ;
-  
-  CGAL_POLYOFFSET_TRACE(3,"Creating Trisegment for " << v2str(*aNode) ) ;
-  
+
+  CGAL_POLYOFFSET_TRACE(3,"Getting Trisegment for " << v2str(*aNode) ) ;
+
   if ( aNode->is_skeleton() )
   {
-    Triedge const& lEventTriedge =  aNode->event_triedge() ;
-    
-    r = CreateTrisegment(lEventTriedge) ;
-    
-    CGAL_stskel_intrinsic_test_assertion
-    (
-      !CGAL_SS_i::is_possibly_inexact_distance_clearly_not_equal_to( Construct_ss_event_time_and_point_2(mTraits)(r)->get<0>()
-                                                                   , aNode->time()
-                                                                   )  
-    ) ;
-    
-    CGAL_POLYOFFSET_TRACE(3,"Event triedge=" << lEventTriedge ) ;
-    
-    if ( r->degenerate_seed_id() == Trisegment_2::LEFT )
-    {
-     CGAL_POLYOFFSET_TRACE(3,"Left seed is degenerate." ) ;
-      
-      Vertex_const_handle lLeftSeed = GetSeedVertex(aNode
-                                                   ,aNode->primary_bisector()->prev()->opposite()
-                                                   ,lEventTriedge.e0()
-                                                   ,lEventTriedge.e1()
-                                                   ) ; 
-      if ( handle_assigned(lLeftSeed) ) 
-        r->set_child_l( CreateTrisegment(lLeftSeed) ) ; // Recursive call
-    }
-    else if ( ! aNode->is_split() && r->degenerate_seed_id() == Trisegment_2::RIGHT )
-    {
-      CGAL_POLYOFFSET_TRACE(3,"Right seed is degenerate." ) ;
-      
-      Vertex_const_handle lRightSeed = GetSeedVertex(aNode
-                                                    ,aNode->primary_bisector()->opposite()->next()
-                                                    ,lEventTriedge.e1()
-                                                    ,lEventTriedge.e2()
-                                                    ) ; 
-      if ( handle_assigned(lRightSeed) ) 
-        r->set_child_r( CreateTrisegment(lRightSeed) ) ; // Recursive call
-    }
+    r = aNode->trisegment() ;
+    CGAL_assertion(bool(r));
   }
-    
+
   return r ;
 }
 
-template<class Ss, class Gt, class Cont, class Visitor>
-typename Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::Vertex_const_handle
-Polygon_offset_builder_2<Ss,Gt,Cont,Visitor>::GetSeedVertex ( Vertex_const_handle   aNode
-                                                            , Halfedge_const_handle aBisector
-                                                            , Halfedge_const_handle aEa
-                                                            , Halfedge_const_handle aEb 
-                                                            ) const
-{
-  Vertex_const_handle rSeed ;
-    
-  if ( Is_bisector_defined_by(aBisector,aEa,aEb) )
-  {
-    rSeed = aBisector->vertex();
-    
-    CGAL_POLYOFFSET_TRACE(3,"Seed of N" << aNode->id() << " for vertex (E" << aEa->id() << ",E" << aEb->id() << ") directly found: V" << rSeed->id() ) ;
-  }
-  else 
-  {
-    typedef typename Vertex::Halfedge_around_vertex_const_circulator Halfedge_around_vertex_const_circulator ;
-    
-    Halfedge_around_vertex_const_circulator cb = aNode->halfedge_around_vertex_begin() ;
-    Halfedge_around_vertex_const_circulator c  = cb ;
-    do
-    {
-      Halfedge_const_handle lBisector = *c ;
-      if ( Is_bisector_defined_by(lBisector,aEa,aEb) )
-      {
-        rSeed = lBisector->opposite()->vertex();
-        CGAL_POLYOFFSET_TRACE(3,"Seed of N" << aNode->id() << " for vertex (E" << aEa->id() << ",E" << aEb->id() << ") indirectly found: V" << rSeed->id() ) ;
-      }
-    }
-    while ( !handle_assigned(rSeed) && ++ c != cb ) ;
-  }
-  
-  return rSeed ;
-}
+} // namespace CGAL
 
-} // end namespace CGAL
-
-#endif // CGAL_POLYGON_OFFSET_BUILDER_2_IMPL_H //
-// EOF //
+#endif // CGAL_POLYGON_OFFSET_BUILDER_2_IMPL_H
