@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Surface_mesh_deformation/include/CGAL/Surface_mesh_deformation.h $
-// $Id: Surface_mesh_deformation.h a2e8a1c 2018-09-04T11:11:41+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Surface_mesh_deformation/include/CGAL/Surface_mesh_deformation.h $
+// $Id: Surface_mesh_deformation.h f0443a6 2022-11-08T14:43:19+01:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Yin Xu, Andreas Fabri and Ilker O. Yaz
 
@@ -25,18 +16,18 @@
 
 #include <CGAL/disable_warnings.h>
 
+#include <CGAL/assertions.h>
+#include <CGAL/boost/graph/named_params_helper.h>
 #include <CGAL/config.h>
 #include <CGAL/Default.h>
 #include <CGAL/tuple.h>
-
-#include <CGAL/Polygon_mesh_processing/Weights.h>
 #include <CGAL/Simple_cartesian.h>
+#include <CGAL/Weights/cotangent_weights.h>
 
 #include <vector>
 #include <list>
 #include <utility>
 #include <limits>
-#include <boost/foreach.hpp>
 
 /*
 #define CGAL_DEFORM_MESH_USE_EXPERIMENTAL_SCALE // define it to activate optimal scale calculation,
@@ -63,94 +54,14 @@ enum Deformation_algorithm_tag
 
 /// @cond CGAL_DOCUMENT_INTERNAL
 namespace internal {
-template<class TriangleMesh, Deformation_algorithm_tag deformation_algorithm_tag>
-struct Types_selectors;
-
-template<class TriangleMesh>
-struct Types_selectors<TriangleMesh, CGAL::SPOKES_AND_RIMS> {
-  typedef internal::Single_cotangent_weight_impl<TriangleMesh> Weight_calculator;
-
-  struct ARAP_visitor{
-    template <class VertexPointMap>
-    void init(TriangleMesh, VertexPointMap){}
-
-    void rotation_matrix_pre(
-      typename boost::graph_traits<TriangleMesh>::vertex_descriptor,
-      TriangleMesh&){}
-
-    template <class Square_matrix_3>
-    void update_covariance_matrix(
-      Square_matrix_3&,
-      const Square_matrix_3&){}
-
-    void set_sre_arap_alpha(double){}
-  };
-};
-
-template<class TriangleMesh>
-struct Types_selectors<TriangleMesh, CGAL::ORIGINAL_ARAP> {
-  typedef internal::Cotangent_weight_impl<TriangleMesh> Weight_calculator;
-
-  typedef typename Types_selectors<TriangleMesh, CGAL::SPOKES_AND_RIMS>
-    ::ARAP_visitor ARAP_visitor;
-};
-
-template<class TriangleMesh>
-struct Types_selectors<TriangleMesh, CGAL::SRE_ARAP> {
-  typedef internal::Cotangent_weight_impl<TriangleMesh> Weight_calculator;
-
-  class ARAP_visitor{
-    double m_nb_edges_incident;
-    double m_area;
-    double m_alpha;
-
-  public:
-    ARAP_visitor(): m_alpha(0.02) {}
-
-    template<class VertexPointMap>
-    void init(TriangleMesh triangle_mesh, const VertexPointMap& vpmap)
-    {
-      // calculate area
-      m_area = 0;
-      typedef typename boost::graph_traits<TriangleMesh>::face_descriptor face_descriptor;
-      BOOST_FOREACH(face_descriptor f, faces(triangle_mesh))
-      {
-        typename boost::graph_traits<TriangleMesh>::halfedge_descriptor
-          h = halfedge(f, triangle_mesh);
-        m_area += std::sqrt(CGAL::squared_area(
-                        get(vpmap, source(h, triangle_mesh) ),
-                        get(vpmap, target(h, triangle_mesh) ),
-                        get(vpmap, target(next(h, triangle_mesh), triangle_mesh) ) ));
-      }
-    }
-
-    void rotation_matrix_pre(
-      typename boost::graph_traits<TriangleMesh>::vertex_descriptor vi,
-      TriangleMesh& hg)
-    {
-      typename boost::graph_traits<TriangleMesh>::in_edge_iterator e, e_end;
-      cpp11::tie(e,e_end) = in_edges(vi, hg);
-      m_nb_edges_incident=(double) std::distance(e,e_end);
-    }
-
-    template <class Square_matrix_3>
-    void update_covariance_matrix(
-      Square_matrix_3& cov,
-      const Square_matrix_3& rot_mtr)
-    {
-      // add neighbor rotation
-      cov += m_alpha * m_area * rot_mtr.transpose() / m_nb_edges_incident;
-    }
-
-    void set_sre_arap_alpha(double a){ m_alpha=a; }
-  };
-};
 
 // property map that create a Simple_cartesian<double>::Point_3
 // on the fly in order the deformation class to be used
 // with points with minimal requirements
 template <class Vertex_point_map>
-struct SC_on_the_fly_pmap: public Vertex_point_map{
+struct SC_on_the_fly_pmap
+  : public Vertex_point_map
+{
   typedef boost::readable_property_map_tag category;
   typedef CGAL::Simple_cartesian<double>::Point_3 value_type;
   typedef value_type reference;
@@ -168,6 +79,89 @@ struct SC_on_the_fly_pmap: public Vertex_point_map{
   }
 };
 
+template<typename TriangleMesh, typename VertexPointMap,
+         Deformation_algorithm_tag deformation_algorithm_tag>
+struct Types_selectors;
+
+template<typename TriangleMesh, typename VertexPointMap>
+struct Types_selectors<TriangleMesh, VertexPointMap, CGAL::SPOKES_AND_RIMS>
+{
+  typedef CGAL::Weights::Single_cotangent_weight<TriangleMesh> Weight_calculator;
+
+  struct ARAP_visitor
+  {
+    void init(TriangleMesh, VertexPointMap){}
+
+    void rotation_matrix_pre(typename boost::graph_traits<TriangleMesh>::vertex_descriptor,
+                             TriangleMesh&){}
+
+    template <class Square_matrix_3>
+    void update_covariance_matrix(Square_matrix_3&,
+                                  const Square_matrix_3&){}
+
+    void set_sre_arap_alpha(double){}
+  };
+};
+
+template<class TriangleMesh, typename VertexPointMap>
+struct Types_selectors<TriangleMesh, VertexPointMap, CGAL::ORIGINAL_ARAP>
+{
+  typedef CGAL::Weights::Cotangent_weight<TriangleMesh> Weight_calculator;
+
+  typedef typename Types_selectors<TriangleMesh, VertexPointMap, CGAL::SPOKES_AND_RIMS>::ARAP_visitor ARAP_visitor;
+};
+
+template<class TriangleMesh, typename VertexPointMap>
+struct Types_selectors<TriangleMesh, VertexPointMap, CGAL::SRE_ARAP>
+{
+  typedef CGAL::Weights::Cotangent_weight<TriangleMesh> Weight_calculator;
+
+  class ARAP_visitor
+  {
+    double m_nb_edges_incident;
+    double m_area;
+    double m_alpha;
+
+  public:
+    ARAP_visitor(): m_alpha(0.02) {}
+
+    void init(TriangleMesh triangle_mesh, const VertexPointMap& vpmap)
+    {
+      // calculate area
+      m_area = 0;
+      typedef typename boost::graph_traits<TriangleMesh>::face_descriptor face_descriptor;
+      for(face_descriptor f : faces(triangle_mesh))
+      {
+        typename boost::graph_traits<TriangleMesh>::halfedge_descriptor
+          h = halfedge(f, triangle_mesh);
+        m_area += std::sqrt(CGAL::squared_area(
+                        get(vpmap, source(h, triangle_mesh) ),
+                        get(vpmap, target(h, triangle_mesh) ),
+                        get(vpmap, target(next(h, triangle_mesh), triangle_mesh) ) ));
+      }
+    }
+
+    void rotation_matrix_pre(
+      typename boost::graph_traits<TriangleMesh>::vertex_descriptor vi,
+      TriangleMesh& hg)
+    {
+      typename boost::graph_traits<TriangleMesh>::in_edge_iterator e, e_end;
+      std::tie(e,e_end) = in_edges(vi, hg);
+      m_nb_edges_incident=(double) std::distance(e,e_end);
+    }
+
+    template <class Square_matrix_3>
+    void update_covariance_matrix(
+      Square_matrix_3& cov,
+      const Square_matrix_3& rot_mtr)
+    {
+      // add neighbor rotation
+      cov += m_alpha * m_area * rot_mtr.transpose() / m_nb_edges_incident;
+    }
+
+    void set_sre_arap_alpha(double a){ m_alpha=a; }
+  };
+};
 
 }//namespace internal
 /// @endcond
@@ -225,13 +219,9 @@ public:
 // Index maps
 #ifndef DOXYGEN_RUNNING
   typedef typename Default::Get<
-    VIM,
-    typename boost::property_map<Triangle_mesh, boost::vertex_index_t>::type
-  >::type Vertex_index_map;
+    VIM, typename CGAL::GetInitializedVertexIndexMap<Triangle_mesh>::type>::type Vertex_index_map;
   typedef typename Default::Get<
-    HIM,
-    typename boost::property_map<Triangle_mesh, boost::halfedge_index_t>::type
-  >::type Hedge_index_map;
+    HIM, typename CGAL::GetInitializedHalfedgeIndexMap<Triangle_mesh>::type>::type Hedge_index_map;
 #else
   /// vertex index map type
   typedef VIM Vertex_index_map;
@@ -239,17 +229,6 @@ public:
   typedef HIM Hedge_index_map;
 #endif
 
-// weight calculator
-#ifndef DOXYGEN_RUNNING
-  typedef typename Default::Get<
-    WC,
-    typename internal::Types_selectors<TM, TAG>::Weight_calculator
-  >::type Weight_calculator;
-#else
-  /// weight calculator functor type
-  typedef WC Weight_calculator;
-#endif
-
 // sparse linear solver
 #ifndef DOXYGEN_RUNNING
   typedef typename Default::Get<
@@ -294,6 +273,17 @@ public:
   typedef VPM Vertex_point_map;
 #endif
 
+// weight calculator
+#ifndef DOXYGEN_RUNNING
+  typedef typename Default::Get<
+    WC,
+    typename internal::Types_selectors<Triangle_mesh, Vertex_point_map, TAG>::Weight_calculator
+  >::type Weight_calculator;
+#else
+  /// weight calculator functor type
+  typedef WC Weight_calculator;
+#endif
+
   /// The type for vertex descriptor
   typedef typename boost::graph_traits<Triangle_mesh>::vertex_descriptor vertex_descriptor;
   /// The type for halfedge descriptor
@@ -308,8 +298,6 @@ public:
 private:
   typedef Surface_mesh_deformation<TM, VIM, HIM, TAG, WC, ST, CR> Self;
   // Repeat Triangle_mesh types
-  typedef typename boost::graph_traits<Triangle_mesh>::vertex_iterator     vertex_iterator;
-  typedef typename boost::graph_traits<Triangle_mesh>::halfedge_iterator       halfedge_iterator;
   typedef typename boost::graph_traits<Triangle_mesh>::in_edge_iterator    in_edge_iterator;
   typedef typename boost::graph_traits<Triangle_mesh>::out_edge_iterator   out_edge_iterator;
 
@@ -344,140 +332,113 @@ private:
 
   bool last_preprocess_successful;                    ///< stores the result of last call to preprocess()
 
+  Vertex_point_map vertex_point_map;
   Weight_calculator weight_calculator;
 
-  Vertex_point_map vertex_point_map;
-
 public:
-  typename internal::Types_selectors<TM, TAG>::ARAP_visitor arap_visitor;
+  typename internal::Types_selectors<Triangle_mesh, Vertex_point_map, TAG>::ARAP_visitor arap_visitor;
 private:
 
 #ifdef CGAL_DEFORM_MESH_USE_EXPERIMENTAL_SCALE
   std::vector<double> scales;
 #endif
 
-#ifndef CGAL_CFG_NO_CPP0X_DELETED_AND_DEFAULT_FUNCTIONS
 public:
   Surface_mesh_deformation(const Self&) = delete; // no copy
-#else
-private:
-  Surface_mesh_deformation(const Self&); // no copy
-#endif
-
 
 // Public methods
 public:
 
   /// \cond SKIP_FROM_MANUAL
-  //vertex_point_map set by default
-  Surface_mesh_deformation(Triangle_mesh& triangle_mesh,
-                           Vertex_index_map vertex_index_map,
-                           Hedge_index_map hedge_index_map
-                          )
-    : m_triangle_mesh(triangle_mesh), vertex_index_map(vertex_index_map), hedge_index_map(hedge_index_map),
-      ros_id_map(std::vector<std::size_t>(num_vertices(triangle_mesh), (std::numeric_limits<std::size_t>::max)() )),
-      is_roi_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
-      is_ctrl_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
-      m_iterations(5), m_tolerance(1e-4),
-      need_preprocess_factorization(true),
-      need_preprocess_region_of_solution(true),
-      last_preprocess_successful(false),
-      weight_calculator(Weight_calculator()),
-      vertex_point_map(get(vertex_point, triangle_mesh))
-  {
-    init();
-  }
-
-  //vertex_point_map and hedge_index_map set by default
-  Surface_mesh_deformation(Triangle_mesh& triangle_mesh,
-                           Vertex_index_map vertex_index_map
-                          )
-    : m_triangle_mesh(triangle_mesh), vertex_index_map(vertex_index_map),
-      hedge_index_map(get(boost::halfedge_index, triangle_mesh)),
-      ros_id_map(std::vector<std::size_t>(num_vertices(triangle_mesh), (std::numeric_limits<std::size_t>::max)() )),
-      is_roi_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
-      is_ctrl_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
-      m_iterations(5), m_tolerance(1e-4),
-      need_preprocess_factorization(true),
-      need_preprocess_region_of_solution(true),
-      last_preprocess_successful(false),
-      weight_calculator(Weight_calculator()),
-      vertex_point_map(get(vertex_point, triangle_mesh))
-  {
-    init();
-  }
-  //vertex_point_map, hedge_index_map and vertex_index_map set by default
-  Surface_mesh_deformation(Triangle_mesh& triangle_mesh)
-    : m_triangle_mesh(triangle_mesh),
-      vertex_index_map(get(boost::vertex_index, triangle_mesh)),
-      hedge_index_map(get(boost::halfedge_index, triangle_mesh)),
-      ros_id_map(std::vector<std::size_t>(num_vertices(triangle_mesh), (std::numeric_limits<std::size_t>::max)() )),
-      is_roi_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
-      is_ctrl_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
-      m_iterations(5), m_tolerance(1e-4),
-      need_preprocess_factorization(true),
-      need_preprocess_region_of_solution(true),
-      last_preprocess_successful(false),
-      weight_calculator(Weight_calculator()),
-      vertex_point_map(get(vertex_point, triangle_mesh))
-  {
-    init();
-  }
 
   // Constructor with all the parameters provided
   Surface_mesh_deformation(Triangle_mesh& triangle_mesh,
                            Vertex_index_map vertex_index_map,
                            Hedge_index_map hedge_index_map,
                            Vertex_point_map vertex_point_map,
-                           Weight_calculator weight_calculator = Weight_calculator()
-                          )
-    : m_triangle_mesh(triangle_mesh), vertex_index_map(vertex_index_map), hedge_index_map(hedge_index_map),
-    ros_id_map(std::vector<std::size_t>(num_vertices(triangle_mesh), (std::numeric_limits<std::size_t>::max)() )),
-    is_roi_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
-    is_ctrl_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
-    m_iterations(5), m_tolerance(1e-4),
-    need_preprocess_factorization(true),
-    need_preprocess_region_of_solution(true),
-    last_preprocess_successful(false),
-    weight_calculator(weight_calculator),
-    vertex_point_map(vertex_point_map)
+                           Weight_calculator weight_calculator)
+    : m_triangle_mesh(triangle_mesh),
+      vertex_index_map(vertex_index_map),
+      hedge_index_map(hedge_index_map),
+      ros_id_map(std::vector<std::size_t>(num_vertices(triangle_mesh), (std::numeric_limits<std::size_t>::max)() )),
+      is_roi_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
+      is_ctrl_map(std::vector<bool>(num_vertices(triangle_mesh), false)),
+      m_iterations(5), m_tolerance(1e-4),
+      need_preprocess_factorization(true),
+      need_preprocess_region_of_solution(true),
+      last_preprocess_successful(false),
+      vertex_point_map(vertex_point_map),
+      weight_calculator(weight_calculator)
   {
     init();
   }
+
+  Surface_mesh_deformation(Triangle_mesh& triangle_mesh,
+                           Vertex_index_map vertex_index_map,
+                           Hedge_index_map hedge_index_map,
+                           Vertex_point_map vertex_point_map)
+    : Surface_mesh_deformation(triangle_mesh,
+                               vertex_index_map,
+                               hedge_index_map,
+                               vertex_point_map,
+                               Weight_calculator())
+  { }
+
+  Surface_mesh_deformation(Triangle_mesh& triangle_mesh,
+                           Vertex_index_map vertex_index_map,
+                           Hedge_index_map hedge_index_map)
+    : Surface_mesh_deformation(triangle_mesh,
+                               vertex_index_map,
+                               hedge_index_map,
+                               get(vertex_point, triangle_mesh))
+  { }
+
+  Surface_mesh_deformation(Triangle_mesh& triangle_mesh,
+                           Vertex_index_map vertex_index_map)
+    : Surface_mesh_deformation(triangle_mesh,
+                               vertex_index_map,
+                               CGAL::get_initialized_halfedge_index_map(triangle_mesh))
+  { }
+
+  Surface_mesh_deformation(Triangle_mesh& triangle_mesh)
+    : Surface_mesh_deformation(triangle_mesh,
+                               CGAL::get_initialized_vertex_index_map(triangle_mesh))
+  { }
+
   /// \endcond
-  #if DOXYGEN_RUNNING
+
+#if DOXYGEN_RUNNING
 /// \name Construction
 /// @{
     /**
-   * The constructor of a deformation object
+   * The constructor of a deformation object.
    *
    * @pre `triangle_mesh` consists of only triangular facets
    * @param triangle_mesh triangulated surface mesh to deform
-   * @param vertex_index_map property map which associates an id to each vertex, from `0` to `num_vertices(triangle_mesh)-1`.
-   * @param hedge_index_map property map which associates an id to each halfedge, from `0` to `2*num_edges(triangle_mesh)-1`.
+   * @param vertex_index_map a property map which associates a unique id to each vertex,
+   *                         between `0` to `num_vertices(triangle_mesh)-1`.
+   * @param hedge_index_map property map which associates a unique id to each halfedge,
+   *                        between `0` to `2*num_edges(triangle_mesh)-1`.
    * @param vertex_point_map property map which associates a point to each vertex of the triangle mesh.
    * @param weight_calculator function object or pointer for weight calculation
+   *
    */
   Surface_mesh_deformation(Triangle_mesh& triangle_mesh,
-    Vertex_index_map vertex_index_map=get(boost::vertex_index, triangle_mesh),
-    Hedge_index_map hedge_index_map=get(boost::halfedge_index, triangle_mesh),
-    Vertex_point_map vertex_point_map=get(boost::vertex_point, triangle_mesh),
-    Weight_calculator weight_calculator = Weight_calculator()
-    );
+                           Vertex_index_map vertex_index_map = unspecified_internal_vertex_index_map,
+                           Hedge_index_map hedge_index_map = unspecified_internal_halfedge_index_map,
+                           Vertex_point_map vertex_point_map = get(boost::vertex_point, triangle_mesh),
+                           Weight_calculator weight_calculator = Weight_calculator(triangle_mesh, vertex_point_map));
 /// @}
   #endif
 
 private:
-  void init() {
+  void init()
+  {
     typedef internal::SC_on_the_fly_pmap<Vertex_point_map> Wrapper;
-    // compute halfedge weights
-    halfedge_iterator eb, ee;
-    hedge_weight.reserve(2*num_edges(m_triangle_mesh));
-    for(cpp11::tie(eb, ee) = halfedges(m_triangle_mesh); eb != ee; ++eb)
-    {
-      hedge_weight.push_back(
-        this->weight_calculator(*eb, m_triangle_mesh, Wrapper(vertex_point_map)));
-    }
+    hedge_weight.reserve(num_halfedges(m_triangle_mesh));
+    for(halfedge_descriptor he : halfedges(m_triangle_mesh))
+      hedge_weight.push_back(this->weight_calculator(he, m_triangle_mesh, Wrapper(vertex_point_map)));
+
     arap_visitor.init(m_triangle_mesh, vertex_point_map);
   }
 
@@ -831,7 +792,7 @@ public:
     region_of_solution(); // since we are using original vector
 
     //restore the current positions to be the original positions
-    BOOST_FOREACH(vertex_descriptor vd, roi_vertices())
+    for(vertex_descriptor vd : roi_vertices())
     {
       put(vertex_point_map, vd, original[ros_id(vd)]);
       solution[ros_id(vd)]=original[ros_id(vd)];
@@ -865,17 +826,17 @@ public:
 
     region_of_solution(); // the roi should be preprocessed since we are using original_position vec
 
-    BOOST_FOREACH(vertex_descriptor vd, roi_vertices())
+    for(vertex_descriptor vd : roi_vertices())
     {
       original[ros_id(vd)] = get(vertex_point_map, vd);
     }
 
     // now I need to compute weights for halfedges incident to roi vertices
     std::vector<bool> is_weight_computed(2*num_edges(m_triangle_mesh), false);
-    BOOST_FOREACH(vertex_descriptor vd, roi_vertices())
+    for(vertex_descriptor vd : roi_vertices())
     {
       in_edge_iterator e, e_end;
-      for (cpp11::tie(e,e_end) = in_edges(vd, m_triangle_mesh); e != e_end; e++)
+      for (std::tie(e,e_end) = in_edges(vd, m_triangle_mesh); e != e_end; e++)
       {
         halfedge_descriptor he = halfedge(*e, m_triangle_mesh);
         std::size_t id_e = id(he);
@@ -984,7 +945,7 @@ private:
                              std::vector<vertex_descriptor>& push_vector)
   {
     in_edge_iterator e, e_end;
-    for (cpp11::tie(e,e_end) = in_edges(vd, m_triangle_mesh); e != e_end; e++)
+    for (std::tie(e,e_end) = in_edges(vd, m_triangle_mesh); e != e_end; e++)
     {
       vertex_descriptor vt = source(*e, m_triangle_mesh);
       if(ros_id(vt) == (std::numeric_limits<std::size_t>::max)())  // neighboring vertex which is outside of roi and not visited previously (i.e. need an id)
@@ -1139,7 +1100,7 @@ private:
       {
         double diagonal = 0;
         in_edge_iterator e, e_end;
-        for (cpp11::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
+        for (std::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
         {
           halfedge_descriptor he = halfedge(*e, m_triangle_mesh);
           vertex_descriptor vj = source(he, m_triangle_mesh);
@@ -1182,7 +1143,7 @@ private:
       {
         double diagonal = 0;
         out_edge_iterator e, e_end;
-        for (cpp11::tie(e,e_end) = out_edges(vi, m_triangle_mesh); e != e_end; e++)
+        for (std::tie(e,e_end) = out_edges(vi, m_triangle_mesh); e != e_end; e++)
         {
           halfedge_descriptor he = halfedge(*e, m_triangle_mesh);
           double total_weight = 0;
@@ -1250,7 +1211,7 @@ private:
 
       arap_visitor.rotation_matrix_pre(vi, m_triangle_mesh);
 
-      for (cpp11::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
+      for (std::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
       {
         halfedge_descriptor he=halfedge(*e, m_triangle_mesh);
         vertex_descriptor vj = source(he, m_triangle_mesh);
@@ -1284,7 +1245,7 @@ private:
 
       //iterate through all triangles
       out_edge_iterator e, e_end;
-      for (cpp11::tie(e,e_end) = out_edges(vi, m_triangle_mesh); e != e_end; e++)
+      for (std::tie(e,e_end) = out_edges(vi, m_triangle_mesh); e != e_end; e++)
       {
         halfedge_descriptor he = halfedge(*e, m_triangle_mesh);
         if(is_border(he, m_triangle_mesh)) { continue; } // no facet
@@ -1321,7 +1282,7 @@ private:
       double eT_eR = 0, eRT_eR = 0;
 
       in_edge_iterator e, e_end;
-      for (cpp11::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
+      for (std::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
       {
         halfedge_descriptor he = *e;
         vertex_descriptor vj = source(he, m_triangle_mesh);
@@ -1375,7 +1336,7 @@ private:
         CR_vector xyz = cr_traits.vector(0, 0, 0);
 
         in_edge_iterator e, e_end;
-        for (cpp11::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
+        for (std::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
         {
           halfedge_descriptor he = halfedge(*e, m_triangle_mesh);
           vertex_descriptor vj = source(he, m_triangle_mesh);
@@ -1439,7 +1400,7 @@ private:
         CR_vector xyz = cr_traits.vector(0, 0, 0);
 
         out_edge_iterator e, e_end;
-        for (cpp11::tie(e,e_end) = out_edges(vi, m_triangle_mesh); e != e_end; e++)
+        for (std::tie(e,e_end) = out_edges(vi, m_triangle_mesh); e != e_end; e++)
         {
           halfedge_descriptor he = halfedge(*e, m_triangle_mesh);
           vertex_descriptor vj = target(he, m_triangle_mesh);
@@ -1526,7 +1487,7 @@ private:
       std::size_t vi_id = ros_id(vi);
 
       in_edge_iterator e, e_end;
-      for (cpp11::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
+      for (std::tie(e,e_end) = in_edges(vi, m_triangle_mesh); e != e_end; e++)
       {
         halfedge_descriptor he = halfedge(*e, m_triangle_mesh);
         vertex_descriptor vj = source(he, m_triangle_mesh);
@@ -1555,7 +1516,7 @@ private:
       std::size_t vi_id = ros_id(vi);
       //iterate through all triangles
       out_edge_iterator e, e_end;
-      for (cpp11::tie(e,e_end) = out_edges(vi, m_triangle_mesh); e != e_end; e++)
+      for (std::tie(e,e_end) = out_edges(vi, m_triangle_mesh); e != e_end; e++)
       {
         halfedge_descriptor he = halfedge(*e, m_triangle_mesh);
         if(is_border(he, m_triangle_mesh)) { continue; } // no facet
