@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Surface_mesh_parameterization/include/CGAL/Surface_mesh_parameterization/ARAP_parameterizer_3.h $
-// $Id: ARAP_parameterizer_3.h ffb18e9 2019-10-07T13:08:01+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Surface_mesh_parameterization/include/CGAL/Surface_mesh_parameterization/ARAP_parameterizer_3.h $
+// $Id: ARAP_parameterizer_3.h d2bc415 2023-05-04T16:37:17+02:00 Laurent Rineau
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mael Rouxel-Labbé
 
@@ -35,14 +26,14 @@
 #include <CGAL/Surface_mesh_parameterization/LSCM_parameterizer_3.h>
 #include <CGAL/Surface_mesh_parameterization/MVC_post_processor_3.h>
 #include <CGAL/Surface_mesh_parameterization/Two_vertices_parameterizer_3.h>
-
 #include <CGAL/Surface_mesh_parameterization/parameterize.h>
+#include <CGAL/Weights/utils.h>
 
 #include <CGAL/Polygon_mesh_processing/connected_components.h>
 
 #if defined(CGAL_EIGEN3_ENABLED)
 #include <CGAL/Eigen_solver_traits.h>
-#ifdef CGAL_SMP_USE_SPARSESUITE_SOLVERS
+#ifdef CGAL_SMP_USE_SUITESPARSE_SOLVERS
 #include <Eigen/UmfPackSupport>
 #endif
 #endif
@@ -90,11 +81,10 @@
 #include <CGAL/Kernel/Conic_misc.h> // used to solve conic equations
 #endif
 
-#include <boost/foreach.hpp>
-#include <boost/function_output_iterator.hpp>
+#include <boost/iterator/function_output_iterator.hpp>
 #include <boost/functional/hash.hpp>
-#include <boost/unordered_set.hpp>
 
+#include <unordered_set>
 #include <iostream>
 #include <fstream>
 #include <limits>
@@ -102,6 +92,7 @@
 #include <string>
 #include <utility>
 #include <vector>
+#include <type_traits>
 
 /// \file ARAP_parameterizer_3.h
 
@@ -138,7 +129,7 @@ namespace Surface_mesh_parameterization {
 /// a random vertex is pinned.
 ///
 /// If flips are present in the initial parameterization, a post-processing step
-/// is applied using `CGAL::Surface_mesh_parameterization::MVC_post_processor_3<TriangleMesh, SolverTraits_>`
+/// is applied using `CGAL::Surface_mesh_parameterization::MVC_post_processor_3<TriangleMesh_, SolverTraits_>`
 /// to attempt to obtain a valid final embedding.
 ///
 /// A one-to-one mapping is *not* guaranteed.
@@ -147,7 +138,7 @@ namespace Surface_mesh_parameterization {
 ///
 /// \tparam TriangleMesh_ must be a model of `FaceGraph`.
 ///
-/// \tparam BorderParameterizer_ is a Strategy to parameterize the surface border
+/// \tparam BorderParameterizer_ is a strategy to parameterize the surface border
 ///         and must be a model of `Parameterizer_3`.<br>
 ///         <b>%Default:</b>
 /// \code
@@ -163,7 +154,7 @@ namespace Surface_mesh_parameterization {
 ///   CGAL::Eigen_solver_traits<
 ///           Eigen::SparseLU<Eigen_sparse_matrix<double>::EigenType> >
 /// \endcode
-///         Moreover, if SparseSuite solvers are available, which is greatly preferable for speed,
+///         Moreover, if SuiteSparse solvers are available, which is greatly preferable for speed,
 ///         then the default parameter is:
 /// \code
 ///   CGAL::Eigen_solver_traits<
@@ -171,6 +162,7 @@ namespace Surface_mesh_parameterization {
 /// \endcode
 ///
 /// \sa `CGAL::Surface_mesh_parameterization::Fixed_border_parameterizer_3<TriangleMesh, BorderParameterizer, SolverTraits>`
+/// \sa `CGAL::Surface_mesh_parameterization::Iterative_authalic_parameterizer_3<TriangleMesh, BorderParameterizer, SolverTraits>`
 ///
 template < class TriangleMesh_,
            class BorderParameterizer_ = Default,
@@ -183,10 +175,15 @@ public:
     BorderParameterizer_,
     Two_vertices_parameterizer_3<TriangleMesh_> >::type       Border_parameterizer;
 
+  #if !defined(CGAL_EIGEN3_ENABLED)
+  CGAL_static_assertion_msg(!(std::is_same<SolverTraits_, Default>::value),
+                            "Error: You must either provide 'SolverTraits_' or link CGAL with the Eigen library");
+  #endif
+
   typedef typename Default::Get<
     SolverTraits_,
   #if defined(CGAL_EIGEN3_ENABLED)
-    #ifdef CGAL_SMP_USE_SPARSESUITE_SOLVERS
+    #ifdef CGAL_SMP_USE_SUITESPARSE_SOLVERS
       CGAL::Eigen_solver_traits<
         Eigen::UmfPackLU<Eigen_sparse_matrix<double>::EigenType> >
     #else
@@ -194,33 +191,43 @@ public:
         Eigen::SparseLU<Eigen_sparse_matrix<double>::EigenType> >
     #endif
   #else
-    #pragma message("Error: You must either provide 'SolverTraits_' or link CGAL with the Eigen library")
     SolverTraits_ // no parameter provided, and Eigen is not enabled: so don't compile!
   #endif
   >::type                                                     Solver_traits;
 #else
+  /// Border parameterizer type
   typedef Border_parameterizer_                               Border_parameterizer;
+
+  /// Solver traits type
   typedef SolverTraits_                                       Solver_traits;
+
+  /// Number type, deduced from the internal vertex point map of `Triangle_mesh`
+  typedef unspecified_type                                    NT;
 #endif
 
+  /// Triangle mesh type
+  typedef TriangleMesh_                                       Triangle_mesh;
+
   typedef TriangleMesh_                                       TriangleMesh;
 
+  /// Mesh halfedge type
+  typedef typename boost::graph_traits<Triangle_mesh>::halfedge_descriptor  halfedge_descriptor;
+
 // Private types
 private:
-  typedef typename boost::graph_traits<TriangleMesh>::vertex_descriptor    vertex_descriptor;
-  typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor  halfedge_descriptor;
-  typedef typename boost::graph_traits<TriangleMesh>::face_descriptor      face_descriptor;
-  typedef typename boost::graph_traits<TriangleMesh>::face_iterator        face_iterator;
-  typedef typename boost::graph_traits<TriangleMesh>::vertex_iterator      vertex_iterator;
+  typedef typename boost::graph_traits<Triangle_mesh>::vertex_descriptor    vertex_descriptor;
+  typedef typename boost::graph_traits<Triangle_mesh>::face_descriptor      face_descriptor;
+  typedef typename boost::graph_traits<Triangle_mesh>::face_iterator        face_iterator;
+  typedef typename boost::graph_traits<Triangle_mesh>::vertex_iterator      vertex_iterator;
 
-  typedef CGAL::Halfedge_around_target_circulator<TriangleMesh>     halfedge_around_target_circulator;
-  typedef CGAL::Halfedge_around_face_circulator<TriangleMesh>       halfedge_around_face_circulator;
+  typedef CGAL::Halfedge_around_target_circulator<Triangle_mesh>    halfedge_around_target_circulator;
+  typedef CGAL::Halfedge_around_face_circulator<Triangle_mesh>      halfedge_around_face_circulator;
 
-  typedef boost::unordered_set<vertex_descriptor>                   Vertex_set;
+  typedef std::unordered_set<vertex_descriptor>                     Vertex_set;
   typedef std::vector<face_descriptor>                              Faces_vector;
 
   // Traits subtypes:
-  typedef typename internal::Kernel_traits<TriangleMesh>::Kernel    Kernel;
+  typedef typename internal::Kernel_traits<Triangle_mesh>::Kernel   Kernel;
   typedef typename Kernel::FT                                       NT;
   typedef typename Kernel::Point_2                                  Point_2;
   typedef typename Kernel::Point_3                                  Point_3;
@@ -282,7 +289,7 @@ private:
   template <typename VertexUVMap,
             typename VertexIndexMap>
   void output_uvmap(const std::string filename,
-                    const TriangleMesh& mesh,
+                    const Triangle_mesh& mesh,
                     const Vertex_set& vertices,
                     const Faces_vector& faces,
                     const VertexUVMap uvmap,
@@ -297,7 +304,7 @@ private:
             typename VertexIndexMap>
   void output_uvmap(const std::string filename,
                     const unsigned int iter,
-                    const TriangleMesh& mesh,
+                    const Triangle_mesh& mesh,
                     const Vertex_set& vertices,
                     const Faces_vector& faces,
                     const VertexUVMap uvmap,
@@ -320,7 +327,7 @@ private:
                        const VertexIndexMap vimap,
                        const VertexParameterizedMap vpmap)
   {
-    BOOST_FOREACH(vertex_descriptor vd, vertices) {
+    for(vertex_descriptor vd : vertices) {
       // The solver might not have managed to exactly constrain the vertex that was marked
       // as constrained; simply don't update its position.
       if(get(vpmap, vd))
@@ -336,12 +343,12 @@ private:
 // Private operations
 private:
   // Store the vertices and faces of the mesh in memory.
-  Error_code initialize_containers(const TriangleMesh& mesh,
+  Error_code initialize_containers(const Triangle_mesh& mesh,
                                    halfedge_descriptor bhd,
                                    Vertex_set& vertices,
                                    Faces_vector& faces) const
   {
-    internal::Containers_filler<TriangleMesh> fc(mesh, vertices, &faces);
+    internal::Containers_filler<Triangle_mesh> fc(mesh, vertices, &faces);
     Polygon_mesh_processing::connected_component(
                                       face(opposite(bhd, mesh), mesh),
                                       mesh,
@@ -356,7 +363,7 @@ private:
   // Initialize the UV values with a first parameterization of the input.
   template <typename VertexUVMap,
             typename VertexIndexMap>
-  Error_code compute_initial_uv_map(TriangleMesh& mesh,
+  Error_code compute_initial_uv_map(Triangle_mesh& mesh,
                                     halfedge_descriptor bhd,
                                     VertexUVMap uvmap,
                                     VertexIndexMap vimap) const
@@ -371,17 +378,17 @@ private:
     }
 
     // temporary vpmap since we do not need it in the future
-    boost::unordered_set<vertex_descriptor> vs;
-    internal::Bool_property_map<boost::unordered_set<vertex_descriptor> > vpmap(vs);
+    std::unordered_set<vertex_descriptor> vs;
+    internal::Bool_property_map<std::unordered_set<vertex_descriptor> > vpmap(vs);
 
     // According to the paper, MVC is better for single border and LSCM is better
     // when there are multiple borders
     if(number_of_borders == 1) {
-      typedef Mean_value_coordinates_parameterizer_3<TriangleMesh>     MVC_parameterizer;
+      typedef Mean_value_coordinates_parameterizer_3<Triangle_mesh>     MVC_parameterizer;
       MVC_parameterizer mvc_parameterizer;
       status = mvc_parameterizer.parameterize(mesh, bhd, uvmap, vimap, vpmap);
     } else {
-      typedef LSCM_parameterizer_3<TriangleMesh, Border_parameterizer> LSCM_parameterizer;
+      typedef LSCM_parameterizer_3<Triangle_mesh, Border_parameterizer> LSCM_parameterizer;
       LSCM_parameterizer lscm_parameterizer;
       status = lscm_parameterizer.parameterize(mesh, bhd, uvmap, vimap, vpmap);
     }
@@ -394,7 +401,7 @@ private:
   template <typename VertexUVMap,
             typename VertexIndexMap,
             typename VertexParameterizedMap>
-  Error_code parameterize_border(const TriangleMesh& mesh,
+  Error_code parameterize_border(const Triangle_mesh& mesh,
                                  const Vertex_set& vertices,
                                  halfedge_descriptor bhd,
                                  VertexIndexMap vimap,
@@ -413,7 +420,7 @@ private:
       // A local uvmap (that is then discarded) is passed to avoid changing
       // the values of the real uvmap. Since we can't get VertexUVMap::C,
       // we build a map with the same key and value types
-      typedef boost::unordered_map<typename VertexUVMap::key_type,
+      typedef std::unordered_map<typename VertexUVMap::key_type,
                                    typename VertexUVMap::value_type> Useless_map;
       typedef boost::associative_property_map<Useless_map>           Useless_pmap;
 
@@ -427,14 +434,14 @@ private:
   }
 
   // Compute the cotangent of the angle between the vectors ij and ik.
-  void compute_cotangent_angle(const TriangleMesh& mesh,
+  void compute_cotangent_angle(const Triangle_mesh& mesh,
                                halfedge_descriptor hd,
                                vertex_descriptor vi,
                                vertex_descriptor vj,
                                vertex_descriptor vk,
                                Cot_map ctmap) const
   {
-    typedef typename boost::property_map<TriangleMesh,
+    typedef typename boost::property_map<Triangle_mesh,
                                          boost::vertex_point_t>::const_type PPmap;
     const PPmap ppmap = get(vertex_point, mesh);
 
@@ -442,16 +449,17 @@ private:
     const Point_3& position_vj = get(ppmap, vj);
     const Point_3& position_vk = get(ppmap, vk);
 
-    NT cot = internal::cotangent<Kernel>(position_vi, position_vj, position_vk);
+    const NT cot = CGAL::Weights::cotangent(position_vi, position_vj, position_vk);
     put(ctmap, hd, cot);
   }
 
   // Fill the map 'ctmap' with the cotangents of the angles of the faces of 'mesh'.
-  Error_code compute_cotangent_angles(const TriangleMesh& mesh,
+  Error_code compute_cotangent_angles(const Triangle_mesh& mesh,
                                       const Faces_vector& faces,
                                       Cot_map ctmap) const
   {
-    BOOST_FOREACH(face_descriptor fd, faces) {
+    // Since we loop faces, we are implicitely defining the weight of border halfedges as 0...
+    for(face_descriptor fd : faces) {
       halfedge_descriptor hd = halfedge(fd, mesh), hdb = hd;
 
       vertex_descriptor vi = target(hd, mesh);
@@ -473,8 +481,8 @@ private:
     return OK;
   }
 
-  // Compute w_ij = (i, j) coefficient of matrix A for j neighbor vertex of i.
-  NT compute_w_ij(const TriangleMesh& mesh,
+  // computes `w_ij`, the `(i,j)`-coefficient of matrix `A` for `j` neighbor vertex of `i`.
+  NT compute_w_ij(const Triangle_mesh& mesh,
                   halfedge_descriptor hd,
                   const Cot_map ctmap) const
   {
@@ -482,13 +490,13 @@ private:
 
     // coefficient corresponding to the angle at vk if vk is the vertex before vj
     // while circulating around vi
-    NT c_k = get(ctmap, opposite(hd, mesh));
+    const NT c_k = get(ctmap, opposite(hd, mesh));
 
     // coefficient corresponding to the angle at vl if vl is the vertex after vj
     // while circulating around vi
-    NT c_l = get(ctmap, hd);
+    const NT c_l = get(ctmap, hd);
 
-    NT weight = c_k + c_l;
+    const NT weight = c_k + c_l;
     return weight;
   }
 
@@ -497,11 +505,11 @@ private:
   // - compute w_ii = - sum of w_ijs.
   //
   // \pre Vertices must be indexed.
-  // \pre Vertex i musn't be already parameterized.
+  // \pre Vertex i mustn't be already parameterized.
   // \pre Line i of A must contain only zeros.
   template <typename VertexIndexMap>
   Error_code fill_linear_system_matrix(Matrix& A,
-                                       const TriangleMesh& mesh,
+                                       const Triangle_mesh& mesh,
                                        vertex_descriptor vertex,
                                        const Cot_map ct_map,
                                        VertexIndexMap vimap) const
@@ -543,7 +551,7 @@ private:
   // after (at least two) border vertices parameterization.
   template <typename VertexIndexMap,
             typename VertexParameterizedMap>
-  Error_code initialize_matrix_A(const TriangleMesh& mesh,
+  Error_code initialize_matrix_A(const Triangle_mesh& mesh,
                                  const Vertex_set& vertices,
                                  const Cot_map ctmap,
                                  VertexIndexMap vimap,
@@ -553,8 +561,7 @@ private:
     Error_code status = OK;
 
     // compute A
-    unsigned int count = 0;
-    BOOST_FOREACH(vertex_descriptor vd, vertices) {
+    for(vertex_descriptor vd : vertices) {
       if(!get(vpmap, vd)) { // not yet parameterized
         // Compute the line i of the matrix A
         status = fill_linear_system_matrix(A, mesh, vd, ctmap, vimap);
@@ -563,7 +570,6 @@ private:
       } else { // fixed vertices
         int index = get(vimap, vd);
         A.set_coef(index, index, 1, true /*new*/);
-        ++count;
       }
     }
     return status;
@@ -700,7 +706,7 @@ private:
 
   // Compute the root that gives the lowest face energy.
   template <typename VertexUVMap>
-  std::size_t compute_root_with_lowest_energy(const TriangleMesh& mesh,
+  std::size_t compute_root_with_lowest_energy(const Triangle_mesh& mesh,
                                               face_descriptor fd,
                                               const Cot_map ctmap,
                                               const Local_points& lp,
@@ -727,7 +733,7 @@ private:
 
   // Compute the root that gives the lowest face energy.
   template <typename VertexUVMap>
-  std::size_t compute_root_with_lowest_energy(const TriangleMesh& mesh,
+  std::size_t compute_root_with_lowest_energy(const Triangle_mesh& mesh,
                                               face_descriptor fd,
                                               const Cot_map ctmap,
                                               const Local_points& lp,
@@ -753,7 +759,7 @@ private:
 
   // Compute the optimal values of the linear transformation matrices Lt.
   template <typename VertexUVMap>
-  Error_code compute_optimal_Lt_matrices(const TriangleMesh& mesh,
+  Error_code compute_optimal_Lt_matrices(const Triangle_mesh& mesh,
                                          const Faces_vector& faces,
                                          const Cot_map ctmap,
                                          const Local_points& lp,
@@ -763,7 +769,7 @@ private:
   {
     Error_code status = OK;
 
-    BOOST_FOREACH(face_descriptor fd, faces) {
+    for(face_descriptor fd : faces) {
       // Compute the coefficients C1, C2, C3
       NT C1 = 0., C2 = 0., C3 = 0.;
 
@@ -879,13 +885,13 @@ private:
   }
 
   // Compute the local parameterization (2D) of a face and store it in memory.
-  void project_face(const TriangleMesh& mesh,
+  void project_face(const Triangle_mesh& mesh,
                     vertex_descriptor vi,
                     vertex_descriptor vj,
                     vertex_descriptor vk,
                     Local_points& lp) const
   {
-    typedef typename boost::property_map<TriangleMesh,
+    typedef typename boost::property_map<Triangle_mesh,
                                          boost::vertex_point_t>::const_type PPmap;
     const PPmap ppmap = get(vertex_point, mesh);
 
@@ -905,14 +911,14 @@ private:
 
   // Utility for fill_linear_system_rhs():
   // Compute the local isometric parameterization (2D) of the faces of the mesh.
-  Error_code compute_local_parameterization(const TriangleMesh& mesh,
+  Error_code compute_local_parameterization(const Triangle_mesh& mesh,
                                             const Faces_vector& faces,
                                             Local_points& lp,
                                             Lp_map lpmap) const
   {
     int global_index = 0;
 
-    BOOST_FOREACH(face_descriptor fd, faces) {
+    for(face_descriptor fd : faces) {
       halfedge_descriptor hd = halfedge(fd, mesh), hdb = hd;
 
       vertex_descriptor vi = target(hd, mesh); // hd is k -- > i
@@ -941,9 +947,9 @@ private:
     return OK;
   }
 
-  // Compute the coefficient b_ij = (i, j) of the right hand side vector B,
+  // Compute the coefficient b_ij = (i,j) of the right hand side vector B,
   // for j neighbor vertex of i.
-  void compute_b_ij(const TriangleMesh& mesh,
+  void compute_b_ij(const Triangle_mesh& mesh,
                     halfedge_descriptor hd,
                     const Cot_map ctmap,
                     const Local_points& lp,
@@ -1011,10 +1017,10 @@ private:
   // - call compute_b_ij() for each neighbor v_j to compute the B coefficient b_i
   //
   // \pre Vertices must be indexed.
-  // \pre Vertex i musn't be already parameterized.
+  // \pre Vertex i mustn't be already parameterized.
   // \pre Lines i of Bu and Bv must be zero.
   template <typename VertexIndexMap>
-  Error_code fill_linear_system_rhs(const TriangleMesh& mesh,
+  Error_code fill_linear_system_rhs(const Triangle_mesh& mesh,
                                     vertex_descriptor vertex,
                                     const Cot_map ctmap,
                                     const Local_points& lp,
@@ -1058,7 +1064,7 @@ private:
   template <typename VertexUVMap,
             typename VertexIndexMap,
             typename VertexParameterizedMap>
-  Error_code compute_rhs(const TriangleMesh& mesh,
+  Error_code compute_rhs(const Triangle_mesh& mesh,
                          const Vertex_set& vertices,
                          const Cot_map ctmap,
                          const Local_points& lp,
@@ -1072,8 +1078,7 @@ private:
     // Initialize the right hand side B in the linear system "A*X = B"
     Error_code status = OK;
 
-    unsigned int count = 0;
-    BOOST_FOREACH(vertex_descriptor vd, vertices) {
+    for(vertex_descriptor vd : vertices) {
       if(!get(vpmap, vd)) { // not yet parameterized
         // Compute the lines i of the vectors Bu and Bv
         status = fill_linear_system_rhs(mesh, vd, ctmap, lp, lpmap,
@@ -1085,7 +1090,6 @@ private:
         const Point_2& uv = get(uvmap, vd);
         Bu.set(index, uv.x());
         Bv.set(index, uv.y());
-        ++count;
       }
     }
     return status;
@@ -1096,7 +1100,7 @@ private:
   template <typename VertexUVMap,
             typename VertexIndexMap,
             typename VertexParameterizedMap>
-  Error_code update_solution(const TriangleMesh& mesh,
+  Error_code update_solution(const Triangle_mesh& mesh,
                              const Vertex_set& vertices,
                              const Cot_map ctmap,
                              const Local_points& lp,
@@ -1121,7 +1125,7 @@ private:
 
     // Solve "A*Xu = Bu". On success, the solution is (1/Du) * Xu.
     // Solve "A*Xv = Bv". On success, the solution is (1/Dv) * Xv.
-    NT Du, Dv;
+    double Du, Dv;
     if(!get_linear_algebra_traits().linear_solver(A, Bu, Xu, Du) ||
        !get_linear_algebra_traits().linear_solver(A, Bv, Xv, Dv)) {
       std::cerr << "Could not solve linear system" << std::endl;
@@ -1136,7 +1140,7 @@ private:
     CGAL_postcondition_code
     (
       // make sure that the constrained vertices have not been moved
-      BOOST_FOREACH(vertex_descriptor vd, vertices) {
+      for(vertex_descriptor vd : vertices) {
         if(get(vpmap, vd)) {
           int index = get(vimap, vd);
           CGAL_warning(std::abs(Xu[index] - Bu[index] ) < 1e-7);
@@ -1152,7 +1156,7 @@ private:
 
   // Compute the current energy of a face, given a linear transformation matrix.
   template <typename VertexUVMap>
-  NT compute_current_face_energy(const TriangleMesh& mesh,
+  NT compute_current_face_energy(const Triangle_mesh& mesh,
                                  face_descriptor fd,
                                  const Cot_map ctmap,
                                  const Local_points& lp,
@@ -1195,7 +1199,7 @@ private:
 
   // Compute the current energy of a face.
   template <typename VertexUVMap>
-  NT compute_current_face_energy(const TriangleMesh& mesh,
+  NT compute_current_face_energy(const Triangle_mesh& mesh,
                                  face_descriptor fd,
                                  const Cot_map ctmap,
                                  const Local_points& lp,
@@ -1212,7 +1216,7 @@ private:
 
   // Compute the current energy of the parameterization.
   template <typename VertexUVMap>
-  NT compute_current_energy(const TriangleMesh& mesh,
+  NT compute_current_energy(const Triangle_mesh& mesh,
                             const Faces_vector& faces,
                             const Cot_map ctmap,
                             const Local_points& lp,
@@ -1222,7 +1226,7 @@ private:
   {
     NT E = 0.;
 
-    BOOST_FOREACH(face_descriptor fd, faces) {
+    for(face_descriptor fd : faces) {
       NT Ef = compute_current_face_energy(mesh, fd, ctmap, lp, lpmap,
                                           ltmap, uvmap);
       E += Ef;
@@ -1237,14 +1241,14 @@ private:
   // the (hopefully few) flips in the result.
   template <typename VertexUVMap,
             typename VertexIndexMap>
-  Error_code post_process(const TriangleMesh& mesh,
+  Error_code post_process(const Triangle_mesh& mesh,
                           const Vertex_set& vertices,
                           const Faces_vector& faces,
                           halfedge_descriptor bhd,
                           VertexUVMap uvmap,
                           const VertexIndexMap vimap) const
   {
-    typedef MVC_post_processor_3<TriangleMesh>     Post_processor;
+    typedef MVC_post_processor_3<Triangle_mesh>     Post_processor;
 
     Post_processor p;
     Error_code status = p.parameterize(mesh, vertices, faces, bhd, uvmap, vimap);
@@ -1260,35 +1264,35 @@ private:
 
 // Public operations
 public:
-  /// Check if the 3D -> 2D mapping is one-to-one.
-  template <typename VertexUVMap>
-  bool is_one_to_one_mapping(const TriangleMesh& mesh,
-                             const Faces_vector& faces,
+  /// returns whether the 3D -> 2D mapping is one-to-one.
+  template <typename FaceRange, typename VertexUVMap>
+  bool is_one_to_one_mapping(const Triangle_mesh& mesh,
+                             const FaceRange& faces,
                              const VertexUVMap uvmap) const
   {
     return internal::is_one_to_one_mapping(mesh, faces, uvmap);
   }
 
-  /// Compute a mapping from a triangular 3D surface mesh to a piece of the 2D space.
+  /// computes a mapping from a triangular 3D surface mesh to a piece of the 2D space.
   /// The mapping is piecewise linear (linear in each triangle).
   /// The result is the (u,v) pair image of each vertex of the 3D surface.
   ///
   /// \tparam VertexUVmap must be a model of `ReadWritePropertyMap` with
-  ///         `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key type and
-  ///         %Point_2 (type deduced from `TriangleMesh` using `Kernel_traits`)
+  ///         `boost::graph_traits<Triangle_mesh>::%vertex_descriptor` as key type and
+  ///         %Point_2 (type deduced from `Triangle_mesh` using `Kernel_traits`)
   ///         as value type.
   /// \tparam VertexIndexMap must be a model of `ReadablePropertyMap` with
-  ///         `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key type and
+  ///         `boost::graph_traits<Triangle_mesh>::%vertex_descriptor` as key type and
   ///         a unique integer as value type.
   /// \tparam VertexParameterizedMap must be a model of `ReadWritePropertyMap` with
-  ///         `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key type and
+  ///         `boost::graph_traits<Triangle_mesh>::%vertex_descriptor` as key type and
   ///         a Boolean as value type.
   ///
   /// \param mesh a triangulated surface.
   /// \param bhd a halfedge descriptor on the boundary of `mesh`.
-  /// \param uvmap an instanciation of the class `VertexUVmap`.
-  /// \param vimap an instanciation of the class `VertexIndexMap`.
-  /// \param vpmap an instanciation of the class `VertexParameterizedMap`.
+  /// \param uvmap an instantiation of the class `VertexUVmap`.
+  /// \param vimap an instantiation of the class `VertexIndexMap`.
+  /// \param vpmap an instantiation of the class `VertexParameterizedMap`.
   ///
   /// \pre `mesh` must be a triangular mesh.
   /// \pre The vertices must be indexed (vimap must be initialized).
@@ -1296,12 +1300,16 @@ public:
   template <typename VertexUVMap,
             typename VertexIndexMap,
             typename VertexParameterizedMap>
-  Error_code parameterize(TriangleMesh& mesh,
+  Error_code parameterize(Triangle_mesh& mesh,
                           halfedge_descriptor bhd,
                           VertexUVMap uvmap,
                           VertexIndexMap vimap,
                           VertexParameterizedMap vpmap)
   {
+    CGAL_precondition(is_valid_polygon_mesh(mesh));
+    CGAL_precondition(is_triangle_mesh(mesh));
+    CGAL_precondition(bhd != boost::graph_traits<Triangle_mesh>::null_halfedge() && is_border(bhd, mesh));
+
     Error_code status = OK;
 
     // vertices and faces containers
