@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Surface_mesh_parameterization/include/CGAL/Surface_mesh_parameterization/MVC_post_processor_3.h $
-// $Id: MVC_post_processor_3.h 79362c0 2019-10-07T13:10:34+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Surface_mesh_parameterization/include/CGAL/Surface_mesh_parameterization/MVC_post_processor_3.h $
+// $Id: MVC_post_processor_3.h 9e137bc 2023-01-31T12:26:55+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mael Rouxel-Labbé
 
@@ -23,12 +14,14 @@
 
 #include <CGAL/license/Surface_mesh_parameterization.h>
 
+#include <CGAL/Surface_mesh_parameterization/internal/Bool_property_map.h>
 #include <CGAL/Surface_mesh_parameterization/internal/Containers_filler.h>
 #include <CGAL/Surface_mesh_parameterization/internal/kernel_traits.h>
 
 #include <CGAL/Surface_mesh_parameterization/Two_vertices_parameterizer_3.h>
 #include <CGAL/Surface_mesh_parameterization/parameterize.h>
 
+#include <CGAL/Weights/tangent_weights.h>
 #include <CGAL/Constrained_triangulation_2.h>
 #include <CGAL/Constrained_Delaunay_triangulation_2.h>
 #include <CGAL/Polygon_mesh_processing/border.h>
@@ -41,9 +34,7 @@
 
 #include <CGAL/Default.h>
 
-#include <boost/foreach.hpp>
-#include <boost/unordered_set.hpp>
-
+#include <unordered_set>
 #include <vector>
 #include <fstream>
 #include <iostream>
@@ -99,34 +90,37 @@ public:
       Eigen::BiCGSTAB<Eigen_sparse_matrix<double>::EigenType,
                       Eigen::IncompleteLUT<double> > >
   #else
-    #pragma message("Error: You must either provide 'SolverTraits_' or link CGAL with the Eigen library")
     SolverTraits_ // no parameter provided, and Eigen is not enabled: so don't compile!
   #endif
   >::type                                                     Solver_traits;
 #else
+  /// Solver traits type
   typedef SolverTraits_                                       Solver_traits;
 #endif
 
+  /// Triangle mesh type
+  typedef TriangleMesh_                                       Triangle_mesh;
+
   typedef TriangleMesh_                                       TriangleMesh;
 
 // Private types
 private:
   // This class
-  typedef MVC_post_processor_3<TriangleMesh, Solver_traits>  Self;
+  typedef MVC_post_processor_3<Triangle_mesh, Solver_traits>  Self;
 
 // Private types
 private:
-  typedef typename boost::graph_traits<TriangleMesh>::vertex_descriptor    vertex_descriptor;
-  typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor  halfedge_descriptor;
-  typedef typename boost::graph_traits<TriangleMesh>::face_descriptor      face_descriptor;
-  typedef typename boost::graph_traits<TriangleMesh>::face_iterator        face_iterator;
-  typedef typename boost::graph_traits<TriangleMesh>::vertex_iterator      vertex_iterator;
+  typedef typename boost::graph_traits<Triangle_mesh>::vertex_descriptor    vertex_descriptor;
+  typedef typename boost::graph_traits<Triangle_mesh>::halfedge_descriptor  halfedge_descriptor;
+  typedef typename boost::graph_traits<Triangle_mesh>::face_descriptor      face_descriptor;
+  typedef typename boost::graph_traits<Triangle_mesh>::face_iterator        face_iterator;
+  typedef typename boost::graph_traits<Triangle_mesh>::vertex_iterator      vertex_iterator;
 
-  typedef boost::unordered_set<vertex_descriptor>       Vertex_set;
+  typedef std::unordered_set<vertex_descriptor>         Vertex_set;
   typedef std::vector<face_descriptor>                  Faces_vector;
 
   // Traits subtypes:
-  typedef typename internal::Kernel_traits<TriangleMesh>::Kernel    Kernel;
+  typedef typename internal::Kernel_traits<Triangle_mesh>::Kernel   Kernel;
   typedef typename Kernel::FT                                       NT;
   typedef typename Kernel::Point_2                                  Point_2;
   typedef typename Kernel::Vector_2                                 Vector_2;
@@ -138,17 +132,16 @@ private:
 
   // Types used for the convexification of the mesh
     // Each triangulation vertex is associated its corresponding vertex_descriptor
-  typedef CGAL::Triangulation_vertex_base_with_info_2<vertex_descriptor,
-                                                      Kernel>       Vb;
-    // Each triangultaion face is associated a color (inside/outside information)
-  typedef CGAL::Triangulation_face_base_with_info_2<int, Kernel>    Fb;
-  typedef CGAL::Constrained_triangulation_face_base_2<Kernel, Fb>   Cfb;
-  typedef CGAL::Triangulation_data_structure_2<Vb, Cfb>             TDS;
-  typedef CGAL::No_intersection_tag                                 Itag;
+  typedef CGAL::Triangulation_vertex_base_with_info_2<vertex_descriptor, Kernel>  Vb;
+    // Each triangulation face is associated a color (inside/outside information)
+  typedef CGAL::Triangulation_face_base_with_info_2<int, Kernel>                  Fb;
+  typedef CGAL::Constrained_triangulation_face_base_2<Kernel, Fb>                 Cfb;
+  typedef CGAL::Triangulation_data_structure_2<Vb, Cfb>                           TDS;
+  typedef CGAL::No_constraint_intersection_requiring_constructions_tag            Itag;
 
     // Can choose either a triangulation or a Delaunay triangulation
-  typedef CGAL::Constrained_triangulation_2<Kernel, TDS, Itag>                CT;
-//    typedef CGAL::Constrained_Delaunay_triangulation_2<Kernel, TDS, Itag>   CT;
+  typedef CGAL::Constrained_triangulation_2<Kernel, TDS, Itag>                    CT;
+//  typedef CGAL::Constrained_Delaunay_triangulation_2<Kernel, TDS, Itag>           CT;
 
 // Private fields
 private:
@@ -190,7 +183,7 @@ private:
                        VertexUVMap uvmap,
                        const VertexIndexMap vimap) const
   {
-    BOOST_FOREACH(vertex_descriptor vd, vertices) {
+    for(vertex_descriptor vd : vertices) {
       int index = get(vimap, vd);
       NT u = Xu(index);
       NT v = Xv(index);
@@ -201,12 +194,12 @@ private:
 // Private operations
 private:
   // Store the vertices and faces of the mesh in memory.
-  void initialize_containers(const TriangleMesh& mesh,
+  void initialize_containers(const Triangle_mesh& mesh,
                              halfedge_descriptor bhd,
                              Vertex_set& vertices,
                              Faces_vector& faces) const
   {
-    internal::Containers_filler<TriangleMesh> fc(mesh, vertices, &faces);
+    internal::Containers_filler<Triangle_mesh> fc(mesh, vertices, &faces);
     CGAL::Polygon_mesh_processing::connected_component(
                                       face(opposite(bhd, mesh), mesh),
                                       mesh,
@@ -215,14 +208,14 @@ private:
 
   // Checks whether the polygon's border is simple.
   template <typename VertexUVMap>
-  bool is_polygon_simple(const TriangleMesh& mesh,
+  bool is_polygon_simple(const Triangle_mesh& mesh,
                          halfedge_descriptor bhd,
                          const VertexUVMap uvmap) const
   {
     // @fixme unefficient: use sweep line algorithms instead of brute force
 
-    BOOST_FOREACH(halfedge_descriptor hd_1, halfedges_around_face(bhd, mesh)) {
-      BOOST_FOREACH(halfedge_descriptor hd_2, halfedges_around_face(bhd, mesh)) {
+    for(halfedge_descriptor hd_1 : halfedges_around_face(bhd, mesh)) {
+      for(halfedge_descriptor hd_2 : halfedges_around_face(bhd, mesh)) {
         if(hd_1 == hd_2 || // equality
            next(hd_1, mesh) == hd_2 || next(hd_2, mesh) == hd_1) // adjacency
           continue;
@@ -285,7 +278,7 @@ private:
   // Triangulate the convex hull of the border of the parameterization.
   template <typename CT,
             typename VertexUVMap>
-  Error_code triangulate_convex_hull(const TriangleMesh& mesh,
+  Error_code triangulate_convex_hull(const Triangle_mesh& mesh,
                                      halfedge_descriptor bhd,
                                      const VertexUVMap uvmap,
                                      CT& ct) const
@@ -294,7 +287,7 @@ private:
 
     // Since the border is closed and we are interested in triangles that are outside
     // of the border, we actually only need to insert points on the border
-    BOOST_FOREACH(halfedge_descriptor hd, halfedges_around_face(bhd, mesh)) {
+    for(halfedge_descriptor hd : halfedges_around_face(bhd, mesh)) {
       vertex_descriptor s = source(hd, mesh);
       const Point_2& sp = get(uvmap, s);
 
@@ -303,7 +296,7 @@ private:
     }
 
     // Insert constraints (the border)
-    BOOST_FOREACH(halfedge_descriptor hd, halfedges_around_face(bhd, mesh)) {
+    for(halfedge_descriptor hd : halfedges_around_face(bhd, mesh)) {
       vertex_descriptor s = source(hd, mesh), t = target(hd, mesh);
       const Point_2& sp = get(uvmap, s), tp = get(uvmap, t);
 
@@ -361,22 +354,6 @@ private:
     return OK;
   }
 
-  //                                                      -> ->
-  // Return angle (in radians) of of (P,Q,R) corner (i.e. QP,QR angle).
-  double compute_angle_rad(const Point_2& P,
-                           const Point_2& Q,
-                           const Point_2& R) const
-  {
-    Vector_2 u = P - Q;
-    Vector_2 v = R - Q;
-
-    double angle = std::atan2(v.y(), v.x()) - std::atan2(u.y(), u.x());
-    if(angle < 0)
-      angle += 2 * CGAL_PI;
-
-    return angle;
-  }
-
   // Fix vertices that are on the convex hull.
   template <typename CT,
             typename VertexParameterizedMap>
@@ -392,23 +369,6 @@ private:
     } while (++vc != vend);
   }
 
-  NT compute_w_ij_mvc(const Point_2& pi, const Point_2& pj, const Point_2& pk) const
-  {
-    //                                                               ->     ->
-    // Compute the angle (pj, pi, pk), the angle between the vectors ij and ik
-    NT angle = compute_angle_rad(pj, pi, pk);
-
-    // For flipped triangles, the connectivity is inversed and thus the angle
-    // computed by the previous function is not the one we need. Instead,
-    // we need the explementary angle.
-    if(angle > CGAL_PI) { // flipped triangle
-      angle = 2 * CGAL_PI - angle;
-    }
-    NT weight = std::tan(0.5 * angle);
-
-    return weight;
-  }
-
   void fill_linear_system_matrix_mvc_from_points(const Point_2& pi, int i,
                                                  const Point_2& pj, int j,
                                                  const Point_2& pk, int k,
@@ -425,27 +385,25 @@ private:
     // The other parts of A(i,j) and A(i,k) will be added when this function
     // is called from the neighboring faces of F_ijk that share the vertex i
 
-    // Compute: - tan(alpha / 2)
-    NT w_i_base = -1.0 * compute_w_ij_mvc(pi, pj, pk);
-
     // @fixme unefficient: lengths are computed (and inversed!) twice per edge
 
+    // Set w_i_base: - tan(alpha / 2)
+    // Match order of the input points to the new weight implementation.
+    const Point_2& p = pk;
+    const Point_2& q = pi;
+    const Point_2& r = pj;
+    const CGAL::Weights::Tangent_weight<NT> tangent_weight(p, q, r);
+
     // Set w_ij in matrix
-    Vector_2 edge_ij = pi - pj;
-    double len_ij = std::sqrt(edge_ij * edge_ij);
-    CGAL_assertion(len_ij != 0.0); // two points are identical!
-    NT w_ij = w_i_base / len_ij;
+    const NT w_ij = tangent_weight.get_w_r();
     A.add_coef(i, j, w_ij);
 
     // Set w_ik in matrix
-    Vector_2 edge_ik = pi - pk;
-    double len_ik = std::sqrt(edge_ik * edge_ik);
-    CGAL_assertion(len_ik != 0.0); // two points are identical!
-    NT w_ik = w_i_base / len_ik;
+    const NT w_ik = tangent_weight.get_w_p();
     A.add_coef(i, k, w_ik);
 
     // Add to w_ii (w_ii = - sum w_ij)
-    NT w_ii = - w_ij - w_ik;
+    const NT w_ii = - w_ij - w_ik;
     A.add_coef(i, i, w_ii);
   }
 
@@ -502,7 +460,7 @@ private:
     CGAL_precondition(!ct.is_infinite(fh));
     typedef typename CT::Vertex_handle                    Vertex_handle;
 
-    // Doing it explicitely rather than a loop for clarity
+    // Doing it explicitly rather than a loop for clarity
     Vertex_handle vh0 = fh->vertex(0);
     Vertex_handle vh1 = fh->vertex(1);
     Vertex_handle vh2 = fh->vertex(2);
@@ -518,7 +476,7 @@ private:
   template <typename VertexUVMap,
             typename VertexIndexMap,
             typename VertexParameterizedMap>
-  void fill_linear_system_matrix_mvc_from_mesh_halfedge(const TriangleMesh& mesh,
+  void fill_linear_system_matrix_mvc_from_mesh_halfedge(const Triangle_mesh& mesh,
                                                         halfedge_descriptor hd,
                                                         const VertexUVMap uvmap,
                                                         const VertexIndexMap vimap,
@@ -551,7 +509,7 @@ private:
   template <typename VertexUVMap,
             typename VertexIndexMap,
             typename VertexParameterizedMap>
-  void fill_linear_system_matrix_mvc_from_mesh_face(const TriangleMesh& mesh,
+  void fill_linear_system_matrix_mvc_from_mesh_face(const Triangle_mesh& mesh,
                                                     face_descriptor fd,
                                                     const VertexUVMap uvmap,
                                                     const VertexIndexMap vimap,
@@ -574,7 +532,7 @@ private:
             typename VertexIndexMap,
             typename VertexParameterizedMap>
   Error_code compute_mvc_matrix(const CT& ct,
-                                const TriangleMesh& mesh,
+                                const Triangle_mesh& mesh,
                                 const Faces_vector& faces,
                                 const VertexUVMap uvmap,
                                 const VertexIndexMap vimap,
@@ -603,7 +561,7 @@ private:
     }
 
     // Loop over the faces of 'mesh'
-    BOOST_FOREACH(face_descriptor fd, faces) {
+    for(face_descriptor fd : faces) {
       fill_linear_system_matrix_mvc_from_mesh_face(mesh, fd, uvmap, vimap, vpmap, A);
     }
 
@@ -620,7 +578,7 @@ private:
                        const VertexParameterizedMap vpmap,
                        Vector& Bu, Vector& Bv) const
   {
-    BOOST_FOREACH(vertex_descriptor vd, vertices) {
+    for(vertex_descriptor vd : vertices) {
       int index = get(vimap, vd);
       const Point_2& uv = get(uvmap, vd);
       if(!get(vpmap, vd)) { // not yet parameterized
@@ -640,7 +598,7 @@ private:
   {
     Error_code status = OK;
 
-    NT Du, Dv;
+    double Du, Dv;
     if(!get_linear_algebra_traits().linear_solver(A, Bu, Xu, Du) ||
        !get_linear_algebra_traits().linear_solver(A, Bv, Xv, Dv)) {
       status = ERROR_CANNOT_SOLVE_LINEAR_SYSTEM;
@@ -672,7 +630,7 @@ private:
             typename VertexUVMap,
             typename VertexIndexMap,
             typename VertexParameterizedMap>
-  Error_code parameterize_convex_hull_with_MVC(const TriangleMesh& mesh,
+  Error_code parameterize_convex_hull_with_MVC(const Triangle_mesh& mesh,
                                                const Vertex_set& vertices,
                                                const Faces_vector& faces,
                                                const CT& ct,
@@ -701,7 +659,7 @@ private:
     CGAL_postcondition_code
     (
       // make sure that the constrained vertices have not been moved
-      BOOST_FOREACH(vertex_descriptor vd, vertices) {
+      for(vertex_descriptor vd : vertices) {
         if(get(vpmap, vd)) {
           int index = get(vimap, vd);
           CGAL_postcondition(std::abs(Xu[index] - Bu[index] ) < 1e-10);
@@ -719,7 +677,7 @@ private:
 public:
   template <typename VertexUVMap,
             typename VertexIndexMap>
-  Error_code parameterize(const TriangleMesh& mesh,
+  Error_code parameterize(const Triangle_mesh& mesh,
                           const Vertex_set& vertices,
                           const Faces_vector& faces,
                           halfedge_descriptor bhd,
@@ -733,7 +691,9 @@ public:
 
     // Not sure how to handle non-simple yet @fixme
     if(!is_param_border_simple) {
+#ifdef CGAL_SMP_ARAP_DEBUG
       std::cerr << "Border is not simple!" << std::endl;
+#endif
       return ERROR_NON_CONVEX_BORDER;
     }
 
@@ -743,8 +703,8 @@ public:
 
     // Prepare the constrained triangulation: collect exterior faces (faces in
     // the convex hull but not -- geometrically -- in 'mesh').
-    boost::unordered_set<vertex_descriptor> vs;
-    internal::Bool_property_map<boost::unordered_set<vertex_descriptor> > vpmap(vs);
+    std::unordered_set<vertex_descriptor> vs;
+    internal::Bool_property_map<std::unordered_set<vertex_descriptor> > vpmap(vs);
     prepare_CT_for_parameterization(ct, vpmap);
 
     // Run the MVC
@@ -753,25 +713,25 @@ public:
     return OK;
   }
 
-  /// Compute a one-to-one mapping from a triangular 2D surface mesh
+  /// computes a one-to-one mapping from a triangular 2D surface mesh
   /// that is not necessarily embedded to a piece of the 2D space.
   ///
   /// \tparam VertexUVmap must be a model of `ReadWritePropertyMap` with
-  ///         `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key type and
-  ///         %Point_2 (type deduced from `TriangleMesh` using `Kernel_traits`)
+  ///         `boost::graph_traits<Triangle_mesh>::%vertex_descriptor` as key type and
+  ///         %Point_2 (type deduced from `Triangle_mesh` using `Kernel_traits`)
   ///         as value type.
   /// \tparam VertexIndexMap must be a model of `ReadablePropertyMap` with
-  ///         `boost::graph_traits<TriangleMesh>::%vertex_descriptor` as key type and
+  ///         `boost::graph_traits<Triangle_mesh>::%vertex_descriptor` as key type and
   ///         a unique integer as value type.
   ///
   /// \param mesh a triangulated surface.
   /// \param bhd a halfedge descriptor on the boundary of `mesh`.
-  /// \param uvmap an instanciation of the class `VertexUVmap`.
-  /// \param vimap an instanciation of the class `VertexIndexMap`.
+  /// \param uvmap an instantiation of the class `VertexUVmap`.
+  /// \param vimap an instantiation of the class `VertexIndexMap`.
   ///
   template <typename VertexUVMap,
             typename VertexIndexMap>
-  Error_code parameterize(const TriangleMesh& mesh,
+  Error_code parameterize(const Triangle_mesh& mesh,
                           halfedge_descriptor bhd,
                           VertexUVMap uvmap,
                           const VertexIndexMap vimap)
