@@ -3,19 +3,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Poisson_surface_reconstruction_3/include/CGAL/Surface_mesher/Poisson_implicit_surface_oracle_3.h $
-// $Id: Poisson_implicit_surface_oracle_3.h 4c13478 2018-05-16T16:27:41+01:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Poisson_surface_reconstruction_3/include/CGAL/Surface_mesher/Poisson_implicit_surface_oracle_3.h $
+// $Id: Poisson_implicit_surface_oracle_3.h ce65fa9 2022-09-28T11:53:10+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Steve OUDOT, Laurent RINEAU
@@ -55,53 +46,13 @@ namespace CGAL {
 
   namespace Surface_mesher {
 
-    /**
-       Type and functions required in GT:
-         - Compute_scalar_product_3             (from rev. 29646)
-         - Compute_squared_distance_3
-         - Compute_squared_radius_3
-         - Construct_center_3
-         - Construct_midpoint_3
-         - Construct_point_on_3                 (from rev. 29646)
-         - Construct_scaled_vector_3
-         - Construct_segment_3                  (from rev. 29646)
-         - Construct_translated_point_3
-         - Construct_vector_3
-         - FT
-         - Has_on_bounded_side_3                (from rev. 29646)
-         - Line_3
-         - Point_3
-         - Ray_3
-         - Segment_3
-         - Sphere_3
-         - Vector_3                             (from rev. 29646)
-         - compute_scalar_product_3_object      (from rev. 29646)
-         - compute_squared_distance_3_object
-         - compute_squared_radius_3_object
-         - construct_center_3_object
-         - construct_line_3_object              (no longer, since rev. 29646)
-         - construct_midpoint_3_object
-         - construct_point_on_3_object          (from rev. 29646)
-         - construct_scaled_vector_3_object
-         - construct_segment_3_object           (from rev. 29646)
-         - construct_translated_point_3_object
-         - construct_vector_3_object
-         - has_on_bounded_side_3_object         (from rev. 29646)
-(Computed by use of:
- perl -ne '/GT\(\)\.([a-zA-Z_0-9]+)/
-             && print "$1\n";' {implicit_surface_oracle_3.h,Sphere_oracle_3.h} | sort -u
- perl -ne '/GT::([a-zA-Z_0-9]+)/
-             && print "$1\n";' {implicit_surface_oracle_3.h,Sphere_oracle_3.h} | sort -u
-)
-    */
 
- 
   template <
     class GT,
     class Surface,
-    class Transform_functor_ = 
+    class Transform_functor_ =
       typename Real_embeddable_traits<typename Surface::FT>::Sgn,
-    class Surface_identifiers_generator_ = 
+    class Surface_identifiers_generator_ =
       Return_min<typename Transform_functor_::result_type>,
     class Point_creator = Creator_uniform_3<typename GT::FT,
                                             typename GT::Point_3>,
@@ -135,7 +86,7 @@ namespace CGAL {
 
     typedef Transform_functor_ Transform_functor;
     typedef Surface_identifiers_generator_ Surface_identifiers_generator;
-    
+
     typedef Point_3 Intersection_point;
 
     typedef Surface Surface_3;
@@ -154,7 +105,7 @@ namespace CGAL {
 
     // Constructors
 //     Poisson_implicit_surface_oracle_3 (Visitor visitor_ = Visitor()) :
-//       visitor(visitor_), 
+//       visitor(visitor_),
 //       transform_functor(),
 //       surface_identifiers_generator()
 //     {
@@ -169,7 +120,7 @@ namespace CGAL {
                                  surface_identifiers_generator
                                    = Surface_identifiers_generator(),
                                Visitor visitor_ = Visitor()) :
-      visitor(visitor_), 
+      visitor(visitor_),
       transform_functor(transform_functor),
       surface_identifiers_generator(surface_identifiers_generator)
     {
@@ -178,7 +129,7 @@ namespace CGAL {
 #endif
     }
 
-    class Intersect_3 
+    class Intersect_3
     {
       Visitor visitor;
       Transform_functor transform_functor;
@@ -217,8 +168,8 @@ namespace CGAL {
       Object operator()(const Surface_3& surface, Segment_3 s)
       // s is passed by value, because it is clipped below
       {
-	CGAL_SURFACE_MESHER_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Segment_3)");
-	CGAL_SURFACE_MESHER_TIME_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Segment_3)");
+        CGAL_SURFACE_MESHER_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Segment_3)");
+        CGAL_SURFACE_MESHER_TIME_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Segment_3)");
         typename GT::Construct_point_on_3 point_on =
           GT().construct_point_on_3_object();
 
@@ -231,7 +182,7 @@ namespace CGAL {
         Point_3 b = point_on(s, 1);
 
 #ifdef CGAL_SURFACE_MESHER_DEBUG_IMPLICIT_ORACLE
-        std::cerr << 
+        std::cerr <<
           boost::format("** Poisson_implicit_surface_oracle_3::operator()( (%1%), (%2%) )\n")
           % a % b;
 #endif
@@ -255,8 +206,8 @@ namespace CGAL {
       } // end operator()(Surface_3, Segment_3)
 
       Object operator()(const Surface_3& surface, const Ray_3& r) {
-	CGAL_SURFACE_MESHER_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Ray_3)");
-	CGAL_SURFACE_MESHER_TIME_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Ray_3)");
+        CGAL_SURFACE_MESHER_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Ray_3)");
+        CGAL_SURFACE_MESHER_TIME_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Ray_3)");
         typename Sphere_oracle::Intersect_3 clip =
           Sphere_oracle().intersect_3_object();
 
@@ -275,8 +226,8 @@ namespace CGAL {
       } // end operator()(Surface_3, Ray_3)
 
       Object operator()(const Surface_3& surface, const Line_3& l) {
-	CGAL_SURFACE_MESHER_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Line_3)");
-	CGAL_SURFACE_MESHER_TIME_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Line_3)");
+        CGAL_SURFACE_MESHER_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Line_3)");
+        CGAL_SURFACE_MESHER_TIME_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Line_3)");
         typename Sphere_oracle::Intersect_3 clip =
           Sphere_oracle().intersect_3_object();
 
@@ -296,10 +247,10 @@ namespace CGAL {
 
       // debug function
       std::string debug_point(const Surface_3& surface,
-                              const Point& p) 
+                              const Point& p)
       {
         std::stringstream s;
-        s << p << " (distance=" 
+        s << p << " (distance="
           << CGAL::sqrt(CGAL::squared_distance(p,
                                  surface.bounding_sphere().center()))
           << ", value=" << surf_equation(surface, p)
@@ -308,7 +259,7 @@ namespace CGAL {
       }
 
       result_type surf_equation (const Surface_3& surface,
-                                 const Point& p) 
+                                 const Point& p)
       {
         return transform_functor(surface(p));
       } // @TODO, @WARNING: we use x(), y() and z()
@@ -324,7 +275,7 @@ namespace CGAL {
 #ifdef CGAL_SURFACE_MESHER_DEBUG_CLIPPED_SEGMENT
         std::cerr << "clipped_segment( ("  << p1 << "), (" << p2 << ") )\n";
 #endif
-        typename GT::Compute_squared_distance_3 squared_distance = 
+        typename GT::Compute_squared_distance_3 squared_distance =
           GT().compute_squared_distance_3_object();
         typename GT::Construct_midpoint_3 midpoint =
           GT().construct_midpoint_3_object();
@@ -345,7 +296,7 @@ namespace CGAL {
           return Object();
 
 #ifdef CGAL_SURFACE_MESHER_PROFILE
-	int steps = 0;
+        int steps = 0;
 #endif
         while(true)
         {
@@ -356,10 +307,10 @@ namespace CGAL {
               return make_object(Point(ORIGIN+ ((value_at_p2 * (p1 - ORIGIN)) - (value_at_p1 * (p2 - ORIGIN))) / (value_at_p2 - value_at_p1)));
               }
           }
-          
+
 
 #ifdef CGAL_SURFACE_MESHER_PROFILE
-	  ++steps;
+          ++steps;
 #endif
 #ifdef CGAL_SURFACE_MESHER_DEBUG_CLIPPED_SEGMENT
           std::cerr << debug_point(surface, p1) << ", "
@@ -380,12 +331,12 @@ namespace CGAL {
 #endif
             // the following function conditionnally call
             // mid.set_on_surface(...) if mid has such a function.
-            set_on_surface(mid, 
+            set_on_surface(mid,
                            surface_identifiers_generator(transform_functor(value_at_p1),
                                                          transform_functor(value_at_p2)));
 
             visitor.new_point(mid);
-	    CGAL_SURFACE_MESHER_HISTOGRAM_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Segment_3) bissection steps", steps)
+            CGAL_SURFACE_MESHER_HISTOGRAM_PROFILER("Implificit_surface_oracle::Intersect_3::operator(Segment_3) bissection steps", steps)
             return make_object(mid);
           }
 
@@ -416,16 +367,16 @@ namespace CGAL {
       Construct_initial_points(const Self& oracle) : oracle(oracle)
       {
       }
-      
+
       // Random points
       template <typename OutputIteratorPoints>
-      OutputIteratorPoints operator() (const Surface_3& surface, 
-                                       OutputIteratorPoints out, 
+      OutputIteratorPoints operator() (const Surface_3& surface,
+                                       OutputIteratorPoints out,
                                        int n = 20) // WARNING: why 20?
       {
         const Sphere_3& sphere = surface.bounding_sphere();
         const Point initial_center = GT().construct_center_3_object()(sphere);
-        const FT squared_radius = 
+        const FT squared_radius =
           GT().compute_squared_radius_3_object()(sphere);
         const FT radius = CGAL::sqrt(squared_radius);
         typename Self::Intersect_3 intersect = oracle.intersect_3_object();
@@ -435,7 +386,7 @@ namespace CGAL {
           Point_creator> random_point_on_sphere(CGAL::to_double(radius), rng);
         typename CGAL::Random_points_in_sphere_3<Point,
           Point_creator> random_point_in_sphere(CGAL::to_double(radius), rng);
-        typename GT::Construct_segment_3 segment_3 = 
+        typename GT::Construct_segment_3 segment_3 =
           GT().construct_segment_3_object();
         typename GT::Construct_vector_3 vector_3 =
           GT().construct_vector_3_object();
@@ -443,13 +394,13 @@ namespace CGAL {
           GT().construct_translated_point_3_object();
 
         Point center = initial_center;
-        while (n>0) 
+        while (n>0)
         {
           const Point p = translate(*random_point_on_sphere++,
                                     vector_3(CGAL::ORIGIN, initial_center));
 
 #ifdef CGAL_SURFACE_MESHER_DEBUG_INITIAL_POINTS
-          std::cerr << "test " 
+          std::cerr << "test "
                     << intersect.debug_point(surface, center)
                     << ", " << intersect.debug_point(surface, p);
 #endif
@@ -488,7 +439,7 @@ namespace CGAL {
     Intersect_3 intersect_3_object() const
     {
       return Intersect_3(visitor,
-                         transform_functor, 
+                         transform_functor,
                          surface_identifiers_generator);
     }
 
