@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Triangulation_2/include/CGAL/Triangulation_2_traits_3.h $
+// $Id: Triangulation_2_traits_3.h d3fca65 2022-09-23T12:49:40+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Triangulation_2/include/CGAL/Triangulation_2_traits_3.h $
-// $Id: Triangulation_2_traits_3.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Mariette Yvinec
 
@@ -31,9 +22,9 @@
 #include <CGAL/Triangle_3.h>
 #include <CGAL/Kernel/global_functions_3.h>
 
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 
-namespace CGAL { 
+namespace CGAL {
 
 template<class R>
 class Compare_yz_3
@@ -48,7 +39,7 @@ public:
     return r;
    }
 };
-    
+
 
 template <class R>
 class Side_of_oriented_circle_2_3
@@ -61,33 +52,33 @@ public:
   typedef typename  R::Point_3                   Point;
   typedef typename  R::Coplanar_side_of_bounded_circle_3
                                                  Side_of_bounded_circle_2_3;
-  Oriented_side operator() (const Point& p, 
-			    const Point& q, 
-			    const Point& r,
-			    const Point& s) {
+  Oriented_side operator() (const Point& p,
+                            const Point& q,
+                            const Point& r,
+                            const Point& s) {
     Side_of_bounded_circle_2_3  side;
     Bounded_side bs = side(p,q,r,s);
     return ( bs == ON_UNBOUNDED_SIDE) ? ON_NEGATIVE_SIDE :
       (bs == ON_BOUNDED_SIDE ) ? ON_POSITIVE_SIDE :
       ON_ORIENTED_BOUNDARY;
-  }   
+  }
 };
 
 
 
 template < class R >
-class Triangulation_2_traits_3 
+class Triangulation_2_traits_3
 {
 public:
   typedef R Rep;
   typedef typename Rep::Point_3    Point_2;
   typedef typename Rep::Segment_3  Segment_2;
   typedef typename Rep::Triangle_3 Triangle_2;
- 
+
   typedef typename Rep::Compare_x_3               Compare_x_2;
   typedef Compare_yz_3<Rep>                       Compare_y_2;
   typedef typename Rep::Coplanar_orientation_3    Orientation_2;
-  typedef Side_of_oriented_circle_2_3<Rep>        Side_of_oriented_circle_2;  
+  typedef Side_of_oriented_circle_2_3<Rep>        Side_of_oriented_circle_2;
   typedef typename Rep::Construct_segment_3       Construct_segment_2;
   typedef typename Rep::Construct_triangle_3      Construct_triangle_2;
 
@@ -103,7 +94,7 @@ public:
   Compare_y_2
   compare_y_2_object() const
     { return Compare_y_2();}
-  
+
   Orientation_2
   orientation_2_object() const
     { return Orientation_2();}
@@ -120,5 +111,5 @@ public:
 
 };
 
-} //namespace CGAL 
+} //namespace CGAL
 #endif // CGAL_TRIANGULATION_2_TRAITS_3_H
