@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Triangulation_3/include/CGAL/Triangulation_hierarchy_3.h $
-// $Id: Triangulation_hierarchy_3.h bfdb89e 2018-05-24T14:50:40+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Triangulation_3/include/CGAL/Triangulation_hierarchy_3.h $
+// $Id: Triangulation_hierarchy_3.h d3fca65 2022-09-23T12:49:40+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Olivier Devillers <Olivier.Devillers@sophia.inria.fr>
 //                 Sylvain Pion
@@ -26,7 +17,7 @@
 
 // Commented because the class is actually used by Delaunay_triangulation_hierarchy_3.h
 // #define CGAL_DEPRECATED_HEADER "<CGAL/Triangulation_hierarchy_3.h>"
-// #include <CGAL/internal/deprecation_warning.h>
+// #include <CGAL/Installation/internal/deprecation_warning.h>
 
 // This class is deprecated, but must be kept for backward compatibility.
 //
@@ -37,13 +28,12 @@
 // Then, later, maybe merge the Compact/Fast codes in a cleaner factorized way.
 
 #include <CGAL/basic.h>
-#include <CGAL/internal/Has_nested_type_Bare_point.h>
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/STL_Extension/internal/Has_nested_type_Bare_point.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Triangulation_hierarchy_vertex_base_3.h>
 #include <CGAL/Location_policy.h>
 
-#include <CGAL/internal/boost/function_property_map.hpp>
-
+#include <boost/property_map/function_property_map.hpp>
 #include <boost/random/linear_congruential.hpp>
 #include <boost/random/geometric_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
@@ -52,7 +42,7 @@
 #ifndef CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
 #include <CGAL/Spatial_sort_traits_adapter_3.h>
 #include <CGAL/spatial_sort.h>
-#include <CGAL/internal/info_check.h>
+#include <CGAL/STL_Extension/internal/info_check.h>
 
 #include <boost/tuple/tuple.hpp>
 #include <boost/iterator/zip_iterator.hpp>
@@ -60,6 +50,9 @@
 #include <boost/mpl/identity.hpp>
 #include <boost/mpl/if.hpp>
 
+#include <array>
+#include <CGAL/array.h>
+
 #endif //CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
 
 namespace CGAL {
@@ -100,8 +93,15 @@ public:
 
 private:
 
+  void init_hierarchy() {
+    hierarchy[0] = this;
+    for(int i=1; i<maxlevel; ++i)
+      hierarchy[i] = &hierarchy_triangulations[i-1];
+  }
+
   // here is the stack of triangulations which form the hierarchy
-  Tr_Base*       hierarchy[maxlevel];
+  std::array<Tr_Base,maxlevel-1> hierarchy_triangulations;
+  std::array<Tr_Base*,maxlevel> hierarchy;
   boost::rand48  random;
 
   void set_up_down(Vertex_handle up, Vertex_handle down)
@@ -116,15 +116,23 @@ public:
 
   Triangulation_hierarchy_3(const Triangulation_hierarchy_3& tr);
 
+  Triangulation_hierarchy_3(Triangulation_hierarchy_3&& other)
+    noexcept( noexcept(Tr_Base(std::move(other))) )
+    : Tr_Base(std::move(other))
+    , hierarchy_triangulations(std::move(other.hierarchy_triangulations))
+    , random(std::move(other.random))
+  {
+    init_hierarchy();
+  }
+
   template < typename InputIterator >
   Triangulation_hierarchy_3(InputIterator first, InputIterator last,
                             const Geom_traits& traits = Geom_traits())
     : Tr_Base(traits)
+    , hierarchy_triangulations(make_filled_array<maxlevel-1, Tr_Base>(traits))
   {
-      hierarchy[0] = this;
-      for(int i=1; i<maxlevel; ++i)
-          hierarchy[i] = new Tr_Base(traits);
-      insert(first, last);
+    init_hierarchy();
+    insert(first, last);
   }
 
   Triangulation_hierarchy_3 & operator=(const Triangulation_hierarchy_3& tr)
@@ -134,9 +142,22 @@ public:
     return *this;
   }
 
-  ~Triangulation_hierarchy_3();
+  Triangulation_hierarchy_3 & operator=(Triangulation_hierarchy_3&& other)
+    noexcept( noexcept(Triangulation_hierarchy_3(std::move(other))) )
+  {
+    static_cast<Tr_Base&>(*this) = std::move(other);
+    hierarchy_triangulations = std::move(other.hierarchy_triangulations);
+    return *this;
+  }
 
-  void swap(Triangulation_hierarchy_3 &tr);
+  ~Triangulation_hierarchy_3() = default;
+
+  void swap(Triangulation_hierarchy_3 &tr)
+  {
+    Tr_Base::swap(tr);
+    using std::swap;
+    swap(hierarchy_triangulations, tr.hierarchy_triangulations);
+  };
 
   void clear();
 
@@ -158,12 +179,12 @@ public:
   template < class InputIterator >
   std::ptrdiff_t
   insert( InputIterator first, InputIterator last,
-          typename boost::enable_if<
+          std::enable_if_t<
             boost::is_convertible<
                 typename std::iterator_traits<InputIterator>::value_type,
                 Point
-            >
-          >::type* = NULL
+            >::value
+          >* = nullptr
   )
 #else
   template < class InputIterator >
@@ -178,12 +199,12 @@ public:
       // Spatial sort can only be used with Geom_traits::Point_3: we need an adapter
       typedef typename Geom_traits::Construct_point_3 Construct_point_3;
       typedef typename boost::result_of<const Construct_point_3(const Point&)>::type Ret;
-      typedef CGAL::internal::boost_::function_property_map<Construct_point_3, Point, Ret> fpmap;
+      typedef boost::function_property_map<Construct_point_3, Point, Ret> fpmap;
       typedef CGAL::Spatial_sort_traits_adapter_3<Geom_traits, fpmap> Search_traits_3;
 
       spatial_sort(points.begin(), points.end(),
                    Search_traits_3(
-                     CGAL::internal::boost_::make_function_property_map<Point, Ret, Construct_point_3>(
+                     boost::make_function_property_map<Point, Ret, Construct_point_3>(
                        geom_traits().construct_point_3_object()), geom_traits()));
 
       // hints[i] is the vertex of the previously inserted point in level i.
@@ -200,7 +221,7 @@ public:
 
           for (int level = 1; level <= vertex_level; ++level) {
               v = hints[level] = hierarchy[level]->insert (*p, hints[level]);
-	      set_up_down(v, prev);
+              set_up_down(v, prev);
               prev = v;
           }
       }
@@ -255,13 +276,13 @@ private:
     typedef Index_to_Bare_point<Construct_point_3,
                                 std::vector<Point> > Access_bare_point;
     typedef typename boost::result_of<const Construct_point_3(const Point&)>::type Ret;
-    typedef CGAL::internal::boost_::function_property_map<Access_bare_point, std::size_t, Ret> fpmap;
+    typedef boost::function_property_map<Access_bare_point, std::size_t, Ret> fpmap;
     typedef CGAL::Spatial_sort_traits_adapter_3<Geom_traits, fpmap> Search_traits_3;
 
     Access_bare_point accessor(points, geom_traits().construct_point_3_object());
     spatial_sort(indices.begin(), indices.end(),
                  Search_traits_3(
-                   CGAL::internal::boost_::make_function_property_map<
+                   boost::make_function_property_map<
                      std::size_t, Ret, Access_bare_point>(accessor),
                    geom_traits()));
 
@@ -295,11 +316,11 @@ public:
   std::ptrdiff_t
   insert( InputIterator first,
           InputIterator last,
-          typename boost::enable_if<
+          std::enable_if_t<
             boost::is_convertible<
               typename std::iterator_traits<InputIterator>::value_type,
               std::pair<Point,typename internal::Info_check<Vertex>::type>
-            > >::type* =NULL
+            >::value >* =nullptr
   )
   {
     return insert_with_info< std::pair<Point,typename internal::Info_check<Vertex>::type> >(first,last);
@@ -309,12 +330,12 @@ public:
   std::ptrdiff_t
   insert( boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > first,
           boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
-          typename boost::enable_if<
+          std::enable_if_t<
             boost::mpl::and_<
               boost::is_convertible< typename std::iterator_traits<InputIterator_1>::value_type, Point >,
               boost::is_convertible< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<Vertex>::type >
-            >
-          >::type* =NULL
+            >::value
+          >* =nullptr
   )
   {
     return insert_with_info< boost::tuple<Point,typename internal::Info_check<Vertex>::type> >(first,last);
@@ -337,8 +358,8 @@ public:
   template < typename InputIterator >
   size_type remove_cluster(InputIterator first, InputIterator beyond)
   {
-    CGAL_triangulation_precondition(!this->does_repeat_in_range(first, beyond));
-    CGAL_triangulation_precondition(!this->infinite_vertex_in_range(first, beyond));
+    CGAL_precondition(!this->does_repeat_in_range(first, beyond));
+    CGAL_precondition(!this->infinite_vertex_in_range(first, beyond));
     size_type n = this->number_of_vertices();
     std::vector<Vertex_handle> vo(first, beyond), vc;
     int l=0;
@@ -364,34 +385,34 @@ public: // some internal methods
   // GIVING NEW FACES
 
   template <class OutputItCells>
-  Vertex_handle insert_and_give_new_cells(const Point  &p, 
+  Vertex_handle insert_and_give_new_cells(const Point  &p,
                                           OutputItCells fit,
                                           Cell_handle start = Cell_handle() );
-		
+
   template <class OutputItCells>
   Vertex_handle insert_and_give_new_cells(const Point& p,
                                           OutputItCells /* fit */,
                                           Vertex_handle hint)
   {
-    return insert_and_give_new_cells(p, hint == Vertex_handle() ? 
-                                     this->infinite_cell() : hint->cell());			
+    return insert_and_give_new_cells(p, hint == Vertex_handle() ?
+                                     this->infinite_cell() : hint->cell());
   }
 
   template <class OutputItCells>
   Vertex_handle insert_and_give_new_cells(const Point& p,
                                           Locate_type lt,
-                                          Cell_handle c, int li, int lj, 
+                                          Cell_handle c, int li, int lj,
                                           OutputItCells fit);
 
   template <class OutputItCells>
-  void remove_and_give_new_cells(Vertex_handle v, 
+  void remove_and_give_new_cells(Vertex_handle v,
                                  OutputItCells fit);
 
   template <class OutputItCells>
-  Vertex_handle move_if_no_collision_and_give_new_cells(Vertex_handle v, 
+  Vertex_handle move_if_no_collision_and_give_new_cells(Vertex_handle v,
                                                         const Point &p, OutputItCells fit);
-	
-public:	
+
+public:
 
 
   //LOCATE
@@ -418,12 +439,12 @@ protected:
 
   struct locs {
       Cell_handle pos;
-      int li, lj;
+      int li = -1, lj = -1;
       Locate_type lt;
   };
 
   void locate(const Point& p, Locate_type& lt, int& li, int& lj,
-	      locs pos[maxlevel], Cell_handle start = Cell_handle ()) const;
+              locs pos[maxlevel], Cell_handle start = Cell_handle ()) const;
 
   int random_level();
 };
@@ -433,10 +454,9 @@ template <class Tr >
 Triangulation_hierarchy_3<Tr>::
 Triangulation_hierarchy_3(const Geom_traits& traits)
   : Tr_Base(traits)
+  , hierarchy_triangulations(make_filled_array<maxlevel-1, Tr_Base>(traits))
 {
-  hierarchy[0] = this;
-  for(int i=1;i<maxlevel;++i)
-    hierarchy[i] = new Tr_Base(traits);
+  init_hierarchy();
 }
 
 // copy constructor duplicates vertices and cells
@@ -444,10 +464,9 @@ template <class Tr>
 Triangulation_hierarchy_3<Tr>::
 Triangulation_hierarchy_3(const Triangulation_hierarchy_3<Tr> &tr)
     : Tr_Base(tr)
+    , hierarchy_triangulations(tr.hierarchy_triangulations)
 {
-  hierarchy[0] = this;
-  for(int i=1; i<maxlevel; ++i)
-    hierarchy[i] = new Tr_Base(*tr.hierarchy[i]);
+  init_hierarchy();
 
   // up and down have been copied in straightforward way
   // compute a map at lower level
@@ -461,36 +480,16 @@ Triangulation_hierarchy_3(const Triangulation_hierarchy_3<Tr> &tr)
 
   for(int j=1; j<maxlevel; ++j) {
     for( Finite_vertices_iterator it = hierarchy[j]->finite_vertices_begin(),
-	 end = hierarchy[j]->finite_vertices_end(); it != end; ++it) {
-	// current it->down() pointer goes in original instead in copied triangulation
-	set_up_down(it, V[it->down()]);
-	// make map for next level
-	if (it->up() != Vertex_handle())
-	    V[ it->up()->down() ] = it;
+         end = hierarchy[j]->finite_vertices_end(); it != end; ++it) {
+        // current it->down() pointer goes in original instead in copied triangulation
+        set_up_down(it, V[it->down()]);
+        // make map for next level
+        if (it->up() != Vertex_handle())
+            V[ it->up()->down() ] = it;
     }
   }
 }
 
-template <class Tr>
-void
-Triangulation_hierarchy_3<Tr>::
-swap(Triangulation_hierarchy_3<Tr> &tr)
-{
-  Tr_Base::swap(tr);
-  for(int i=1; i<maxlevel; ++i)
-      std::swap(hierarchy[i], tr.hierarchy[i]);
-}
-
-template <class Tr>
-Triangulation_hierarchy_3<Tr>::
-~Triangulation_hierarchy_3()
-{
-  clear();
-  for(int i=1; i<maxlevel; ++i) {
-    delete hierarchy[i];
-  }
-}
-
 template <class Tr>
 void
 Triangulation_hierarchy_3<Tr>::
@@ -509,7 +508,7 @@ is_valid(bool verbose, int level) const
 
   // verify correctness of triangulation at all levels
   for(int i=0; i<maxlevel; ++i)
-	result = result && hierarchy[i]->is_valid(verbose, level);
+        result = result && hierarchy[i]->is_valid(verbose, level);
 
   // verify that lower level has no down pointers
   for( Finite_vertices_iterator it = hierarchy[0]->finite_vertices_begin(),
@@ -519,15 +518,15 @@ is_valid(bool verbose, int level) const
   // verify that other levels has down pointer and reciprocal link is fine
   for(int j=1; j<maxlevel; ++j)
     for( Finite_vertices_iterator it = hierarchy[j]->finite_vertices_begin(),
-	 end = hierarchy[j]->finite_vertices_end(); it != end; ++it)
+         end = hierarchy[j]->finite_vertices_end(); it != end; ++it)
       result = result && &*(it) == &*(it->down()->up());
 
   // verify that other levels has down pointer and reciprocal link is fine
   for(int k=0; k<maxlevel-1; ++k)
     for( Finite_vertices_iterator it = hierarchy[k]->finite_vertices_begin(),
-	 end = hierarchy[k]->finite_vertices_end(); it != end; ++it)
+         end = hierarchy[k]->finite_vertices_end(); it != end; ++it)
       result = result && ( it->up() == Vertex_handle() ||
-	        &*it == &*(it->up())->down() );
+                &*it == &*(it->up())->down() );
 
   return result;
 }
@@ -539,16 +538,16 @@ insert(const Point &p, Cell_handle start)
 {
   int vertex_level = random_level();
   Locate_type lt;
-  int i, j;
+  int i = -1, j = -1;
   // locate using hierarchy
   locs positions[maxlevel];
   locate(p, lt, i, j, positions, start);
   // insert at level 0
   Vertex_handle vertex = hierarchy[0]->insert(p,
-	                                      positions[0].lt,
-	                                      positions[0].pos,
-	                                      positions[0].li,
-	                                      positions[0].lj);
+                                              positions[0].lt,
+                                              positions[0].pos,
+                                              positions[0].li,
+                                              positions[0].lj);
   Vertex_handle previous = vertex;
   Vertex_handle first = vertex;
 
@@ -558,10 +557,10 @@ insert(const Point &p, Cell_handle start)
           vertex = hierarchy[level]->insert(p);
       else
           vertex = hierarchy[level]->insert(p,
-	                                    positions[level].lt,
-	                                    positions[level].pos,
-	                                    positions[level].li,
-	                                    positions[level].lj);
+                                            positions[level].lt,
+                                            positions[level].pos,
+                                            positions[level].li,
+                                            positions[level].lj);
     set_up_down(vertex, previous);
     previous=vertex;
     level++;
@@ -628,13 +627,13 @@ insert(const Point &p, Locate_type lt, Cell_handle loc, int li, int lj)
     int level = 1;
     while (level <= vertex_level ){
       if (positions[level].pos == Cell_handle())
-	vertex = hierarchy[level]->insert(p);
+        vertex = hierarchy[level]->insert(p);
       else
-	vertex = hierarchy[level]->insert(p,
-	    positions[level].lt,
-	    positions[level].pos,
-	    positions[level].li,
-	    positions[level].lj);
+        vertex = hierarchy[level]->insert(p,
+            positions[level].lt,
+            positions[level].pos,
+            positions[level].li,
+            positions[level].lj);
       set_up_down(vertex, previous);
       previous=vertex;
       level++;
@@ -647,12 +646,12 @@ template <class Tr>
 template <class OutputItCells>
 typename Triangulation_hierarchy_3<Tr>::Vertex_handle
 Triangulation_hierarchy_3<Tr>::
-insert_and_give_new_cells(const Point &p, Locate_type lt, Cell_handle loc, 
+insert_and_give_new_cells(const Point &p, Locate_type lt, Cell_handle loc,
   int li, int lj, OutputItCells fit)
 {
   int vertex_level = random_level();
   // insert at level 0
-  Vertex_handle vertex = 
+  Vertex_handle vertex =
     hierarchy[0]->insert_and_give_new_cells(p,lt,loc,li,lj,fit);
   Vertex_handle previous = vertex;
   Vertex_handle first = vertex;
@@ -667,9 +666,9 @@ insert_and_give_new_cells(const Point &p, Locate_type lt, Cell_handle loc,
     int level = 1;
     while (level <= vertex_level ){
       if (positions[level].pos == Cell_handle())
-	vertex = hierarchy[level]->insert(p);
+        vertex = hierarchy[level]->insert(p);
       else
-	vertex = hierarchy[level]->insert(p,
+        vertex = hierarchy[level]->insert(p,
                                           positions[level].lt,
                                           positions[level].pos,
                                           positions[level].li,
@@ -687,12 +686,12 @@ void
 Triangulation_hierarchy_3<Tr>::
 remove(Vertex_handle v)
 {
-  CGAL_triangulation_precondition(v != Vertex_handle());
+  CGAL_precondition(v != Vertex_handle());
   for (int l = 0; l < maxlevel; ++l) {
     Vertex_handle u = v->up();
     hierarchy[l]->remove(v);
     if (u == Vertex_handle())
-	break;
+        break;
     v = u;
   }
 }
@@ -703,14 +702,14 @@ void
 Triangulation_hierarchy_3<Tr>::
 remove_and_give_new_cells(Vertex_handle v, OutputItCells fit)
 {
-  CGAL_triangulation_precondition(v != Vertex_handle());
-  CGAL_triangulation_precondition(!is_infinite(v));
+  CGAL_precondition(v != Vertex_handle());
+  CGAL_precondition(!is_infinite(v));
   for (int l = 0; l < maxlevel; ++l) {
     Vertex_handle u = v->up();
     if(l) hierarchy[l]->remove(v);
     else hierarchy[l]->remove_and_give_new_cells(v, fit);
     if (u == Vertex_handle())
-	break;
+        break;
     v = u;
   }
 }
@@ -720,7 +719,7 @@ typename Triangulation_hierarchy_3<Tr>::Vertex_handle
 Triangulation_hierarchy_3<Tr>::
 move_if_no_collision(Vertex_handle v, const Point & p)
 {
-  CGAL_triangulation_precondition(!this->is_infinite(v));	
+  CGAL_precondition(!this->is_infinite(v));
   if(v->point() == p) return v;
   Vertex_handle ans;
   for (int l = 0; l < maxlevel; ++l) {
@@ -740,7 +739,7 @@ typename Triangulation_hierarchy_3<Tr>::Vertex_handle
 Triangulation_hierarchy_3<Tr>::
 move(Vertex_handle v, const Point & p)
 {
-  CGAL_triangulation_precondition(!this->is_infinite(v));
+  CGAL_precondition(!this->is_infinite(v));
   if(v->point() == p) return v;
   Vertex_handle w = move_if_no_collision(v,p);
   if(w != v) {
@@ -757,13 +756,13 @@ Triangulation_hierarchy_3<Tr>::
 move_if_no_collision_and_give_new_cells(
   Vertex_handle v, const Point & p, OutputItCells fit)
 {
-  CGAL_triangulation_precondition(!is_infinite(v));	
+  CGAL_precondition(!is_infinite(v));
   if(v->point() == p) return v;
   Vertex_handle ans;
   for (int l = 0; l < maxlevel; ++l) {
     Vertex_handle u = v->up();
     if(l) hierarchy[l]->move_if_no_collision(v, p);
-    else ans = 
+    else ans =
            hierarchy[l]->move_if_no_collision_and_give_new_cells(v, p, fit);
     if(ans != v) return ans;
     if (u == Vertex_handle())
@@ -810,7 +809,7 @@ locate(const Point& p, Locate_type& lt, int& li, int& lj,
   // find the highest level with enough vertices
   while (hierarchy[--level]->number_of_vertices() < (size_type) minsize) {
     if ( ! level)
-	break;  // do not go below 0
+        break;  // do not go below 0
   }
 
   for (int i=level+1; i<maxlevel; ++i)
@@ -821,10 +820,10 @@ locate(const Point& p, Locate_type& lt, int& li, int& lj,
     // locate at that level from "position"
     // result is stored in "position" for the next level
     pos[level].pos = position = hierarchy[level]->locate(p,
-	                                                 pos[level].lt,
-	                                                 pos[level].li,
-	                                                 pos[level].lj,
-	                                                 position);
+                                                         pos[level].lt,
+                                                         pos[level].li,
+                                                         pos[level].lj,
+                                                         position);
     // find the nearest vertex.
     Vertex_handle nearest = hierarchy[level]->nearest_vertex_in_cell(p, position);
 
@@ -856,7 +855,7 @@ int
 Triangulation_hierarchy_3<Tr>::
 random_level()
 {
-  boost::geometric_distribution<> proba(1.0/ratio);
+  boost::geometric_distribution<> proba(1.0/double(ratio));
   boost::variate_generator<boost::rand48&, boost::geometric_distribution<> > die(random, proba);
 
   return (std::min)(die(), (int)maxlevel)-1;
