@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2/Vertex.h $
+// $Id: Vertex.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2/Vertex.h $
-// $Id: Vertex.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
@@ -66,7 +57,7 @@ class Vertex
 
   // CONSTRUCTORS
   //-------------
-  Vertex(const VDA* vda = NULL) : vda_(vda) {}
+  Vertex(const VDA* vda = nullptr) : vda_(vda) {}
   Vertex(const VDA* vda, Delaunay_face_handle f) : vda_(vda), f_(f) {
     CGAL_precondition( !vda_->dual().is_infinite(f_) );
   }
@@ -77,35 +68,35 @@ class Vertex
     Delaunay_face_handle fvalid = find_valid_vertex(f_);
     for (int i = 0; i < 3; i++) {
       int ccw_i = CW_CCW_2::ccw(i);
-      
+
       // if I want to return also infinite edges replace the test in
       // the if statement by the following test (i.e., should omit the
       // testing for infinity):
       //           !vda_->edge_rejector()(vda_->dual(), fvalid, i)
       if ( !vda_->edge_rejector()(vda_->dual(), fvalid, i) &&
-	   !vda_->dual().is_infinite(fvalid, i) ) {
-	if ( vda_->face_rejector()(vda_->dual(), fvalid->vertex(ccw_i)) ) {
-	  Delaunay_face_handle fopp;
-	  int iopp, i_mirror = vda_->dual().tds().mirror_index(fvalid, i);
+           !vda_->dual().is_infinite(fvalid, i) ) {
+        if ( vda_->face_rejector()(vda_->dual(), fvalid->vertex(ccw_i)) ) {
+          Delaunay_face_handle fopp;
+          int iopp, i_mirror = vda_->dual().tds().mirror_index(fvalid, i);
 
-	  Find_opposite_halfedge<VDA>()(vda_,
-					fvalid->neighbor(i),
-					i_mirror,
-					fopp, iopp);
+          Find_opposite_halfedge<VDA>()(vda_,
+                                        fvalid->neighbor(i),
+                                        i_mirror,
+                                        fopp, iopp);
 #if !defined(CGAL_NO_ASSERTIONS) && !defined(NDEBUG)
-	  Halfedge h(vda_, fopp, iopp);
-	  Vertex_handle v_this(*this);
-	  CGAL_assertion( h.has_target() && h.target() == v_this );
+          Halfedge h(vda_, fopp, iopp);
+          Vertex_handle v_this(*this);
+          CGAL_assertion( h.has_target() && h.target() == v_this );
 #endif
-	  return Halfedge_handle( Halfedge(vda_, fopp, iopp) );
-	} else {
+          return Halfedge_handle( Halfedge(vda_, fopp, iopp) );
+        } else {
 #if !defined(CGAL_NO_ASSERTIONS) && !defined(NDEBUG)
-	  Halfedge h(vda_, fvalid, i);
-	  Vertex_handle v_this(*this);
-	  CGAL_assertion( h.has_target() && h.target() == v_this );
+          Halfedge h(vda_, fvalid, i);
+          Vertex_handle v_this(*this);
+          CGAL_assertion( h.has_target() && h.target() == v_this );
 #endif
-	  return Halfedge_handle( Halfedge(vda_, fvalid, i) );
-	}
+          return Halfedge_handle( Halfedge(vda_, fvalid, i) );
+        }
       }
     }
 
@@ -118,7 +109,7 @@ class Vertex
 
   Halfedge_around_vertex_circulator incident_halfedges() const {
     CGAL_assertion( halfedge()->has_target() &&
-		    halfedge()->target() == Vertex_handle(*this) );
+                    halfedge()->target() == Vertex_handle(*this) );
     return Halfedge_around_vertex_circulator( *halfedge() );
   }
 
@@ -183,7 +174,7 @@ class Vertex
   // VALIDITY TESTING
   //-----------------
   bool is_valid() const {
-    if ( vda_ == NULL ) { return true; }
+    if ( vda_ == nullptr ) { return true; }
 
     bool valid = !vda_->dual().is_infinite(f_);
 
@@ -218,8 +209,8 @@ class Vertex
   // COMPARISON OPERATORS
   //---------------------
   bool operator==(const Self& other) const {
-    if ( vda_ == NULL ) { return other.vda_ == NULL; }
-    if ( other.vda_ == NULL ) { return vda_ == NULL; }
+    if ( vda_ == nullptr ) { return other.vda_ == nullptr; }
+    if ( other.vda_ == nullptr ) { return vda_ == nullptr; }
     return ( vda_ == other.vda_ && f_ == other.f_ );
   }
 
@@ -228,8 +219,8 @@ class Vertex
   }
 
   bool operator<(const Self& other) const {
-    if ( vda_ == NULL ) { return other.vda_ != NULL; }
-    if ( other.vda_ == NULL ) { return false; }
+    if ( vda_ == nullptr ) { return other.vda_ != nullptr; }
+    if ( other.vda_ == nullptr ) { return false; }
     if ( vda_ != other.vda_ ) { return vda_ < other.vda_; }
     return f_ < other.f_;
   }
