@@ -1,19 +1,10 @@
 // Copyright (c) 2016  GeometryFactory (France).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/BGL/include/CGAL/boost/graph/Graph_with_descriptor_with_graph.h $
-// $Id: Graph_with_descriptor_with_graph.h a5576cd 2019-02-14T10:53:48+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/BGL/include/CGAL/boost/graph/Graph_with_descriptor_with_graph.h $
+// $Id: Graph_with_descriptor_with_graph.h 590ddf8 2021-10-08T15:38:47+02:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Andreas Fabri
@@ -44,11 +35,11 @@ public:
   Descriptor descriptor;
 
   Gwdwg_descriptor()
-    : graph(NULL), descriptor()
+    : graph(nullptr), descriptor()
   {}
 
   Gwdwg_descriptor(Descriptor descriptor)
-    : graph(NULL), descriptor(descriptor)
+    : graph(nullptr), descriptor(descriptor)
   {}
 
   Gwdwg_descriptor(Descriptor descriptor, Graph& graph)
@@ -60,7 +51,7 @@ template<typename Graph,typename Descriptor>
 bool operator==(const Gwdwg_descriptor<Graph,Descriptor>& lhs,
                 const Gwdwg_descriptor<Graph,Descriptor>& rhs)
 {
-  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==NULL || lhs.graph==NULL);
+  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==nullptr || lhs.graph==nullptr);
   return lhs.descriptor == rhs.descriptor;
 }
 
@@ -75,7 +66,7 @@ template<typename Graph,typename Descriptor>
 bool operator<(const Gwdwg_descriptor<Graph,Descriptor>& lhs,
                 const Gwdwg_descriptor<Graph,Descriptor>& rhs)
 {
-  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==NULL || lhs.graph==NULL);
+  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==nullptr || lhs.graph==nullptr);
   return lhs.descriptor < rhs.descriptor;
 }
 
@@ -83,7 +74,7 @@ template<typename Graph,typename Descriptor>
 bool operator>(const Gwdwg_descriptor<Graph,Descriptor>& lhs,
                 const Gwdwg_descriptor<Graph,Descriptor>& rhs)
 {
-  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==NULL || lhs.graph==NULL);
+  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==nullptr || lhs.graph==nullptr);
   return lhs.descriptor > rhs.descriptor;
 }
 
@@ -91,7 +82,7 @@ template<typename Graph,typename Descriptor>
 bool operator<=(const Gwdwg_descriptor<Graph,Descriptor>& lhs,
                 const Gwdwg_descriptor<Graph,Descriptor>& rhs)
 {
-  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==NULL || lhs.graph==NULL);
+  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==nullptr || lhs.graph==nullptr);
   return lhs.descriptor <= rhs.descriptor;
 }
 
@@ -99,7 +90,7 @@ template<typename Graph,typename Descriptor>
 bool operator>=(const Gwdwg_descriptor<Graph,Descriptor>& lhs,
                 const Gwdwg_descriptor<Graph,Descriptor>& rhs)
 {
-  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==NULL || lhs.graph==NULL);
+  CGAL_assertion( lhs.graph == rhs.graph || rhs.graph==nullptr || lhs.graph==nullptr);
   return lhs.descriptor >= rhs.descriptor;
 }
 
@@ -142,7 +133,7 @@ struct Graph_with_descriptor_with_graph
   typedef Gwdwg_descriptor<Graph, typename gt::face_descriptor> face_descriptor;
 
   Graph_with_descriptor_with_graph()
-    : graph(NULL)
+    : graph(nullptr)
   {}
 
   Graph_with_descriptor_with_graph(Graph& graph)
@@ -156,7 +147,7 @@ struct Descriptor2Descriptor: public CGAL::cpp98::unary_function<Graph_descripto
 {
 
   Descriptor2Descriptor()
-    : graph(NULL)
+    : graph(nullptr)
   {}
 
   Descriptor2Descriptor(Graph& graph)
@@ -166,7 +157,7 @@ struct Descriptor2Descriptor: public CGAL::cpp98::unary_function<Graph_descripto
   Descriptor
   operator()(Graph_descriptor gd) const
   {
-    CGAL_assertion(graph!=NULL);
+    CGAL_assertion(graph!=nullptr);
     return Descriptor(gd,*graph);
   }
 
@@ -716,7 +707,7 @@ struct Graph_with_descriptor_with_graph_property_map {
   PM pm;
 
   Graph_with_descriptor_with_graph_property_map()
-    : graph(NULL)
+    : graph(nullptr)
   {}
 
   Graph_with_descriptor_with_graph_property_map(const Graph& graph, const PM& pm)
@@ -728,7 +719,7 @@ struct Graph_with_descriptor_with_graph_property_map {
   reference
   get(const Graph_with_descriptor_with_graph_property_map<Graph,PM>& gpm, const Descriptor& d)
   {
-    CGAL_assertion(gpm.graph!=NULL);
+    CGAL_assertion(gpm.graph!=nullptr);
     CGAL_assertion(d.graph == gpm.graph);
     return get(gpm.pm, d.descriptor);
   }
@@ -736,9 +727,9 @@ struct Graph_with_descriptor_with_graph_property_map {
   template <typename Descriptor>
   friend
   void
-  put(const Graph_with_descriptor_with_graph_property_map<Graph,PM>& gpm, const Descriptor& d,   const value_type& v)
+  put(const Graph_with_descriptor_with_graph_property_map<Graph,PM>& gpm, const Descriptor& d, const value_type& v)
   {
-    CGAL_assertion(gpm.graph!=NULL);
+    CGAL_assertion(gpm.graph!=nullptr);
     CGAL_assertion(d.graph == gpm.graph);
     put(gpm.pm, d.descriptor, v);
   }
@@ -756,13 +747,13 @@ struct Graph_with_descriptor_with_graph_property_map<Graph, PM, boost::lvalue_pr
   Graph* graph;
   PM pm;
 
-  value_type& operator[](key_type& k) const
+  reference operator[](key_type& k) const
   {
-      return get(*this, k);
+    return get(*this, k);
   }
 
   Graph_with_descriptor_with_graph_property_map()
-    : graph(NULL)
+    : graph(nullptr)
   {}
 
   Graph_with_descriptor_with_graph_property_map(const Graph& graph, const PM& pm)
@@ -774,7 +765,7 @@ struct Graph_with_descriptor_with_graph_property_map<Graph, PM, boost::lvalue_pr
   reference
   get(const Graph_with_descriptor_with_graph_property_map<Graph,PM>& gpm, const Descriptor& d)
   {
-    CGAL_assertion(gpm.graph!=NULL);
+    CGAL_assertion(gpm.graph!=nullptr);
     CGAL_assertion(d.graph == gpm.graph);
     return get(gpm.pm, d.descriptor);
   }
@@ -784,7 +775,7 @@ struct Graph_with_descriptor_with_graph_property_map<Graph, PM, boost::lvalue_pr
   void
   put(const Graph_with_descriptor_with_graph_property_map<Graph,PM>& gpm, const Descriptor& d,   const value_type& v)
   {
-    CGAL_assertion(gpm.graph!=NULL);
+    CGAL_assertion(gpm.graph!=nullptr);
     CGAL_assertion(d.graph == gpm.graph);
     put(gpm.pm, d.descriptor, v);
   }
