@@ -1,19 +1,10 @@
 // Copyright (c) 2018  GeometryFactory (France).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/HalfedgeDS/include/CGAL/boost/graph/graph_traits_HalfedgeDS_default.h $
-// $Id: graph_traits_HalfedgeDS_default.h 2f81a21 2019-07-28T18:38:59+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/HalfedgeDS/include/CGAL/boost/graph/graph_traits_HalfedgeDS_default.h $
+// $Id: graph_traits_HalfedgeDS_default.h 4b9032f 2022-07-08T20:24:58+02:00 Sebastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Andreas Fabri
@@ -30,14 +21,14 @@
 
 namespace CGAL {
 
-template <class Traits_, class HalfedgeDSItems, 
+template <class Traits_, class HalfedgeDSItems,
           class Alloc>
 class HalfedgeDS_default;
 } // namespace CGAL
 
 namespace boost {
 
-  
+
 
 template<class T, class I, class A>
 struct graph_traits< CGAL::HalfedgeDS_default<T,I,A> >
@@ -54,7 +45,7 @@ struct graph_traits< CGAL::HalfedgeDS_default<T,I,A> const >
 } // namespace boost
 
 namespace CGAL {
-  
+
 template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::vertices_size_type
 num_vertices(const HalfedgeDS_default<T,I,A>& p)
@@ -72,25 +63,28 @@ num_edges(const HalfedgeDS_default<T,I,A>& p)
 template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::degree_size_type
 degree(typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::vertex_descriptor v
-       , const HalfedgeDS_default<T,I,A>&)
+       , const HalfedgeDS_default<T,I,A>& hds)
 {
-  return v->vertex_degree();
+  if(halfedge(v,hds) == boost::graph_traits<HalfedgeDS_default<T,I,A> const>::null_halfedge()){
+    return 0;
+  }
+  return halfedges_around_target(v,hds).size();
 }
 
 template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::degree_size_type
 out_degree(typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::vertex_descriptor v
-           , const HalfedgeDS_default<T,I,A>&)
+           , const HalfedgeDS_default<T,I,A>& hds)
 {
-  return v->vertex_degree();
+    return degree(v, hds);
 }
 
 template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::degree_size_type
 in_degree(typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::vertex_descriptor v
-          , const HalfedgeDS_default<T,I,A>&)
+          , const HalfedgeDS_default<T,I,A>& hds)
 {
-  return v->vertex_degree();
+  return degree(v,hds);
 }
 
 template<class T, class I, class A>
@@ -181,9 +175,17 @@ out_edges( typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::verte
   return make_range(Iter(halfedge(u,p),p), Iter(halfedge(u,p),p,1));
 }
 
+template<class T, class I, class A>
+inline Iterator_range<typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::adjacency_iterator>
+adjacent_vertices( typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::vertex_descriptor u
+                   , const HalfedgeDS_default<T,I,A>& p)
+{
+  return CGAL::vertices_around_target(u,p);
+}
+
 //
 // MutableHalfedgeGraph
-// 
+//
 
 template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::vertex_descriptor
@@ -212,9 +214,9 @@ remove_vertex(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::vertex_
 template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::edge_descriptor
 add_edge(HalfedgeDS_default<T,I,A>& g)
-{ 
+{
   return typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::edge_descriptor(
-    g.edges_push_back(typename HalfedgeDS_default<T,I,A>::Halfedge(), 
+    g.edges_push_back(typename HalfedgeDS_default<T,I,A>::Halfedge(),
                             typename HalfedgeDS_default<T,I,A>::Halfedge()));
 }
 
@@ -254,7 +256,7 @@ set_next(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::halfedge_des
 }
 
 //
-// MutableFaceGraph 
+// MutableFaceGraph
 //
 
 template<class T, class I, class A>
@@ -274,7 +276,7 @@ add_face(InputIterator begin, InputIterator end, HalfedgeDS_default<T,I,A>& g)
 template<class T, class I, class A>
 void
 remove_face(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::face_descriptor f
-            , HalfedgeDS_default<T,I,A>& g) 
+            , HalfedgeDS_default<T,I,A>& g)
 {
   g.faces_erase(f);
 }
@@ -323,7 +325,7 @@ template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::edge_descriptor
 edge(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::halfedge_descriptor h
      , const HalfedgeDS_default<T,I,A>&)
-{ 
+{
   return typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::edge_descriptor(h);
 }
 
@@ -331,7 +333,7 @@ template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::halfedge_descriptor
 halfedge(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::edge_descriptor e
          , const HalfedgeDS_default<T,I,A>&)
-{ 
+{
   return e.halfedge();
 }
 
@@ -339,7 +341,7 @@ template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::halfedge_descriptor
 halfedge(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::vertex_descriptor v
          , const HalfedgeDS_default<T,I,A>&)
-{ 
+{
   return v->halfedge();
 }
 
@@ -349,7 +351,7 @@ std::pair< typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::halfedge_d
 halfedge(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::vertex_descriptor u
          , typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::vertex_descriptor v
          , const HalfedgeDS_default<T,I,A>& g)
-{ 
+{
   std::pair< typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::edge_descriptor
              , bool> e = edge(u, v, g);
   return std::make_pair(e.first.halfedge(), e.second);
@@ -420,7 +422,7 @@ num_halfedges(const HalfedgeDS_default<T,I,A>& p)
 template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::face_descriptor
 face(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::halfedge_descriptor h
-     , const HalfedgeDS_default<T,I,A>&) 
+     , const HalfedgeDS_default<T,I,A>&)
 {
   return h->face();
 }
@@ -428,7 +430,7 @@ face(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::halfedge_descrip
 template<class T, class I, class A>
 typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::halfedge_descriptor
 halfedge(typename boost::graph_traits< HalfedgeDS_default<T,I,A> >::face_descriptor f
-         , const HalfedgeDS_default<T,I,A>&) 
+         , const HalfedgeDS_default<T,I,A>&)
 {
   return f->halfedge();
 }
@@ -449,29 +451,6 @@ num_faces(const HalfedgeDS_default<T,I,A>& p)
   return p.size_of_faces();
 }
 
-template <class T>
-struct HDS_property_map;
-  
-template <>
-struct HDS_property_map<vertex_point_t>
-{
-  template<class T, class I, class A>
-  struct bind_
-  {
-    typedef internal::Point_accessor<
-      typename boost::graph_traits<
-        HalfedgeDS_default<T, I, A>
-        >::vertex_descriptor,
-      typename T::Point_3, typename T::Point_3&> type;
-
-    typedef internal::Point_accessor<
-      typename boost::graph_traits<
-        HalfedgeDS_default<T, I, A>
-        >::vertex_descriptor,
-      typename T::Point_3, const typename T::Point_3&> const_type;
-  };
-};
-
 template<class T, class I, class A>
 void reserve(HalfedgeDS_default<T,I,A>& p,
              typename boost::graph_traits< HalfedgeDS_default<T,I,A> const>::vertices_size_type nv,
@@ -482,43 +461,7 @@ void reserve(HalfedgeDS_default<T,I,A>& p,
 }
 
 }// namespace CGAL
-namespace boost {
 
-// property_map dispatcher into Polyhedron
-template<class T, class I, class A, class Tag>
-struct property_map<CGAL::HalfedgeDS_default<T,I,A>, Tag>
-{
-  typedef typename CGAL::HDS_property_map<Tag>::
-      template bind_<T,I,A> map_gen;
-  typedef typename map_gen::type       type;
-  typedef typename map_gen::const_type const_type;
-};
+#include <CGAL/boost/graph/properties_HalfedgeDS_default.h>
 
-// property_map dispatcher into const Polyhedron
-template<class T, class I, class A, class Tag>
-struct property_map<const CGAL::HalfedgeDS_default<T,I,A>, Tag>
-{
-  typedef typename CGAL::HDS_property_map<Tag>::
-      template bind_<T,I,A> map_gen;
-  typedef typename map_gen::type       type;
-  typedef typename map_gen::const_type const_type;
-};
-
-} // namespace boost
-
-namespace CGAL {
-
-// generalized 2-ary get functions
-template<class Gt, class I, class A, class PropertyTag>
-typename boost::property_map< CGAL::HalfedgeDS_default<Gt,I,A>, PropertyTag >::const_type
-get(PropertyTag, CGAL::HalfedgeDS_default<Gt,I,A> const&)
-{ return typename boost::property_map< CGAL::HalfedgeDS_default<Gt,I,A>, PropertyTag >::const_type(); }
-
-template<class Gt, class I, class A, class PropertyTag>
-typename boost::property_map< CGAL::HalfedgeDS_default<Gt,I,A>, PropertyTag >::type
-get(PropertyTag, CGAL::HalfedgeDS_default<Gt,I,A>&)
-{ return typename boost::property_map< CGAL::HalfedgeDS_default<Gt,I,A>, PropertyTag >::type(); }
-
-
-} // namespace CGAL
 #endif
