@@ -5,20 +5,11 @@
 // Max-Planck-Institute Saarbruecken (Germany),
 // and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Installation/include/CGAL/config.h $
-// $Id: config.h 856b772 2019-10-15T09:03:13+02:00 Maxime Gimeno
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Installation/include/CGAL/config.h $
+// $Id: config.h d2bc415 2023-05-04T16:37:17+02:00 Laurent Rineau
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 //
@@ -30,6 +21,11 @@
 #ifndef CGAL_CONFIG_H
 #define CGAL_CONFIG_H
 
+// CGAL is header-only by default since CGAL-5.0.
+#if !defined(CGAL_HEADER_ONLY) && ! CGAL_NOT_HEADER_ONLY
+#  define CGAL_HEADER_ONLY 1
+#endif
+
 #ifdef CGAL_HEADER_ONLY
 #  define CGAL_NO_AUTOLINK 1
 #endif
@@ -40,6 +36,11 @@
 #  define WIN64
 #endif
 
+#ifdef _MSC_VER
+#define _SILENCE_CXX17_ALLOCATOR_VOID_DEPRECATION_WARNING 1
+#define _SILENCE_CXX17_OLD_ALLOCATOR_MEMBERS_DEPRECATION_WARNING 1
+#endif
+
 #ifdef CGAL_INCLUDE_WINDOWS_DOT_H
 // Mimic users including this file which defines min max macros
 // and other names leading to name clashes
@@ -51,7 +52,7 @@
 #endif // CGAL_TEST_SUITE and NDEBUG
 
 // See [[Small features/Visual_Leak_Detector]] in CGAL developers wiki
-// See also: http://vld.codeplex.com/
+// See also: https://kinddragon.github.io/vld/
 #if defined(CGAL_ENABLE_VLD)
 #  include <vld.h>
 #endif // CGAL_ENABLE_VLD
@@ -105,47 +106,16 @@
 // <boost/type_traits/detail/has_postfix_operator.hpp> fails as well
 #  define BOOST_TT_HAS_POST_DECREMENT_HPP_INCLUDED
 #  define BOOST_TT_HAS_POST_INCREMENT_HPP_INCLUDED
+//work around for moc bug : https://bugreports.qt.io/browse/QTBUG-80990
+#if defined(CGAL_LINKED_WITH_TBB)
+#undef CGAL_LINKED_WITH_TBB
+#endif
 #endif
-
-// Macro used by Boost Parameter. Mesh_3 needs at least 12, before the
-// Boost Parameter headers are included: <boost/parameter/config.hpp>
-// defines the value to 8, if it is not yet defined.
-// The CGAL BGL properties mechanism includes
-// <boost/graph/named_function_params.hpp>, that includes
-// <boost/parameter/name.hpp>, and maybe other Boost libraries may use
-// Boost Parameter as well.
-// That is why that is important to define that macro as early as possible,
-// in <CGAL/config.h>
-#define BOOST_PARAMETER_MAX_ARITY 12
 
 // The following header file defines among other things  BOOST_PREVENT_MACRO_SUBSTITUTION
 #include <boost/config.hpp>
 #include <boost/version.hpp>
 
-// bug-fix for g++-5.x and Boost.Config<1.57
-//    https://svn.boost.org/trac/boost/ticket/10500
-#if BOOST_VERSION < 105700 && BOOST_GCC < 60000 && \
-  ! defined(__GXX_EXPERIMENTAL_CXX0X__) && defined(BOOST_HAS_VARIADIC_TMPL)
-#  undef BOOST_HAS_VARIADIC_TMPL
-#  define BOOST_NO_CXX11_VARIADIC_TEMPLATES
-#endif
-
-// workaround for the bug https://svn.boost.org/trac10/ticket/12534
-// That bug was introduced in Boost 1.62 and fixed in 1.63.
-#if BOOST_VERSION >= 106200 && BOOST_VERSION < 106300
-#  include <boost/container/flat_map.hpp>
-#endif
-
-// Hack: Boost<1.55 does not detect correctly the C++11 features of ICC.
-// We declare by hand two features that we need (variadic templates and
-// rvalue references).
-#if defined(__INTEL_COMPILER) && defined(__GXX_EXPERIMENTAL_CXX0X__)
-#  undef BOOST_NO_VARIADIC_TEMPLATES
-#  undef BOOST_NO_CXX11_VARIADIC_TEMPLATES
-#  undef BOOST_NO_RVALUE_REFERENCES
-#  undef BOOST_NO_CXX11_RVALUE_REFERENCES
-#endif
-
 #include <CGAL/version.h>
 
 //----------------------------------------------------------------------//
@@ -153,10 +123,7 @@
 //----------------------------------------------------------------------//
 
 #if CGAL_HEADER_ONLY
-#  include <CGAL/internal/enable_third_party_libraries.h>
-#  if(BOOST_MSVC)
-#    include <CGAL/MSVC_compiler_config.h>
-#  endif
+#  include <CGAL/Installation/internal/enable_third_party_libraries.h>
 #else
 #  include <CGAL/compiler_config.h>
 #endif
@@ -179,123 +146,13 @@
 #define CGAL_USE_SSE2_FABS
 #endif
 
-//----------------------------------------------------------------------//
-//  Detect features at compile-time. Some macros have only been
-//  introduced as of Boost 1.40. In that case, we simply say that the
-//  feature is not available, even if that is wrong.
-//  ----------------------------------------------------------------------//
-
-#if defined(BOOST_NO_CXX11_RANGE_BASED_FOR) || BOOST_VERSION < 105000
-#define CGAL_CFG_NO_CPP0X_RANGE_BASED_FOR 1
+// Same for C++17
+#if __cplusplus >= 201703L || _MSVC_LANG >= 201703L
+#  define CGAL_CXX17 1
 #endif
-#if defined(BOOST_NO_0X_HDR_ARRAY) || \
-    defined(BOOST_NO_CXX11_HDR_ARRAY) || BOOST_VERSION < 104000
-#define CGAL_CFG_NO_CPP0X_ARRAY 1
-#endif
-#if defined(BOOST_NO_0X_HDR_UNORDERED_SET) || \
-    defined(BOOST_NO_0X_HDR_UNORDERED_MAP) || \
-    defined(BOOST_NO_CXX11_HDR_UNORDERED_SET) || \
-    defined(BOOST_NO_CXX11_HDR_UNORDERED_MAP) || \
-   (defined(_MSC_VER) && (_MSC_VER == 1800)) // std::unordered_set is very bad in MSVC2013
-#define CGAL_CFG_NO_CPP0X_UNORDERED 1
-#endif
-#if defined( BOOST_NO_0X_HDR_THREAD) || \
-    defined( BOOST_NO_CXX11_HDR_THREAD)
-#define CGAL_CFG_NO_STD_THREAD 1
-#endif
-#if defined(BOOST_NO_DECLTYPE) || \
-    defined(BOOST_NO_CXX11_DECLTYPE) || (BOOST_VERSION < 103600)
-#define CGAL_CFG_NO_CPP0X_DECLTYPE 1
-#endif
-#if defined(BOOST_NO_DELETED_FUNCTIONS) || \
-    defined(BOOST_NO_DEFAULTED_FUNCTIONS) || \
-    defined(BOOST_NO_CXX11_DELETED_FUNCTIONS) || \
-    defined(BOOST_NO_CXX11_DEFAULTED_FUNCTIONS) || (BOOST_VERSION < 103600) || \
-    (defined(_MSC_VER) && _MSC_VER < 1900) // MSVC 2013 has only partial support
-#define CGAL_CFG_NO_CPP0X_DELETED_AND_DEFAULT_FUNCTIONS 1
-#endif
-#if defined(BOOST_NO_FUNCTION_TEMPLATE_DEFAULT_ARGS) || \
-    defined(BOOST_NO_CXX11_FUNCTION_TEMPLATE_DEFAULT_ARGS) || \
-    (BOOST_VERSION < 104100)
-#define CGAL_CFG_NO_CPP0X_DEFAULT_TEMPLATE_ARGUMENTS_FOR_FUNCTION_TEMPLATES 1
-#endif
-#if defined(BOOST_NO_INITIALIZER_LISTS) || \
-    defined(BOOST_NO_CXX11_HDR_INITIALIZER_LIST) || (BOOST_VERSION < 103900)
-#define CGAL_CFG_NO_CPP0X_INITIALIZER_LISTS 1
-#endif
-#if defined(BOOST_MSVC)
-#define CGAL_CFG_NO_CPP0X_ISFINITE 1 // used in <CGAL/CORE/Filter.h>
-#endif
-#if defined(BOOST_NO_LONG_LONG) || (BOOST_VERSION < 103600)
-#define CGAL_CFG_NO_CPP0X_LONG_LONG 1
-#endif
-#if defined(BOOST_NO_LAMBDAS) || \
-    defined(BOOST_NO_CXX11_LAMBDAS) || BOOST_VERSION < 104000
-#define CGAL_CFG_NO_CPP0X_LAMBDAS 1
-#endif
-#if defined(BOOST_NO_RVALUE_REFERENCES) || \
-    defined(BOOST_NO_CXX11_RVALUE_REFERENCES) || (BOOST_VERSION < 103600)
-#define CGAL_CFG_NO_CPP0X_RVALUE_REFERENCE 1
-#endif
-#if defined(BOOST_NO_STATIC_ASSERT) || \
-    defined(BOOST_NO_CXX11_STATIC_ASSERT) || (BOOST_VERSION < 103600)
-#define CGAL_CFG_NO_CPP0X_STATIC_ASSERT 1
-#endif
-#if defined(BOOST_NO_0X_HDR_TUPLE) || \
-    defined(BOOST_NO_CXX11_HDR_TUPLE) || (BOOST_VERSION < 104000)
-#define CGAL_CFG_NO_CPP0X_TUPLE 1
-#endif
-#if defined(BOOST_NO_VARIADIC_TEMPLATES) || \
-    defined(BOOST_NO_CXX11_VARIADIC_TEMPLATES) || (BOOST_VERSION < 103600)
-#define CGAL_CFG_NO_CPP0X_VARIADIC_TEMPLATES 1
-#endif
-// never use TR1
-#define CGAL_CFG_NO_TR1_ARRAY 1
-// never use TR1
-#define CGAL_CFG_NO_TR1_TUPLE 1
-#if !defined(__GNUC__) || defined(__INTEL_COMPILER)
-#define CGAL_CFG_NO_STATEMENT_EXPRESSIONS 1
-#endif
-#if defined(BOOST_NO_CXX11_UNIFIED_INITIALIZATION_SYNTAX) || (BOOST_VERSION < 105100) || _MSC_VER==1800
-#define CGAL_CFG_NO_CPP0X_UNIFIED_INITIALIZATION_SYNTAX
-#endif
-#if __cplusplus < 201103L && !(_MSC_VER >= 1600)
-#define CGAL_CFG_NO_CPP0X_COPY_N 1
-#define CGAL_CFG_NO_CPP0X_NEXT_PREV 1
-#endif
-#if defined(BOOST_NO_EXPLICIT_CONVERSION_OPERATIONS) \
-    || defined(BOOST_NO_EXPLICIT_CONVERSION_OPERATORS) \
-    || defined(BOOST_NO_CXX11_EXPLICIT_CONVERSION_OPERATORS) \
-    || (BOOST_VERSION < 103600)
-#define CGAL_CFG_NO_CPP0X_EXPLICIT_CONVERSION_OPERATORS 1
-#endif
-#if defined(BOOST_NO_CXX11_TEMPLATE_ALIASES) || \
-    defined(BOOST_NO_TEMPLATE_ALIASES) || (BOOST_VERSION < 103900)
-#define CGAL_CFG_NO_CPP0X_TEMPLATE_ALIASES 1
-#endif
-
-// Some random list to let us write C++11 without thinking about
-// each feature we are using.
-#if ( __cplusplus >= 201103L || _MSVC_LANG >= 201103L ) &&      \
-    !defined CGAL_CFG_NO_CPP0X_VARIADIC_TEMPLATES && \
-    !defined CGAL_CFG_NO_CPP0X_RVALUE_REFERENCE && \
-    !defined CGAL_CFG_NO_CPP0X_EXPLICIT_CONVERSION_OPERATORS && \
-    !defined CGAL_CFG_NO_CPP0X_TUPLE && \
-    !defined CGAL_CFG_NO_CPP0X_UNIFIED_INITIALIZATION_SYNTAX && \
-    !defined CGAL_CFG_NO_CPP0X_STATIC_ASSERT && \
-    !defined CGAL_CFG_NO_CPP0X_DECLTYPE && \
-    !defined CGAL_CFG_NO_CPP0X_DELETED_AND_DEFAULT_FUNCTIONS && \
-    !defined CGAL_CFG_NO_CPP0X_DEFAULT_TEMPLATE_ARGUMENTS_FOR_FUNCTION_TEMPLATES
-#define CGAL_CXX11 1
-#endif
-// Same for C++14.
-#if __cplusplus >= 201402L || _MSVC_LANG >= 201402L
-#  define CGAL_CXX14 1
-#endif
-
-#if defined(BOOST_NO_CXX11_HDR_FUNCTIONAL) || BOOST_VERSION < 105000
-#define CGAL_CFG_NO_STD_HASH 1
-#define CGAL_CFG_NO_STD_FUNCTION 1
+// Same for C++20
+#if __cplusplus >= 202002L || _MSVC_LANG >= 202002L
+#  define CGAL_CXX20 1
 #endif
 
 
@@ -330,66 +187,33 @@
 #define CGAL_END_NAMESPACE }
 #endif
 
-
-#ifndef CGAL_CFG_NO_CPP0X_LONG_LONG
-#  define CGAL_USE_LONG_LONG
-#endif
-
-
 #ifndef CGAL_CFG_TYPENAME_BEFORE_DEFAULT_ARGUMENT_BUG
 #  define CGAL_TYPENAME_DEFAULT_ARG typename
 #else
 #  define CGAL_TYPENAME_DEFAULT_ARG
 #endif
 
-
-#ifdef CGAL_CFG_NO_CPP0X_DELETED_AND_DEFAULT_FUNCTIONS
-#  define CGAL_DELETED
-#  define CGAL_EXPLICITLY_DEFAULTED
-#else
-#  define CGAL_DELETED = delete
-#  define CGAL_EXPLICITLY_DEFAULTED = default
-#endif
-
-
 // Big endian or little endian machine.
 // ====================================
 
-#if (BOOST_VERSION >= 105500)
-#  include <boost/predef.h>
-#  if BOOST_ENDIAN_BIG_BYTE
-#    define CGAL_BIG_ENDIAN
-#  elif BOOST_ENDIAN_LITTLE_BYTE
-#    define CGAL_LITTLE_ENDIAN
-#  else
-#    error Unknown endianness
-#  endif
-#elif defined (__GLIBC__)
-#  include <endian.h>
-#  if (__BYTE_ORDER == __LITTLE_ENDIAN)
-#    define CGAL_LITTLE_ENDIAN
-#  elif (__BYTE_ORDER == __BIG_ENDIAN)
-#    define CGAL_BIG_ENDIAN
-#  else
-#    error Unknown endianness
-#  endif
-#elif defined(__sparc) || defined(__sparc__) \
-   || defined(_POWER) || defined(__powerpc__) \
-   || defined(__ppc__) || defined(__hppa) \
-   || defined(_MIPSEB) || defined(_POWER) \
-   || defined(__s390__)
+#include <boost/predef.h>
+#if BOOST_ENDIAN_BIG_BYTE
 #  define CGAL_BIG_ENDIAN
-#elif defined(__i386__) || defined(__alpha__) \
-   || defined(__x86_64) || defined(__x86_64__) \
-   || defined(__ia64) || defined(__ia64__) \
-   || defined(_M_IX86) || defined(_M_IA64) \
-   || defined(_M_ALPHA) || defined(_WIN64)
+#elif BOOST_ENDIAN_LITTLE_BYTE
 #  define CGAL_LITTLE_ENDIAN
-#else
-#  error Unknown endianness
 #endif
 
-
+#if ! defined(CGAL_LITTLE_ENDIAN) && ! defined(CGAL_BIG_ENDIAN)
+#  ifdef CGAL_DEFAULT_IS_LITTLE_ENDIAN
+#    if CGAL_DEFAULT_IS_LITTLE_ENDIAN
+#      define CGAL_LITTLE_ENDIAN
+#    else
+#      define CGAL_BIG_ENDIAN
+#    endif
+#  else
+#    error Unknown endianness: Define CGAL_DEFAULT_IS_LITTLE_ENDIAN to 1 for little endian and to 0 for big endian.
+#  endif
+#endif
 // Symbolic constants to tailor inlining. Inlining Policy.
 // =======================================================
 #ifndef CGAL_MEDIUM_INLINE
@@ -450,12 +274,6 @@ using std::min;
 using std::max;
 #endif
 
-//-------------------------------------------------------------------//
-// Is Geomview usable ?
-#if !defined(_MSC_VER) && !defined(__MINGW32__)
-#  define CGAL_USE_GEOMVIEW
-#endif
-
 
 //-------------------------------------------------------------------//
 // Compilers provide different macros to access the current function name
@@ -478,8 +296,8 @@ using std::max;
 
 // Macros to detect features of clang. We define them for the other
 // compilers.
-// See http://clang.llvm.org/docs/LanguageExtensions.html
-// See also http://en.cppreference.com/w/cpp/experimental/feature_test
+// See https://clang.llvm.org/docs/LanguageExtensions.html
+// See also https://en.cppreference.com/w/cpp/experimental/feature_test
 #ifndef __has_feature
   #define __has_feature(x) 0  // Compatibility with non-clang compilers.
 #endif
@@ -503,8 +321,10 @@ using std::max;
 #endif
 
 // Macro to specify a 'unused' attribute.
-#if defined(__GNUG__) || __has_attribute(__unused__)
-#  define CGAL_UNUSED  __attribute__ ((__unused__))
+#if __has_cpp_attribute(maybe_unused)
+#  define CGAL_UNUSED [[maybe_unused]]
+#elif defined(__GNUG__) || __has_attribute(__unused__) // [[maybe_unused]] is C++17
+#  define CGAL_UNUSED __attribute__ ((__unused__))
 #else
 #  define CGAL_UNUSED
 #endif
@@ -512,58 +332,40 @@ using std::max;
 // Macro to trigger deprecation warnings
 #ifdef CGAL_NO_DEPRECATION_WARNINGS
 #  define CGAL_DEPRECATED
+#  define CGAL_DEPRECATED_MSG(msg)
 #  define CGAL_DEPRECATED_UNUSED CGAL_UNUSED
-#elif defined(__GNUC__) || __has_attribute(__deprecated__)
-#  define CGAL_DEPRECATED __attribute__((__deprecated__))
-#if __has_attribute(__unused__)
-#  define CGAL_DEPRECATED_UNUSED __attribute__((__deprecated__, __unused__))
 #else
-#  define CGAL_DEPRECATED_UNUSED __attribute__((__deprecated__))
-#endif
-#elif defined (_MSC_VER) && (_MSC_VER > 1300)
-#  define CGAL_DEPRECATED __declspec(deprecated)
-#  define CGAL_DEPRECATED_UNUSED __declspec(deprecated)
-#else
-#  define CGAL_DEPRECATED
-#  define CGAL_DEPRECATED_UNUSED
-#endif
-
-// Macro to trigger deprecation warnings with a custom message
-#ifdef CGAL_NO_DEPRECATION_WARNINGS
-#  define CGAL_DEPRECATED_MSG(msg)
-#elif defined(__GNUC__) || __has_attribute(__deprecated__)
-#  if BOOST_GCC >= 40500 || __has_attribute(__deprecated__)
-#    define CGAL_DEPRECATED_MSG(msg) __attribute__ ((deprecated(msg)))
-#  else
-#    define CGAL_DEPRECATED_MSG(msg) __attribute__ ((deprecated))
-#  endif
-#elif defined (_MSC_VER) && (_MSC_VER > 1300)
-#  define CGAL_DEPRECATED_MSG(msg) __declspec(deprecated(msg))
-#elif defined(__clang__)
-#  define CGAL_DEPRECATED_MSG(msg) __attribute__ ((deprecated(msg)))
-#else
-#  define CGAL_DEPRECATED_MSG(msg)
+#  define CGAL_DEPRECATED [[deprecated]]
+#  define CGAL_DEPRECATED_MSG(msg) [[deprecated(msg)]]
+#  define CGAL_DEPRECATED_UNUSED [[deprecated]] CGAL_UNUSED
 #endif
 
 // Macro to specify a 'noreturn' attribute.
-#if defined(__GNUG__) || __has_attribute(__noreturn__)
-#  define CGAL_NORETURN  __attribute__ ((__noreturn__))
-#elif defined (_MSC_VER)
-#  define CGAL_NORETURN __declspec(noreturn)
-#else  
-#  define CGAL_NORETURN
+// (This macro existed in CGAL before we switched to C++11. Let's keep
+// the macro defined for backward-compatibility. That cannot harm.)
+#define CGAL_NORETURN  [[noreturn]]
+
+// Macro to specify [[no_unique_address]] if supported
+#if _MSC_VER >= 1929 && _MSVC_LANG >= 202002L
+// see https://devblogs.microsoft.com/cppblog/msvc-cpp20-and-the-std-cpp20-switch/#c20-no_unique_address
+#  define CGAL_NO_UNIQUE_ADDRESS [[msvc::no_unique_address]]
+#elif __has_cpp_attribute(no_unique_address)
+#  define CGAL_NO_UNIQUE_ADDRESS [[no_unique_address]]
+#else
+#  define CGAL_NO_UNIQUE_ADDRESS
 #endif
 
-
-// Macro CGAL_ASSUME
+// Macro CGAL_ASSUME and CGAL_UNREACHABLE
 // Call a builtin of the compiler to pass a hint to the compiler
-#if __has_builtin(__builtin_unreachable) || (CGAL_GCC_VERSION >= 40500 && !__STRICT_ANSI__)
+#if __has_builtin(__builtin_unreachable) || (CGAL_GCC_VERSION > 0 && !__STRICT_ANSI__)
 // From g++ 4.5, there exists a __builtin_unreachable()
 // Also in LLVM/clang
 #  define CGAL_ASSUME(EX) if(!(EX)) { __builtin_unreachable(); }
+#  define CGAL_UNREACHABLE() __builtin_unreachable()
 #elif defined(_MSC_VER)
 // MSVC has __assume
 #  define CGAL_ASSUME(EX) __assume(EX)
+#  define CGAL_UNREACHABLE() __assume(0)
 #endif
 // If CGAL_ASSUME is not defined, then CGAL_assume and CGAL_assume_code are
 // defined differently, in <CGAL/assertions.h>
@@ -576,25 +378,14 @@ using std::max;
 #  endif
 #endif
 
-#if __has_feature(cxx_thread_local) || \
-    ( (__GNUC__ * 100 + __GNUC_MINOR__) >= 408 && __cplusplus >= 201103L ) || \
-    ( _MSC_VER >= 1900 )
-// see also Installation/cmake/modules/config/support/CGAL_test_cpp_version.cpp
-#define CGAL_CAN_USE_CXX11_THREAD_LOCAL
-#endif
-
-#if ( BOOST_VERSION >= 105000 && ! defined(BOOST_NO_CXX11_HDR_MUTEX) ) || \
-    (__has_include(<mutex>) && __cplusplus >= 201103L ) | \
-    ( (__GNUC__ * 100 + __GNUC_MINOR__) >= 408 && __cplusplus >= 201103L ) || \
-    ( _MSC_VER >= 1700 )
-#define CGAL_CAN_USE_CXX11_MUTEX
-#endif
-
-#if ( BOOST_VERSION >= 105600 && ! defined(BOOST_NO_CXX11_HDR_ATOMIC) ) || \
-    (__has_include(<atomic>) && __cplusplus >= 201103L ) || \
-    ( (__GNUC__ * 100 + __GNUC_MINOR__) >= 408 && __cplusplus >= 201103L ) || \
-    ( _MSC_VER >= 1700 )
-#define CGAL_CAN_USE_CXX11_ATOMIC
+#ifndef CGAL_HAS_THREADS
+  namespace CGAL { inline bool is_currently_single_threaded(){ return true; } }
+#elif __has_include(<sys/single_threaded.h>)
+#  include <sys/single_threaded.h>
+  namespace CGAL { inline bool is_currently_single_threaded(){ return ::__libc_single_threaded; } }
+#else
+  /* This is the conservative default */
+  namespace CGAL { inline bool is_currently_single_threaded(){ return false; } }
 #endif
 
 // Support for LEDA with threads
@@ -607,7 +398,7 @@ using std::max;
 #define LEDA_NUMBERS_DLL 1
 
 // Helper macros to disable macros
-#if defined(__clang__) || (BOOST_GCC >= 40600)
+#if defined(__clang__) || defined(BOOST_GCC)
 #  define CGAL_PRAGMA_DIAG_PUSH _Pragma("GCC diagnostic push")
 #  define CGAL_PRAGMA_DIAG_POP  _Pragma("GCC diagnostic pop")
 #else
@@ -615,30 +406,84 @@ using std::max;
 #  define CGAL_PRAGMA_DIAG_POP
 #endif
 
+//
+// Compatibility with CGAL-4.14.
+#ifndef CGAL_NO_DEPRECATED_CODE
+//
+// That is temporary, and will be replaced by a namespace alias, as
+// soon as we can remove cpp11::result_of, and <CGAL/atomic.h> and
+// <CGAL/thread.h>.
+//
+#  include <iterator>
+#  include <array>
+#  include <utility>
+#  include <type_traits>
+#  include <unordered_set>
+#  include <unordered_map>
+#  include <functional>
+#  include <thread>
+#  include <chrono>
+#  include <atomic>
+//
+namespace CGAL {
+//
+  namespace cpp11 {
+    using std::next;
+    using std::prev;
+    using std::copy_n;
+    using std::array;
+    using std::function;
+    using std::tuple;
+    using std::make_tuple;
+    using std::tie;
+    using std::get;
+    using std::tuple_size;
+    using std::tuple_element;
+    using std::is_enum;
+    using std::unordered_set;
+    using std::unordered_map;
+    using std::atomic;
+    using std::memory_order_relaxed;
+    using std::memory_order_consume;
+    using std::memory_order_acquire;
+    using std::memory_order_release;
+    using std::memory_order_acq_rel;
+    using std::memory_order_seq_cst;
+    using std::atomic_thread_fence;
+    using std::thread;
+
+  }
+//
+  namespace cpp0x = cpp11;
+  using cpp11::array;
+  using cpp11::copy_n;
+} // end of the temporary compatibility with CGAL-4.14
+#endif // CGAL_NO_DEPRECATED_CODE
 namespace CGAL {
 
-// Typedef for the type of NULL.
+// Typedef for the type of nullptr.
 typedef const void * Nullptr_t;   // Anticipate C++0x's std::nullptr_t
-
-} //namespace CGAL
-
-//Support for c++11 noexcept
-#if BOOST_VERSION > 104600 && !defined(BOOST_NO_CXX11_NOEXCEPT) && !defined(BOOST_NO_NOEXCEPT)
-#define CGAL_NOEXCEPT(x) noexcept(x)
+namespace cpp11{
+#if CGAL_CXX20 || __cpp_lib_is_invocable>=201703L
+    template<typename Signature> class result_of;
+    template<typename F, typename... Args>
+    class result_of<F(Args...)> : public std::invoke_result<F, Args...> { };
 #else
-#define CGAL_NOEXCEPT(x)
+    using std::result_of;
 #endif
+}//namespace cpp11
+} //namespace CGAL
 
 // The fallthrough attribute
 // See for clang:
-//   http://clang.llvm.org/docs/AttributeReference.html#statement-attributes
+//   https://clang.llvm.org/docs/AttributeReference.html#statement-attributes
 // See for gcc:
 //   https://gcc.gnu.org/onlinedocs/gcc/Warning-Options.html
-#if __cpp_attributes >= 200809 && __has_cpp_attribute(fallthrough)
+#if __cplusplus > 201402L && __has_cpp_attribute(fallthrough)
 #  define CGAL_FALLTHROUGH [[fallthrough]]
-#elif __cpp_attributes >= 200809 && __has_cpp_attribute(gnu::fallthrough)
+#elif __has_cpp_attribute(gnu::fallthrough)
 #  define CGAL_FALLTHROUGH [[gnu::fallthrough]]
-#elif __cpp_attributes >= 200809 && __has_cpp_attribute(clang::fallthrough)
+#elif __has_cpp_attribute(clang::fallthrough)
 #  define CGAL_FALLTHROUGH [[clang::fallthrough]]
 #elif __has_attribute(fallthrough) && ! __clang__
 #  define CGAL_FALLTHROUGH __attribute__ ((fallthrough))
@@ -646,9 +491,10 @@ typedef const void * Nullptr_t;   // Anticipate C++0x's std::nullptr_t
 #  define CGAL_FALLTHROUGH while(false){}
 #endif
 
-// https://svn.boost.org/trac/boost/ticket/2839
-#if defined(BOOST_MSVC) && BOOST_VERSION < 105600
-#define CGAL_CFG_BOOST_VARIANT_SWAP_BUG 1
+#if CGAL_CXX17
+#  define CGAL_CPP17_INLINE inline
+#else
+#  define CGAL_CPP17_INLINE
 #endif
 
 #ifndef CGAL_NO_ASSERTIONS
@@ -675,7 +521,7 @@ typedef const void * Nullptr_t;   // Anticipate C++0x's std::nullptr_t
 /// Macro `CGAL_WARNING`.
 /// Must be used with `#pragma`, this way:
 ///
-///     #pragma CGAL_WARNING(This line should trigger a warning)
+///     #pragma CGAL_WARNING("This line should trigger a warning")
 ///
 /// @{
 #ifdef BOOST_MSVC
@@ -686,6 +532,7 @@ typedef const void * Nullptr_t;   // Anticipate C++0x's std::nullptr_t
 /// @}
 
 /// Macro `CGAL_pragma_warning`.
+/// @{
 #ifdef BOOST_MSVC
 #  define CGAL_pragma_warning(desc) __pragma(CGAL_WARNING(desc))
 #else // not BOOST_MSVC
@@ -694,5 +541,120 @@ typedef const void * Nullptr_t;   // Anticipate C++0x's std::nullptr_t
 /// @}
 #include <CGAL/license/lgpl.h>
 
+//----------------------------------------------------------------------//
+//  Function to define data directory
+//----------------------------------------------------------------------//
+#include <cstdlib>
+#include <string>
+#include <fstream>
+#include <iostream>
+
+namespace CGAL {
+
+// Returns filename prefixed by the directory of CGAL containing data.
+// This directory is either defined in the environment variable CGAL_DATA_DIR,
+// otherwise it is taken from the constant CGAL_DATA_DIR (defined in CMake),
+// otherwise it is empty (and thus returns filename unmodified).
+inline std::string data_file_path(const std::string& filename)
+{
+  const char* cgal_dir=nullptr;
+
+#ifdef _MSC_VER
+  char* cgal_dir_windows=nullptr;
+  _dupenv_s( &cgal_dir_windows, nullptr, "CGAL_DATA_DIR");
+  if (cgal_dir_windows!=nullptr)
+  { cgal_dir=cgal_dir_windows; }
+#else
+  cgal_dir=getenv("CGAL_DATA_DIR");
+#endif
+
+#ifdef CGAL_DATA_DIR
+ if (cgal_dir==nullptr)
+ { cgal_dir=CGAL_DATA_DIR; }
+#endif
+
+ std::string cgal_dir_string;
+ if (cgal_dir!=nullptr)
+ { cgal_dir_string=std::string(cgal_dir); }
+
+ std::string res=cgal_dir_string;
+ if (!res.empty() && res.back()!='/')
+ { res+=std::string("/"); }
+ res+=filename;
+
+ // Test if the file exists, write a warning otherwise
+ std::ifstream f(res);
+ if (!f)
+ {
+   std::cerr<<"[WARNING] file "<<res<<" does not exist or cannot be read "
+            <<"(CGAL_DATA_DIR='"<<cgal_dir_string<<"')."<<std::endl;
+ }
+
+#ifdef _MSC_VER
+ if (cgal_dir_windows!=nullptr)
+ { free(cgal_dir_windows); }
+#endif
+
+ return res;
+}
+
+} // end namespace CGAL
+
+
+#if BOOST_VERSION < 107900
+
+// Workaround for an accidental enable if of Eigen::Matrix in the
+// boost::multiprecision::cpp_int constructor for some versions of
+// boost
+
+namespace Eigen{
+  template <class A, int B, int C, int D, int E, int F>
+  class Matrix;
+  template <class A, int B, class C>
+  class Ref;
+
+  template <class A, class B, int C>
+  class Product;
+
+  template<typename BinaryOp, typename Lhs, typename Rhs>  class CwiseBinaryOp;
+
+}
+
+namespace boost {
+    namespace multiprecision {
+        namespace detail {
+            template <typename T>
+            struct is_byte_container;
+
+
+            template <class A, int B, int C, int D, int E, int F>
+            struct is_byte_container< Eigen::Matrix<A, B, C, D, E, F>>
+            {
+                static const bool value = false;
+            };
+
+            template <class A, int B, class C>
+            struct is_byte_container< Eigen::Ref<A, B, C>>
+            {
+                static const bool value = false;
+            };
+
+            template <class A, class B, int C>
+            struct is_byte_container< Eigen::Product<A, B, C>>
+            {
+                static const bool value = false;
+            };
+
+            template <class A, class B, class C>
+            struct is_byte_container< Eigen::CwiseBinaryOp<A, B, C>>
+            {
+                static const bool value = false;
+            };
+
+        }
+    }
+}
+
+#endif // BOOST_VERSION < 107900
 
 #endif // CGAL_CONFIG_H
