@@ -2,21 +2,12 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Point_set_processing_3/include/CGAL/edge_aware_upsample_point_set.h $
+// $Id: edge_aware_upsample_point_set.h d3b13fb 2022-12-05T19:00:39+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Point_set_processing_3/include/CGAL/edge_aware_upsample_point_set.h $
-// $Id: edge_aware_upsample_point_set.h 2f81a21 2019-07-28T18:38:59+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-//
-// Author(s) : Shihao Wu, Clement Jamin, Pierre Alliez 
+// Author(s) : Shihao Wu, Clement Jamin, Pierre Alliez
 
 #ifndef CGAL_UPSAMPLE_POINT_SET_H
 #define CGAL_UPSAMPLE_POINT_SET_H
@@ -26,13 +17,13 @@
 #include <CGAL/disable_warnings.h>
 
 #include <CGAL/property_map.h>
-#include <CGAL/point_set_processing_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Point_set_processing_3/internal/Rich_grid.h>
 #include <CGAL/Real_timer.h>
 #include <CGAL/Memory_sizer.h>
 #include <CGAL/compute_average_spacing.h>
 
-#include <CGAL/boost/graph/Named_function_parameters.h>
+#include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
 
 #include <iterator>
@@ -53,8 +44,8 @@ namespace upsample_internal{
 
 /// For each query point, select a best "base point" in its neighborhoods.
 /// Then, a new point will be interpolated between query point and "base point".
-/// This is the key part of the upsample algorithm 
-/// 
+/// This is the key part of the upsample algorithm
+///
 /// \pre `radius > 0`
 ///
 /// @tparam Kernel Geometric traits class.
@@ -64,7 +55,7 @@ template <typename Kernel>
 typename Kernel::FT
 base_point_selection(
   const rich_grid_internal::Rich_point<Kernel>& query, ///< 3D point to project
-  const std::vector<rich_grid_internal::Rich_point<Kernel> >& 
+  const std::vector<rich_grid_internal::Rich_point<Kernel> >&
                     neighbor_points,///< neighbor sample points
   const typename Kernel::FT edge_sensitivity,///< edge sensitivity parameter
   unsigned int& output_base_index ///< base point index
@@ -97,7 +88,7 @@ base_point_selection(
 
     Vector diff_v_t = t - v.pt;
     Point mid_point = v.pt + (diff_v_t * FT(0.5));
-    
+
     FT dot_produce = std::pow((FT(2.0) - vm * tm), edge_sensitivity);
 
     Vector diff_t_mid = mid_point - t;
@@ -126,12 +117,12 @@ base_point_selection(
     }
   }
 
-  return best_dist2; 
+  return best_dist2;
 }
 
 /// For each new inserted point, we need to do the following job
 /// 1, get neighbor information from the two "parent points"
-/// 2, update position and determine normal by bilateral projection 
+/// 2, update position and determine normal by bilateral projection
 /// 3, update neighbor information again
 ///
 /// \pre `radius > 0`
@@ -156,10 +147,8 @@ update_new_point(
   typedef typename rich_grid_internal::Rich_point<Kernel> Rich_point;
 
   CGAL_assertion_code( unsigned int size = static_cast<unsigned int>(rich_point_set.size()) );
-  CGAL_point_set_processing_precondition(father_index >= 0 &&
-                                         father_index < size);
-  CGAL_point_set_processing_precondition(mother_index >= 0 &&
-                                           mother_index < size);
+  CGAL_precondition(father_index < size);
+  CGAL_precondition(mother_index < size);
 
   // 1, get neighbor information from the two "parent points"
   Rich_point& new_v = rich_point_set[new_point_index];
@@ -189,7 +178,7 @@ update_new_point(
 
   new_v.neighbors.clear();
   std::set<int>::iterator set_iter;
-  for (set_iter = neighbor_indexes.begin(); 
+  for (set_iter = neighbor_indexes.begin();
        set_iter != neighbor_indexes.end(); ++set_iter)
   {
     Rich_point& t = rich_point_set[*set_iter];
@@ -201,7 +190,7 @@ update_new_point(
     }
   }
 
-  // 2, update position and normal by bilateral projection 
+  // 2, update position and normal by bilateral projection
   const unsigned int candidate_num = 2; // we have two normal candidates:
                                         // we say father's is 0
                                         //        mother's is 1
@@ -212,7 +201,7 @@ update_new_point(
   std::vector<FT> project_dist_sum(candidate_num, FT(0.0));
   std::vector<FT> weight_sum(candidate_num, FT(0.0));
   std::vector<Vector> normal_sum(candidate_num, NULL_VECTOR);
-   
+
   FT radius16 = FT(-4.0) / radius2;
 
   for (unsigned int i = 0; i < new_v.neighbors.size(); ++i)
@@ -223,8 +212,8 @@ update_new_point(
 
     for (unsigned int j = 0; j < candidate_num; j++)
     {
-      FT psi = std::exp(-std::pow(1 - normal_cadidate[j] * t.normal, 2)
-                       / sharpness_bandwidth);
+      FT psi = std::exp(-CGAL::square(FT(1) - normal_cadidate[j] * t.normal)
+                            / sharpness_bandwidth);
       FT project_diff_t_v = (t.pt - new_v.pt) * t.normal;
       FT weight = psi * theta;
 
@@ -258,7 +247,7 @@ update_new_point(
 
   // 3, update neighbor information again
   new_v.neighbors.clear();
-  for (set_iter = neighbor_indexes.begin(); 
+  for (set_iter = neighbor_indexes.begin();
        set_iter != neighbor_indexes.end(); ++set_iter)
   {
     Rich_point& t = rich_point_set[*set_iter];
@@ -282,94 +271,131 @@ update_new_point(
 
 /**
    \ingroup PkgPointSetProcessing3Algorithms
-   This method progressively upsamples the point set while 
-   approaching the edge singularities (detected by normal variation), which 
-   generates a denser point set from an input point set. This has applications 
-   in point-based rendering, hole filling, and sparse surface reconstruction. 
+   This method progressively upsamples the point set while
+   approaching the edge singularities (detected by normal variation), which
+   generates a denser point set from an input point set. This has applications
+   in point-based rendering, hole filling, and sparse surface reconstruction.
    Normals of points are required as input. For more details, please refer to \cgalCite{ear-2013}.
- 
+
    \tparam ConcurrencyTag enables sequential versus parallel versions
-   of `compute_average_spacing()` (called internally).  Possible
-   values are `Sequential_tag` and `Parallel_tag`.
+   of `compute_average_spacing()` (called internally). Possible
+   values are `Sequential_tag`, `Parallel_tag`, and `Parallel_if_available_tag`.
    \tparam PointRange is a model of `ConstRange`. The value type of
    its iterator is the key type of the named parameter `point_map`.
-   \tparam OutputIterator Type of the output iterator. 
-   The type of the objects put in it is 
+   \tparam OutputIterator Type of the output iterator.
+   The type of the objects put in it is
    `std::pair<geom_traits::Point_3, geom_traits::Vector_3>`.
-   Note that the user may use a 
+   Note that the user may use a
    <A HREF="https://www.boost.org/libs/iterator/doc/function_output_iterator.html">function_output_iterator</A>
    to match specific needs.
 
-   \param points input point range.
+   \param points input point range
    \param output iterator where output points and normals are put.
-   \param np optional sequence of \ref psp_namedparameters "Named Parameters" among the ones listed below.
+   \param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
 
    \cgalNamedParamsBegin
-     \cgalParamBegin{point_map} a model of `ReadablePropertyMap` with value type `geom_traits::Point_3`.
-     If this parameter is omitted, `CGAL::Identity_property_map<geom_traits::Point_3>` is used.\cgalParamEnd
-     \cgalParamBegin{normal_map} a model of `ReadablePropertyMap` with value type
-     `geom_traits::Vector_3`.\cgalParamEnd
-     \cgalParamBegin{sharpness_angle} controls the sharpness of the result.\cgalParamEnd
-     \cgalParamBegin{edge_sensitivity} controls the priority of points inserted along sharp features. See
-     section \ref Point_set_processing_3Upsample_Parameter1 for an example.\cgalParamEnd
-     \cgalParamBegin{neighbor_radius} spherical neighborhood radius.\cgalParamEnd
-     \cgalParamBegin{number_of_output_points} is the number of output points to generate.\cgalParamEnd
-     \cgalParamBegin{geom_traits} an instance of a geometric traits class, model of `Kernel`\cgalParamEnd
-   \cgalNamedParamsEnd
+     \cgalParamNBegin{point_map}
+       \cgalParamDescription{a property map associating points to the elements of the point set `points`}
+       \cgalParamType{a model of `ReadablePropertyMap` whose key type is the value type
+                      of the iterator of `PointRange` and whose value type is `geom_traits::Point_3`}
+       \cgalParamDefault{`CGAL::Identity_property_map<geom_traits::Point_3>`}
+     \cgalParamNEnd
 
+     \cgalParamNBegin{normal_map}
+       \cgalParamDescription{a property map associating normals to the elements of the point set `points`}
+       \cgalParamType{a model of `ReadablePropertyMap` whose key type is the value type
+                      of the iterator of `PointRange` and whose value type is `geom_traits::Vector_3`}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{sharpness_angle}
+       \cgalParamDescription{controls the sharpness of the result}
+       \cgalParamType{floating scalar value}
+       \cgalParamDefault{`30.00`}
+       \cgalParamExtra{The larger the value is, the smoother the result will be.
+                       The range of possible value is `[0, 90]`}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{edge_sensitivity}
+       \cgalParamDescription{controls the priority of points inserted along sharp features}
+       \cgalParamType{floating scalar value}
+       \cgalParamDefault{`1`}
+       \cgalParamExtra{Larger values of edge-sensitivity give higher priority to inserting points
+                       along sharp features. The range of possible values is `[0, 1]`.
+                       See section \ref Point_set_processing_3Upsample_Parameter1 for an example}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{number_of_output_points}
+       \cgalParamDescription{the number of output points to generate}
+       \cgalParamType{unsigned int}
+       \cgalParamDefault{`1000`}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{neighbor_radius}
+       \cgalParamDescription{the spherical neighborhood radius}
+       \cgalParamType{floating scalar value}
+       \cgalParamDefault{`0` (no limit)}
+       \cgalParamExtra{If provided, the neighborhood of a query point is computed with a fixed spherical
+                       radius instead of a fixed number of neighbors. In that case, the parameter
+                       `k` is used as a limit on the number of points returned by each spherical
+                       query (to avoid overly large number of points in high density areas).}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{geom_traits}
+       \cgalParamDescription{an instance of a geometric traits class}
+       \cgalParamType{a model of `Kernel`}
+       \cgalParamDefault{a \cgal Kernel deduced from the point type, using `CGAL::Kernel_traits`}
+     \cgalParamNEnd
+   \cgalNamedParamsEnd
 */
 template <typename ConcurrencyTag,
           typename PointRange,
-	  typename OutputIterator,
-          typename NamedParameters>
+          typename OutputIterator,
+          typename NamedParameters = parameters::Default_named_parameters>
 OutputIterator
 edge_aware_upsample_point_set(
   const PointRange& points,
   OutputIterator output,
-  const NamedParameters& np)
+  const NamedParameters& np = parameters::default_values())
 {
   using parameters::choose_parameter;
   using parameters::get_parameter;
-  
-  // basic geometric types
-  typedef typename Point_set_processing_3::GetPointMap<PointRange, NamedParameters>::type PointMap;
-  typedef typename Point_set_processing_3::GetNormalMap<PointRange, NamedParameters>::type NormalMap;
-  typedef typename Point_set_processing_3::GetK<PointRange, NamedParameters>::Kernel Kernel;
 
-  CGAL_static_assertion_msg(!(boost::is_same<NormalMap,
-                              typename Point_set_processing_3::GetNormalMap<PointRange, NamedParameters>::NoMap>::value),
-                            "Error: no normal map");
-  
+  // basic geometric types
+  typedef Point_set_processing_3_np_helper<PointRange, NamedParameters> NP_helper;
+  typedef typename NP_helper::Const_point_map PointMap;
+  typedef typename NP_helper::Normal_map NormalMap;
+  typedef typename NP_helper::Geom_traits Kernel;
+
+
+  CGAL_assertion_msg(NP_helper::has_normal_map(points, np), "Error: no normal map");
+
   typedef typename Kernel::Point_3 Point;
   typedef typename Kernel::Vector_3 Vector;
   typedef typename Kernel::FT FT;
   typedef typename rich_grid_internal::Rich_point<Kernel> Rich_point;
 
-  PointMap point_map = choose_parameter(get_parameter(np, internal_np::point_map), PointMap());
-  NormalMap normal_map = choose_parameter(get_parameter(np, internal_np::normal_map), NormalMap());
+  PointMap point_map = NP_helper::get_const_point_map(points, np);
+  NormalMap normal_map = NP_helper::get_normal_map(points, np);
   double sharpness_angle = choose_parameter(get_parameter(np, internal_np::sharpness_angle), 30.);
   double edge_sensitivity = choose_parameter(get_parameter(np, internal_np::edge_sensitivity), 1);
   double neighbor_radius = choose_parameter(get_parameter(np, internal_np::neighbor_radius), -1);
   std::size_t number_of_output_points = choose_parameter(get_parameter(np, internal_np::number_of_output_points), 1000);
 
-  std::cerr << sharpness_angle << " " << edge_sensitivity << " " << neighbor_radius
-            << " " << number_of_output_points << std::endl;
   // trick in case the output iterator add points to the input container
   typename PointRange::const_iterator begin = points.begin();
   typename PointRange::const_iterator end = points.end();
-  
+
   // preconditions
-  CGAL_point_set_processing_precondition(begin != end);
-  CGAL_point_set_processing_precondition(sharpness_angle >= 0 
-                                       &&sharpness_angle <= 90);
-  CGAL_point_set_processing_precondition(edge_sensitivity >= 0 
-                                       &&edge_sensitivity <= 1);
-  CGAL_point_set_processing_precondition(neighbor_radius > 0);
+  CGAL_precondition(begin != end);
+  CGAL_precondition(sharpness_angle >= 0
+                    &&sharpness_angle <= 90);
+  CGAL_precondition(edge_sensitivity >= 0
+                    &&edge_sensitivity <= 1);
 
   edge_sensitivity *= 10;  // just project [0, 1] to [0, 10].
 
   std::size_t number_of_input = std::distance(begin, end);
-  CGAL_point_set_processing_precondition(number_of_output_points > number_of_input);
+  CGAL_precondition(number_of_output_points > number_of_input);
 
 
   const unsigned int nb_neighbors = 6; // 1 ring
@@ -383,13 +409,13 @@ edge_aware_upsample_point_set(
     std::cout << "neighbor radius: " << neighbor_radius << std::endl;
 #endif
   }
-  
+
   Real_timer task_timer;
 
   // copy rich point set
   std::vector<Rich_point> rich_point_set(number_of_input);
-  CGAL::Bbox_3 bbox(0., 0., 0., 0., 0., 0.);
-  
+  CGAL::Bbox_3 bbox;
+
   typename PointRange::const_iterator it = begin; // point iterator
   for(unsigned int i = 0; it != end; ++it, ++i)
   {
@@ -398,7 +424,7 @@ edge_aware_upsample_point_set(
 
     rich_point_set[i].index = i;
     bbox += rich_point_set[i].pt.bbox();
-    CGAL_point_set_processing_precondition(rich_point_set[i].normal.squared_length() > 1e-10);
+    CGAL_precondition(rich_point_set[i].normal.squared_length() > 1e-10);
   }
 
   // compute neighborhood
@@ -407,8 +433,9 @@ edge_aware_upsample_point_set(
                                                       FT(neighbor_radius));
 
   //
-  FT cos_sigma = static_cast<FT>(std::cos(CGAL::to_double(sharpness_angle) / 180.0 * CGAL_PI));
-  FT sharpness_bandwidth = std::pow((CGAL::max)((FT)1e-8, (FT)1.0 - cos_sigma), 2);
+  FT cos_sigma = static_cast<FT>(std::cos(FT(CGAL::to_double(sharpness_angle))
+                                          / FT(180) * FT(CGAL_PI)));
+  FT sharpness_bandwidth = CGAL::square((CGAL::max)((FT)1e-8, (FT)1.0 - cos_sigma));
 
   FT sum_density = 0.0;
   unsigned int count_density = 1;
@@ -433,7 +460,7 @@ edge_aware_upsample_point_set(
                                                           current_radius);
     }
  #ifdef CGAL_PSP3_VERBOSE
-    std::cout << "current radius: " << current_radius << std::endl; 
+    std::cout << "current radius: " << current_radius << std::endl;
  #endif
 
     std::size_t current_size = rich_point_set.size();
@@ -477,7 +504,7 @@ edge_aware_upsample_point_set(
     sum_density = 0.;
     count_density = 1;
 
-    FT density_pass_threshold2 = density_pass_threshold * 
+    FT density_pass_threshold2 = density_pass_threshold *
                                  density_pass_threshold;
  #ifdef CGAL_PSP3_VERBOSE
     std::cout << "pass_threshold:  " << density_pass_threshold << std::endl;
@@ -511,7 +538,7 @@ edge_aware_upsample_point_set(
           neighbor_rich_points[n] = rich_point_set[v.neighbors[n]];
         }
 
-        // select base point 
+        // select base point
         unsigned int base_index = 0;
         FT density2 = upsample_internal::
                               base_point_selection(v,
@@ -545,10 +572,10 @@ edge_aware_upsample_point_set(
         is_pass_threshold.push_back(false);
 
         //update new rich point
-        upsample_internal::update_new_point(new_point_index, 
-                                            father_index, 
-                                            mother_index, 
-                                            rich_point_set, 
+        upsample_internal::update_new_point(new_point_index,
+                                            father_index,
+                                            mother_index,
+                                            rich_point_set,
                                             current_radius,
                                             sharpness_bandwidth);
 
@@ -560,8 +587,8 @@ edge_aware_upsample_point_set(
    #ifdef CGAL_PSP3_VERBOSE
       std::cout << "current size: " << rich_point_set.size() << std::endl;
    #endif
-      if (count_not_pass == 0 || 
-          loop >= max_loop_time || 
+      if (count_not_pass == 0 ||
+          loop >= max_loop_time ||
           rich_point_set.size() >= number_of_output_points)
       {
         break;
@@ -582,137 +609,10 @@ edge_aware_upsample_point_set(
     Vector normal = v.normal;
     *output++ = std::make_pair(point, normal);
   }
- 
+
   return output;
 }
 
-
-/// \cond SKIP_IN_MANUAL
-// variant with default NP
-template <typename ConcurrencyTag,
-          typename PointRange,
-	  typename OutputIterator>
-OutputIterator
-edge_aware_upsample_point_set(
-  const PointRange& points,
-  OutputIterator output)
-{
-  return edge_aware_upsample_point_set<ConcurrencyTag>
-    (points, output, CGAL::Point_set_processing_3::parameters::all_default(points));
-}
-
-
-#ifndef CGAL_NO_DEPRECATED_CODE  
-// deprecated API
-template <typename ConcurrencyTag,
-	  typename OutputIterator,
-          typename ForwardIterator, 
-          typename PointMap, 
-          typename NormalMap,
-          typename Kernel>
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::edge_aware_upsample_point_set(), please update your code")
-OutputIterator
-edge_aware_upsample_point_set(
-  ForwardIterator first,  ///< forward iterator on the first input point.
-  ForwardIterator beyond, ///< past-the-end iterator.
-  OutputIterator output,  ///< output iterator where output points and normals 
-                          ///< are put.
-  PointMap point_map,   ///< point property map.
-  NormalMap normal_map, ///< vector property map.
-  const typename Kernel::FT sharpness_angle,  ///< 
-                    ///< controls the preservation of sharp features. 
-                    ///< The larger the value is,
-                    ///< the smoother the result will be.
-                    ///< The range of possible values is `[0, 90]`.
-                    ///< See section \ref Point_set_processing_3Upsample_Parameter2
-                    ///< for an example.
-  typename Kernel::FT edge_sensitivity,  ///<  
-                    ///< larger values of edge-sensitivity give higher priority 
-                    ///< to inserting points along sharp features.
-                    ///< The range of possible values is `[0, 1]`.
-                    ///< See section \ref Point_set_processing_3Upsample_Parameter1
-                    ///< for an example.
-  typename Kernel::FT neighbor_radius, ///< 
-                    ///< indicates the radius of the largest hole that should be filled.
-                    ///< The default value is set to 3 times the average spacing of the point set.
-                    ///< If the value given by user is smaller than the average spacing, 
-                    ///< the function will use the default value instead.
-  const std::size_t number_of_output_points,///< number of output
-                                             ///< points to generate.
-  const Kernel& /*kernel*/ ///< geometric traits.
-)
-{
-  return edge_aware_upsample_point_set<ConcurrencyTag>
-    (CGAL::make_range (first, beyond), output,
-     CGAL::parameters::point_map (point_map).
-     normal_map (normal_map).
-     sharpness_angle (sharpness_angle).
-     edge_sensitivity (edge_sensitivity).
-     neighbor_radius (neighbor_radius).
-     number_of_output_points (number_of_output_points).
-     geom_traits (Kernel()));
-}
-  
-
-// deprecated API
-template <typename ConcurrencyTag,
-	  typename OutputIterator,
-          typename ForwardIterator,
-          typename PointMap,
-          typename NormalMap>
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::edge_aware_upsample_point_set(), please update your code")
-OutputIterator
-edge_aware_upsample_point_set(
-  ForwardIterator first,    ///< forward iterator to the first input point.
-  ForwardIterator beyond,   ///< past-the-end iterator.
-  OutputIterator output, ///< output iterator over points.
-  PointMap point_map, ///< property map: `ForwardIterator` -> Point_3.
-  NormalMap normal_map, ///< property map: `ForwardIterator` -> Vector_3.
-  double sharpness_angle,  ///< control sharpness(0-90)
-  double edge_sensitivity,  ///< edge sensitivity(0-5)
-  double neighbor_radius, ///< initial size of neighbors.
-  const std::size_t number_of_output_points///< number of iterations.   
-  )
-{
-  return edge_aware_upsample_point_set<ConcurrencyTag>
-    (CGAL::make_range (first, beyond), output,
-     CGAL::parameters::point_map (point_map).
-     normal_map (normal_map).
-     sharpness_angle (sharpness_angle).
-     edge_sensitivity (edge_sensitivity).
-     neighbor_radius (neighbor_radius).
-     number_of_output_points (number_of_output_points));
-}
-
-// deprecated API
-template <typename ConcurrencyTag,
-	  typename OutputIterator,
-          typename ForwardIterator,
-          typename NormalMap>
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::edge_aware_upsample_point_set(), please update your code")
-OutputIterator
-edge_aware_upsample_point_set(
-  ForwardIterator first, ///< iterator over the first input point
-  ForwardIterator beyond, ///< past-the-end iterator
-  OutputIterator output, ///< output iterator over points.
-  NormalMap normal_map, ///< property map:  OutputIterator -> Vector_3.
-  double sharpness_angle = 30,  ///< control sharpness(0-90)
-  double edge_sensitivity = 1,  ///< edge sensitivity(0-5)
-  double neighbor_radius = -1, ///< initial size of neighbors.
-  const std::size_t number_of_output_points = 1000///< number of output points.     
-  )
-{
-  return edge_aware_upsample_point_set<ConcurrencyTag>
-    (CGAL::make_range (first, beyond), output,
-     CGAL::parameters::normal_map (normal_map).
-     sharpness_angle (sharpness_angle).
-     edge_sensitivity (edge_sensitivity).
-     neighbor_radius (neighbor_radius).
-     number_of_output_points (number_of_output_points));
-}
-#endif // CGAL_NO_DEPRECATED_CODE
-/// \endcond
-
 } //namespace CGAL
 
 #include <CGAL/enable_warnings.h>
