@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Envelope_2/include/CGAL/envelope_2.h $
-// $Id: envelope_2.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Envelope_2/include/CGAL/envelope_2.h $
+// $Id: envelope_2.h a46398d 2020-08-25T13:43:49+02:00 Ahmed Essam
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Ron Wein   <wein@post.tau.ac.il>
 
@@ -102,6 +93,30 @@ void lower_envelope_x_monotone_2 (InputIterator begin, InputIterator end,
   return;
 }
 
+/*!
+ * Compute the lower envelope of a range of x-monotone curves.
+ * \param begin An iterator for the first x-monotone curve.
+ * \param end A past-the-end iterator for the x-monotone curves.
+ * \param diag Output: The minimization diagram.
+ * \param traits The arrangement traits responsible for the x-monotone curves.
+ * \pre The value-type of the iterator is Traits::X_monotone_curve_2.
+ */
+template <class InputIterator, class EnvelopeDiagram, class Traits>
+void lower_envelope_x_monotone_2 (InputIterator begin, InputIterator end,
+                                  EnvelopeDiagram& diag, const Traits& traits)
+{
+  typedef typename EnvelopeDiagram::Traits_2                       Traits_2;
+  typedef Envelope_divide_and_conquer_2<Traits_2, EnvelopeDiagram> Envelope_2;
+
+  Envelope_2      env{&traits};
+
+  env.insert_x_monotone_curves (begin, end,
+                                true,              // Lower envelope.
+                                diag);
+
+  return;
+}
+
 /*!
  * Compute the upper envelope of a range of x-monotone curves.
  * \param begin An iterator for the first x-monotone curve.
@@ -125,6 +140,30 @@ void upper_envelope_x_monotone_2 (InputIterator begin, InputIterator end,
   return;
 }
 
+/*!
+ * Compute the upper envelope of a range of x-monotone curves.
+ * \param begin An iterator for the first x-monotone curve.
+ * \param end A past-the-end iterator for the x-monotone curves.
+ * \param diag Output: The maximization diagram.
+ * \param traits The arrangement traits responsible for the x-monotone curves.
+ * \pre The value-type of the iterator is Traits::X_monotone_curve_2.
+ */
+template <class InputIterator, class EnvelopeDiagram, class Traits>
+void upper_envelope_x_monotone_2 (InputIterator begin, InputIterator end,
+                                  EnvelopeDiagram& diag, const Traits& traits)
+{
+  typedef typename EnvelopeDiagram::Traits_2                       Traits_2;
+  typedef Envelope_divide_and_conquer_2<Traits_2, EnvelopeDiagram> Envelope_2;
+
+  Envelope_2      env{&traits};
+
+  env.insert_x_monotone_curves (begin, end,
+                                false,          // Upper envelope.
+                                diag);
+
+  return;
+}
+
 } //namespace CGAL
 
 #endif
