@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Principal_component_analysis/include/CGAL/linear_least_squares_fitting_circles_2.h $
-// $Id: linear_least_squares_fitting_circles_2.h f3baef9 2018-07-06T10:10:19+02:00 Simon Giraudot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Principal_component_analysis/include/CGAL/linear_least_squares_fitting_circles_2.h $
+// $Id: linear_least_squares_fitting_circles_2.h e07672a 2022-01-26T21:04:59+05:30 G Yuvan Shankar
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Pierre Alliez and Sylvain Pion and Ankit Gupta
 
@@ -45,13 +36,13 @@ namespace internal {
 template < typename InputIterator, typename K, typename DiagonalizeTraits >
 typename K::FT
 linear_least_squares_fitting_2(InputIterator first,
-                               InputIterator beyond, 
+                               InputIterator beyond,
                                typename K::Line_2& line,   // best fit line
                                typename K::Point_2& c,     // centroid
                                const typename K::Circle_2*,// used for indirection
                                const K&,                   // kernel
-			       const CGAL::Dimension_tag<2>& tag,
-			       const DiagonalizeTraits&)
+                               const CGAL::Dimension_tag<2>& tag,
+                               const DiagonalizeTraits&)
 {
   // types
   typedef typename K::FT       FT;
@@ -68,7 +59,7 @@ linear_least_squares_fitting_2(InputIterator first,
   // compute centroid
   c = centroid(first,beyond,K(),tag);
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1
   //   2
@@ -76,9 +67,9 @@ linear_least_squares_fitting_2(InputIterator first,
   FT mass = 0.0;
   typename DiagonalizeTraits::Covariance_matrix covariance = {{ 0., 0., 0. }};
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[4] = {0.25, 0.0,
-		0.0, 0.25};
+                0.0, 0.25};
   Matrix moment = init_matrix<FT>(2,temp);
   //  Matrix moment = Matrix(2,true,PI);
 
@@ -92,38 +83,40 @@ linear_least_squares_fitting_2(InputIterator first,
 
     // defined for convenience.
     // FT example = CGAL::to_double(t[0].x());
-    FT radius = std::sqrt(t.squared_radius());
-    FT delta[4] = {radius, 0.0, 
-		   0.0, radius};
+    FT radius = CGAL::approximate_sqrt(t.squared_radius());
+    FT delta[4] = {radius, 0.0,
+                   0.0, radius};
     Matrix transformation = init_matrix<FT>(2,delta);
     FT area = t.squared_radius();
-    CGAL_assertion(area != 0.0);
+    CGAL_assertion(!CGAL::is_zero(area));
 
     // Find the 2nd order moment for the circle wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = area * transformation * moment * LA::transpose(transformation);
-    
+
     // Translate the 2nd order moment to the center of the circle.
     FT x0 = t.center().x();
     FT y0 = t.center().y();
 
     // and add to covariance matrix
-    covariance[0] += transformation[0][0] + area * x0*x0;
+    covariance[0] += transformation[0][0] + area * CGAL::square(x0);
     covariance[1] += transformation[0][1] + area * x0*y0;
-    covariance[2] += transformation[1][1] + area * y0*y0;
+    covariance[2] += transformation[1][1] + area * CGAL::square(y0);
 
     mass += area;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
-  covariance[0] += mass * (-1.0 * c.x() * c.x());
-  covariance[1] += mass * (-1.0 * c.x() * c.y());
-  covariance[2] += mass * (-1.0 * c.y() * c.y());
+  covariance[0] -= mass * (CGAL::square(c.x()));
+  covariance[1] -= mass * (c.x() * c.y());
+  covariance[2] -= mass * (CGAL::square(c.y()));
 
   // solve for eigenvalues and eigenvectors.
-  // eigen values are sorted in ascending order, 
+  // eigen values are sorted in ascending order,
   // eigen vectors are sorted in accordance.
   typename DiagonalizeTraits::Vector eigen_values = {{ 0. , 0. }};
   typename DiagonalizeTraits::Matrix eigen_vectors = {{ 0., 0., 0. }};
@@ -136,28 +129,28 @@ linear_least_squares_fitting_2(InputIterator first,
     // regular case
     line = Line(c, Vector (eigen_vectors[2],eigen_vectors[3]));
     return (FT)1.0 - eigen_values[0] / eigen_values[1];
-  } 
+  }
   else
   {
     // isotropic case (infinite number of directions)
-    // by default: assemble a line that goes through 
+    // by default: assemble a line that goes through
     // the centroid and with a default horizontal vector.
-    line = Line(c, Vector(1.0, 0.0));
+    line = Line(c, Vector(FT(1), FT(0)));
     return (FT)0.0;
-  } 
-  
+  }
+
 } // end linear_least_squares_fitting_2 for circle set with 2D tag
 
 template < typename InputIterator, typename K, typename DiagonalizeTraits >
 typename K::FT
 linear_least_squares_fitting_2(InputIterator first,
-                               InputIterator beyond, 
+                               InputIterator beyond,
                                typename K::Line_2& line,   // best fit line
                                typename K::Point_2& c,     // centroid
                                const typename K::Circle_2*,// used for indirection
                                const K&,                   // kernel
-			       const CGAL::Dimension_tag<1>& tag,
-			       const DiagonalizeTraits& )
+                               const CGAL::Dimension_tag<1>& tag,
+                               const DiagonalizeTraits& )
 {
   // types
   typedef typename K::FT       FT;
@@ -173,7 +166,7 @@ linear_least_squares_fitting_2(InputIterator first,
   // compute centroid
   c = centroid(first,beyond,K(),tag);
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1
   //   2
@@ -181,9 +174,9 @@ linear_least_squares_fitting_2(InputIterator first,
   FT mass = 0.0;
   typename DiagonalizeTraits::Covariance_matrix covariance = {{ 0., 0., 0. }};
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[4] = {1.0, 0.0,
-		0.0, 1.0};
+                0.0, 1.0};
   Matrix moment = init_matrix<FT>(2,temp);
 
   for(InputIterator it = first;
@@ -196,59 +189,61 @@ linear_least_squares_fitting_2(InputIterator first,
 
     // defined for convenience.
     // FT example = CGAL::to_double(t[0].x());
-    FT radius = std::sqrt(t.squared_radius());
-    FT delta[4] = {radius, 0.0, 
-		   0.0, radius};
+    FT radius = CGAL::approximate_sqrt(t.squared_radius());
+    FT delta[4] = {radius, 0.0,
+                   0.0, radius};
     Matrix transformation = init_matrix<FT>(2,delta);
     FT length = 2 * radius;
-    CGAL_assertion(length != 0.0);
+    CGAL_assertion(!CGAL::is_zero(length));
 
     // Find the 2nd order moment for the circle wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
-    transformation = 0.5 * length * transformation * moment * LA::transpose(transformation);
-    
+    transformation = FT(0.5) * length * transformation * moment * LA::transpose(transformation);
+
     // Translate the 2nd order moment to the center of the circle.
     FT x0 = t.center().x();
     FT y0 = t.center().y();
 
     // and add to covariance matrix
-    covariance[0] += transformation[0][0] + length * x0*x0;
+    covariance[0] += transformation[0][0] + length * CGAL::square(x0);
     covariance[1] += transformation[0][1] + length * x0*y0;
-    covariance[2] += transformation[1][1] + length * y0*y0;
+    covariance[2] += transformation[1][1] + length * CGAL::square(y0);
 
     mass += length;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
-  covariance[0] += mass * (-1.0 * c.x() * c.x());
-  covariance[1] += mass * (-1.0 * c.x() * c.y());
-  covariance[2] += mass * (-1.0 * c.y() * c.y());
+  covariance[0] -= mass * (CGAL::square(c.x()));
+  covariance[1] -= mass * (c.x() * c.y());
+  covariance[2] -= mass * (CGAL::square(c.y()));
 
   // solve for eigenvalues and eigenvectors.
-  // eigen values are sorted in ascending order, 
+  // eigen values are sorted in ascending order,
   // eigen vectors are sorted in accordance.
   typename DiagonalizeTraits::Vector eigen_values = {{ 0. , 0. }};
   typename DiagonalizeTraits::Matrix eigen_vectors = {{ 0., 0., 0. }};
   DiagonalizeTraits::diagonalize_selfadjoint_covariance_matrix
     (covariance, eigen_values, eigen_vectors);
-  
+
   // check unicity and build fitting line accordingly
   if(eigen_values[1] != eigen_values[0])
   {
     // regular case
     line = Line(c, Vector(eigen_vectors[2],eigen_vectors[3]));
     return (FT)1.0 - eigen_values[0] / eigen_values[1];
-  } 
+  }
   else
   {
     // isotropic case (infinite number of directions)
-    // by default: assemble a line that goes through 
+    // by default: assemble a line that goes through
     // the centroid and with a default horizontal vector.
-    line = Line(c, Vector(1.0, 0.0));
+    line = Line(c, Vector(FT(1), FT(0)));
     return (FT)0.0;
-  } 
+  }
 } // end linear_least_squares_fitting_2 for circle set with 1D tag
 
 } // end namespace internal
