@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/make_mesh_3.h $
-// $Id: make_mesh_3.h 89b4c98 2019-08-16T11:10:49+02:00 Laurent Rineau
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Mesh_3/include/CGAL/make_mesh_3.h $
+// $Id: make_mesh_3.h b76f640 2023-04-24T13:59:48+02:00 Jane Tournois
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Stéphane Tayeb
@@ -28,111 +19,19 @@
 
 #include <CGAL/license/Mesh_3.h>
 
-#include <CGAL/disable_warnings.h>
-
 #include <CGAL/Mesh_3/config.h>
-#include <CGAL/boost/parameter.h>
 #include <CGAL/refine_mesh_3.h>
 #include <CGAL/tags.h>
 #include <CGAL/Mesh_3/Protect_edges_sizing_field.h>
-#include <CGAL/Mesh_3/Has_features.h>
+#include <CGAL/STL_Extension/internal/Has_features.h>
 #include <CGAL/Mesh_3/C3T3_helpers.h>
 
 #include <boost/mpl/has_xxx.hpp>
-#include <boost/parameter/preprocessor.hpp>
+
+#include <atomic>
 
 namespace CGAL {
 
-namespace parameters {
-  namespace internal {
-    // Features
-    struct Features_options
-    {
-      Features_options(bool b) : b_(b) {}
-      bool features() const { return b_; }
-    private:
-      bool b_;
-    };
-
-    // -----------------------------------
-    // Features generator
-    // -----------------------------------
-    // struct Features_option_generator
-    template <typename HasFeatures>
-    struct Features_options_generator {};
-
-    template<>
-    struct Features_options_generator<CGAL::Tag_true>
-    {
-      Features_options operator()() { return Features_options(true); }
-    };
-
-    template<>
-    struct Features_options_generator<CGAL::Tag_false>
-    {
-      Features_options operator()() { return Features_options(false); }
-    };
-
-    // struct Domain_features_generator is designed to handle cases where
-    // MeshDomain::Has_features is not a valid type
-    template< typename MeshDomain, bool MeshDomainHasHasFeatures >
-    struct Domain_features_generator {};
-
-    template< typename MeshDomain >
-    struct Domain_features_generator< MeshDomain, false >
-    {
-      Features_options operator()()
-      {
-        return Features_options_generator<CGAL::Tag_false>()();
-      }
-    };
-
-    template< typename MeshDomain >
-    struct Domain_features_generator< MeshDomain, true >
-    {
-      Features_options operator()()
-      {
-        return Features_options_generator<typename MeshDomain::Has_features>()();
-      }
-    };
-
-  } // end namespace internal
-
-  // -----------------------------------
-  // Features_options
-  // -----------------------------------
-  inline internal::Features_options
-  features() { return internal::Features_options(true); }
-
-  inline internal::Features_options
-  no_features() { return internal::Features_options(false); }
-
-  template < typename MeshDomain >
-  inline internal::Features_options
-  features(const MeshDomain& /*domain*/)
-  {
-    typedef typename internal::Domain_features_generator<
-      MeshDomain,
-      CGAL::Mesh_3::internal::has_Has_features<MeshDomain>::value > Generator;
-
-    return Generator()();
-  }
-
-  // -----------------------------------
-  // Parameters
-  // -----------------------------------
-
-// see <CGAL/config.h>
-CGAL_PRAGMA_DIAG_PUSH
-// see <CGAL/boost/parameter.h>
-CGAL_IGNORE_BOOST_PARAMETER_NAME_WARNINGS
-
-  BOOST_PARAMETER_NAME( features_param )
-
-CGAL_PRAGMA_DIAG_POP
-
-} // end namespace parameters::internal
-
 // -----------------------------------
 // Initialize c3t3 stuff
 // -----------------------------------
@@ -201,7 +100,7 @@ void init_c3t3_with_features(C3T3& c3t3,
                              std::size_t maximal_number_of_vertices = 0,
                              Mesh_error_code* pointer_to_error_code = 0
 #ifndef CGAL_NO_ATOMIC
-                             , CGAL::cpp11::atomic<bool>* pointer_to_stop = 0
+                             , std::atomic<bool>* pointer_to_stop = 0
 #endif
                              )
 {
@@ -212,7 +111,7 @@ void init_c3t3_with_features(C3T3& c3t3,
     protect_edges(c3t3,
                   domain,
                   Sizing_field(criteria.edge_criteria_object()),
-                  typename Edge_criteria::FT(),
+                  criteria.edge_criteria_object().min_length_bound(),
                   maximal_number_of_vertices,
                   pointer_to_error_code
 #ifndef CGAL_NO_ATOMIC
@@ -333,6 +232,13 @@ struct C3t3_initializer < C3T3, MD, MC, true, CGAL::Tag_true >
         if (c3t3.number_of_facets() == 0) {
           need_more_init = true;
         }
+        else
+        {
+          helper.update_restricted_cells();
+          if(c3t3.number_of_cells() == 0) {
+            need_more_init = true;
+          }
+        }
       }
       if(need_more_init) {
         init_c3t3(c3t3, domain, criteria,
@@ -376,127 +282,189 @@ struct C3t3_initializer < C3T3, MD, MC, true, CGAL::Tag_false >
 // make_mesh_3 stuff
 // -----------------------------------
 
-// Manual redirections
-// boost::parameter can't handle make_mesh_3 return_type alone...
-#ifndef CGAL_CFG_NO_CPP0X_VARIADIC_TEMPLATES
-
-template <typename C3T3, typename MD, typename MC, typename ... T>
-C3T3 make_mesh_3(const MD& md, const MC& mc, const T& ...t)
+/*!
+ * \ingroup PkgMesh3Functions
+ *
+ * The function `make_mesh_3()` is a 3D
+ * mesh generator. It produces simplicial meshes which discretize
+ * 3D domains.
+ *
+ * The mesh generation algorithm is a Delaunay refinement process
+ * followed by an optimization phase.
+ * The criteria driving the Delaunay refinement
+ * process may be tuned to achieve the user needs with respect to
+ * the size of mesh elements, the accuracy of boundaries approximation,
+ * etc.
+ *
+ * The optimization phase is a sequence of optimization processes,
+ * amongst the following available optimizers: an ODT-smoothing,
+ * a Lloyd-smoothing, a sliver perturber, and a sliver exuder.
+ * Each optimization process
+ * can be activated or not,
+ * according to the user requirements
+ * and available time.
+ * By default, only the perturber and the exuder are activated.
+ * Note that the benefits of the exuder will be lost if the mesh
+ * is further refined afterward, and that ODT-smoothing, Lloyd-smoothing,
+ * and sliver perturber should never be called after the sliver exuder.
+ * In the case of further refinement, only the sliver exuder can be used.
+ *
+ * The function outputs the mesh to an object which provides iterators to
+ * traverse the resulting mesh data structure or can be written to a file
+ * (see \ref Mesh_3_section_examples ).
+ *
+ * \tparam C3T3 either a model of the concept `MeshComplex_3InTriangulation_3` or
+ *              of `MeshComplexWithFeatures_3InTriangulation_3` if `MD`
+ *              is a model of `MeshDomainWithFeatures_3`.
+ *              The type `C3T3` is in particular required to provide a nested type
+ *              `C3T3::Triangulation` for the 3D triangulation
+ *              embedding the mesh. The vertex and cell base classes of the
+ *              triangulation `C3T3::Triangulation` are required to be models of the
+ *              concepts `MeshVertexBase_3` and `MeshCellBase_3` respectively.
+ *
+ * \tparam MD either a model of the concept `MeshDomain_3` or of
+ *            `MeshDomainWithFeatures_3` if 0 and 1-dimensional features
+ *            of the input complex have to be accurately represented in the mesh.
+ *
+ * \tparam MC either a model of the concept `MeshCriteria_3` or a model
+ *            of `MeshCriteriaWithFeatures_3` if the domain has exposed features.
+ *
+ * \tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
+ *
+ * \param domain the domain used to create the `c3t3` parameter. It is the sole link through which the domain
+ *               to be discretized is known by the mesh generation algorithm.
+ * \param criteria specifies the size and shape requirements for mesh tetrahedra
+ *                 and surface facets. These criteria form the rules which drive
+ *                 the refinement process. All mesh elements satisfy those criteria
+ *                 at the end of the refinement process.
+ *                 In addition, if the domain has features, the argument
+ *                 `criteria` provides a sizing field to guide the discretization
+ *                 of 1-dimensional exposed features.
+ *
+ *  \param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below:
+ *
+ * \cgalNamedParamsBegin
+ *   \cgalParamSectionBegin{Feature preservation options}
+ *     \cgalParamDescription{If the domain is a model of `MeshDomainWithFeatures_3`, 0 and 1-dimensional features can be
+ *                           taken into account while generating the mesh. The following two named parameters control
+ *                           this option:
+ *                           <UL>
+ *                             <LI>\link parameters::features() `parameters::features(domain)` \endlink
+ *                             <LI>`parameters::no_features()`
+ *                           </UL>}
+ *     \cgalParamDefault{`parameters::features(domain)`}
+ *   \cgalParamSectionEnd
+ *   \cgalParamSectionBegin{Topological options (manifoldness)}
+ *     \cgalParamDescription{In order to drive the meshing algorithm and ensure that the output mesh follows a desired topological criterion,
+ *                           three named parameters control this option:
+ *                           <UL>
+ *                             <LI>`parameters::manifold()`
+ *                             <LI>`parameters::manifold_with_boundary()`
+ *                             <LI>`parameters::non_manifold()`
+ *                           </UL>
+ *                           Note that the meshing algorithm cannot generate a manifold surface if the input surface is not manifold.}
+ *     \cgalParamDefault{`parameters::non_manifold()`}
+ *   \cgalParamSectionEnd
+ *   \cgalParamSectionBegin{Lloyd optimization}
+ *     \cgalParamDescription{`lloyd_optimize_mesh_3()` can optionally be called after the meshing process.
+ *                           Two named parameters control this behavior:
+ *                           <UL>
+ *                             <LI> `parameters::no_lloyd()`
+ *                             <LI> `parameters::lloyd_optimize_mesh_3()`
+ *                           </UL>}
+ *     \cgalParamDefault{`parameters::no_lloyd()`}
+ *   \cgalParamSectionEnd
+ *   \cgalParamSectionBegin{ODT optimization}
+ *     \cgalParamDescription{`odt_optimize_mesh_3()` can optionally be called after the meshing process.
+ *                           Two named parameters control this behavior:
+ *                           <UL>
+ *                             <LI> `parameters::no_odt()`
+ *                             <LI> `parameters::odt()`
+ *                           </UL>}
+ *     \cgalParamDefault{`parameters::no_odt()`}
+ *   \cgalParamSectionEnd
+ *   \cgalParamSectionBegin{Mesh perturbation}
+ *     \cgalParamDescription{`perturb_mesh_3()` can optionally be called after the meshing process.
+ *                           Two named parameters control this behavior:
+ *                           <UL>
+ *                             <LI> `parameters::no_perturb()`
+ *                             <LI> `parameters::perturb()`
+ *                           </UL>}
+ *     \cgalParamDefault{`parameters::perturb()`}
+ *   \cgalParamSectionEnd
+ *   \cgalParamSectionBegin{Mesh exudation}
+ *     \cgalParamDescription{`exude_mesh_3()` can optionally be called after the meshing process.
+ *                           Two named parameters control this behavior:
+ *                           <UL>
+ *                             <LI> `parameters::no_exude()`
+ *                             <LI> `parameters::exude()`
+ *                           </UL>}
+ *     \cgalParamDefault{`parameters::exude()`}
+ *   \cgalParamSectionEnd
+ * \cgalNamedParamsEnd
+ *
+ * Note that regardless of which optimization processes are activated,
+ * they are always launched in the order that is a suborder
+ * of the following (see user manual for further
+ * details): *ODT-smoother*, *Lloyd-smoother*, *perturber*, and *exuder*.
+ *
+ * Beware that optimization of the mesh is obtained
+ * by perturbing mesh vertices and modifying the mesh connectivity
+ * and that this has an impact
+ * on the strict compliance to the refinement criteria.
+ * Though a strict compliance to mesh criteria
+ * is guaranteed at the end of the Delaunay refinement, this may no longer be true after
+ * some optimization processes. Also beware that the default behavior does involve some
+ * optimization processes.
+ *
+ * \sa `refine_mesh_3()`
+ * \sa `exude_mesh_3()`
+ * \sa `perturb_mesh_3()`
+ * \sa `lloyd_optimize_mesh_3()`
+ * \sa `odt_optimize_mesh_3()`
+ */
+template<typename C3T3, typename MeshDomain, typename MeshCriteria, typename CGAL_NP_TEMPLATE_PARAMETERS>
+C3T3 make_mesh_3(const MeshDomain& domain, const MeshCriteria& criteria, const CGAL_NP_CLASS& np = parameters::default_values())
 {
-  C3T3 c3t3;
-  make_mesh_3_bp(c3t3,md,mc,t...);
-  return c3t3;
+    using parameters::choose_parameter;
+    using parameters::get_parameter;
+    C3T3 c3t3;
+    parameters::internal::Exude_options exude_param = choose_parameter(get_parameter(np, internal_np::exude_options_param), parameters::exude().v);
+    parameters::internal::Perturb_options perturb_param = choose_parameter(get_parameter(np, internal_np::perturb_options_param), parameters::perturb().v);
+    parameters::internal::Odt_options odt_param = choose_parameter(get_parameter(np, internal_np::odt_options_param), parameters::no_odt().v);
+    parameters::internal::Lloyd_options lloyd_param = choose_parameter(get_parameter(np, internal_np::lloyd_options_param), parameters::no_lloyd().v);
+    parameters::internal::Features_options features_param = choose_parameter(get_parameter(np, internal_np::features_options_param), parameters::features(domain).v);
+    parameters::internal::Mesh_3_options mesh_options_param = choose_parameter(get_parameter(np, internal_np::mesh_param), parameters::internal::Mesh_3_options());
+    parameters::internal::Manifold_options manifold_options_param = choose_parameter(get_parameter(np, internal_np::manifold_param), parameters::internal::Manifold_options());
+
+    make_mesh_3_impl(c3t3, domain, criteria,
+            exude_param, perturb_param, odt_param, lloyd_param,
+            features_param.features(), mesh_options_param,
+            manifold_options_param);
+    return c3t3;
 }
 
-#else
-
-template <typename C3T3, typename MD, typename MC>
-C3T3 make_mesh_3(const MD& md, const MC& mc)
+#ifndef DOXYGEN_RUNNING
+// Overload handling parameters passed with operator=
+template<typename C3T3, typename MeshDomain, typename MeshCriteria,
+         typename CGAL_NP_TEMPLATE_PARAMETERS_NO_DEFAULT_1,
+         typename CGAL_NP_TEMPLATE_PARAMETERS_NO_DEFAULT_2,
+         typename ... NP>
+C3T3 make_mesh_3(const MeshDomain& domain, const MeshCriteria& criteria,
+                 const CGAL_NP_CLASS_1&  np1,
+                 const CGAL_NP_CLASS_2&  np2,
+                 const NP& ... nps)
 {
-  C3T3 c3t3;
-  make_mesh_3_bp(c3t3,md,mc);
-  return c3t3;
+  return make_mesh_3<C3T3>(domain, criteria, internal_np::combine_named_parameters(np1, np2, nps...));
 }
 
-template <typename C3T3, typename MD, typename MC,
-  typename Arg1>
-C3T3 make_mesh_3(const MD& md, const MC& mc, const Arg1& a1)
-{
-  C3T3 c3t3;
-  make_mesh_3_bp(c3t3,md,mc,a1);
-  return c3t3;
-}
-
-template <typename C3T3, typename MD, typename MC,
-  typename Arg1, typename Arg2>
-C3T3 make_mesh_3(const MD& md, const MC& mc, const Arg1& a1, const Arg2& a2)
-{
-  C3T3 c3t3;
-  make_mesh_3_bp(c3t3,md,mc,a1,a2);
-  return c3t3;
-}
-
-template <typename C3T3, typename MD, typename MC,
-  typename Arg1, typename Arg2, typename Arg3>
-C3T3 make_mesh_3(const MD& md, const MC& mc, const Arg1& a1, const Arg2& a2,
-                 const Arg3& a3)
-{
-  C3T3 c3t3;
-  make_mesh_3_bp(c3t3,md,mc,a1,a2,a3);
-  return c3t3;
-}
-
-template <typename C3T3, typename MD, typename MC,
-  typename Arg1, typename Arg2, typename Arg3, typename Arg4>
-C3T3 make_mesh_3(const MD& md, const MC& mc, const Arg1& a1, const Arg2& a2,
-                 const Arg3& a3, const Arg4& a4)
-{
-  C3T3 c3t3;
-  make_mesh_3_bp(c3t3,md,mc,a1,a2,a3,a4);
-  return c3t3;
-}
-
-template <typename C3T3, typename MD, typename MC,
-  typename Arg1, typename Arg2, typename Arg3, typename Arg4, typename Arg5>
-C3T3 make_mesh_3(const MD& md, const MC& mc, const Arg1& a1, const Arg2& a2,
-                 const Arg3& a3, const Arg4& a4, const Arg5& a5)
-{
-  C3T3 c3t3;
-  make_mesh_3_bp(c3t3,md,mc,a1,a2,a3,a4,a5);
-  return c3t3;
-}
-
-#endif
-
-#if defined(BOOST_MSVC)
-#  pragma warning(push)
-#  pragma warning(disable:4003) // not enough actual parameters for macro
-#endif
-
-// see <CGAL/config.h>
-CGAL_PRAGMA_DIAG_PUSH
-// see <CGAL/boost/parameter.h>
-CGAL_IGNORE_BOOST_PARAMETER_NAME_WARNINGS
-
-BOOST_PARAMETER_FUNCTION(
-  (void),
-  make_mesh_3_bp,
-  parameters::tag,
-  (required (in_out(c3t3),*) (domain,*) (criteria,*) ) // nondeduced
-  (deduced
-    (optional
-      (features_param, (parameters::internal::Features_options), parameters::features(domain))
-      (exude_param, (parameters::internal::Exude_options), parameters::exude())
-      (perturb_param, (parameters::internal::Perturb_options), parameters::perturb())
-      (odt_param, (parameters::internal::Odt_options), parameters::no_odt())
-      (lloyd_param, (parameters::internal::Lloyd_options), parameters::no_lloyd())
-      (mesh_options_param, (parameters::internal::Mesh_3_options),
-                           parameters::internal::Mesh_3_options())
-      (manifold_options_param, (parameters::internal::Manifold_options),
-                               parameters::internal::Manifold_options())
-    )
-  )
-)
-{
-  make_mesh_3_impl(c3t3, domain, criteria,
-                   exude_param, perturb_param, odt_param, lloyd_param,
-                   features_param.features(), mesh_options_param,
-                   manifold_options_param);
-}
-
-CGAL_PRAGMA_DIAG_POP
-
-#if defined(BOOST_MSVC)
-#  pragma warning(pop)
-#endif
-
 /**
  * @brief This function meshes the domain defined by mesh_traits
  * (respecting criteria), and outputs the mesh to c3t3
  *
  * @param domain the domain to be discretized
  * @param criteria the criteria
- * @param exude if it is set to \c true, an exudation step will be done at
+ * @param exude if it is set to `true`, an exudation step will be done at
  *   the end of the Delaunay refinement process
  *
  * @return The mesh as a C3T3 object
@@ -524,7 +492,7 @@ void make_mesh_3_impl(C3T3& c3t3,
     C3T3,
     MeshDomain,
     MeshCriteria,
-    Mesh_3::internal::has_Has_features<MeshDomain>::value > () (c3t3,
+    ::CGAL::internal::has_Has_features<MeshDomain>::value > () (c3t3,
             domain,
             criteria,
             with_features,
@@ -535,12 +503,12 @@ void make_mesh_3_impl(C3T3& c3t3,
   // Build mesher and launch refinement process
   // Don't reset c3t3 as we just created it
   refine_mesh_3(c3t3, domain, criteria,
-                exude, perturb, odt, lloyd, parameters::no_reset_c3t3(), mesh_options,
-                manifold_options);
+                parameters::exude_options=exude, parameters::perturb_options=perturb, parameters::odt_options=odt, parameters::lloyd_options= lloyd,
+                parameters::no_reset_c3t3(), parameters::mesh_options= mesh_options,
+                parameters::manifold_option= manifold_options);
 }
 
+#endif //DOXYGEN_RUNNING
 } // end namespace CGAL
 
-#include <CGAL/enable_warnings.h>
-
 #endif // CGAL_MAKE_MESH_3_H
