@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Minkowski_sum_2/include/CGAL/minkowski_sum_2.h $
-// $Id: minkowski_sum_2.h 8cdfad0 2017-11-15T22:58:57+01:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Minkowski_sum_2/include/CGAL/minkowski_sum_2.h $
+// $Id: minkowski_sum_2.h 4e48b0b 2021-11-03T15:10:16+02:00 Efi Fogel
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Ron Wein   <wein_r@yahoo.com>
 //             Efi Fogel  <efifogel@gmail.com>
@@ -321,7 +312,7 @@ minkowski_sum_2(const Polygon_2<Kernel_, Container_>& pgn1,
  *   const typename Minkowski_sum_by_decomposition_2<DecompositionStrategy1_,
  *                                                   DecompositionStrategy2_,
  *                                                   Container_>::Traits_2>
- * are exchangable except for in one case, where there is an ambiguity.
+ * are exchangeable except for in one case, where there is an ambiguity.
  * Thus, we use the former, even though it is less generic, as change to the
  * traits type in Minkowski_sum_by_decomposition_2 would require a similar
  * change here.
@@ -770,10 +761,10 @@ minkowski_sum_by_decomposition_2
  const Decomposition_& decomp,
  const Gps_segment_traits_2<Kernel_, Container_>& traits)
 {
-  typedef Kernel_                               Kernel;
-  typedef Container_                            Container;
-  typedef Decomposition_                        Decomposition;
-  typedef Polygon_nop_decomposition_2<Kernel>   Nop_decomposition;
+  typedef Kernel_                                         Kernel;
+  typedef Container_                                      Container;
+  typedef Decomposition_                                  Decomposition;
+  typedef Polygon_nop_decomposition_2<Kernel, Container>  Nop_decomposition;
 
   if (pgn1.is_convex()) {
     Nop_decomposition decomp_nop;
@@ -848,11 +839,11 @@ minkowski_sum_by_decomposition_2
  const WithHolesDecomposition_& decomp_with_holes,
  const Gps_segment_traits_2<Kernel_, Container_>& traits)
 {
-  typedef Kernel_                               Kernel;
-  typedef Container_                            Container;
-  typedef NoHolesDecomposition_                 No_holes_decomposition;
-  typedef WithHolesDecomposition_               With_holes_decomposition;
-  typedef Polygon_nop_decomposition_2<Kernel>   Nop_decomposition;
+  typedef Kernel_                                         Kernel;
+  typedef Container_                                      Container;
+  typedef NoHolesDecomposition_                           No_holes_decomposition;
+  typedef WithHolesDecomposition_                         With_holes_decomposition;
+  typedef Polygon_nop_decomposition_2<Kernel, Container>  Nop_decomposition;
 
   Hole_filter_2<Kernel, Container> hole_filter;
   Polygon_with_holes_2<Kernel, Container> filtered_pgn1;
@@ -991,11 +982,11 @@ minkowski_sum_by_decomposition_2
  const WithHolesDecomposition_& decomp_with_holes,
  const Gps_segment_traits_2<Kernel_, Container_>& traits)
 {
-  typedef Kernel_                               Kernel;
-  typedef Container_                            Container;
-  typedef NoHolesDecomposition_                 No_holes_decomposition;
-  typedef WithHolesDecomposition_               With_holes_decomposition;
-  typedef Polygon_nop_decomposition_2<Kernel>   Nop_decomposition;
+  typedef Kernel_                                         Kernel;
+  typedef Container_                                      Container;
+  typedef NoHolesDecomposition_                           No_holes_decomposition;
+  typedef WithHolesDecomposition_                         With_holes_decomposition;
+  typedef Polygon_nop_decomposition_2<Kernel, Container>  Nop_decomposition;
 
   Hole_filter_2<Kernel, Container> hole_filter;
   Polygon_with_holes_2<Kernel,Container> filtered_pgn2;
