@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Bounding_volumes/include/CGAL/rectangular_3_center_2.h $
+// $Id: rectangular_3_center_2.h 0c20a5b 2023-04-24T17:37:51+02:00 Michael Hoffmann
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Bounding_volumes/include/CGAL/rectangular_3_center_2.h $
-// $Id: rectangular_3_center_2.h 31de650 2018-11-13T09:10:20+01:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
 
@@ -26,13 +17,11 @@
 
 
 #include <CGAL/basic.h>
-#include <CGAL/Optimisation/assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/algorithm.h>
 #include <CGAL/Rectangular_p_center_traits_2.h>
 #include <algorithm>
 #include <vector>
-#include <boost/bind.hpp>
-#include <boost/function.hpp>
 
 namespace CGAL {
 
@@ -47,8 +36,6 @@ rectangular_2_center_2(
   Traits& t)
 {
   using std::pair;
-  using std::greater;
-  using std::less;
 
   typedef typename Traits::Iso_rectangle_2        Rectangle;
   typedef typename Traits::Point_2                Point;
@@ -62,7 +49,6 @@ rectangular_2_center_2(
     P_below_right;
   typedef typename Traits::Construct_point_2_below_left_implicit_point_2
     P_below_left;
-  typedef boost::function1<FT, Point>              Gamma;
 
   // fetch function objects from traits class
   CVertex       v      = t.construct_vertex_2_object();
@@ -81,15 +67,15 @@ rectangular_2_center_2(
 
   // two cases: top-left & bottom-right or top-right & bottom-left
   Min< FT > minft;
-  Gamma gamma1 =
-    boost::bind(minft, boost::bind(dist, v(bb, 0), _1), boost::bind(dist, v(bb, 2), _1));
-  Gamma gamma2 =
-    boost::bind(minft, boost::bind(dist, v(bb, 1), _1), boost::bind(dist, v(bb, 3), _1));
+  auto gamma1 =
+    [&minft, &bb, &dist, &v](const Point& p){ return minft(dist( v(bb, 0), p), dist(v(bb, 2),p));};
+  auto gamma2 =
+    [&minft, &bb, &dist, &v](const Point& p){ return minft(dist( v(bb, 1), p), dist(v(bb, 3),p));};
 
   pair< ForwardIterator, ForwardIterator > cand =
     min_max_element(f, l,
-                    boost::bind(greater<FT>(), boost::bind(gamma1, _1), boost::bind(gamma1, _2)),
-                    boost::bind(less<FT>(), boost::bind(gamma2, _1), boost::bind(gamma2, _2)));
+                    [&gamma1](const Point& p1, const Point& p2){ return std::greater<FT>()(gamma1(p1), gamma1(p2)); },
+                    [&gamma2](const Point& p1, const Point& p2){ return std::less<FT>()(gamma2(p1), gamma2(p2)); });
 
   // return the result
   if (gamma1(*cand.first) < gamma2(*cand.second)) {
@@ -115,9 +101,6 @@ rectangular_3_center_2_type1(
   typename Traits::FT& rad,
   Traits& t)
 {
-  using std::max;
-  using std::less;
-
   typedef typename Traits::FT                         FT;
   typedef typename Traits::Iso_rectangle_2            Rectangle;
   typedef typename Traits::Point_2                    Point;
@@ -133,7 +116,6 @@ rectangular_3_center_2_type1(
     P_below_right;
   typedef typename Traits::Construct_point_2_below_left_implicit_point_2
     P_below_left;
-  typedef boost::function1<FT, Point>                 Gamma;
 
   // fetch function objects from traits class
   Rect          rect   = t.construct_iso_rectangle_2_object();
@@ -167,15 +149,15 @@ rectangular_3_center_2_type1(
     RandomAccessIterator e = l;
     bool b_empty = true;
     Min< FT > minft;
-    Gamma gamma = boost::bind(minft, 
-		       boost::bind(dist, v(r, i), _1),
-		       boost::bind(dist, v(r, 2 + i), _1));
-    
+    auto gamma = [&minft, &dist, &v, &r, i](const Point& p)
+                  { return minft(dist(v(r, i), p), dist(v(r, 2 + i), p)); };
+
     while (e - s > 1) {
       // step (a)
       RandomAccessIterator m = s + (e - s - 1) / 2;
-      std::nth_element(s, m, e, boost::bind(less<FT>(), boost::bind(gamma, _1), boost::bind(gamma, _2)));
-      
+      std::nth_element(s, m, e, [&gamma](const Point& p1, const Point& p2)
+                                {return gamma(p1) < gamma(p2);});
+
       // step (b)
       Rectangle b_prime = bounding_box_2(m + 1, e, t);
       if (!b_empty)
@@ -229,8 +211,9 @@ struct Rectangular_3_center_2_type2_operations_base {
   typedef typename R::Infinity_distance_2        Infinity_distance_2;
   typedef typename R::Less_x_2                   Less_x_2;
   typedef typename R::Less_y_2                   Less_y_2;
-  typedef boost::function2<bool,Point_2,Point_2> Greater_x_2;
-  typedef boost::function2<bool,Point_2,Point_2> Greater_y_2;
+  typedef std::function<bool(const Point_2& ,
+                             const Point_2&)>    Greater_x_2;
+  typedef Greater_x_2                            Greater_y_2;
   typedef Min< Point_2, Less_x_2 >               Min_x_2;
   typedef Max< Point_2, Less_x_2 >               Max_x_2;
   typedef Min< Point_2, Less_y_2 >               Min_y_2;
@@ -245,22 +228,22 @@ struct Rectangular_3_center_2_type2_operations_base {
     Construct_point_2_below_right_implicit_point_2;
   typedef typename R::Construct_point_2_below_left_implicit_point_2
     Construct_point_2_below_left_implicit_point_2;
-  typedef boost::function1<FT,Point_2>           Delta;
-  
+  typedef std::function<FT(const Point_2&)>           Delta;
+
   Delta  delta() const { return delta_; }
   Less_x_2  less_x_2_object() const { return r_.less_x_2_object(); }
   Less_y_2  less_y_2_object() const { return r_.less_y_2_object(); }
   Greater_x_2  greater_x_2_object() const
-  { return boost::bind(less_x_2_object(),_2,_1); }
+  { return [this](const Point_2& p1, const Point_2& p2){ return this->less_x_2_object()(p2, p1); }; }
   Greater_y_2  greater_y_2_object() const
-  { return boost::bind(less_y_2_object(),_2,_1); }
+  { return [this](const Point_2& p1, const Point_2& p2){ return this->less_y_2_object()(p2, p1); }; }
   Infinity_distance_2  distance() const
   { return r_.infinity_distance_2_object(); }
   Construct_vertex_2  construct_vertex_2_object() const
   { return r_.construct_vertex_2_object(); }
   Construct_iso_rectangle_2 construct_iso_rectangle_2_object() const
   { return r_.construct_iso_rectangle_2_object(); }
-  
+
   Construct_point_2_below_left_implicit_point_2
   pt_b_l() const
   { return r_.construct_point_2_below_left_implicit_point_2_object(); }
@@ -273,12 +256,12 @@ struct Rectangular_3_center_2_type2_operations_base {
   Construct_point_2_above_right_implicit_point_2
   pt_a_r() const
   { return r_.construct_point_2_above_right_implicit_point_2_object(); }
-  
+
   Min_x_2 minx() const { return Min_x_2(less_x_2_object()); }
   Min_y_2 miny() const { return Min_y_2(less_y_2_object()); }
   Max_x_2 maxx() const { return Max_x_2(less_x_2_object()); }
   Max_y_2 maxy() const { return Max_y_2(less_y_2_object()); }
-  
+
   private:
     R& r_;
     Delta delta_;
@@ -286,7 +269,7 @@ struct Rectangular_3_center_2_type2_operations_base {
 public:
 
   Rectangular_3_center_2_type2_operations_base(R& r, const Point_2& p)
-    : r_(r), delta_(boost::bind(r.infinity_distance_2_object(), p, _1))
+    : r_(r), delta_([&r, &p](const Point_2& q){ return r.infinity_distance_2_object()(p, q); })
   {}
 
 };
@@ -324,7 +307,7 @@ struct Rectangular_3_center_2_type2_operations0
 
   X_compare  compare_x() const { return less_x_2_object(); }
   Y_compare  compare_y() const { return greater_y_2_object(); }
-  
+
   Point place_x_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Point& first_uncovered,
@@ -337,7 +320,7 @@ struct Rectangular_3_center_2_type2_operations0
                     v(bbox, 2)),
                3);
     }
-  
+
     Point place_x_square(bool constraint_empty,
                          const Rectangle& constraint,
                          const Rectangle& bbox) const
@@ -348,7 +331,7 @@ struct Rectangular_3_center_2_type2_operations0
                     v(bbox, 2)),
                3);
     }
-  
+
     Point place_x_square(const Point& so_far,
                          const Rectangle& bbox,
                          FT radius) const
@@ -359,7 +342,7 @@ struct Rectangular_3_center_2_type2_operations0
                     so_far),
              3);
     }
-  
+
     Point place_y_square(bool constraint_empty,
                          const Rectangle& constraint,
                          const Point& first_uncovered,
@@ -372,7 +355,7 @@ struct Rectangular_3_center_2_type2_operations0
                       miny()(first_uncovered, v(constraint, 0))),
                1);
     }
-  
+
     Point place_y_square(bool constraint_empty,
                          const Rectangle& constraint,
                          const Rectangle& bbox) const
@@ -383,7 +366,7 @@ struct Rectangular_3_center_2_type2_operations0
                     constraint_empty ? v(bbox, 2) : v(constraint, 0)),
                1);
     }
-  
+
     Point place_y_square(const Point& so_far,
                          const Rectangle& bbox,
                          FT radius) const
@@ -395,37 +378,37 @@ struct Rectangular_3_center_2_type2_operations0
                            so_far)),
                1);
     }
-  
+
     Point update_x_square(const Point& s, const Point& newp) const
     {
       Construct_iso_rectangle_2 rect = construct_iso_rectangle_2_object();
       Construct_vertex_2        v    = construct_vertex_2_object();
-  
+
       return v(rect(minx()(s, newp), s), 3);
     }
-  
+
     Point update_y_square(const Point& s, const Point& newp) const {
       Construct_iso_rectangle_2 rect = construct_iso_rectangle_2_object();
       Construct_vertex_2        v    = construct_vertex_2_object();
-  
+
       return v(rect(s, miny()(s, newp)), 1);
     }
-  
+
     FT compute_x_distance(const Point& extreme,
                           const Rectangle& constraint) const
     { return distance()(extreme, construct_vertex_2_object()(constraint, 1)); }
-  
+
     FT compute_y_distance(const Point& extreme,
                           const Rectangle& constraint) const
     { return distance()(extreme, construct_vertex_2_object()(constraint, 3)); }
-  
+
     Point construct_corner_square(const Rectangle& bbox, FT r) const
     { return pt_a_r()(construct_vertex_2_object()(bbox, 0),
                       construct_vertex_2_object()(bbox, 0), r); }
-  
+
     Point construct_x_square(const Point& p, FT r) const
     { return pt_b_r()(p, p, r); }
-  
+
     Point construct_y_square(const Point& p, FT r) const
     { return pt_a_l()(p, p, r); }
 };
@@ -462,7 +445,7 @@ struct Rectangular_3_center_2_type2_operations1
 
   X_compare  compare_x() const { return greater_x_2_object(); }
   Y_compare  compare_y() const { return greater_y_2_object(); }
-  
+
   Point place_x_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Point& first_uncovered,
@@ -475,7 +458,7 @@ struct Rectangular_3_center_2_type2_operations1
                   v(bbox, 3)),
              2);
   }
-  
+
   Point place_x_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Rectangle& bbox) const
@@ -486,7 +469,7 @@ struct Rectangular_3_center_2_type2_operations1
                   v(bbox, 3)),
              2);
   }
-  
+
   Point place_x_square(const Point& so_far,
                        const Rectangle& bbox,
                        FT radius) const
@@ -498,7 +481,7 @@ struct Rectangular_3_center_2_type2_operations1
                   so_far),
              2);
   }
-  
+
   Point place_y_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Point& first_uncovered,
@@ -511,7 +494,7 @@ struct Rectangular_3_center_2_type2_operations1
                     miny()(first_uncovered, v(constraint, 0))),
              0);
   }
-  
+
   Point place_y_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Rectangle& bbox) const
@@ -522,7 +505,7 @@ struct Rectangular_3_center_2_type2_operations1
                   constraint_empty ? v(bbox, 2) : v(constraint, 0)),
              0);
   }
-  
+
   Point place_y_square(const Point& so_far,
                        const Rectangle& bbox,
                        FT radius) const
@@ -534,34 +517,34 @@ struct Rectangular_3_center_2_type2_operations1
                                           v(bbox, 2), radius))),
              0);
   }
-  
+
   Point update_x_square(const Point& s, const Point& newp) const {
     Construct_iso_rectangle_2 rect = construct_iso_rectangle_2_object();
     Construct_vertex_2        v    = construct_vertex_2_object();
     return v(rect(maxx()(s, newp), s), 2);
   }
-  
+
   Point update_y_square(const Point& s, const Point& newp) const {
     Construct_iso_rectangle_2 rect = construct_iso_rectangle_2_object();
     Construct_vertex_2        v    = construct_vertex_2_object();
     return v(rect(s, miny()(s, newp)), 0);
   }
-  
+
   FT compute_x_distance(const Point& extreme,
                         const Rectangle& constraint) const
   { return distance()(extreme, construct_vertex_2_object()(constraint, 0)); }
-  
+
   FT compute_y_distance(const Point& extreme,
                         const Rectangle& constraint) const
   { return distance()(extreme, construct_vertex_2_object()(constraint, 2)); }
-  
+
   Point construct_corner_square(const Rectangle& bbox, FT r) const
   { return pt_a_l()(construct_vertex_2_object()(bbox, 2),
                     construct_vertex_2_object()(bbox, 0), r); }
-  
+
   Point construct_x_square(const Point& p, FT r) const
   { return pt_b_l()(p, p, r); }
-  
+
   Point construct_y_square(const Point& p, FT r) const
   { return pt_a_r()(p, p, r); }
 };
@@ -599,7 +582,7 @@ struct Rectangular_3_center_2_type2_operations2
 
   X_compare  compare_x() const { return greater_x_2_object(); }
   Y_compare  compare_y() const { return less_y_2_object(); }
-  
+
   Point place_x_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Point& first_uncovered,
@@ -612,7 +595,7 @@ struct Rectangular_3_center_2_type2_operations2
                   v(bbox, 0)),
              1);
   }
-  
+
   Point place_x_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Rectangle& bbox) const
@@ -623,7 +606,7 @@ struct Rectangular_3_center_2_type2_operations2
                   v(bbox, 0)),
              1);
   }
-  
+
   Point place_x_square(const Point& so_far,
                        const Rectangle& bbox,
                        FT radius) const
@@ -635,7 +618,7 @@ struct Rectangular_3_center_2_type2_operations2
                   so_far),
              1);
   }
-  
+
   Point place_y_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Point& first_uncovered,
@@ -648,7 +631,7 @@ struct Rectangular_3_center_2_type2_operations2
                     maxy()(first_uncovered, v(constraint, 2))),
              3);
   }
-  
+
   Point place_y_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Rectangle& bbox) const
@@ -659,7 +642,7 @@ struct Rectangular_3_center_2_type2_operations2
                   constraint_empty ? v(bbox, 0) : v(constraint, 2)),
              3);
   }
-  
+
   Point place_y_square(const Point& so_far,
                        const Rectangle& bbox,
                        FT radius) const
@@ -671,34 +654,34 @@ struct Rectangular_3_center_2_type2_operations2
                                   v(bbox, 0), radius), so_far)),
              3);
   }
-  
+
   Point update_x_square(const Point& s, const Point& newp) const {
     Construct_iso_rectangle_2 rect = construct_iso_rectangle_2_object();
     Construct_vertex_2        v    = construct_vertex_2_object();
     return v(rect(maxx()(s, newp), s), 1);
   }
-  
+
   Point update_y_square(const Point& s, const Point& newp) const {
     Construct_iso_rectangle_2 rect = construct_iso_rectangle_2_object();
     Construct_vertex_2        v    = construct_vertex_2_object();
     return v(rect(s, maxy()(s, newp)), 3);
   }
-  
+
   FT compute_x_distance(const Point& extreme,
                         const Rectangle& constraint) const
   { return distance()(extreme, construct_vertex_2_object()(constraint, 3)); }
-  
+
   FT compute_y_distance(const Point& extreme,
                         const Rectangle& constraint) const
   { return distance()(extreme, construct_vertex_2_object()(constraint, 1)); }
-  
+
   Point construct_corner_square(const Rectangle& bbox, FT r) const
   { return pt_b_l()(construct_vertex_2_object()(bbox, 2),
                     construct_vertex_2_object()(bbox, 2), r); }
-  
+
   Point construct_x_square(const Point& p, FT r) const
   { return pt_a_l()(p, p, r); }
-  
+
   Point construct_y_square(const Point& p, FT r) const
   { return pt_b_r()(p, p, r); }
 };
@@ -735,7 +718,7 @@ struct Rectangular_3_center_2_type2_operations3
 
   X_compare  compare_x() const { return less_x_2_object(); }
   Y_compare  compare_y() const { return less_y_2_object(); }
-  
+
   Point place_x_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Point& first_uncovered,
@@ -748,7 +731,7 @@ struct Rectangular_3_center_2_type2_operations3
                   v(bbox, 1)),
              0);
   }
-  
+
   Point place_x_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Rectangle& bbox) const
@@ -759,7 +742,7 @@ struct Rectangular_3_center_2_type2_operations3
                   v(bbox, 1)),
              0);
   }
-  
+
   Point place_x_square(const Point& so_far,
                        const Rectangle& bbox,
                        FT radius) const
@@ -771,7 +754,7 @@ struct Rectangular_3_center_2_type2_operations3
                   so_far),
              0);
   }
-  
+
   Point place_y_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Point& first_uncovered,
@@ -784,7 +767,7 @@ struct Rectangular_3_center_2_type2_operations3
                     maxy()(first_uncovered, v(constraint, 2))),
              2);
   }
-  
+
   Point place_y_square(bool constraint_empty,
                        const Rectangle& constraint,
                        const Rectangle& bbox) const
@@ -795,7 +778,7 @@ struct Rectangular_3_center_2_type2_operations3
                   constraint_empty ? v(bbox, 0) : v(constraint, 2)),
              2);
   }
-  
+
   Point place_y_square(const Point& so_far,
                        const Rectangle& bbox,
                        FT radius) const
@@ -807,34 +790,34 @@ struct Rectangular_3_center_2_type2_operations3
                                   v(bbox, 0), radius), so_far)),
              2);
   }
-  
+
   Point update_x_square(const Point& s, const Point& newp) const {
     Construct_iso_rectangle_2 rect = construct_iso_rectangle_2_object();
     Construct_vertex_2        v    = construct_vertex_2_object();
     return v(rect(minx()(s, newp), s), 0);
   }
-  
+
   Point update_y_square(const Point& s, const Point& newp) const {
     Construct_iso_rectangle_2 rect = construct_iso_rectangle_2_object();
     Construct_vertex_2        v    = construct_vertex_2_object();
     return v(rect(s, maxy()(s, newp)), 2);
   }
-  
+
   FT compute_x_distance(const Point& extreme,
                         const Rectangle& constraint) const
   { return distance()(extreme, construct_vertex_2_object()(constraint, 2)); }
-  
+
   FT compute_y_distance(const Point& extreme,
                         const Rectangle& constraint) const
   { return distance()(extreme, construct_vertex_2_object()(constraint, 0)); }
-  
+
   Point construct_corner_square(const Rectangle& bbox, FT r) const
   { return pt_b_r()(construct_vertex_2_object()(bbox, 0),
                     construct_vertex_2_object()(bbox, 2), r); }
-  
+
   Point construct_x_square(const Point& p, FT r) const
   { return pt_a_r()(p, p, r); }
-  
+
   Point construct_y_square(const Point& p, FT r) const
   { return pt_b_l()(p, p, r); }
 };
@@ -855,10 +838,6 @@ rectangular_3_center_2_type2(
   Operations op)
 {
   BOOST_USING_STD_MAX();
-  using std::less;
-  using std::greater;
-  using std::greater_equal;
-  using std::not_equal_to;
   using std::logical_and;
   using std::max_element;
   using std::find_if;
@@ -903,7 +882,7 @@ rectangular_3_center_2_type2(
   {
     // First try whether the best radius so far can be reached at all
     RandomAccessIterator m =
-      partition(f, l, boost::bind(greater< FT >(), rad, boost::bind(op.delta(), _1)));
+      partition(f, l, [&rad, &op](const Point& p){ return rad > op.delta()(p); });
     IP pos = min_max_element(m, l, op.compare_x(), op.compare_y());
     // extreme points of the two other squares
     Point q_t =
@@ -914,11 +893,11 @@ rectangular_3_center_2_type2(
       op.place_y_square(op.place_y_square(Q_r_empty, Q_r, *pos.second, r),
                         r,
                         rad);
-    boost::function1<bool,FT> le_rad = boost::bind(greater_equal<FT>(), rad, _1);
+    auto le_rad = [&rad](const FT& v){return rad >= v;};
     RandomAccessIterator b1 =
-      partition(m, l, boost::bind(le_rad, boost::bind(op.distance(), q_t, _1)));
+      partition(m, l, [&le_rad, &op, q_t](const Point& p){ return le_rad(op.distance()(q_t, p)); });
     RandomAccessIterator b2 =
-      partition(b1, l, boost::bind(le_rad, boost::bind(op.distance(), q_r, _1)));
+      partition(b1, l, [&le_rad, &op, q_r](const Point& p){ return le_rad(op.distance()(q_r, p)); });
 
     if (b2 != l)
       return o;
@@ -930,9 +909,8 @@ rectangular_3_center_2_type2(
   while (e - s > 6) {
     std::ptrdiff_t cutoff = (e - s) / 2;
     RandomAccessIterator m = s + cutoff - 1;
-    std::nth_element(s, m, e, 
-		boost::bind(less<FT>(), boost::bind(op.delta(), _1), boost::bind(op.delta(), _2)));
-    
+    std::nth_element(s, m, e, [&op](const Point& p1, const Point& p2){ return op.delta()(p1) < op.delta()(p2); });
+
     // step (b)
     IP pos = min_max_element(m + 1, e, op.compare_x(), op.compare_y());
     // extreme points of the two other squares
@@ -944,13 +922,11 @@ rectangular_3_center_2_type2(
     Point q_r = op.place_y_square(q_r_afap, r, op.delta()(*m));
 
     // check for covering
-    boost::function1<bool,FT>
-      le_delta_m = boost::bind(greater_equal<FT>(), op.delta()(*m), _1);
+    auto le_delta_m = [&op, m](const FT& v){ return op.delta()(*m) >= v; };
     RandomAccessIterator b1 =
-      partition(m + 1, e,
-                boost::bind(le_delta_m, boost::bind(op.distance(), q_t, _1)));
+      partition(m + 1, e, [&le_delta_m, &op, & q_t](const Point& p){ return le_delta_m(op.distance()(q_t, p)); });
     RandomAccessIterator b2 =
-      partition(b1, e, boost::bind(le_delta_m, boost::bind(op.distance(), q_r, _1)));
+      partition(b1, e, [&le_delta_m, &op, & q_r](const Point& p){ return le_delta_m(op.distance()(q_r, p)); });
 
     if (b2 != e)
       s = m;
@@ -968,9 +944,9 @@ rectangular_3_center_2_type2(
     // step (a)
     std::ptrdiff_t cutoff = (e - s) / fraction;
     RandomAccessIterator m = s + cutoff - 1;
-    std::nth_element(s, m, e, 
-		boost::bind(less<FT>(), boost::bind(op.delta(), _1), boost::bind(op.delta(), _2)));
-    
+    std::nth_element(s, m, e,
+                [&op](const Point& p1, const Point& p2){ return op.delta()(p1) < op.delta()(p2); });
+
     // step (b)
     IP pos = min_max_element(m + 1, e, op.compare_x(), op.compare_y());
     // extreme points of the two other squares
@@ -987,45 +963,45 @@ rectangular_3_center_2_type2(
     // to Q_t and Q_r are covered by q_t and q_r
     if ((Q_t_empty || op.compute_x_distance(q_t, Q_t) <= op.delta()(*m)) &&
         (Q_r_empty || op.compute_y_distance(q_r, Q_r) <= op.delta()(*m))) {
-      boost::function1<bool,FT> 
+      boost::function1<bool,FT>
         greater_delta_m = boost::bind(less< FT >(), op.delta()(*m));
-      CGAL_optimisation_assertion_code(RandomAccessIterator iii =)
+      CGAL_assertion_code(RandomAccessIterator iii =)
         find_if(e,
                 l,
                 boost::bind(logical_and< bool >(),
-		     boost::bind(greater_delta_m,
-			  boost::bind(op.distance(), q_t, _1)),
-		     boost::bind(greater_delta_m,
-			  boost::bind(op.distance(), q_r, _1))));
-        CGAL_optimisation_assertion(iii == l);
+                     boost::bind(greater_delta_m,
+                          boost::bind(op.distance(), q_t, _1)),
+                     boost::bind(greater_delta_m,
+                          boost::bind(op.distance(), q_r, _1))));
+        CGAL_assertion(iii == l);
     }
     // check whether the points in [f,s) are covered
     {
-      boost::function1<bool,FT> 
-	le_delta_m = boost::bind(greater_equal<FT>(), op.delta()(*m));
+      boost::function1<bool,FT>
+        le_delta_m = boost::bind(greater_equal<FT>(), op.delta()(*m));
       RandomAccessIterator iii =
         partition(f, s, boost::bind(le_delta_m, boost::bind(op.delta(), _1)));
       iii = partition(iii, s,
                       boost::bind(le_delta_m, boost::bind(op.distance(), q_t, _1)));
       iii = partition(iii, s,
                       boost::bind(le_delta_m, boost::bind(op.distance(), q_r, _1)));
-      CGAL_optimisation_assertion(iii == s);
+      CGAL_assertion(iii == s);
     }
 #endif // CGAL_3COVER_CHECK
 
     // partition the range [m+1, e) into ranges
     // [m+1, b1), [b1, b2),   [b2, b3) and [b3, e)
     //     R      G cap q_t  G cap q_r      none
-    boost::function1<bool,FT> 
-      le_delta_m = boost::bind(greater_equal<FT>(), op.delta()(*m), _1);
+    auto le_delta_m = [&op, m](const FT& v){ return op.delta()(*m) >= v; };
     RandomAccessIterator b2 =
-      partition(m + 1, e, boost::bind(le_delta_m, boost::bind(op.distance(), q_t, _1)));
+      partition(m + 1, e,
+                [&le_delta_m, &op, &q_t](const Point& p) { return le_delta_m(op.distance()(q_t, p)); });
     RandomAccessIterator b1 =
       partition(m + 1, b2,
-                boost::bind(le_delta_m, boost::bind(op.distance(), q_r, _1)));
+                [&le_delta_m, &op, &q_r](const Point& p) { return le_delta_m(op.distance()(q_r, p)); });
     RandomAccessIterator b3 =
-      partition(b2, e, boost::bind(le_delta_m, boost::bind(op.distance(), q_r, _1)));
-
+      partition(b2, e,
+                [&le_delta_m, &op, &q_r](const Point& p) { return le_delta_m(op.distance()(q_r, p)); });
 
     // step (c)
     if (b3 != e ||
@@ -1076,7 +1052,7 @@ rectangular_3_center_2_type2(
     }
 
     // step (e) [not enough points in G]
-    CGAL_optimisation_assertion(b1 - (m + 1) >= 5 * cutoff);
+    CGAL_assertion(b1 - (m + 1) >= 5 * cutoff);
 
     // compute the four cutting lines for R
     std::nth_element(m + 1, m + 1 + cutoff, b1, less_x_2);
@@ -1109,9 +1085,8 @@ rectangular_3_center_2_type2(
       // step 1
       RandomAccessIterator s_m = s_b + (s_e - s_b - 1) / 2;
       std::nth_element(s_b, s_m, s_e,
-                  boost::bind(less<FT>(), 
-		       boost::bind(op.delta(), _1), 
-		       boost::bind(op.delta(), _2)));
+                       [&op](const Point& p1, const Point& p2)
+                       { return op.delta()(p1) < op.delta()(p2); });
 
       // step 2 (as above)
       Point q_t_m = q_t_afap;
@@ -1138,7 +1113,7 @@ rectangular_3_center_2_type2(
 
     // now s_b corresponds to the first moment in [s, m+1)
     // where q_t and q_r cover B
-    CGAL_optimisation_assertion_code(bool loopcheck = false;)
+    CGAL_assertion_code(bool loopcheck = false;)
 CGAL_3CENTER_REPEAT_CHECK:
     // place q_t and q_r
     q_t = op.place_x_square(q_t_afap, r, op.delta()(*s_b));
@@ -1147,27 +1122,30 @@ CGAL_3CENTER_REPEAT_CHECK:
     // partition the range [s_b+1, e) into ranges
     // [s_b+1, b1), [b1, b2),   [b2, b3) and [b3, e)
     //     R      G cap q_t  G cap q_r      none
-    boost::function1<bool,FT>
-      le_delta_sb = boost::bind(greater_equal<FT>(), op.delta()(*s_b), _1);
-    b2 = partition(s_b + 1, e, boost::bind(le_delta_sb,
-				    boost::bind(op.distance(), q_t, _1)));
-    b1 = partition(s_b + 1, b2, boost::bind(le_delta_sb,
-				     boost::bind(op.distance(), q_r, _1)));
+    auto le_delta_sb = [&op, s_b](const FT& v){ return op.delta()(*s_b) >= v;} ;
+
+    b2 = partition(s_b + 1, e,
+                   [&le_delta_sb, &op, &q_t](const Point& p)
+                   { return le_delta_sb(op.distance()(q_t, p)); });
+    b1 = partition(s_b + 1, b2,
+                   [&le_delta_sb, &op, &q_r](const Point& p)
+                   { return le_delta_sb(op.distance()(q_r, p)); });
     b3 = partition(b2, e,
-                   boost::bind(le_delta_sb, boost::bind(op.distance(), q_r, _1)));
+                   [&le_delta_sb, &op, &q_r](const Point& p)
+                   { return le_delta_sb(op.distance()(q_r, p)); });
 
     if (b3 != e ||
         (!Q_t_empty && op.compute_x_distance(q_t, Q_t) > op.delta()(*s_b)) ||
         (!Q_r_empty && op.compute_y_distance(q_r, Q_r) > op.delta()(*s_b))) {
       // no covering
       if (b1 - s < cutoff) {
-	// in degenerate situations it can happen that the number of
-	// points in R is too small => decrease radius and check again
-	--s_b;
-	CGAL_optimisation_assertion(!loopcheck);
-	CGAL_optimisation_assertion(s != s_b);
-	CGAL_optimisation_assertion_code(loopcheck = true;)
-	goto CGAL_3CENTER_REPEAT_CHECK;
+        // in degenerate situations it can happen that the number of
+        // points in R is too small => decrease radius and check again
+        --s_b;
+        CGAL_assertion(!loopcheck);
+        CGAL_assertion(s != s_b);
+        CGAL_assertion_code(loopcheck = true;)
+        goto CGAL_3CENTER_REPEAT_CHECK;
       }
       s = b1;
       rho_min = op.delta()(*s_b);
@@ -1188,17 +1166,17 @@ CGAL_3CENTER_REPEAT_CHECK:
     // we still have a covering
 
     if (s_b == s) {
-      CGAL_optimisation_expensive_assertion_code(
+      CGAL_expensive_assertion_code(
         std::vector< Point > tmppts(f, l);
         RandomAccessIterator ii =
           partition(tmppts.begin(), tmppts.end(),
-                    boost::bind(le_delta_sb, boost::bind(op.delta(), _1)));
+                    [&le_delta_sb, &op](const FT& v){ return le_delta_sb(op.delta()(v)); });
         IP tmppos = min_max_element(ii, tmppts.end(),
                                     op.compare_x(), op.compare_y());
         )
-      CGAL_optimisation_expensive_assertion(
+      CGAL_expensive_assertion(
         !op.compare_x()(*tmppos.first, q_t));
-      CGAL_optimisation_expensive_assertion(
+      CGAL_expensive_assertion(
         !op.compare_y()(q_r, *tmppos.second));
 
       // we are done
@@ -1237,29 +1215,24 @@ CGAL_3CENTER_REPEAT_CHECK:
     // we have to take the next smaller radius
     RandomAccessIterator next =
       max_element_if(s, s_b,
-                     boost::bind(less<FT>(), 
-			  boost::bind(op.delta(), _1), 
-			  boost::bind(op.delta(), _2)),
-                     boost::bind(not_equal_to<FT>(),
-			  op.delta()(*s_b),
-			  boost::bind(op.delta(), _1)));
+                     [&op](const Point& p1, const Point& p2){ return op.delta()(p1) < op.delta()(p2); },
+                     [&op, s_b](const Point& p){ return op.delta()(*s_b) != op.delta()(p); });
     rho_max = op.delta()(*s_b);
     q_t_at_rho_max = q_t, q_r_at_rho_max = q_r;
-    CGAL_optimisation_assertion(op.delta()(*next) < op.delta()(*s_b));
+    CGAL_assertion(op.delta()(*next) < op.delta()(*s_b));
     q_t_afap = op.update_x_square(q_t_afap, *s_b);
     q_r_afap = op.update_y_square(q_r_afap, *s_b);
     q_t = op.place_x_square(q_t_afap, r, op.delta()(*next));
     q_r = op.place_y_square(q_r_afap, r, op.delta()(*next));
 
     // again check for covering
-    boost::function1<bool,FT>
-      le_delta_next = boost::bind(greater_equal<FT>(), op.delta()(*next), _1);
+    auto le_delta_next = [&op, next](const FT& v){ return op.delta()(*next) >= v; };
     b2 = partition(s_b, e,
-                   boost::bind(le_delta_next, boost::bind(op.distance(), q_t, _1)));
+                   [&op, &le_delta_next, &q_t](const Point& p){ return le_delta_next( op.distance()(q_t,p) ); });
     b1 = partition(s_b, b2,
-                   boost::bind(le_delta_next, boost::bind(op.distance(), q_r, _1)));
+                   [&op, &le_delta_next, &q_r](const Point& p){ return le_delta_next( op.distance()(q_r,p) ); });
     b3 = partition(b2, e,
-                   boost::bind(le_delta_next, boost::bind(op.distance(), q_r, _1)));
+                   [&op, &le_delta_next, &q_r](const Point& p){ return le_delta_next( op.distance()(q_r,p) ); });
 
     if (b3 != e ||
         (!Q_t_empty && op.compute_x_distance(q_t, Q_t) > op.delta()(*next)) ||
@@ -1282,7 +1255,7 @@ CGAL_3CENTER_REPEAT_CHECK:
     }
 
 
-    CGAL_optimisation_assertion(b3 - b1 >= cutoff);
+    CGAL_assertion(b3 - b1 >= cutoff);
     e = b1;
     // adjust Q_t
     if (b1 != b2) {
@@ -1313,7 +1286,7 @@ CGAL_3CENTER_REPEAT_CHECK:
     Point q_t_afap = op.place_x_square(Q_t_empty, Q_t, r);
     Point q_r_afap = op.place_y_square(Q_r_empty, Q_r, r);
     if (s != e) {
-      sort(s, e, boost::bind(less<FT>(), boost::bind(op.delta(), _1), boost::bind(op.delta(), _2)));
+      sort(s, e, [&op](const Point& p1, const Point& p2){ return op.delta()(p1) < op.delta()(p2);});
       rho_max = op.delta()(*--t);
     } else
       rho_max = rho_min;
@@ -1326,7 +1299,7 @@ CGAL_3CENTER_REPEAT_CHECK:
       rho_max = max BOOST_PREVENT_MACRO_SUBSTITUTION (op.compute_x_distance(q_t, Q_t),
                                op.compute_y_distance(q_r, Q_r));
 #ifndef CGAL_3COVER_NO_CHECK_OPTIMUM_FIRST
-      CGAL_optimisation_assertion(rho_max <= rad);
+      CGAL_assertion(rho_max <= rad);
 #endif // ! CGAL_3COVER_NO_CHECK_OPTIMUM_FIRST
       rad = rho_max;
       *o++ = op.construct_corner_square(r, rad / FT(2));
@@ -1334,7 +1307,7 @@ CGAL_3CENTER_REPEAT_CHECK:
       *o++ = op.construct_y_square(q_r, rad / FT(2));
       return o;
     }
-    CGAL_optimisation_assertion(s != e);
+    CGAL_assertion(s != e);
 
     // find the first diameter where covering is possible
     for (;;) {
@@ -1351,21 +1324,20 @@ CGAL_3CENTER_REPEAT_CHECK:
 
       // try the next possible diameter value
       FT try_rho = op.delta()(*t);
-      CGAL_optimisation_assertion(t == s || try_rho < rho_max);
+      CGAL_assertion(t == s || try_rho < rho_max);
       q_t = op.place_x_square(q_t_afap, r, try_rho);
       q_r = op.place_y_square(q_r_afap, r, try_rho);
 
       // check for covering
-      boost::function1<bool,FT>
-        greater_rho_max = boost::bind(less<FT>(), try_rho, _1);
+      auto greater_rho_max = [&try_rho](const FT& v){ return try_rho < v; };
       if ((!Q_t_empty && op.compute_x_distance(q_t, Q_t) > try_rho) ||
           (!Q_r_empty && op.compute_y_distance(q_r, Q_r) > try_rho) ||
           e != find_if(
             t + 1,
             e,
-            boost::bind(logical_and<bool>(),
-		 boost::bind(greater_rho_max, boost::bind(op.distance(), q_t, _1)),
-		 boost::bind(greater_rho_max, boost::bind(op.distance(), q_r, _1)))))
+            [&greater_rho_max, &q_t, &q_r, &op](const Point& p)
+            { return greater_rho_max(op.distance()(q_t,p)) &&
+                     greater_rho_max(op.distance()(q_r,p)); }))
         {
           rho_min = try_rho;
           q_t_q_r_cover_at_rho_min = 0;
@@ -1398,26 +1370,23 @@ CGAL_3CENTER_REPEAT_CHECK:
   //   - q_r_at_rho_max is the corr. position of q_r.
 
   // try rho_min
-  CGAL_optimisation_assertion(rho_min <= rho_max);
-  CGAL_optimisation_assertion(rho_min >= 0);
+  CGAL_assertion(rho_min <= rho_max);
   FT rad_2 = q_t_q_r_cover_at_rho_min;
-  if (s_at_rho_min != e_at_rho_min) {
-    boost::function1<FT,Point>
-      mydist = boost::bind(Min<FT>(),
-		    boost::bind(op.distance(), q_t_at_rho_min, _1),
-		    boost::bind(op.distance(), q_r_at_rho_min, _1));
+  if (rho_min >= 0 && s_at_rho_min != e_at_rho_min) {
+    auto mydist = [&q_t_at_rho_min, &q_r_at_rho_min, &op](const Point& p)
+                  { return Min<FT>()( op.distance()(q_t_at_rho_min, p),
+                                      op.distance()(q_r_at_rho_min, p)); };
     rad_2 =
       max BOOST_PREVENT_MACRO_SUBSTITUTION (
         rad_2,
         mydist(*max_element(s_at_rho_min, e_at_rho_min,
-                            boost::bind(less< FT >(), 
-				 boost::bind(mydist, _1), 
-				 boost::bind(mydist, _2)))));
+                            [&mydist](const Point& p1, const Point& p2)
+                            { return mydist(p1) < mydist(p2); })));
   }
-  CGAL_optimisation_assertion(rad_2 == 0 || rad_2 > rho_min);
+  CGAL_assertion(rad_2 == 0 || rad_2 > rho_min);
 
   // if a covering with rho == 0 is possible,
-  // it will be catched in the type1 functions
+  // it will be caught in the type1 functions
   Point q_t, q_r;
   if (rad_2 > rho_max || rho_min == -1) {
     // it is rho_max ...
@@ -1427,7 +1396,7 @@ CGAL_3CENTER_REPEAT_CHECK:
     q_t = q_t_at_rho_min, q_r = q_r_at_rho_min;
 
 #ifndef CGAL_3COVER_NO_CHECK_OPTIMUM_FIRST
-  CGAL_optimisation_assertion(rad_2 <= rad);
+  CGAL_assertion(rad_2 <= rad);
 #endif // ! CGAL_3COVER_NO_CHECK_OPTIMUM_FIRST
   rad = rad_2;
   *o++ = op.construct_corner_square(r, rad / FT(2));
@@ -1444,7 +1413,7 @@ rectangular_3_center_2(
   typename Traits::FT& r,
   Traits& t)
 {
-  CGAL_optimisation_precondition(f != l);
+  CGAL_precondition(f != l);
   typedef typename Traits::FT                                    FT;
   typedef typename Traits::Point_2                            Point;
   typedef typename Traits::Iso_rectangle_2                Rectangle;
